(function ($) {
    "use strict";

    var $window = $(window);

    if( $('body').hasClass('rtl') ) {
        var rtlMode = true;
    }else{
        var rtlMode = false;
    }

    function debounce(func, wait, immediate) {
        var timeout;
        return function () {
            var context = this,
                args = arguments;

            var later = function later() {
                timeout = null;
                if (!immediate) func.apply(context, args);
            };

            var callNow = immediate && !timeout;
            clearTimeout(timeout);
            timeout = setTimeout(later, wait);
            if (callNow) func.apply(context, args);
        };
    }

    $window.on('elementor/frontend/init', function () {

        var ModuleHandler = elementorModules.frontend.handlers.Base;
        var CarouselBase = ModuleHandler.extend({
            bindEvents: function bindEvents() {
                this.run();
            },
            getDefaultSettings: function getDefaultSettings() {
                return {
                    slidesToShow: 6,
                    slidesToScroll: 2,
                    autoplay: true,
                    autoplaySpeed: 5000,
                    infinite: true,
                    arrows: false,
                    dots: true,
                    customPaging : function(slider, i) {
                        return '<span data-index="' + i + '"></span>';
                    },
                    rtl: rtlMode,
                    rows: 0,
                    initialSlide: 0,
                    appendArrows: this.findElement('.dl-carousel-nav'),
                    appendDots: this.findElement('.dl-carousel-dots'),
                    prevArrow: $('<div />').append(this.findElement('.slick-prev').clone().show()).html(),
                    nextArrow: $('<div />').append(this.findElement('.slick-next').clone().show()).html()
                };
            },
            getDefaultElements: function getDefaultElements() {
                return {
                    $container: this.findElement('.dl-carousel'),
                    $carousel: !!this.getElementSettings('carousel')
                };
            },
            onElementChange: debounce(function () {
                this.elements.$container.slick('unslick');
                this.run();
            }, 200),
            getSlickSettings: function getSlickSettings() {
                var settings = {
                    slidesToShow: parseInt(this.getElementSettings('slides_per_show')) || 1,
                    slidesToScroll: parseInt(this.getElementSettings('slides_per_scroll')),
                    infinite: !!this.getElementSettings('infinite_loop'),
                    speed: parseInt(this.getElementSettings('anim_speed')) || 500
                };

                settings.autoplay = !!this.getElementSettings('autoplay');

                if ( 'yes' == this.getElementSettings('autoplay') ) {
                    settings.autoplaySpeed = parseInt(this.getElementSettings('autoplay_speed')) || 5000;
                    settings.pauseOnHover = !!this.getElementSettings('pause_on_hover');
                }

                if ( 'yes' == this.getElementSettings('center_mode') ) {
                    settings.centerMode = !!this.getElementSettings('center_mode');
                    settings.centerPadding = parseInt(this.getElementSettings('center_padding')) || 0 + 'px';
                }

                switch (this.getElementSettings('navigation')) {
                    case 'arrow':
                        settings.arrows = true;
                        break;

                    case 'dots':
                        settings.dots = true;
                        break;

                    case 'both':
                        settings.arrows = true;
                        settings.dots = true;
                        break;
                }

                settings.responsive = [{
                    breakpoint: elementorFrontend.config.breakpoints.lg,
                    settings: {
                        slidesToShow: parseInt(this.getElementSettings('slides_per_show_tablet')) || 1,
                        slidesToScroll: parseInt(this.getElementSettings('slides_per_scroll_tablet')) || 1,
                        centerPadding: parseInt(this.getElementSettings('center_padding_tablet')) || 0 + 'px',
                    }
                }, {
                    breakpoint: elementorFrontend.config.breakpoints.md,
                    settings: {
                        slidesToShow: parseInt(this.getElementSettings('slides_per_show_mobile')) || parseInt(this.getElementSettings('slides_per_show_tablet')) || 1,
                        slidesToScroll: parseInt(this.getElementSettings('slides_per_scroll_mobile')) || parseInt(this.getElementSettings('slides_per_scroll_tablet')) || 1,
                        centerPadding: parseInt(this.getElementSettings('center_padding_mobile')) || 0 + 'px',
                    }
                }];

                return $.extend({}, this.getSettings(), settings);
            },
            run: function run() {
                if( this.elements.$carousel ) {
                    this.elements.$container.slick(this.getSlickSettings());
                }
            }
        });

        // Testimonials
        elementorFrontend.hooks.addAction('frontend/element_ready/redias-testimonials.default', function ($scope) {
            elementorFrontend.elementsHandler.addHandler(CarouselBase, {
                $element: $scope
            });
        });

        // Blog Carousel
        elementorFrontend.hooks.addAction('frontend/element_ready/redias-blog.default', function ($scope) {
            elementorFrontend.elementsHandler.addHandler(CarouselBase, {
                $element: $scope
            });
        });

        // Projects
        elementorFrontend.hooks.addAction('frontend/element_ready/redias-projects.default', function ($scope) {
            var wrapper = $($scope).find('.el-project-wrapper'),
                settings = wrapper.data('settings');

            if( 'yes' === settings.carousel ) {
                elementorFrontend.elementsHandler.addHandler(CarouselBase, {
                    $element: $scope
                });
            }else{
                if( 'yes' === settings.filter ) {
                    var projectItems = wrapper.find(".el-project-items"),
                    projectFilter = wrapper.find(".dl-project-filter li"),
                    filterActive = wrapper.find(".dl-project-filter");
                    projectItems.imagesLoaded(function () {
                        projectFilter.on('click', function () {
                            filterActive.find('.active').removeClass("active");
                            $(this).addClass("active");
    
                            var FilterSelector = $(this).attr('data-filter');
                            projectItems.isotope({
                                filter: FilterSelector,
                                animationOptions: {
                                    duration: 750,
                                    easing: 'linear',
                                    queue: false
                                }
                            });
                            return false;
                        });
    
                        projectItems.isotope({
                            itemSelector: '.el-project-card',
                            layoutMode: 'masonry',
                        });
                    });
                }
                
            }
            
        });

        // Sponsor Carousel
        elementorFrontend.hooks.addAction('frontend/element_ready/redias-sponsor-carousel.default', function ($scope) {
            elementorFrontend.elementsHandler.addHandler(CarouselBase, {
                $element: $scope
            });
        });

        // Instagram Carousel
        elementorFrontend.hooks.addAction('frontend/element_ready/redias-instagram.default', function ($scope) {
            elementorFrontend.elementsHandler.addHandler(CarouselBase, {
                $element: $scope
            });
        });

        // Animated text
        elementorFrontend.hooks.addAction("frontend/element_ready/redias-animated-heading.default", function (scope, $) {
            var $item = $(scope).find('.cd-headline'),
                $animationDelay = $item.data('animation-delay');

            dlAnimatedText({
                selector: $item,
                animationDelay: $animationDelay,
            });

        });

        // Button
        elementorFrontend.hooks.addAction("frontend/element_ready/redias-button.default", function (scope, $) {
            var $wrap = $(scope).find('.dl-el-btn-wrap'),
                $btn1 = $wrap.find('.btn-1'),
                $btn2 = $wrap.find('.btn-2'),
                $btn1_style = $wrap.data('btn-1-style'),
                $btn2_style = $wrap.data('btn-2-style');
            if ('style-3' == $btn1_style) {
                $btn1.append('<span class="btn-ov"></span>');
                $btn1.on('mouseenter', function (e) {
                    var parentOffset = $(this).offset(),
                        relX = e.pageX - parentOffset.left,
                        relY = e.pageY - parentOffset.top;
                    $(this).find('.btn-ov').css({ top: relY, left: relX });
                }).on('mouseout', function (e) {
                    var parentOffset = $(this).offset(),
                        relX = e.pageX - parentOffset.left,
                        relY = e.pageY - parentOffset.top;
                    $(this).find('.btn-ov').css({ top: relY, left: relX });
                });
            }

            if ('style-3' == $btn2_style) {
                $btn2.append('<span class="btn-ov"></span>');
                $btn2.on('mouseenter', function (e) {
                    var parentOffset = $(this).offset(),
                        relX = e.pageX - parentOffset.left,
                        relY = e.pageY - parentOffset.top;
                    $(this).find('.btn-ov').css({ top: relY, left: relX });
                }).on('mouseout', function (e) {
                    var parentOffset = $(this).offset(),
                        relX = e.pageX - parentOffset.left,
                        relY = e.pageY - parentOffset.top;
                    $(this).find('.btn-ov').css({ top: relY, left: relX });
                });
            }

        });

        // Contact heading animation
        elementorFrontend.hooks.addAction('frontend/element_ready/redias-contact-form.default', function ($scope) {
            var $select = $($scope).find('.wpcf7-select');
            $select.selectmenu();
        });

        // Tab & Accordion
        var dlTabHandlerBase = elementorModules.frontend.handlers.Base.extend({
            $activeContent: null,

            getDefaultSettings: function () {
                return {
                    selectors: {
                        tabTitle: '.dl-tab__title',
                        tabContent: '.dl-tab__content'
                    },
                    classes: {
                        active: 'dl-tab--active'
                    },
                    showTabFn: 'show',
                    hideTabFn: 'hide',
                    toggleSelf: false,
                    hidePrevious: true,
                    autoExpand: true
                };
            },

            getDefaultElements: function () {
                var selectors = this.getSettings('selectors');

                return {
                    $tabTitles: this.findElement(selectors.tabTitle),
                    $tabContents: this.findElement(selectors.tabContent)
                };
            },

            activateDefaultTab: function () {
                var settings = this.getSettings();

                if (!settings.autoExpand || 'editor' === settings.autoExpand && !this.isEdit) {
                    return;
                }

                var defaultActiveTab = this.getEditSettings('activeItemIndex') || 1,
                    originalToggleMethods = {
                        showTabFn: settings.showTabFn,
                        hideTabFn: settings.hideTabFn
                    };

                // Toggle tabs without animation to avoid jumping
                this.setSettings({
                    showTabFn: 'show',
                    hideTabFn: 'hide'
                });

                this.changeActiveTab(defaultActiveTab);

                // Return back original toggle effects
                this.setSettings(originalToggleMethods);
            },

            deactivateActiveTab: function (tabIndex) {
                var settings = this.getSettings(),
                    activeClass = settings.classes.active,
                    activeFilter = tabIndex ? '[data-tab="' + tabIndex + '"]' : '.' + activeClass,
                    $activeTitle = this.elements.$tabTitles.filter(activeFilter),
                    $activeContent = this.elements.$tabContents.filter(activeFilter);

                $activeTitle.add($activeContent).removeClass(activeClass);

                $activeContent[settings.hideTabFn]();
            },

            activateTab: function (tabIndex) {
                var settings = this.getSettings(),
                    activeClass = settings.classes.active,
                    $requestedTitle = this.elements.$tabTitles.filter('[data-tab="' + tabIndex + '"]'),
                    $requestedContent = this.elements.$tabContents.filter('[data-tab="' + tabIndex + '"]');

                $requestedTitle.add($requestedContent).addClass(activeClass);

                $requestedContent[settings.showTabFn]();
            },

            isActiveTab: function (tabIndex) {
                return this.elements.$tabTitles.filter('[data-tab="' + tabIndex + '"]').hasClass(this.getSettings('classes.active'));
            },

            bindEvents: function () {
                var _this = this;

                this.elements.$tabTitles.on({
                    keydown: function keydown(event) {
                        if ('Enter' === event.key) {
                            event.preventDefault();

                            _this.changeActiveTab(event.currentTarget.getAttribute('data-tab'));
                        }
                    },
                    click: function click(event) {
                        event.preventDefault();

                        _this.changeActiveTab(event.currentTarget.getAttribute('data-tab'));
                    }
                });
            },

            onInit: function () {
                elementorModules.frontend.handlers.Base.prototype.onInit.apply(this, arguments);
                this.activateDefaultTab();
            },

            onEditSettingsChange: function (propertyName) {
                if ('activeItemIndex' === propertyName) {
                    this.activateDefaultTab();
                }
            },

            changeActiveTab: function (tabIndex) {
                var isActiveTab = this.isActiveTab(tabIndex),
                    settings = this.getSettings();

                if ((settings.toggleSelf || !isActiveTab) && settings.hidePrevious) {
                    this.deactivateActiveTab();
                }

                if (!settings.hidePrevious && isActiveTab) {
                    this.deactivateActiveTab(tabIndex);
                }

                if (!isActiveTab) {
                    this.activateTab(tabIndex);
                }
            }
        });

        elementorFrontend.hooks.addAction(
            'frontend/element_ready/redias-tabs.default',
            function ($scope) {
                elementorFrontend.elementsHandler.addHandler(dlTabHandlerBase, {
                    $element: $scope,
                });
            }
        );

        elementorFrontend.hooks.addAction(
            'frontend/element_ready/redias-accordion.default',
            function ($scope) {
                elementorFrontend.elementsHandler.addHandler(dlTabHandlerBase, {
                    $element: $scope,
                    selectors: {
                        tabTitle: '.dl-accordion__item-title',
                        tabContent: '.dl-accordion__item-content'
                    },
                    classes: {
                        active: 'dl-accordion__item--active'
                    },
                    showTabFn: 'slideDown',
                    hideTabFn: 'slideUp',
                });
            }
        );

        // Countdown
        elementorFrontend.hooks.addAction("frontend/element_ready/redias-countdown.default", function (scope, $) {
            var $item = $(scope).find('.dl-countdown');
            var $countdown_item = $item.find('.dl-countdown-item');
            var $end_action = $item.data('end-action');
            var $redirect_link = $item.data('redirect-link');
            var $end_action_div = $item.find('.dl-countdown-end-action');
            var $editor_mode_on = $(scope).hasClass('elementor-element-edit-mode');
            $item.countdown({
                end: function () {
                    if (('message' === $end_action || 'img' === $end_action) && $end_action_div !== undefined) {
                        $countdown_item.css("display", "none");
                        $end_action_div.css("display", "block");
                    } else if ('url' === $end_action && $redirect_link !== undefined && $editor_mode_on !== true) {
                        window.location.replace($redirect_link)
                    }
                }
            });
        });

        // Counter
        elementorFrontend.hooks.addAction("frontend/element_ready/redias-counter.default", function (scope, $) {
            var counter_elem = $(scope).find(".dl-counter").eq(0),
                $target = counter_elem.data("target");

            $(counter_elem).waypoint(
                function () {
                    $($target).each(function () {
                        var v = $(this).data("to"),
                            speed = $(this).data("speed"),
                            od = new Odometer({
                                el: this,
                                value: 0,
                                duration: speed
                            });
                        od.render();
                        setInterval(function () {
                            od.update(v);
                        });
                    });
                },
                {
                    offset: "80%",
                    triggerOnce: true
                }
            );
        });

        // PieChart
        elementorFrontend.hooks.addAction('frontend/element_ready/redias-piecharts.default', function ($scope) {
            var pieChart = $scope.find(".dl-chart"),
                pieSettings = pieChart.data('settings'),
                pieChartSelector = pieChart.find(".percentage");

            if (elementorFrontend.isEditMode()) {
                
                pieChartSelector.easyPieChart({
                    animate: pieSettings.animate,
                    lineWidth: pieSettings.lineWidth,
                    barColor: pieSettings.barColor,
                    trackColor: pieSettings.trackColor,
                    scaleColor: pieSettings.scaleColor,
                    lineCap: pieSettings.lineCap,
                    size: pieSettings.size,
                    onStep: function(value) {
                        this.$el.find('span').text(Math.round(value));
                    },
                    onStop: function(value, to) {
                        this.$el.find('span').text(Math.round(to));
                    }
                });

            } else {
                pieChart.waypoint(function (direction) {

                    pieChartSelector.easyPieChart({
                        animate: pieSettings.animate,
                        lineWidth: pieSettings.lineWidth,
                        barColor: pieSettings.barColor,
                        trackColor: pieSettings.trackColor,
                        scaleColor: pieSettings.scaleColor,
                        lineCap: pieSettings.lineCap,
                        size: pieSettings.size,
                        onStep: function(value) {
                            this.$el.find('span').text(Math.round(value));
                        },
                        onStop: function(value, to) {
                            this.$el.find('span').text(Math.round(to));
                        }
                        });

                }, {
                    offset: (window.innerHeight || document.documentElement.clientHeight) - 100,
                    triggerOnce: true
                });
            }

        });

        //Google Map
        elementorFrontend.hooks.addAction('frontend/element_ready/redias-google-map.default', function ($scope) {
            var gMap = $scope.find("#dl-google-map").eq(0);
            if (gMap.length > 0) {
                var mapsettings = gMap.data('mapmarkers');
                var mapsoptions = gMap.data('mapoptions');
                var mapstyles = gMap.data('mapstyle');
                var myMarkers = {
                    "markers": mapsettings,
                };
                gMap.mapmarker({
                    zoom: mapsoptions.zoom,
                    center: mapsoptions.center,
                    styles: mapstyles,
                    markers: myMarkers,
                });
            };
        });

        // Progress Bars
        var ProgressBarHandler = function ($scope) {
            elementorFrontend.waypoint($scope, function () {
                $scope.find('.dl-skill-level').each(function () {
                    var $current = $(this),
                        $lt = $current.find('.dl-skill-level-text'),
                        lv = $current.data('level');
                    $current.animate({
                        width: lv + '%'
                    }, 500);
                    $lt.numerator({
                        toValue: lv + '%',
                        duration: 1300,
                        onStep: function () {
                            $lt.append('%');
                        }
                    });
                });
            });
        };

        elementorFrontend.hooks.addAction('frontend/element_ready/redias-progress-bars.default', ProgressBarHandler);

    });

})(jQuery);