<?php
/**
 * Acf Extend
 *
 * @package RediasCore
 */
namespace RediasCore\Classes;

defined( 'ABSPATH' ) || die();

class AcfExtend {

    /**
     * Initialize
     */
    public function __construct() {
        // Admin script
        add_action( "admin_enqueue_scripts", [$this, "admin_assets"], 5 );
        // Load service icons
        add_filter( 'acf/load_field/name=service_icon', [ $this, 'load_service_icon'] );
        // Load all menus
        add_action('acf/load_field/name=redias_custom_menu', array($this, 'custom_menu_field'));
        // Load all widgets areas
        add_filter( 'acf/load_field/name=redias_sidebar_widgets', [ $this, 'load_sidebars'] );
    }

    /**
     * Load admin assets
     *
     * @return void
     */
    public function admin_assets(){
        wp_register_style( 'line-awesome', REDIASCORE_ASSETS . '/css/lib/line-awesome.min.css', false, REDIASCORE_VERSION );
        wp_register_style( 'dl-business-icons', REDIASCORE_ASSETS . '/css/lib/business-icons.min.css', false, REDIASCORE_VERSION );
    }

    /**
     * Load Service Icon
     *
     * @param [type] $field
     * @return void
     */
    public function load_service_icon( $field ) {
        wp_enqueue_style( 'line-awesome' );
        wp_enqueue_style( 'dl-business-icons' );

        $la_icons = Icons::get_line_awesome_icons();
        $business_icons = Icons::get_business_icons();

        if($la_icons){
            foreach( $la_icons as $la_icon ) {
                $la_label = str_replace( '-', ' ', $la_icon );
                $field['choices']['la la-' . $la_icon] = '<i class="la la-'. $la_icon .'"></i> '. ucwords( $la_label ) .'';
            }
        }

        if($business_icons){
            foreach( $business_icons as $business_icon ) {
                $bi_label = str_replace( '-', ' ', $business_icon );
                $field['choices']['bi bi-' . $business_icon] = '<i class="bi bi-'. $business_icon .'"></i> '. ucwords( $bi_label ) .'';
            }
        }

        return $field;
    }

    /**
     * Load All Menus
     *
     * @param [type] $field
     * @return void
     */
    public function custom_menu_field( $field ) {
        $field['choices']            = array();
        $menus                       = wp_get_nav_menus();
        $i                           = 0;
        $field['choices']['default'] = esc_html__( 'Default', 'redias-core' );
        foreach ( $menus as $menu ) {
            if ( $i == 0 ) {
                $default = $menu->slug;
                $i++;
            }
            $field['choices'][$menu->slug] = $menu->name;
        }

        return $field;
    }

    /**
     * Load Sidebars
     *
     * @param [type] $field
     * @return void
     */
    public function load_sidebars($field) {
        global $wp_registered_sidebars;

        $field['choices'] = array();
        
        if ( ! empty( $wp_registered_sidebars ) ) {
            $field['choices']['default'] = esc_html__( 'Default', 'redias' );
            foreach ( $wp_registered_sidebars as $sidebar_id => $sidebar ) {
                $field['choices'][$sidebar_id] = $sidebar['name'];
            }
        } else {
            $field['choices']['none'] = esc_html__( 'No sidebar found', 'redias' );
        }
        
        return $field;
    }
}
