<?php
/**
 * Assets class
 *
 * @package RediasCore
 */
namespace RediasCore\Classes;

defined( 'ABSPATH' ) || die();

class Assets {

    /**
     * Init
     */
    function __construct() {

        add_action( "wp_enqueue_scripts", [$this, 'assets'] );

    }

    /**
     * Elementor Scripts
     *
     * @return void
     */
    function el_scripts() {
        add_action( "elementor/editor/after_enqueue_styles", [$this, 'el_editor_styles'] );
        add_action( "elementor/frontend/after_enqueue_styles", [$this, 'el_frontend_assets_styles'], 5);
        add_action( "elementor/frontend/after_register_scripts", [$this, 'el_frontend_assets_scripts'], 10 );
    }

    /**
     * Elementor Styles List
     *
     * @return object
     */
    public function get_el_styles() {
        $min = ( WP_DEBUG === true ) ? '' : '.min';
        return [
            'redias-keyfram-anim' => [
                'src'     => REDIASCORE_ASSETS . '/css/keyfram-animation' . $min . '.css',
                'version' => Helper::get_version( 'keyfram-animation' ),
            ],
            'slick' => [
                'src'     => REDIASCORE_ASSETS . '/js/lib/slick/slick.css',
                'version' => '1.8.0',
            ],
            'redias-adv-heading' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/advanced-heading' . $min . '.css',
                'version' => Helper::get_version( 'widgets/advanced-heading' ),
            ],
            'redias-animated-text' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/animated-text' . $min . '.css',
                'version' => Helper::get_version( 'widgets/animated-text' ),
            ],
            'redias-button' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/button' . $min . '.css',
                'version' => Helper::get_version( 'widgets/button' ),
            ],
            'redias-section-heading' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/section-heading' . $min . '.css',
                'version' => Helper::get_version( 'widgets/section-heading' ),
            ],
            'redias-tabs' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/tabs' . $min . '.css',
                'version' => Helper::get_version( 'widgets/tabs' ),
            ],
            'redias-accordion' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/accordion' . $min . '.css',
                'version' => Helper::get_version( 'widgets/accordion' ),
            ],
            'redias-countdown' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/countdown' . $min . '.css',
                'version' => Helper::get_version( 'widgets/countdown' ),
            ],
            'redias-sponsor-grid' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/sponsor-grid' . $min . '.css',
                'version' => Helper::get_version( 'widgets/sponsor-grid' ),
            ],
            'redias-flip-box' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/flip-box' . $min . '.css',
                'version' => Helper::get_version( 'widgets/flip-box' ),
            ],
            'redias-play-button' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/play-button' . $min . '.css',
                'version' => Helper::get_version( 'widgets/play-button' ),
            ],
            'redias-video-box' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/video-box' . $min . '.css',
                'version' => Helper::get_version( 'widgets/video-box' ),
            ],
            'redias-image' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/image' . $min . '.css',
                'version' => Helper::get_version( 'widgets/image' ),
            ],
            'redias-counter' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/counter' . $min . '.css',
                'version' => Helper::get_version( 'widgets/counter' ),
            ],
            'redias-progress-bars' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/progress-bars' . $min . '.css',
                'version' => Helper::get_version( 'widgets/progress-bars' ),
            ],
            'redias-service' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/service' . $min . '.css',
                'version' => Helper::get_version( 'widgets/service' ),
            ],
            'redias-project' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/projects' . $min . '.css',
                'version' => Helper::get_version( 'widgets/projects' ),
            ],
            'redias-icon-boxes' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/icon-boxes' . $min . '.css',
                'version' => Helper::get_version( 'widgets/icon-boxes' ),
            ],
            'redias-piechart' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/piechart' . $min . '.css',
                'version' => Helper::get_version( 'widgets/piechart' ),
            ],
            'redias-sponsor-carousel' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/sponsor-carousel' . $min . '.css',
                'version' => Helper::get_version( 'widgets/sponsor-carousel' ),
            ],
            'redias-mailchimp' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/mc4wp' . $min . '.css',
                'version' => Helper::get_version( 'widgets/mc4wp' ),
            ],
            'redias-testimonials' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/testimonials' . $min . '.css',
                'version' => Helper::get_version( 'widgets/testimonials' ),
            ],
            'redias-team' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/team' . $min . '.css',
                'version' => Helper::get_version( 'widgets/team' ),
            ],
            'redias-blog' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/blog' . $min . '.css',
                'version' => Helper::get_version( 'widgets/blog' ),
            ],
            'redias-pricing-table' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/pricing-table' . $min . '.css',
                'version' => Helper::get_version( 'widgets/pricing-table' ),
            ],
            'redias-page-header' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/page-header' . $min . '.css',
                'version' => Helper::get_version( 'widgets/page-header' ),
            ],
            'redias-hero' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/hero' . $min . '.css',
                'version' => Helper::get_version( 'widgets/hero' ),
            ],
            'redias-slider' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/slider' . $min . '.css',
                'version' => Helper::get_version( 'widgets/slider' ),
            ],
            'redias-contact-form' => [
                'src'     => REDIASCORE_ASSETS . '/css/widgets/contact-form' . $min . '.css',
                'version' => Helper::get_version( 'widgets/contact-form' ),
            ],
            'splitting' => [
                'src'     => REDIASCORE_ASSETS . '/css/lib/splitting.min.css',
                'version' => '1.0',
            ]

        ];
    }

    /**
     * Elementor Editor Stykes
     *
     * @return void
     */
    public function el_editor_styles() {
        wp_register_style( 'redias-el-editor-style', REDIASCORE_ASSETS . '/admin/css/el-editor.css', false, time() );
        wp_enqueue_style( 'redias-el-editor-style' );
    }

    /**
     * Elementor Frontend Styles
     *
     * @return void
     */
    public function el_frontend_assets_styles() {

        $styles = $this->get_el_styles();
        foreach ( $styles as $handle => $style ) {

            $deps = isset( $style['deps'] ) ? $style['deps'] : false;
            wp_register_style( $handle, $style['src'], $deps, $style['version'] );

        }

    }

    /**
     * Elementor Scripts List
     *
     * @return object
     */
    public function get_el_scripts() {

        $min = ( WP_DEBUG === true ) ? '' : '.min';

        return [
            'modernizr' => [
                'src'     => REDIASCORE_ASSETS . '/js/lib/modernizr-2.8.3-respond-1.4.2.min.js',
                'version' => '2.8.3',
                'deps'    => '',
                'footer'  => false
            ],
            'slick' => [
                'src'     => REDIASCORE_ASSETS . '/js/lib/slick/slick.min.js',
                'version' => '1.8.0',
                'deps'    => '',
                'footer'  => true
            ],
            'isotope' => [
                'src'     => REDIASCORE_ASSETS . '/js/lib/isotope.min.js',
                'version' => '3.0.6',
                'deps'    => '',
                'footer'  => true
            ],
            'redias-countdown' => [
                'src'     => REDIASCORE_ASSETS . '/js/lib/countdown.min.js',
                'version' => '0.1.0',
                'deps'    => ['redias-el-script'],
                'footer'  => true
            ],
            'simpleparallax' => [
                'src'     => REDIASCORE_ASSETS . '/js/lib/simpleparallax.min.js',
                'version' => '5.2.0',
                'deps'    => ['redias-el-script'],
                'footer'  => true
            ],
            'redias-animated-text' => [
                'src'     => REDIASCORE_ASSETS . '/js/lib/animated-text.min.js',
                'version' => '1.0.0',
                'deps'    => ['redias-el-script'],
                'footer'  => true,
            ],
            'splitting' => [
                'src'     => REDIASCORE_ASSETS . '/js/lib/splitting.min.js',
                'version' => '1.0',
                'deps'    => [],
                'footer'  => true,
            ],
            'easypiechart' => [
                'src'     => REDIASCORE_ASSETS . '/js/lib/jquery.easypiechart.min.js',
                'version' => '1.6.3',
                'deps'    => [],
                'footer'  => true,
            ],
            'redias-slider'   => [
                'src'     => REDIASCORE_ASSETS . '/js/slider' . $min . '.js',
                'version' => Helper::get_version( 'slider', 'js' ),
                'deps'    => ['jquery', 'elementor-frontend'],
                'footer'  => true
            ],
            'redias-el-script'   => [
                'src'     => REDIASCORE_ASSETS . '/js/el-scripts' . $min . '.js',
                'version' => Helper::get_version( 'el-scripts', 'js' ),
                'deps'    => ['jquery', 'elementor-frontend'],
                'footer'  => true,
            ],
        ];
    }

    /**
     * Elementor Frontend Scripts
     *
     * @return void
     */
    public function el_frontend_assets_scripts() {

        $scripts = $this->get_el_scripts();
        foreach ( $scripts as $handle => $script ) {

            $deps = isset( $script['deps'] ) ? $script['deps'] : false;
            wp_register_script( $handle, $script['src'], $deps, $script['version'], $script['footer'] );

        }

        wp_localize_script( 'redias-el-script', 'ajax', [ 'url' => admin_url( 'admin-ajax.php' ) ] );
    }

    /**
     * Plugin Assets
     *
     * @return void
     */
    public function assets($hook) {

        $min = ( WP_DEBUG === true ) ? '' : '.min';

        wp_register_style( 'odometer', REDIASCORE_ASSETS . '/css/lib/odometer-theme-default.min.css', false, '1.0' );
        wp_register_style( 'venobox-style', REDIASCORE_ASSETS . '/css/lib/venobox.min.css', false, '1.0.0' );
        wp_register_style( 'redias-keyfram-anim', REDIASCORE_ASSETS . '/css/keyfram-animation' . $min . '.css', false, Helper::get_version( 'keyfram-animation' ) );
        wp_register_style( 'redias-core-style', REDIASCORE_ASSETS . '/css/redias-core.css', false, time() );

        wp_enqueue_style( 'odometer' );
        wp_enqueue_style( 'venobox-style' );
        wp_enqueue_style( 'redias-core-style' );

        wp_register_script( 'waypoints', REDIASCORE_ASSETS . '/js/lib/jquery.waypoints.min.js', [], '4.0.1', true );
        wp_register_script( 'odometer', REDIASCORE_ASSETS . '/js/lib/odometer.min.js', [], '1.0.1', true );
        wp_register_script( 'redias-wow-js', REDIASCORE_ASSETS . '/js/lib/wow.min.js', [], '1.0.0', true );
        wp_register_script( 'venobox-script', REDIASCORE_ASSETS . '/js/lib/venobox.min.js', [], '1.0.0', true );
        wp_register_script( 'redias-core-script', REDIASCORE_ASSETS . '/js/scripts.js', ['jquery', 'redias-wow-js', 'venobox-script'], time(), true );

        wp_enqueue_script('redias-wow-js');
        wp_enqueue_script('venobox-script');
        wp_enqueue_script('waypoints');
        wp_enqueue_script('odometer');
        wp_enqueue_script('redias-core-script');

    }

}
