<?php
/**
 * Demo Importer
 *
 * @package RediasCore
 */
namespace RediasCore\Classes;

defined( 'ABSPATH' ) || die();

class DemoImporter {

    /**
     * Construct function
     */
    function __construct() {

        add_action( "admin_enqueue_scripts", [$this, 'admin_ocdi_styles'] );
        add_action( "pt-ocdi/after_import", [$this, 'after_import_setup'] );
        add_filter( "pt-ocdi/import_files", [$this, 'import_files'] );
        add_filter( "pt-ocdi/plugin_page_setup", [$this, 'one_click_page'] );
        add_filter( "pt-ocdi/confirmation_dialog_options", [$this, 'ocdi_confirmation_dialog_options'], 10, 1 );
        add_filter( "ocdi/register_plugins", [$this, 'register_plugins'] );
        // Disable the branding notice - ProteusThemes
        add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );

    }

    /**
     * Get CSF options data
     *
     * @return void
     */
    static function get_options_data() {
        $json_data = file_get_contents( REDIASCORE_ASSETS . '/demo/options.json' );
        $data      = ( ! empty( $json_data ) ) ? wp_kses_post_deep( json_decode( wp_unslash( trim( $json_data ) ), true ) ) : array();
        return $data;
    }

    /**
     * Get page id by title
     *
     * @param [type] $page_name
     * @return void
     */
    static function get_page_id_by_title( $page_title ) {
        global $wpdb;
        $page_id = $wpdb->get_var( "SELECT ID FROM $wpdb->posts WHERE post_title = '$page_title' AND post_type = 'page'" );
        if ( $page_id ) {
            return $page_id;
        } else {
            return null;
        }
    }

    /**
     * Admin OCDI Styles
     *
     * @param [type] $hook
     * @return void
     */
    public function admin_ocdi_styles( $hook ) {
        if ( 'appearance_page_redias-demo-import' === $hook ) {
            wp_enqueue_style( 'redias-one-click-scripts', REDIASCORE_ASSETS . '/admin/css/importer.css' );
        }
    }

    /**
     * Import Files
     *
     * @return void
     */
    public function import_files() {
        return array(
            array(
                'import_file_name'           => 'redias',
                'import_file_url'            => trailingslashit( REDIASCORE_ASSETS ) . '/demo/contents.xml',
                'import_widget_file_url'     => trailingslashit( REDIASCORE_ASSETS ) . '/demo/widgets.json',
                'import_customizer_file_url' => trailingslashit( REDIASCORE_ASSETS ) . '/demo/customizer.dat',
                'import_notice'              => esc_html__( 'Import process may take 3-5 minutes, please be patient. It\'s really based on your network speed.', 'redias-core' ),
                'preview_url'                => 'https://redias.dynamiclayers.net',
            ),
        );
    }

    /**
     * Assign Homepage, Blog Page & Menu
     *
     * @return void
     */
    public function after_import_setup() {
        // Assign menus to their locations.
        $main_menu = get_term_by( 'name', 'Main Menu', 'nav_menu' );

        set_theme_mod( 'nav_menu_locations', array(
            'primary' => $main_menu->term_id,
        ) );

        // Assign front page and posts page (blog page).
        $front_page_id = self::get_page_id_by_title( 'Homepage Default' );
        $blog_page_id  = self::get_page_id_by_title( 'Blog' );

        update_option( 'show_on_front', 'page' );
        update_option( 'page_on_front', $front_page_id );
        update_option( 'page_for_posts', $blog_page_id );
        update_option( 'redias_opt', self::get_options_data() );
    }

    /**
     * OCDI Custom Info
     *
     * @param [type] $settings
     * @return void
     */
    public function one_click_page( $settings ) {
        $settings['parent_slug'] = 'themes.php';
        $settings['page_title']  = esc_html__( 'Install Demos', 'redias-core' );
        $settings['menu_title']  = esc_html__( 'Install Demos', 'redias-core' );
        $settings['capability']  = 'import';
        $settings['menu_slug']   = 'redias-demo-import';

        return $settings;
    }

    /**
     * OCDI Model Popup - Width Increased
     *
     * @return void
     */
    public function ocdi_confirmation_dialog_options( $options ) {
        return array_merge( $options, array(
            'width'       => 600,
            'dialogClass' => 'wp-dialog',
            'resizable'   => false,
            'height'      => 'auto',
            'modal'       => true,
        ) );
    }

    /**
     * Restister Plugins
     *
     * @param [type] $plugins
     * @return void
     */
    public function register_plugins( $plugins ) {
        $theme_plugins = [
            [
                'name'        => 'Redias Core',
                'description' => 'Redias companion plugin.',
                'slug'        => 'redias-core',
                'source'      => 'https://plugins.dynamiclayers.net/redias/redias-core-v1.0.0.zip',
                'required'    => true,
            ],
            [
                'name'     => 'Advanced Custom Fields PRO',
                'slug'     => 'advanced-custom-fields-pro',
                'source'   => 'https://plugins.dynamiclayers.net/acf-pro/advanced-custom-fields-pro-v6.2.0.zip',
                'required' => true,
            ],
            [
                'name'     => 'Elementor Page Builder',
                'slug'     => 'elementor',
                'required' => true,
            ],
            [
                'name'     => 'Contact Form 7',
                'slug'     => 'contact-form-7',
                'required' => true,
            ],
            [
                'name'     => 'Mailchimp for WordPress',
                'slug'     => 'mailchimp-for-wp',
                'required' => true,
            ],
            [
                'name'     => 'WooCommerce',
                'slug'     => 'woocommerce',
                'required' => true,
            ],
        ];

        return array_merge( $plugins, $theme_plugins );
    }

}