<?php
/**
 * Elementor class
 *
 * @package RediasCore
 */
namespace RediasCore\Classes;

use RediasCore\Classes\Helper;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class PostTypes {
    /**
     * Constructor
     */
    public function __construct() {

        add_action( 'init', [$this, 'register_posts'] );
        add_action( 'init', [$this, 'register_taxomies'] );
        // Post Columns
        add_filter( 'manage_edit-post_columns', [$this, 'add_thumbnail_columns_post'], 10, 1 );
        add_action( 'manage_post_posts_custom_column', [$this, 'display_thumbnail_post'], 10, 1 );

        // Project Columns
        add_filter( 'manage_edit-dl-project_columns', [$this, 'add_project_columns_post'], 10, 1 );
        add_action( 'manage_dl-project_posts_custom_column', [$this, 'display_project_post'], 10, 1 );

        // Service Columns
        add_filter( 'manage_edit-dl-service_columns', [$this, 'add_service_columns_post'], 10, 1 );
        add_action( 'manage_dl-service_posts_custom_column', [$this, 'display_service_post'], 10, 1 );

        add_action( 'after_switch_theme', [$this, 'flush_rewrite_rules'] );

    }

    /**
     * Register Posts Type
     *
     * @return void
     */
    public function register_posts() {

        // Projects
        register_post_type( 'dl-project', array(
            'labels' => array(
                'name' => esc_html__( 'Projects', 'redias-core' ),
                'singular_name' => esc_html__( 'Project', 'redias-core' ),
                'menu_name' => esc_html__( 'Projects', 'redias-core' ),
                'all_items' => esc_html__( 'All Projects', 'redias-core' ),
                'edit_item' => esc_html__( 'Edit Project', 'redias-core' ),
                'view_item' => esc_html__( 'View Project', 'redias-core' ),
                'view_items' => esc_html__( 'View Projects', 'redias-core' ),
                'add_new_item' => esc_html__( 'Add New Project', 'redias-core' ),
                'add_new' => esc_html__( 'Add New', 'redias-core' ),
                'new_item' => esc_html__( 'New Project', 'redias-core' ),
                'parent_item_colon' => esc_html__( 'Parent Project:', 'redias-core' ),
                'search_items' => esc_html__( 'Search Projects', 'redias-core' ),
                'not_found' => esc_html__( 'No projects found', 'redias-core' ),
                'not_found_in_trash' => esc_html__( 'No projects found in Trash', 'redias-core' ),
                'archives' => esc_html__( 'Project Archives', 'redias-core' ),
                'attributes' => esc_html__( 'Project Attributes', 'redias-core' ),
                'featured_image' => esc_html__( 'Project Image', 'redias-core' ),
                'set_featured_image' => esc_html__( 'Set Project Image', 'redias-core' ),
                'remove_featured_image' => esc_html__( 'Remove Project Image', 'redias-core' ),
                'use_featured_image' => esc_html__( 'Use as Project Image', 'redias-core' ),
                'insert_into_item' => esc_html__( 'Insert into project', 'redias-core' ),
                'uploaded_to_this_item' => esc_html__( 'Uploaded to this project', 'redias-core' ),
                'filter_items_list' => esc_html__( 'Filter projects list', 'redias-core' ),
                'filter_by_date' => esc_html__( 'Filter projects by date', 'redias-core' ),
                'items_list_navigation' => esc_html__( 'Projects list navigation', 'redias-core' ),
                'items_list' => esc_html__( 'Projects list', 'redias-core' ),
                'item_published' => esc_html__( 'Project published.', 'redias-core' ),
                'item_published_privately' => esc_html__( 'Project published privately.', 'redias-core' ),
                'item_reverted_to_draft' => esc_html__( 'Project reverted to draft.', 'redias-core' ),
                'item_scheduled' => esc_html__( 'Project scheduled.', 'redias-core' ),
                'item_updated' => esc_html__( 'Project updated.', 'redias-core' ),
                'item_link' => esc_html__( 'Project Link', 'redias-core' ),
                'item_link_description' => esc_html__( 'A link to a project.', 'redias-core' ),
            ),
            'public' => true,
            'has_archive' => true,
            'show_in_rest' => true,
            'menu_position' => 20,
            'menu_icon' => 'dashicons-portfolio',
            'supports' => array(
                0 => 'title',
                1 => 'comments',
                2 => 'editor',
                3 => 'excerpt',
                4 => 'thumbnail',
            ),
            'rewrite' => array(
                'slug' => 'project',
            ),
            'delete_with_user' => false,
        ) );
        
        // Services
        register_post_type( 'dl-service', array(
            'labels' => array(
                'name' => esc_html__('Services', 'redias-core'),
                'singular_name' => esc_html__('Service', 'redias-core'),
                'menu_name' => esc_html__('Services', 'redias-core'),
                'all_items' => esc_html__('All Services', 'redias-core'),
                'edit_item' => esc_html__('All Services', 'redias-core'),
                'view_item' => esc_html__('View Service', 'redias-core'),
                'view_items' => esc_html__('View Services', 'redias-core'),
                'add_new_item' => esc_html__('Add New Service', 'redias-core'),
                'new_item' => esc_html__('New Service', 'redias-core'),
                'parent_item_colon' => esc_html__('Parent Service:', 'redias-core'),
                'search_items' => esc_html__('Search Services', 'redias-core'),
                'not_found' => esc_html__('No services found', 'redias-core'),
                'not_found_in_trash' => esc_html__('No services found in Trash', 'redias-core'),
                'archives' => esc_html__('Service Archives', 'redias-core'),
                'attributes' => esc_html__('Service Attributes', 'redias-core'),
                'featured_image' => esc_html__('Service Image', 'redias-core'),
                'set_featured_image' => esc_html__('Set Service Image', 'redias-core'),
                'remove_featured_image' => esc_html__('Remove Service Image', 'redias-core'),
                'use_featured_image' => esc_html__('Use as Service Image', 'redias-core'),
                'insert_into_item' => esc_html__('Insert into service', 'redias-core'),
                'uploaded_to_this_item' => esc_html__('Uploaded to this service', 'redias-core'),
                'filter_items_list' => esc_html__('Filter services list', 'redias-core'),
                'filter_by_date' => esc_html__('Filter services by date', 'redias-core'),
                'items_list_navigation' => esc_html__('Services list navigation', 'redias-core'),
                'items_list' => esc_html__('Services list', 'redias-core'),
                'item_published' => esc_html__('Service published.', 'redias-core'),
                'item_published_privately' => esc_html__('Service published privately.', 'redias-core'),
                'item_reverted_to_draft' => esc_html__('Service reverted to draft.', 'redias-core'),
                'item_scheduled' => esc_html__('Service scheduled.', 'redias-core'),
                'item_updated' => esc_html__('Service updated.', 'redias-core'),
                'item_link' => esc_html__('Service Link', 'redias-core'),
                'item_link_description' => esc_html__('A link to a service.', 'redias-core')
            ),
            'public' => true,
            'show_in_admin_bar' => false,
            'show_in_rest' => true,
            'menu_position' => 20,
            'menu_icon' => 'dashicons-buddicons-topics',
            'supports' => array(
                0 => 'title',
                1 => 'editor',
                2 => 'excerpt',
                3 => 'thumbnail'
            ),
            'taxonomies' => array(
                0 => 'service-category'
            ),
            'rewrite' => array(
                'slug' => 'service'
            ),
            'delete_with_user' => false
        ) );

    }

    /**
     * Register Taxonomies
     *
     * @return void
     */
    public function register_taxomies() {

        // Project Category
        register_taxonomy( 'project-category', array(
            0 => 'dl-project',
        ), array(
            'labels' => array(
                'name' => esc_html__( 'Categories', 'redias-core' ),
                'singular_name' => esc_html__( 'Category', 'redias-core' ),
                'menu_name' => esc_html__( 'Category', 'redias-core' ),
                'all_items' => esc_html__( 'All Categories', 'redias-core' ),
                'edit_item' => esc_html__( 'Edit Category', 'redias-core' ),
                'view_item' => esc_html__( 'View Category', 'redias-core' ),
                'update_item' => esc_html__( 'Update Category', 'redias-core' ),
                'add_new_item' => esc_html__( 'Add New Category', 'redias-core' ),
                'new_item_name' => esc_html__( 'New Category Name', 'redias-core' ),
                'search_items' => esc_html__( 'Search Categories', 'redias-core' ),
                'popular_items' => esc_html__( 'Popular Categories', 'redias-core' ),
                'separate_items_with_commas' => esc_html__( 'Separate categories with commas', 'redias-core' ),
                'add_or_remove_items' => esc_html__( 'Add or remove categories', 'redias-core' ),
                'choose_from_most_used' => esc_html__( 'Choose from the most used categories', 'redias-core' ),
                'not_found' => esc_html__( 'No categories found', 'redias-core' ),
                'no_terms' => esc_html__( 'No categories', 'redias-core' ),
                'items_list_navigation' => esc_html__( 'Categories list navigation', 'redias-core' ),
                'items_list' => esc_html__( 'Categories list', 'redias-core' ),
                'back_to_items' => esc_html__( '← Go to categories', 'redias-core' ),
                'item_link' => esc_html__( 'Category Link', 'redias-core' ),
                'item_link_description' => esc_html__( 'A link to a category', 'redias-core' ),
            ),
            'public' => true,
            'hierarchical' => true,
            'show_in_menu' => true,
            'show_in_nav_menus' => false,
            'show_in_rest' => true,
            'show_tagcloud' => false,
            'show_admin_column' => true,
            'sort' => true
        ) );

        // Service Category
        register_taxonomy( 'service-category', array(
            0 => 'dl-service'
        ), array(
            'labels' => array(
                'name' => esc_html__( 'Categories', 'redias-core'),
                'singular_name' => esc_html__( 'Category', 'redias-core'),
                'menu_name' => esc_html__( 'Categories', 'redias-core'),
                'all_items' => esc_html__( 'All Categories', 'redias-core'),
                'edit_item' => esc_html__( 'Edit Category', 'redias-core'),
                'view_item' => esc_html__( 'View Category', 'redias-core'),
                'update_item' => esc_html__( 'Update Category', 'redias-core'),
                'add_new_item' => esc_html__( 'Add New Category', 'redias-core'),
                'new_item_name' => esc_html__( 'New Category Name', 'redias-core'),
                'parent_item' => esc_html__( 'Parent Category', 'redias-core'),
                'parent_item_colon' => esc_html__( 'Parent Category:', 'redias-core'),
                'search_items' => esc_html__( 'Search Categories', 'redias-core'),
                'not_found' => esc_html__( 'No categories found', 'redias-core'),
                'no_terms' => esc_html__( 'No categories', 'redias-core'),
                'filter_by_item' => esc_html__( 'Filter by category', 'redias-core'),
                'items_list_navigation' => esc_html__( 'Categories list navigation', 'redias-core'),
                'items_list' => esc_html__( 'Categories list', 'redias-core'),
                'back_to_items' => esc_html__( '← Go to categories', 'redias-core'),
                'item_link' => esc_html__( 'Category Link', 'redias-core'),
                'item_link_description' => esc_html__( 'A link to a category', 'redias-core')
            ),
            'public' => true,
            'hierarchical' => true,
            'show_in_menu' => true,
            'show_in_nav_menus' => false,
            'show_in_rest' => true,
            'show_tagcloud' => false,
            'show_admin_column' => true,
            'sort' => true
        ) );

    }

    /**
     * Add column to posts edit screen
     *
     * @param [type] $columns
     * @return void
     */
    public function add_thumbnail_columns_post( $columns ) {
        $column_thumbnail = array( 'thumbnail' => esc_html__( 'Thumbnail', 'redias-core' ) );
        $columns          = array_slice( $columns, 0, 2, true ) + $column_thumbnail + array_slice( $columns, 1, NULL, true );
        return $columns;
    }

    /**
     * Display thumbnail in post
     *
     * @param [type] $column
     * @return void
     */
    public function display_thumbnail_post( $column ) {
        global $post;
        switch ( $column ) {
        case 'thumbnail':
            if ( has_post_thumbnail() ) {
                echo get_the_post_thumbnail( $post->ID, array( 120, 80 ) );
            } else {
                echo '<img src="' . esc_url( REDIASCORE_ASSETS . '/img/no_img_thumb.jpg' ) . '" alt="' . esc_attr__( 'No Image', 'redias-core' ) . '"/>';
            }
            break;
        }
    }

    /**
     * Add column to services edit screen
     *
     * @param [type] $columns
     * @return void
     */
    public function add_service_columns_post( $columns ) {
        $column_icon = array( 
            'thumbnail' => esc_html__( 'Thumbnail', 'redias-core' ),
            'icon' => esc_html__( 'Icon', 'redias-core' )
        );
        $columns          = array_slice( $columns, 0, 2, true ) + $column_icon + array_slice( $columns, 1, NULL, true );
        return $columns;
    }

    /**
     * Display icon and thumbnail in service
     *
     * @param [type] $column
     * @return void
     */
    public function display_service_post( $column ) {
        global $post;
        $icon = Helper::get_field_by_id('service_icon', $post->ID);
        switch ( $column ) {
        case 'thumbnail':
            if ( has_post_thumbnail() ) {
                echo get_the_post_thumbnail( $post->ID, array( 120, 80 ) );
            } else {
                echo '<img src="' . esc_url( REDIASCORE_ASSETS . '/img/no_img_thumb.jpg' ) . '" alt="' . esc_attr__( 'No Image', 'redias-core' ) . '"/>';
            }
            break;
        case 'icon':
            if ( ! empty( $icon ) ) {
                echo '<i class="'. esc_attr( $icon ) .'" style="font-size: 24px"></i>';
            } else {
                echo '<span>'. esc_html__('No icon selected!') .'</span>';
            }
            break;
        }
    }

    /**
     * Add column to project edit screen
     *
     * @param [type] $columns
     * @return void
     */
    public function add_project_columns_post( $columns ) {
        $column_icon = array( 'thumbnail' => esc_html__( 'Thumbnail', 'redias-core' ) );
        $columns          = array_slice( $columns, 0, 2, true ) + $column_icon + array_slice( $columns, 1, NULL, true );
        return $columns;
    }

    /**
     * Display thumbnail in project
     *
     * @param [type] $column
     * @return void
     */
    public function display_project_post( $column ) {
        global $post;
        switch ( $column ) {
        case 'thumbnail':
            if ( has_post_thumbnail() ) {
                echo get_the_post_thumbnail( $post->ID, array( 120, 80 ) );
            } else {
                echo '<img src="' . esc_url( REDIASCORE_ASSETS . '/img/no_img_thumb.jpg' ) . '" alt="' . esc_attr__( 'No Image', 'redias-core' ) . '"/>';
            }
            break;
        }
    }

    /**
     * Flush rewrite rules
     *
     * @return void
     */
    public function flush_rewrite_rules() {
        flush_rewrite_rules();
    }

}
