<?php
/**
 * Slider Helper class
 *
 * @package RediasCore
 */
namespace RediasCore\Classes;

defined( 'ABSPATH' ) || die();

class SliderHelper {

    /**
     * Excluded Effects
     * @return array
     */
    static function get_excluded_effects() {
        return [
            'clip-text', 
            'reveal-text', 
            'char-top', 
            'char-right', 
            'char-bottom', 
            'char-expand', 
            'dlTrackingInContract', 
            'dlTrackingInExpand',
            'dlFrackingInExpandFwd',
            'dlTrackingInExpandFwdTop',
            'dlTrackingInExpandFwdBottom',
            'dlTrackingInContractBack',
            'dlTrackingInContractBackTop',
            'dlTrackingInContractBackbottom',
            'dlFocusInExpand',
            'dlFocusInExpandForword',
            'dlFocusInContract',
            'dlFocusInContractBack'
        ];
    }

    /**
     * Animation Effects
     * @return array
     */
    static function get_effects( $exclude = [] ) {
        $effects = [
            'none'  => __( 'None', 'redias-core' ),
            'dlFadeIn' => __( 'Fade In', 'redias-core' ),
            'dlFadeInForword' => __( 'Fade In Forword', 'redias-core' ),
            'dlFadeInBack' => __( 'Fade In Back', 'redias-core' ),
            'dlFadeInTop' => __( 'Fade In Top', 'redias-core' ),
            'dlFadeInTopRight' => __( 'Fade In Top Right', 'redias-core' ),
            'dlFadeInRight' => __( 'Fade In Right', 'redias-core' ),
            'dlFadeInBottomRight' => __( 'Fade In Bottom Right', 'redias-core' ),
            'dlFadeInBottom' => __( 'Fade In Bottom', 'redias-core' ),
            'dlFadeInBottomLeft' => __( 'Fade In Bottom Left', 'redias-core' ),
            'dlFadeInleft' => __( 'Fade In Left', 'redias-core' ),
            'dlFadeInTopLeft' => __( 'Fade In Top Left', 'redias-core' ),
            'clip-text' => __( 'Clip Text', 'redias-core' ),
            'reveal-text' => __( 'Reveal Text', 'redias-core' ),
            'char-top' => __( 'Splitting Text Top', 'redias-core' ),
            'char-right' => __( 'Splitting Text Right', 'redias-core' ),
            'char-bottom' => __( 'Splitting Text Bottom', 'redias-core' ),
            'char-expand' => __( 'Splitting Text Expand', 'redias-core' ),
            'dlSlideInTop' => __( 'Slide In Top', 'redias-core' ),
            'dlSlideInRight' => __( 'Slide In Right', 'redias-core' ),
            'dlSlideInBottom' => __( 'Slide In Bottom', 'redias-core' ),
            'dlSlideInLeft' => __( 'Slide In Left', 'redias-core' ),
            'dlBounceInTop' => __( 'Bounce In Top', 'redias-core' ),
            'dlBounceInRight' => __( 'Bounce In Right', 'redias-core' ),
            'dlBounceInBottom' => __( 'Bounce In Bottom', 'redias-core' ),
            'dlBounceInLeft' => __( 'Bounce In Left', 'redias-core' ),
            'dlBounceInForword' => __( 'Bounce In Forword', 'redias-core' ),
            'dlBounceInBack' => __( 'Bounce In Back', 'redias-core' ),
            'dlTrackingInExpand' => __( 'Tracking In Expand', 'redias-core' ),
            'dlFrackingInExpandFwd' => __( 'Tracking In Expand Forword', 'redias-core' ),
            'dlTrackingInExpandFwdTop' => __( 'Tracking In Expand Forword Top', 'redias-core' ),
            'dlTrackingInExpandFwdBottom' => __( 'Tracking In Expand Forword Bottom', 'redias-core' ),
            'dlTrackingInContract' => __( 'Tracking In Contract', 'redias-core' ),
            'dlTrackingInContractBack' => __( 'Tracking In Contract Back', 'redias-core' ),
            'dlTrackingInContractBackTop' => __( 'Tracking In Contract Back Top', 'redias-core' ),
            'dlTrackingInContractBackbottom' => __( 'Tracking In Contract Back Bottom', 'redias-core' ),
            'dlTextFocusIn' => __( 'Text Focus In', 'redias-core' ),
            'dlFocusInExpand' => __( 'Focus In Expand', 'redias-core' ),
            'dlFocusInExpandForword' => __( 'Focus In Expand Forword', 'redias-core' ),
            'dlFocusInContract' => __( 'Focus In Contract', 'redias-core' ),
            'dlFocusInContractBack' => __( 'Focus In Contract Back', 'redias-core' ),
            'dlPopUp' => __( 'PopUp', 'redias-core' )
        ];

        if( ! empty( $exclude ) ) {
            foreach( $exclude as $key ) {
                unset( $effects[$key] );
            }
            return $effects;
        }else{
            return $effects;
        }
    }

    /**
     * Kenburns Effects
     * @return array
     */
    static function get_kenburns_effects() {
        $effects = [
            'kenburns-top' => __( 'Top', 'redias-core' ),
            'kenburns-right' => __( 'Right', 'redias-core' ),
            'kenburns-bottom' => __( 'Bottom', 'redias-core' ),
            'kenburns-left' => __( 'Left', 'redias-core' ),
            'kenburns-top-left' => __( 'Top Left', 'redias-core' ),
            'kenburns-top-right' => __( 'Top Right', 'redias-core' ),
            'kenburns-bottom-right' => __( 'Bottom Right', 'redias-core' ),
            'kenburns-bottom-left' => __( 'Bottom Left', 'redias-core' )
        ];

        return $effects;
    }
    
    /**
     * Get Allowed HTML
     *
     * @return void
     */
    static function allowed_html() {
        $kses_defaults = wp_kses_allowed_html( 'post' );

        $svg_args = array(
            'svg'   => array(
                'class'           => true,
                'aria-hidden'     => true,
                'aria-labelledby' => true,
                'role'            => true,
                'xmlns'           => true,
                'width'           => true,
                'height'          => true,
                'viewbox'         => true, // <= Must be lower case!
            ),
            'g'     => array( 'fill' => true ),
            'title' => array( 'title' => true ),
            'path'  => array(
                'd'    => true,
                'fill' => true,
            ),
        );
        return array_merge( $kses_defaults, $svg_args );
    }

    /**
     * Highlighted text
     *
     * @param [type] $text
     * @return string
     */
    static function get_highlighted_text( $text ) {
		return str_replace( array( '{{', '}}' ), array( '<mark>', '</mark>' ), $text );
	}

    /**
     * Get image alt text by attachement ID
     *
     * @param [type] $image_id
     * @return void
     */
    static function get_image_alt_text( $image_id ) {
        $img_alt = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
        if( ! empty( get_the_title( $img_alt ) ) ) {
            return get_the_title($img_alt);
        }else{
            return 'Image';
        }
    }

    /**
     * Get Slider Image
     *
     * @param string $img_url
     * @param string $kenburns_effecct
     * @param boolean $echo
     * @return void
     */
    static function get_slider_image( $settings, $data = [], $echo = true ) {
        if( 'image' === $data['bg_type'] ) {
            $kenburns_duration = 'none' != $data['kenburns_effect'] ? 'animation-duration: ' . $data['kenburns_duration'] . 'ms;': '';
            $kenburns_cls = 'none' != $data['kenburns_effect'] ? 'kenburns ' . $data['kenburns_effect'] : '';
            $image_url = ! empty( $data['slide_image']['id'] ) ? self::get_slide_image_url( $data['slide_image']['id'], 'imagesize', $settings ) : self::get_el_placeholder_img();
            $image_alt = ! empty( $data['slide_image']['id'] ) ? self::get_image_alt_text( $data['slide_image']['id'] ) : esc_html__( 'Placeholder', 'enova-toolkit' );
            $output = '<div class="slide-img-wrap"><img src="'. esc_url( $image_url ) .'" alt="'. esc_attr( $image_alt ) .'" class="slide-img '. esc_attr( $kenburns_cls ) .'" style="'. esc_attr( $kenburns_duration ) .'"/></div>';
        }else{
            $output = '<div class="slide-img-wrap"></div>';
        }
        if( $echo === true ){
            echo $output;
        }else{
            return $output;
        }
    }

    /**
     * Splitting Text Effect
     *
     * @param array $data
     * @param string $text
     * @param string $effect
     * @param boolean $echo
     * @return void
     */
    static function get_splitting_text_effect( $data = [], $text = '', $effect = 'char-top', $echo = true ) {
        $output = '';
        if( ! empty( $text ) ) {
            $output .= 'yes' === $data['text_masking'] ? '<div class="inner-layer">' : '';
            $output .= '<div class="dl-cap '. $effect .'" data-splitting>'. self::get_highlighted_text( $text ) .'</div>';
            $output .= 'yes' === $data['text_masking'] ? '</div>' : '';
        }
        if ( $echo === true ) {
            echo wp_kses( $output, self::allowed_html() );
        } else {
            return $output;
        }
    }

    /**
     * Get Slider Text
     *
     * @param string $text
     * @param string $effect
     * @param string $delay
     * @param string $duration
     * @param string $mask
     * @param boolean $echo
     * @return void
     */
    static function get_slider_text( $data = [], $text = '', $effect = 'fadeIn', $delay = '1000', $duration = '800', $echo = true ) {
        $output = '';
        $reveal_text = 'reveal-text' === $effect ? '<span style="animation-delay: '. $delay .'ms; animation-duration: '. $duration .'ms;"></span>' : '';
        if( ! empty( $text ) ) {
            $output .= 'yes' === $data['text_masking'] ? '<div class="inner-layer">' : '';
            $output .= '<div class="dl-cap" '. self::render_animation( $effect, $delay, $duration ) .'>'. $reveal_text . self::get_highlighted_text( $text ) .'</div>';
            $output .= 'yes' === $data['text_masking'] ? '</div>' : '';
        }
        if( $echo === true ){
            echo $output;
        }else{
            return $output;
        }
    }

    /**
     * Get Sub Heading
     *
     * @param array $data
     * @return void
     */
    static function get_sub_heading( $data = [] ) {
        $splitting_text = self::is_splitting_effect( $data['sh_animation'] );
        if( ! empty( $data['sub_heading'] ) ) : ?>
            <div class="dl-caption sub-heading">
            <?php
            if( $splitting_text === true ) {
                self::get_splitting_text_effect( $data, $data['sub_heading'], $data['sh_animation'] );
            }else{
                self::get_slider_text( $data, $data['sub_heading'], $data['sh_animation'], $data['sh_anim_delay']['size'], $data['sh_anim_duration']['size'] );
            } ?>
            </div>
        <?php endif;
    }

    /**
     * Get Heading
     *
     * @param array $data
     * @return void
     */
    static function get_heading( $data = [] ) {
        $splitting_text = self::is_splitting_effect( $data['h_animation'] );
        if( ! empty( $data['heading'] ) ) :
            $heading_arr = preg_split ("/\,/", $data['heading'] );
        if( is_array($heading_arr) ) :
        foreach ( $heading_arr as $index => $val  ) :
        ?>
        <div class="dl-caption heading">
        <?php
            if( $splitting_text === true ) {
                self::get_splitting_text_effect( $data, $val, $data['h_animation'] );
            }else{
                self::get_slider_text( $data, $val, $data['h_animation'], ($data['h_anim_delay']['size'] + ( $index * 400 ) ), $data['h_anim_duration']['size'] );
            }
        ?>
        </div>
        <?php 
        endforeach;
        else: ?>
        <div class="dl-caption heading">
        <?php
            if( $splitting_text === true ) {
                self::get_splitting_text_effect( $data, $data['heading'], $data['h_animation'] );
            }else{
                self::get_slider_text( $data, $data['heading'], $data['h_animation'], $data['h_anim_delay']['size'], $data['h_anim_duration']['size'] );
            }
        ?>
        </div>
        <?php 
        endif;
        endif;
    }

    /**
     * Get Description
     *
     * @param array $data
     * @return void
     */
    static function get_description( $data = [] ) {
        $splitting_text = self::is_splitting_effect( $data['d_animation'] );
        if( ! empty( $data['desc'] ) ) : ?>
        <div class="dl-caption desc">
        <?php
            if( $splitting_text === true ) {
                self::get_splitting_text_effect( $data, $data['desc'], $data['d_animation'] );
            }else{
                self::get_slider_text( $data, $data['desc'], $data['d_animation'], $data['d_anim_delay']['size'], $data['d_anim_duration']['size'] );
            }
        ?>
        </div>
        <?php endif;
    }

    /**
     * Get Button
     *
     * @param array $data
     * @return void
     */
    static function get_btn( $data = [] ) {
        if( ! empty( $data['btn_label'] && $data['btn_url']['url'] ) ) {
            $target = $data['btn_url']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $data['btn_url']['nofollow'] ? ' rel="nofollow"' : '';
            $splitting_text = self::is_splitting_effect( $data['btn_animation'] );
            $icon = ! empty( $data['btn_icon']['value'] ) ? ' <i class="'. $data['btn_icon']['value'] .'"></i>' : '';
            if( $splitting_text == true ) {
                $output = '<a href="'. esc_url( $data['btn_url']['url'] ) .'" '. $target . $nofollow .' class="slider-btn" '. self::render_animation( $data['btn_animation'], 0, 0 ) .' data-splitting>'. $data['btn_label'] . $icon . '</a>';
            }else{
                $output = '<a href="'. esc_url( $data['btn_url']['url'] ) .'" '. $target . $nofollow .' class="slider-btn" '. self::render_animation( $data['btn_animation'], $data['btn_anim_delay']['size'], $data['btn_anim_duration']['size'] ) .'>'. $data['btn_label'] . $icon .'</a>';
            }
            echo wp_kses( $output, self::allowed_html() );
        }
    }

    /**
     * Get Secondary Button
     *
     * @param array $data
     * @return void
     */
    static function get_secondary_btn( $data = [] ) {
        if( ! empty( $data['secondary_btn_label'] && $data['secondary_btn_url']['url'] ) ) {
            $target = $data['secondary_btn_url']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $data['secondary_btn_url']['nofollow'] ? ' rel="nofollow"' : '';
            $splitting_text = self::is_splitting_effect( $data['secondary_btn_animation'] );
            $icon = ! empty( $data['secondary_btn_icon']['value'] ) ? ' <i class="'. $data['secondary_btn_icon']['value'] .'"></i>' : '';
            if( $splitting_text == true ) {
                $output = '<a href="'. esc_url( $data['secondary_btn_url']['url'] ) .'" '. $target . $nofollow .' class="slider-secondary-btn" '. self::render_animation( $data['secondary_btn_animation'], 0, 0 ) .' data-splitting>'. $data['secondary_btn_label'] . $icon . '</a>';
            }else{
                $output = '<a href="'. esc_url( $data['secondary_btn_url']['url'] ) .'" '. $target . $nofollow .' class="slider-secondary-btn" '. self::render_animation( $data['secondary_btn_animation'], $data['secondary_btn_anim_delay']['size'], $data['secondary_btn_anim_duration']['size'] ) .'>'. $data['secondary_btn_label'] . $icon .'</a>';
            }
            echo wp_kses( $output, self::allowed_html() );
        }
    }

    /**
     * Get Play Button
     *
     * @param array $data
     * @return void
     */
    static function get_play_btn( $data = [] ) {
        if( ! empty( $data['play_btn_url']['url'] ) ) {
            $target = $data['play_btn_url']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $data['play_btn_url']['nofollow'] ? ' rel="nofollow"' : '';
            $btn_text = ! empty( $data['play_btn_label'] ) ? '<small>'. $data['play_btn_label'] .'</small>' : '';
            $output = '<a class="dl-play-btn" '. $target . $nofollow .' data-animation="'. $data['play_btn_animation'] .'" data-delay="'. $data['play_btn_anim_delay']['size'] .'ms" data-duration="'. $data['play_btn_anim_delay']['size'] .'ms" href="'. esc_url( $data['play_btn_url']['url'] ) .'"><span class="play-icon"><svg aria-hidden="true" focusable="false" role="img" xmlns="http://www.w3.org/2000/svg" width="13" viewBox="0 0 448 512"><path fill="currentColor" d="M424.4 214.7L72.4 6.6C43.8-10.3 0 6.1 0 47.9V464c0 37.5 40.7 60.1 72.4 41.3l352-208c31.4-18.5 31.5-64.1 0-82.6z"></path></svg></span>'. $btn_text .'</a>';
            echo wp_kses( $output, self::allowed_html() );
        }
    }

    /**
     * Get Slider Shape
     *
     * @param array $data
     * @return void
     */
    static function get_slider_shapes( $settings = [] ) {
        $output = '';
        if( 'yes' === $settings['slider_shape'] ) {
            $output .= '<div class="slider-shape-wrap">
                <div class="slider-shape" '. self::render_animation( $settings['shape1_animation'], $settings['shape1_anim_delay']['size'], $settings['shape1_anim_duration']['size'] ) .'></div>
                <div class="slider-shape" '. self::render_animation( $settings['shape2_animation'], $settings['shape2_anim_delay']['size'], $settings['shape2_anim_duration']['size'] ) .'></div>
            </div>';
        }
        echo wp_kses( $output, self::allowed_html() );
    }

    /**
     * Gel Slider Image URL
     *
     * @param string $atts_id
     * @param string $size
     * @param [type] $settings
     * @return void
     */
    static function get_slide_image_url( $atts_id = '', $size = 'imagesize', $settings = [] ) {
        if( ! empty( $atts_id ) ) {
            return \Elementor\Group_Control_Image_Size::get_attachment_image_src( $atts_id, $size, $settings );
        }else{
            return '';
        }
    }

    /**
     * Get Elementor Placeholder Image
     *
     * @return void
     */
    static function get_el_placeholder_img(){
        return \Elementor\Utils::get_placeholder_image_src();
    }

    /**
     * Return true if is splitting effect
     *
     * @param string $val
     * @return boolean
     */
    static function is_splitting_effect( $val = '' ) {
        $effects = ['char-top', 'char-right', 'char-bottom', 'char-expand' ];
        if(in_array( $val, $effects, true ) ) {
            return true;
        }
    }

    /**
     * Render Animation
     *
     * @param string $effect
     * @param integer $delay
     * @param integer $duration
     * @return void
     */
    static function render_animation( $effect = 'fadeIn', $delay = 1000, $duration = 1000 ) {
        if( 'none' != $effect && '' != $effect ) {
            $delay_val = ! empty( $delay ) ? $delay.'ms' : '0ms';
            $duration_val = ! empty( $duration ) ? $duration.'ms' : '0ms';
            return 'data-animation="'. $effect .'" data-delay="'. $delay_val .'" data-duration="'. $duration_val .'"';
        }else{
            return '';
        }
    }

    /**
     * Slider Controls
     *
     * @param array $settings
     * @return void
     */
    static function get_slider_controls( $settings = [] ) {
        if( 'yes' === $settings['slider_nav'] || 'yes' === $settings['slider_pagination'] ) :
            $autoplay_status = 'yes' === $settings['autoplay'] ? ' autoplay-active' : '';
            $left_icon = ! empty( $settings['nav_left_arrow']['value'] ) ? $settings['nav_left_arrow']['value'] : 'las la-long-arrow-alt-left';
            $right_icon = ! empty( $settings['nav_right_arrow']['value'] ) ? $settings['nav_right_arrow']['value'] : 'las la-long-arrow-alt-right';
        ?>
        <div class="dl-slider-controls style-<?php echo esc_attr( $settings['nav_layout'] ) . esc_attr( $autoplay_status ); ?>">
        <?php
            if( 'yes' === $settings['slider_nav'] && '1' === $settings['nav_layout'] ) {
                echo '<div class="dl-slider-button-prev"><i class="'. esc_attr( $left_icon ) .'"></i></div>';
            }
            if( 'yes' === $settings['slider_pagination'] ) {
                echo '<div class="dl-swiper-pagination pagi-style-'. esc_attr( $settings['pagi_style'] ) .'"></div>';
            }
            if( 'yes' === $settings['slider_nav'] && '1' === $settings['nav_layout'] ) {
                echo '<div class="dl-slider-button-next"><i class="'. esc_attr( $right_icon ) .'"></i></div>';
            }
        ?>
        </div>
        <?php
        if( 'yes' === $settings['slider_nav'] && '2' === $settings['nav_layout'] ) {
            echo '<div class="dl-slider-button-prev nav-2"><i class="'. esc_attr( $left_icon ) .'"></i></div>';
        }
        if( 'yes' === $settings['slider_nav'] && '2' === $settings['nav_layout'] ) {
            echo '<div class="dl-slider-button-next nav-2"><i class="'. esc_attr( $right_icon ) .'"></i></div>';
        }
        endif;
    }

}