<?php
/**
 * WPML Manager
 *
 * @package RediasCore
 */
namespace RediasCore\Classes;

defined( 'ABSPATH' ) || die();

class WpmlManager{

    public function init() {
		add_filter( 'wpml_elementor_widgets_to_translate', [ $this, 'add_widgets_to_translate' ] );
	}

    public function add_widgets_to_translate( $widgets ) {
        $widgets_map = [
            // Accordion
            'redias-accordion' => [
				'fields' => [],
				'integration-class' => '\RediasCore\Elementor\Wpml\Accordion',
			],
            // Advanced Heading
            'redias-advanced-heading' => [
				'fields' => [
                    [
                        'field'       => 'heading_before',
                        'type'        => esc_html__( 'Advanced Heading: Before Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'heading_center',
                        'type'        => esc_html__( 'Advanced Heading: Center Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'heading_after',
                        'type'        => esc_html__( 'Advanced Heading: After Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'background_text',
                        'type'        => esc_html__( 'Advanced Heading: Background Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    'link' => [
						'field'       => 'url',
						'type'        => esc_html__( 'Advanced Heading: Link', 'redias-core' ),
						'editor_type' => 'LINK',
					],
                ],
			],
            // Animated Heading
            'redias-animated-heading' => [
				'fields' => [
                    [
                        'field'       => 'before_text',
                        'type'        => esc_html__( 'Animated Text: Before Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'after_text',
                        'type'        => esc_html__( 'Animated Text: After Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                ],
				'integration-class' => '\RediasCore\Elementor\Wpml\AnimatedText',
			],
            // Blog
            'redias-blog' => [
				'fields' => [
                    [
                        'field'       => 'readmore_text',
                        'type'        => esc_html__( 'Blog: Readmore Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                ]
			],
            // Button
            'redias-button' => [
				'fields' => [
                    [
                        'field'       => 'btn_text',
                        'type'        => esc_html__( 'Button: Label Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    'btn_link' => [
						'field'       => 'url',
						'type'        => esc_html__( 'Button: Link', 'redias-core' ),
						'editor_type' => 'LINK',
					],
                    [
                        'field'       => 'btn_2nd_text',
                        'type'        => esc_html__( 'Secondary Button: Label Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    'btn_2nd_text' => [
						'field'       => 'url',
						'type'        => esc_html__( 'Secondary Button: Link', 'redias-core' ),
						'editor_type' => 'LINK',
					],
                ],
			],
            // Contact Form
            'redias-contact-form' => [
				'fields' => [
                    [
                        'field'       => 'sub_heading',
                        'type'        => esc_html__( 'Contact Form: Sub Heading', 'redias-core' ),
                        'editor_type' => 'AREA',
                    ],
                    [
                        'field'       => 'heading_text',
                        'type'        => esc_html__( 'Contact Form: Heading', 'redias-core' ),
                        'editor_type' => 'AREA',
                    ],
                    [
                        'field'       => 'background_text',
                        'type'        => esc_html__( 'Contact Form: Background Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'desc',
                        'type'        => esc_html__( 'Contact Form: Description', 'redias-core' ),
                        'editor_type' => 'AREA',
                    ],
                ]
			],
            // Countdown
            'redias-countdown' => [
				'fields' => [
                    [
                        'field'       => 'label_days',
                        'type'        => esc_html__( 'Countdown: Label Days', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'label_hours',
                        'type'        => esc_html__( 'Countdown: Label Hours', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'label_minutes',
                        'type'        => esc_html__( 'Countdown: Label Minutes', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'label_seconds',
                        'type'        => esc_html__( 'Countdown: Label Seconds', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'end_message',
                        'type'        => esc_html__( 'Countdown: End Message', 'redias-core' ),
                        'editor_type' => 'AREA',
                    ],
                ]
			],
            // Counter
            'redias-counter' => [
				'fields' => [
                    [
                        'field'       => 'number_prefix',
                        'type'        => esc_html__( 'Counter: Prefix', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'number_suffix',
                        'type'        => esc_html__( 'Counter: Suffix', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'counter_title',
                        'type'        => esc_html__( 'Counter: Title', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                ]
			],
            // Flip Box
            'redias-flipbox' => [
				'fields' => [
                    [
                        'field'       => 'front_title',
                        'type'        => esc_html__( 'Flip Box: Front Title', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'front_description',
                        'type'        => esc_html__( 'Flip Box: Front Description', 'redias-core' ),
                        'editor_type' => 'AREA',
                    ],
                    [
                        'field'       => 'back_title',
                        'type'        => esc_html__( 'Flip Box: Back Title', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'back_description',
                        'type'        => esc_html__( 'Flip Box: Back Description', 'redias-core' ),
                        'editor_type' => 'AREA',
                    ],
                ]
			],
            // Google Map
            'redias-google-map' => [
				'fields' => [
                    [
                        'field'       => 'dl_center_address',
                        'type'        => esc_html__( 'Google Map: Center Address', 'redias-core' ),
                        'editor_type' => 'AREA',
                    ]
                ]
			],
            // Image
            'redias-image' => [
				'fields' => [
                    [
                        'field'       => 'caption',
                        'type'        => esc_html__( 'Image: Caption', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ]
                ]
			],
            // List Items
            'redias-list-items' => [
				'fields' => [],
				'integration-class' => '\RediasCore\Elementor\Wpml\ListItems',
			],
            // Page Header
            'redias-page-header' => [
				'fields' => [
                    [
                        'field'       => 'sub_heading',
                        'type'        => esc_html__( 'Page Header: Sub Heading', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'heading',
                        'type'        => esc_html__( 'Page Header: Heading Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'description',
                        'type'        => esc_html__( 'Page Header: Description', 'redias-core' ),
                        'editor_type' => 'AREA',
                    ],
                ]
			],
            // Progress Bars
            'redias-progress-bars' => [
				'fields' => [],
                'integration-class' => '\RediasCore\Elementor\Wpml\ProgressBar',
			],
            // Section Heading
            'redias-section-heading' => [
				'fields' => [
                    [
                        'field'       => 'sub_heading',
                        'type'        => esc_html__( 'Section Heading: Sub Heading', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'heading_text',
                        'type'        => esc_html__( 'Section Heading: Heading', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'background_text',
                        'type'        => esc_html__( 'Section Heading: Background Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'desc',
                        'type'        => esc_html__( 'Section Heading: Description', 'redias-core' ),
                        'editor_type' => 'AREA',
                    ],
                ]
			],
            // Service
            'redias-service' => [
				'fields' => [
                    [
                        'field'       => 'readmore_text',
                        'type'        => esc_html__( 'Service: Readmore Text', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ]
                ]
			],
            // Sponsor Grid
            'redias-sponsor-grid' => [
				'fields' => [],
                'integration-class' => '\RediasCore\Elementor\Wpml\SponsorGrid',
			],
            // Tabs
            'redias-tabs' => [
				'fields' => [],
                'integration-class' => '\RediasCore\Elementor\Wpml\Tabs',
			],
            // Testimonials
            'redias-testimonials' => [
				'fields' => [],
                'integration-class' => '\RediasCore\Elementor\Wpml\Testimonials',
			],
            // Video Box
            'redias-video-box' => [
				'fields' => [
                    [
                        'field'       => 'vb_title',
                        'type'        => esc_html__( 'Video Box: Title', 'redias-core' ),
                        'editor_type' => 'LINE',
                    ],
                    [
                        'field'       => 'vb_content',
                        'type'        => esc_html__( 'Video Box: Content', 'redias-core' ),
                        'editor_type' => 'AREA',
                    ],
                ],
			],
        ];

        foreach ( $widgets_map as $key => $data ) {

			$entry = [
				'conditions' => [
					'widgetType' => $key,
				],
				'fields' => $data['fields'],
			];

			if ( isset( $data['integration-class'] ) ) {
				$entry['integration-class'] = $data['integration-class'];
			}

			$widgets[ $key ] = $entry;
		}

		return $widgets;
    }
}