<?php
/**
 * Advanced Background Module
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Module;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;

class AdvancedBackground {

    public function __construct() {
        add_action( 'elementor/element/after_section_end', [ $this, 'register_controls' ], 10, 3 );
    }

    public function register_controls( $element, $section_id, $args ) {

        if (  ( 'section' === $element->get_name() && 'section_background' === $section_id ) || ( 'column' === $element->get_name() && 'section_style' === $section_id ) ) {
            $element->start_controls_section(
                'neobiz_advance_background',
                [
                    'tab'   => Controls_Manager::TAB_STYLE,
                    'label' => esc_html__( 'Redias Background', 'redias-core' ),
                ]
            );

            $element->add_control(
                'adv_bg',
                [
                    'type'         => Controls_Manager::SWITCHER,
                    'label'        => esc_html__( 'Enable Background', 'redias-core' ),
                    'default'      => '',
                    'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                    'label_off'    => esc_html__( 'No', 'redias-core' ),
                    'return_value' => 'yes',
                    'prefix_class' => 'adv-bg-',
                    'render_type'  => 'template',
                ]
            );

            $element->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name'      => 'adv_bg',
                    'label'     => esc_html__( 'Background', 'redias-core' ),
                    'types'     => ['classic', 'gradient'],
                    'selector'  => '{{WRAPPER}} .adv-bg',
                    'separator' => 'before',
                    'condition' => [
                        'adv_bg' => 'yes',
                    ],
                ]
            );

            $element->add_control(
                'image_blend_mode',
                [
                    'label'     => esc_html__( 'Blend Mode', 'redias-core' ),
                    'type'      => Controls_Manager::SELECT,
                    'separator' => 'before',
                    'default'   => 'luminosity',
                    'options'   => [
                        'inherit'     => esc_html__( 'Normal', 'redias-core' ),
                        'multiply'    => 'Multiply',
                        'screen'      => 'Screen',
                        'overlay'     => 'Overlay',
                        'darken'      => 'Darken',
                        'lighten'     => 'Lighten',
                        'color-dodge' => 'Color Dodge',
                        'saturation'  => 'Saturation',
                        'color'       => 'Color',
                        'difference'  => 'Difference',
                        'exclusion'   => 'Exclusion',
                        'hue'         => 'Hue',
                        'luminosity'  => 'Luminosity',
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .adv-bg' => 'background-blend-mode: {{VALUE}}',
                    ],
                    'condition' => [
                        'adv_bg' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'bg_width',
                [
                    'label'      => esc_html__( 'Width', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['px', '%'],
                    'range'      => [
                        'px' => [
                            'min'  => 0,
                            'max'  => 5000,
                            'step' => 5,
                        ],
                        '%'  => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default'    => [
                        'unit' => '%',
                        'size' => 50,
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .adv-bg' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                    'separator'  => 'before',
                    'condition'  => [
                        'adv_bg' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'bg_height',
                [
                    'label'      => esc_html__( 'Height', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['px', '%'],
                    'range'      => [
                        'px' => [
                            'min'  => 0,
                            'max'  => 5000,
                            'step' => 5,
                        ],
                        '%'  => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default'    => [
                        'unit' => '%',
                        'size' => 100,
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .adv-bg' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                    'separator'  => 'before',
                    'condition'  => [
                        'adv_bg' => 'yes',
                    ],
                ]
            );

            $element->add_control(
                'popover_bg_position',
                [
                    'label'        => esc_html__( 'Position', 'redias-core' ),
                    'type'         => Controls_Manager::POPOVER_TOGGLE,
                    'label_off'    => esc_html__( 'Default', 'redias-core' ),
                    'label_on'     => esc_html__( 'Custom', 'redias-core' ),
                    'return_value' => 'yes',
                    'separator'    => 'before',
                    'condition'    => [
                        'adv_bg' => 'yes',
                    ],
                ]
            );

            $element->start_popover();

            $element->add_control(
                'position_from',
                [
                    'label'                => esc_html__( 'Position From', 'redias-core' ),
                    'type'                 => Controls_Manager::CHOOSE,
                    'options'              => [
                        'top-left'     => [
                            'title' => esc_html__( 'Top Left', 'redias-core' ),
                            'icon'  => 'eicon-h-align-left',
                        ],
                        'top-right'    => [
                            'title' => esc_html__( 'Top Right', 'redias-core' ),
                            'icon'  => 'eicon-v-align-top',
                        ],
                        'bottom-left'  => [
                            'title' => esc_html__( 'Bottom Left', 'redias-core' ),
                            'icon'  => 'eicon-v-align-bottom',
                        ],
                        'bottom-right' => [
                            'title' => esc_html__( 'Bottom Right', 'redias-core' ),
                            'icon'  => 'eicon-h-align-right',
                        ],
                    ],
                    'default'              => 'top-left',
                    'toggle'               => false,
                    'prefix_class'         => 'adv-bg-pos-',
                    'selectors_dictionary' => [
                        'top-left'     => 'top: 0; left: 0',
                        'top-right'    => 'top: 0; right: 0',
                        'bottom-left'  => 'bottom: 0; left: 0',
                        'bottom-right' => 'bottom: 0; right: 0',
                    ],
                    'selectors'            => [
                        '{{WRAPPER}} .adv-bg' => '{{VALUE}}',
                    ],
                    'condition'            => [
                        'adv_bg' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'bg_x_posotion',
                [
                    'label'      => esc_html__( 'X Position', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['px', '%'],
                    'range'      => [
                        'px' => [
                            'min'  => -8000,
                            'max'  => 8000,
                            'step' => 5,
                        ],
                        '%'  => [
                            'min' => -100,
                            'max' => 100,
                        ],
                    ],
                    'selectors'  => [
                        '{{WRAPPER}}.adv-bg-pos-top-left .adv-bg, {{WRAPPER}}.adv-bg-pos-bottom-left .adv-bg'   => 'left: {{SIZE}}{{UNIT}};',
                        '{{WRAPPER}}.adv-bg-pos-top-right .adv-bg, {{WRAPPER}}.adv-bg-pos-bottom-right .adv-bg' => 'right: {{SIZE}}{{UNIT}};',
                    ],
                    'condition'  => [
                        'adv_bg' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'bg_y_posotion',
                [
                    'label'      => esc_html__( 'Y Position', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['px', '%'],
                    'range'      => [
                        'px' => [
                            'min'  => -8000,
                            'max'  => 8000,
                            'step' => 5,
                        ],
                        '%'  => [
                            'min' => -100,
                            'max' => 100,
                        ],
                    ],
                    'selectors'  => [
                        '{{WRAPPER}}.adv-bg-pos-top-left .adv-bg, {{WRAPPER}}.adv-bg-pos-top-right .adv-bg'       => 'top: {{SIZE}}{{UNIT}};',
                        '{{WRAPPER}}.adv-bg-pos-bottom-left .adv-bg, {{WRAPPER}}.adv-bg-pos-bottom-right .adv-bg' => 'bottom: {{SIZE}}{{UNIT}};',
                    ],
                    'condition'  => [
                        'adv_bg' => 'yes',
                    ],
                ]
            );

            $element->end_popover();

            $element->add_responsive_control(
                'bg_z_index',
                [
                    'label'     => esc_html__( 'Z-Index', 'redias-core' ),
                    'type'      => Controls_Manager::NUMBER,
                    'min'       => -100,
                    'max'       => 4000,
                    'step'      => 1,
                    'default'   => '',
                    'selectors' => [
                        '{{WRAPPER}} .adv-bg' => 'z-index: {{VALUE}}',
                    ],
                    'separator' => 'before',
                    'condition' => [
                        'adv_bg' => 'yes',
                    ],
                ]
            );

            $element->add_control(
                'adv_overlay_bg',
                [
                    'type'         => Controls_Manager::SWITCHER,
                    'label'        => esc_html__( 'Overlay Background', 'redias-core' ),
                    'default'      => '',
                    'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                    'label_off'    => esc_html__( 'No', 'redias-core' ),
                    'return_value' => 'yes',
                    'prefix_class' => 'adv-ov-bg-',
                    'render_type'  => 'template',
                    'separator'    => 'before',
                    'condition'    => [
                        'adv_bg' => 'yes',
                    ],
                ]
            );

            $element->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name'      => 'avd_overlay_bg',
                    'label'     => esc_html__( 'Background', 'redias-core' ),
                    'types'     => ['classic', 'gradient'],
                    'selector'  => '{{WRAPPER}} .adv-bg .adv-overlay-bg',
                    'separator' => 'before',
                    'condition' => [
                        'adv_bg'         => 'yes',
                        'adv_overlay_bg' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'adv_overlay_opacity',
                [
                    'label'      => esc_html__( 'Opacity', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['px'],
                    'range'      => [
                        'px' => [
                            'min'  => 0,
                            'max'  => 1,
                            'step' => 0.1,
                        ]
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .adv-bg .adv-overlay-bg' => 'opacity: {{SIZE}};',
                    ],
                    'separator' => 'before',
                    'condition' => [
                        'adv_bg'         => 'yes',
                        'adv_overlay_bg' => 'yes',
                    ],
                ]
            );

            $element->add_control(
                'nb_custom_shape',
                [
                    'type'         => Controls_Manager::SWITCHER,
                    'label'        => esc_html__( 'Custom Shape', 'redias-core' ),
                    'default'      => '',
                    'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                    'label_off'    => esc_html__( 'No', 'redias-core' ),
                    'return_value' => 'yes',
                    'separator' => 'before',
                    'prefix_class' => 'nb-shape-',
                    'render_type'  => 'template',
                ]
            );

            $element->add_control(
                'shape_ov_x',
                [
                    'label'   => esc_html__( 'Overflow X', 'redias-core' ),
                    'type'    => Controls_Manager::SELECT,
                    'default' => '',
                    'options' => [
                        ''  => esc_html__( 'None', 'redias-core' ),
                        'visible' => esc_html__( 'Visible', 'redias-core' ),
                        'hidden' => esc_html__( 'Hidden', 'redias-core' ),
                        'scroll' => esc_html__( 'Scroll', 'redias-core' ),
                        'auto' => esc_html__( 'Auto', 'redias-core' ),
                    ],
                    'selectors'  => [
                        '{{WRAPPER}}.nb-shape-yes' => 'overflow-x: {{VALUE}};',
                    ],
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                    ],
                ]
            );

            $element->add_control(
                'shape_ov_y',
                [
                    'label'   => esc_html__( 'Overflow Y', 'redias-core' ),
                    'type'    => Controls_Manager::SELECT,
                    'default' => '',
                    'options' => [
                        ''  => esc_html__( 'None', 'redias-core' ),
                        'visible' => esc_html__( 'Visible', 'redias-core' ),
                        'hidden' => esc_html__( 'Hidden', 'redias-core' ),
                        'scroll' => esc_html__( 'Scroll', 'redias-core' ),
                        'auto' => esc_html__( 'Auto', 'redias-core' ),
                    ],
                    'selectors'  => [
                        '{{WRAPPER}}.nb-shape-yes' => 'overflow-y: {{VALUE}};',
                    ],
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                    ],
                ]
            );

            $element->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name'     => 'nb_custom_shape_background',
                    'label'    => esc_html__( 'Background', 'redias-core' ),
                    'types'    => ['classic', 'gradient',],
                    'selector' => '{{WRAPPER}} .nb-custom-shape',
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'shape_width',
                [
                    'label'      => esc_html__( 'Width', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['px', '%'],
                    'range'      => [
                        'px' => [
                            'min'  => 0,
                            'max'  => 5000,
                            'step' => 5,
                        ],
                        '%'  => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default'    => [
                        'unit' => '%',
                        'size' => 100,
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .nb-custom-shape' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                    'separator'  => 'before',
                    'condition'  => [
                        'nb_custom_shape' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'shape_height',
                [
                    'label'      => esc_html__( 'Height', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['px', '%'],
                    'range'      => [
                        'px' => [
                            'min'  => 0,
                            'max'  => 5000,
                            'step' => 5,
                        ],
                        '%'  => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default'    => [
                        'unit' => '%',
                        'size' => 100,
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .nb-custom-shape' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                    'separator'  => 'before',
                    'condition'  => [
                        'nb_custom_shape' => 'yes',
                    ],
                ]
            );

            $element->add_control(
                'popover_shape_position',
                [
                    'label'        => esc_html__( 'Position', 'redias-core' ),
                    'type'         => Controls_Manager::POPOVER_TOGGLE,
                    'label_off'    => esc_html__( 'Default', 'redias-core' ),
                    'label_on'     => esc_html__( 'Custom', 'redias-core' ),
                    'return_value' => 'yes',
                    'separator'    => 'before',
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                    ],
                ]
            );

            $element->start_popover();

            $element->add_control(
                'shape_position_from',
                [
                    'label'                => esc_html__( 'Position From', 'redias-core' ),
                    'type'                 => Controls_Manager::CHOOSE,
                    'options'              => [
                        'top-left'     => [
                            'title' => esc_html__( 'Top Left', 'redias-core' ),
                            'icon'  => 'eicon-h-align-left',
                        ],
                        'top-right'    => [
                            'title' => esc_html__( 'Top Right', 'redias-core' ),
                            'icon'  => 'eicon-v-align-top',
                        ],
                        'bottom-left'  => [
                            'title' => esc_html__( 'Bottom Left', 'redias-core' ),
                            'icon'  => 'eicon-v-align-bottom',
                        ],
                        'bottom-right' => [
                            'title' => esc_html__( 'Bottom Right', 'redias-core' ),
                            'icon'  => 'eicon-h-align-right',
                        ],
                    ],
                    'default'              => 'top-left',
                    'toggle'               => false,
                    'prefix_class'         => 'shape-pos-',
                    'selectors_dictionary' => [
                        'top-left'     => 'top: 0; left: 0',
                        'top-right'    => 'top: 0; right: 0',
                        'bottom-left'  => 'bottom: 0; left: 0',
                        'bottom-right' => 'bottom: 0; right: 0',
                    ],
                    'selectors'            => [
                        '{{WRAPPER}} .nb-custom-shape' => '{{VALUE}}',
                    ],
                    'condition'            => [
                        'nb_custom_shape' => 'yes',
                        'popover_shape_position' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'shape_x_posotion',
                [
                    'label'      => esc_html__( 'X Position', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['px', '%'],
                    'range'      => [
                        'px' => [
                            'min'  => -8000,
                            'max'  => 8000,
                            'step' => 5,
                        ],
                        '%'  => [
                            'min' => -100,
                            'max' => 100,
                        ],
                    ],
                    'selectors'  => [
                        '{{WRAPPER}}.shape-pos-top-left .nb-custom-shape, {{WRAPPER}}.shape-pos-bottom-left .nb-custom-shape'   => 'left: {{SIZE}}{{UNIT}};',
                        '{{WRAPPER}}.shape-pos-top-right .nb-custom-shape, {{WRAPPER}}.shape-pos-bottom-right .nb-custom-shape' => 'right: {{SIZE}}{{UNIT}};',
                    ],
                    'condition'  => [
                        'nb_custom_shape' => 'yes',
                        'popover_shape_position' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'shape_y_posotion',
                [
                    'label'      => esc_html__( 'Y Position', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['px', '%'],
                    'range'      => [
                        'px' => [
                            'min'  => -8000,
                            'max'  => 8000,
                            'step' => 5,
                        ],
                        '%'  => [
                            'min' => -100,
                            'max' => 100,
                        ],
                    ],
                    'selectors'  => [
                        '{{WRAPPER}}.shape-pos-top-left .nb-custom-shape, {{WRAPPER}}.shape-pos-top-right .nb-custom-shape'       => 'top: {{SIZE}}{{UNIT}};',
                        '{{WRAPPER}}.shape-pos-bottom-left .nb-custom-shape, {{WRAPPER}}.shape-pos-bottom-right .nb-custom-shape' => 'bottom: {{SIZE}}{{UNIT}};',
                    ],
                    'condition'  => [
                        'nb_custom_shape' => 'yes',
                        'popover_shape_position' => 'yes',
                    ],
                ]
            );

            $element->end_popover();

            $element->add_control(
                'popover_custom_shape_corners',
                [
                    'label'        => esc_html__( 'Shape Corners', 'redias-core' ),
                    'type'         => Controls_Manager::POPOVER_TOGGLE,
                    'label_off'    => esc_html__( 'Default', 'redias-core' ),
                    'label_on'     => esc_html__( 'Custom', 'redias-core' ),
                    'return_value' => 'yes',
                    'separator'    => 'before',
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                    ],
                ]
            );

            $element->start_popover();

            $element->add_responsive_control(
                'shape_top_to_bottom_left',
                [
                    'label'      => esc_html__( 'Top To Bottom Left', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['%'],
                    'range'      => [
                        '%'  => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .nb-custom-shape' => '--redias-top-to-bottom-left: {{SIZE}}{{UNIT}} ',
                    ],
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                        'popover_custom_shape_corners' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'shape_top_left_to_right',
                [
                    'label'      => esc_html__( 'Top Left To Right', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['%'],
                    'range'      => [
                        '%'  => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .nb-custom-shape' => '--redias-top-left-to-right: {{SIZE}}{{UNIT}} ',
                    ],
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                        'popover_custom_shape_corners' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'shape_top_to_bottom_right',
                [
                    'label'      => esc_html__( 'Top To Bottom Right', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['%'],
                    'range'      => [
                        '%'  => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .nb-custom-shape' => '--redias-top-to-bottom-right: {{SIZE}}{{UNIT}} ',
                    ],
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                        'popover_custom_shape_corners' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'shape_top_right_to_left',
                [
                    'label'      => esc_html__( 'Top Right To Left', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['%'],
                    'range'      => [
                        '%'  => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .nb-custom-shape' => '--redias-top-right-to-left: {{SIZE}}{{UNIT}} ',
                    ],
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                        'popover_custom_shape_corners' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'shape_bottom_to_top_left',
                [
                    'label'      => esc_html__( 'Bottom To Top Left', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['%'],
                    'range'      => [
                        '%'  => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .nb-custom-shape' => '--redias-bottom-to-top-left: {{SIZE}}{{UNIT}} ',
                    ],
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                        'popover_custom_shape_corners' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'shape_bottom_left_to_right',
                [
                    'label'      => esc_html__( 'Bottom Left To Right', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['%'],
                    'range'      => [
                        '%'  => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .nb-custom-shape' => '--redias-bottom-left-to-right: {{SIZE}}{{UNIT}} ',
                    ],
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                        'popover_custom_shape_corners' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'shape_bottom_to_top_right',
                [
                    'label'      => esc_html__( 'Bottom To Top Right', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['%'],
                    'range'      => [
                        '%'  => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .nb-custom-shape' => '--redias-bottom-to-top-right: {{SIZE}}{{UNIT}} ',
                    ],
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                        'popover_custom_shape_corners' => 'yes',
                    ],
                ]
            );

            $element->add_responsive_control(
                'shape_bottom_right_to_left',
                [
                    'label'      => esc_html__( 'Bottom Right To Left', 'redias-core' ),
                    'type'       => Controls_Manager::SLIDER,
                    'size_units' => ['%'],
                    'range'      => [
                        '%'  => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                        'popover_custom_shape_corners' => 'yes',
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .nb-custom-shape' => '--redias-bottom-to-top-left: {{SIZE}}{{UNIT}}',
                    ],
                ]
            );

            $element->end_popover();

            $element->add_responsive_control(
                'number',
                [
                    'label'   => esc_html__( 'Z-Index', 'redias-core' ),
                    'type'    => Controls_Manager::NUMBER,
                    'min'     => -999,
                    'max'     => 999,
                    'step'    => 1,
                    'condition'    => [
                        'nb_custom_shape' => 'yes',
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .nb-custom-shape' => 'z-index: {{VALUE}};',
                    ],
                ]
            );

            $element->end_controls_section();

        }
    }
}