<?php
/**
 * Advanced Heading
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\AdvancedHeading;

use RediasCore\Classes\Helper;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Text_Shadow;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {
	
	/**
	 * Get widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name(){
		return 'redias-advanced-heading';
	}

	/**
	 * Get widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Advanced Heading', 'redias-core' );
	}

	public function get_custom_help_url() {
		return 'https://dynamiclayers.net';
	}

	/**
	 * Get widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'redias-icon eicon-heading';
	}

	public function get_categories() {
		return [ 'redias-core' ];
	}

	public function get_keywords() {
		return [ 'advance', 'heading', 'title', 'redias-core' ];
	}

	public function get_style_depends() {
		return [ 'redias-adv-heading' ];
	}

	/**
	 * Register content related controls
	 */
	protected function register_controls() {

        $this->heading_content();
        $this->before_text_style();
        $this->center_text_style();
        $this->after_text_style();
        $this->custom_border_style();
        $this->background_text_style();
	}

    /**
     * Heding Content Control
     *
     * @return void
     */
    protected function heading_content() {

        $this->start_controls_section(
			'section_heading',
			[
				'label' => esc_html__( 'Advanced Heading', 'redias-core' )
			]
		);

		$this->add_control(
            'heading_before',
            [
                'label' => esc_html__( 'Before Text', 'redias-core' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Elementor', 'redias-core' ),
                'placeholder' => esc_html__( 'Before Text', 'redias-core' ),
				'dynamic' => [
					'active' => true,
				]
            ]
        );

        $this->add_control(
            'heading_center',
            [
                'label' => esc_html__( 'Center Text', 'redias-core' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Advanced', 'redias-core' ),
                'placeholder' => esc_html__( 'Center Text', 'redias-core' ),
				'dynamic' => [
					'active' => true,
				]
            ]
        );

        $this->add_control(
            'heading_after',
            [
                'label' => esc_html__( 'After Text', 'redias-core' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Heading', 'redias-core' ),
                'placeholder' => esc_html__( 'After Text', 'redias-core' ),
				'dynamic' => [
					'active' => true,
				]
            ]
        );

		$this->add_control(
			'show_background_text',
			[
				'label' => esc_html__( 'Background Text', 'redias-core' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'redias-core' ),
				'label_off' => esc_html__( 'Hide', 'redias-core' ),
				'return_value' => 'yes',
				'default' => 'no',
                'style_transfer' => true,
			]
		);

		$this->add_control(
			'background_text',
			[
				'label' => esc_html__( 'Text', 'redias-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Background', 'redias-core' ),
				'placeholder' => esc_html__( 'Background Text', 'redias-core' ),
				'condition' => [
					'show_background_text' => 'yes'
				],
				'dynamic' => [
					'active' => true,
				]
			]
		);

        $this->add_control(
            'link',
            [
                'label' => esc_html__( 'Link', 'redias-core' ),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://example.com/', 'redias-core' ),
				'separator' => 'after',
				'dynamic' => [
					'active' => true,
				]
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__( 'HTML Tag', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'default' => 'h2',
                'options' => [
                    'h1'  => [
                        'title' => esc_html__( 'H1', 'redias-core' ),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2'  => [
                        'title' => esc_html__( 'H2', 'redias-core' ),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3'  => [
                        'title' => esc_html__( 'H3', 'redias-core' ),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4'  => [
                        'title' => esc_html__( 'H4', 'redias-core' ),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5'  => [
                        'title' => esc_html__( 'H5', 'redias-core' ),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6'  => [
                        'title' => esc_html__( 'H6', 'redias-core' ),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'toggle' => false,
            ]
        );

        $this->add_responsive_control(
            'heading_align',
            [
                'label' => esc_html__( 'Alignment', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon' => 'eicon-text-align-right',
                    ]
                ],
                'default' => 'left',
                'toggle' => false,
                'prefix_class' => 'dl-align-',
                'selectors_dictionary' => [
                    'left' => 'justify-content: flex-start',
                    'center' => 'justify-content: center',
                    'right' => 'justify-content: flex-end',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-tag' => '{{VALUE}}'
                ]
            ]
        );

        $this->add_responsive_control(
            'heading_position',
            [
                'label' => esc_html__( 'Layout', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'inline' => [
                        'title' => esc_html__( 'Inline', 'redias-core' ),
                        'icon' => 'eicon-ellipsis-h',
                    ],
                    'block' => [
                        'title' => esc_html__( 'Block', 'redias-core' ),
                        'icon' => 'eicon-menu-bar',
                    ]
                ],
                'toggle' => false,
                'selectors_dictionary' => [
                    'inline' => 'flex-direction: row',
                    'block' => 'flex-direction: column',
                ],
                'default' => 'inline',
                'prefix_class' => 'dl-layout-',
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-wrap' => '{{VALUE}}',
                ]
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Before Text Style Control
     *
     * @return void
     */
    protected function before_text_style() {

        $this->start_controls_section(
			'section_before_text',
			[
                'label' => esc_html__( 'Before Text', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'before_text_typography',
                'selector' => '{{WRAPPER}} .dl-heading-before',
            ]
        );

        $this->add_control(
            'before_text_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-before' => 'color: {{VALUE}}',
                ],
                'default' => '#111'
            ]
        );

        $this->add_responsive_control(
            'before_text_padding',
            [
                'label' => esc_html__( 'Padding', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-before' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'before_text_spacing',
            [
                'label' => esc_html__( 'Spacing', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => -400,
                        'max' => 400,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}}.dl-layout-inline .dl-heading-before' => 'margin-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}}.dl-layout-block .dl-heading-before' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'before_text_border',
                'selector' => '{{WRAPPER}} .dl-heading-before',
            ]
        );

        $this->add_control(
            'before_text_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'before_text_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-heading-before',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'before_text_background',
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .dl-heading-before',
            ]
        );

        $this->add_control(
            'before_text_blend_mode',
            [
                'label' => esc_html__( 'Blend Mode', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'separator' => 'none',
                'options' => [
                    'inherit' => esc_html__( 'Normal', 'redias-core' ),
                    'multiply' => 'Multiply',
                    'screen' => 'Screen',
                    'overlay' => 'Overlay',
                    'darken' => 'Darken',
                    'lighten' => 'Lighten',
                    'color-dodge' => 'Color Dodge',
                    'saturation' => 'Saturation',
                    'color' => 'Color',
                    'difference' => 'Difference',
                    'exclusion' => 'Exclusion',
                    'hue' => 'Hue',
                    'luminosity' => 'Luminosity',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-before' => 'mix-blend-mode: {{VALUE}}',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Center Text Style Control
     *
     * @return void
     */
    protected function center_text_style() {

        $this->start_controls_section(
			'section_center_text',
			[
                'label' => esc_html__( 'Center Text', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'center_text_typography',
                'selector' => '{{WRAPPER}} .dl-heading-center',
            ]
        );

        $this->add_control(
            'center_text_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-center' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'center_text_padding',
            [
                'label' => esc_html__( 'Padding', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-center' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'center_text_spacing',
            [
                'label' => esc_html__( 'Spacing', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => -400,
                        'max' => 400,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}}.dl-layout-inline .dl-heading-center' => 'margin-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}}.dl-layout-block .dl-heading-center' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'center_text_border',
                'selector' => '{{WRAPPER}} .dl-heading-center',
            ]
        );

        $this->add_control(
            'center_text_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-center' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'center_text_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-heading-center',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'center_text_background',
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .dl-heading-center',
            ]
        );

        $this->add_control(
            'center_text_blend_mode',
            [
                'label' => esc_html__( 'Blend Mode', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'separator' => 'none',
                'options' => [
                    'inherit' => esc_html__( 'Normal', 'redias-core' ),
                    'multiply' => 'Multiply',
                    'screen' => 'Screen',
                    'overlay' => 'Overlay',
                    'darken' => 'Darken',
                    'lighten' => 'Lighten',
                    'color-dodge' => 'Color Dodge',
                    'saturation' => 'Saturation',
                    'color' => 'Color',
                    'difference' => 'Difference',
                    'exclusion' => 'Exclusion',
                    'hue' => 'Hue',
                    'luminosity' => 'Luminosity',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-center' => 'mix-blend-mode: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * After Text Style Control
     *
     * @return void
     */
    protected function after_text_style() {

        $this->start_controls_section(
			'section_after_text',
			[
                'label' => esc_html__( 'After Text', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'after_text_typography',
                'selector' => '{{WRAPPER}} .dl-heading-after',
            ]
        );

        $this->add_control(
            'after_text_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-after' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'after_text_padding',
            [
                'label' => esc_html__( 'Padding', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-after' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'after_text_spacing',
            [
                'label' => esc_html__( 'Spacing', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => -400,
                        'max' => 400,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}}.dl-layout-inline .dl-heading-after' => 'margin-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}}.dl-layout-block .dl-heading-after' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'after_text_border',
                'selector' => '{{WRAPPER}} .dl-heading-after',
            ]
        );

        $this->add_control(
            'after_text_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-after' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'after_text_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-heading-after',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'after_text_background',
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .dl-heading-after',
            ]
        );

        $this->add_control(
            'after_text_blend_mode',
            [
                'label' => esc_html__( 'Blend Mode', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'separator' => 'none',
                'options' => [
                    'inherit' => esc_html__( 'Normal', 'redias-core' ),
                    'multiply' => 'Multiply',
                    'screen' => 'Screen',
                    'overlay' => 'Overlay',
                    'darken' => 'Darken',
                    'lighten' => 'Lighten',
                    'color-dodge' => 'Color Dodge',
                    'saturation' => 'Saturation',
                    'color' => 'Color',
                    'difference' => 'Difference',
                    'exclusion' => 'Exclusion',
                    'hue' => 'Hue',
                    'luminosity' => 'Luminosity',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-after' => 'mix-blend-mode: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Custom Border Style Control
     *
     * @return void
     */
    protected function custom_border_style() {

        $this->start_controls_section(
			'section_custom_border',
			[
                'label' => esc_html__( 'Custom Border', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
            'border_type',
            [
                'label' => esc_html__( 'Border Type', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'none' => esc_html__( 'None', 'redias-core' ),
                    'solid' => esc_html__( 'Solid', 'redias-core' ),
                    'double' => esc_html__( 'Double', 'redias-core' ),
                    'dotted' => esc_html__( 'Dotted', 'redias-core' ),
                    'dashed' => esc_html__( 'Dashed', 'redias-core' ),
                    'groove' => esc_html__( 'Groove', 'redias-core' ),
                ],
                'default' => 'none',
                'selectors' => [
                    '{{WRAPPER}} .dl-border:after' => 'border-bottom-style: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'border_length',
            [
                'label' => esc_html__( 'Length', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 800,
                    ],
                ],
                'condition' => [
                    'border_type!' => 'none',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-border:after' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'border_width',
            [
                'label' => esc_html__( 'Width', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'unit' => 'px',
                    'size' => 3
                ],
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'border_type!' => 'none',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-border:after' => 'border-bottom-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'border_color',
            [
                'label' => esc_html__( 'Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'border_type!' => 'none',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-border:after' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'border_radius',
            [
                'label' => esc_html__( 'Border radius', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'condition' => [
                    'border_type!' => 'none',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-border:after' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );

        $this->add_control(
            'border_offset_toggle',
            [
                'label' => esc_html__( 'Offset', 'redias-core' ),
                'type' => Controls_Manager::POPOVER_TOGGLE,
                'label_off' => esc_html__( 'None', 'redias-core' ),
                'label_on' => esc_html__( 'Custom', 'redias-core' ),
                'return_value' => 'yes',
                'condition' => [
                    'border_type!' => 'none',
                ],
            ]
        );

        $this->start_popover();

        $this->add_responsive_control(
            'border_horizontal_position',
            [
                'label' => esc_html__( 'Horizontal Position', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ '%' ],
                'default' => [
                    'unit' => '%',
                    'size' => 0
                ],
                'range' => [
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                   'border_offset_toggle' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-border:after' => 'left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'border_vertical_position',
            [
                'label' => esc_html__( 'Vertical Position', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ '%' ],
                'default' => [
                    'unit' => '%',
                    'size' => 0
                ],
                'range' => [
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'border_offset_toggle' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-border:after' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_popover();

        $this->end_controls_section();

    }

    /**
     * Background Text Style Control
     *
     * @return void
     */
    protected function background_text_style() {

        $this->start_controls_section(
			'section_bg_text',
			[
                'label' => esc_html__( 'Background Text', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
            'background_note',
            [
                'label' => false,
                'type' => Controls_Manager::RAW_HTML,
                'raw' => esc_html__( '<strong>Background Text</strong> is Hidden on Content Tab', 'redias-core' ),
                'condition' => [
                    'show_background_text!' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'background_text_color',
            [
                'label' => esc_html__( 'Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'show_background_text' => 'yes',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-wrap:before' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'background_text_typography',
                'selector' => '{{WRAPPER}} .dl-heading-wrap:before',
                'condition' => [
                    'show_background_text' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'background_offset_toggle',
            [
                'label' => esc_html__( 'Offset', 'redias-core' ),
                'type' => Controls_Manager::POPOVER_TOGGLE,
                'label_off' => esc_html__( 'None', 'redias-core' ),
                'label_on' => esc_html__( 'Custom', 'redias-core' ),
                'return_value' => 'yes',
                'condition' => [
                    'show_background_text' => 'yes',
                ],
            ]
        );

        $this->start_popover();

        $this->add_responsive_control(
            'background_horizontal_position',
            [
                'label' => esc_html__( 'Horizontal Position', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'default' => [
                    'unit' => '%',
                ],
                'range' => [
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'background_offset_toggle' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-wrap:before' => 'left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'background_vertical_position',
            [
                'label' => esc_html__( 'Vertical Position', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'default' => [
                    'unit' => '%',
                ],
                'range' => [
                    '%' => [
                        'min' => -100,
                        'max' => 200,
                    ],
                ],
                'condition' => [
                    'background_offset_toggle' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-heading-wrap:before' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_popover();

        $this->add_control(
            'background_text_rotation',
            [
                'label'        => esc_html__( 'Text Rotaion', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'redias-core' ),
                'label_off'    => esc_html__( 'Off', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'no',
                'condition' => [
                    'show_background_text' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'bg_text_rotation_val',
            [
                'label'      => esc_html__( 'Rotate The Text', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => -360,
                        'max'  => 360,
                        'step' => 1,
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-heading-wrap:before' => 'transform: rotate({{SIZE}}deg);',
                ],
                'condition' => [
                    'show_background_text' => 'yes',
                    'background_text_rotation' => 'yes'
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
	protected function render(){
		$settings = $this->get_settings_for_display();
        $has_link = false;

		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_link_attributes( 'link', $settings['link'] );
			$has_link = true;
        }
        $this->add_render_attribute( 'heading_before', [ 'class' => 'dl-heading-before' ] );
        $this->add_render_attribute( 'heading_center', [ 'class' => 'dl-heading-center' ] );
        $this->add_render_attribute( 'heading_after', [ 'class' => 'dl-heading-after' ] );
        $this->add_inline_editing_attributes( 'heading_before', 'none' );
        $this->add_inline_editing_attributes( 'heading_center', 'none' );
        $this->add_inline_editing_attributes( 'heading_after', 'none' ); ?>

        <<?php echo esc_attr( $settings['title_tag'] ); ?> class="dl-heading-tag">
        <?php if( $has_link ) : ?>
            <a <?php $this->print_render_attribute_string( 'link' ) ?>>
        <?php endif; ?>
            <div class="dl-heading-wrap" data-bg-text="<?php echo esc_attr( $settings['background_text'] ); ?>">
                <?php if( ! empty( $settings[ 'heading_before' ] ) ) : ?>
                <span <?php echo $this->get_render_attribute_string( 'heading_before' ); ?>><?php echo Helper::kses_basic( $settings[ 'heading_before' ] ); ?></span>
                <?php endif; ?>
                <?php if( ! empty( $settings[ 'heading_center' ] ) ) : ?>
                <span <?php echo $this->get_render_attribute_string( 'heading_center' ); ?>><?php echo Helper::kses_basic( $settings[ 'heading_center' ] ); ?></span>
                <?php endif; ?>
                <?php if( ! empty( $settings[ 'heading_after' ] ) ) : ?>
                <span <?php echo $this->get_render_attribute_string( 'heading_after' ); ?>><?php echo Helper::kses_basic( $settings[ 'heading_after' ] ); ?></span>
                <?php endif; ?>
                <?php if( 'none' != $settings['border_type'] ) : ?>
                <span class="dl-border"></span>
                <?php endif; ?>
            </div>
        <?php if( $has_link ) : ?>
            </a>
        <?php endif; ?>
        </<?php echo esc_attr( $settings['title_tag'] ); ?>>
	    <?php
    }
    
    /**
     * Content Template
     *
     * @return void
     */
    protected function content_template() {
        ?>
        <#
        var has_link = false;

        if( '' != settings.link.url ) {
            var has_link = true;
        }

        var target = settings.link.is_external ? ' target="_blank"' : '';
        var nofollow = settings.link.nofollow ? ' rel="nofollow"' : '';
        var bg_text = settings.show_background_text === 'yes' ? settings.background_text : '';

        view.addRenderAttribute( 'heading_before', 'class', [ 'dl-heading-before' ] );
        view.addRenderAttribute( 'heading_center', 'class', [ 'dl-heading-center' ] );
        view.addRenderAttribute( 'heading_after', 'class', [ 'dl-heading-after' ] );

        view.addInlineEditingAttributes( 'heading_before', 'none' );
		view.addInlineEditingAttributes( 'heading_center', 'none' );
		view.addInlineEditingAttributes( 'heading_after', 'none' );
        #>
        <{{{ settings.title_tag }}} class="dl-heading-tag">
            <# if( has_link ){ #>
            <a href="{{ settings.link.url }}"{{ target }}{{ nofollow }}>
            <# } #>
            <div class="dl-heading-wrap" data-bg-text="{{{ bg_text }}}">
                <# if( '' != settings.heading_before ) { #>
                <span {{{ view.getRenderAttributeString( 'heading_before' ) }}}>{{{ settings.heading_before }}}</span>
                <# } #>
                <# if( '' != settings.heading_center ) { #>
                <span {{{ view.getRenderAttributeString( 'heading_center' ) }}}>{{{ settings.heading_center }}}</span>
                <# } #>
                <# if( '' != settings.heading_after ) { #>
                <span {{{ view.getRenderAttributeString( 'heading_after' ) }}}>{{{ settings.heading_after }}}</span>
                <# } #>
                <# if( 'none' != settings.border_type ) { #>
                <span class="dl-border"></span>
                <# } #>
            </div>
            <# if( has_link ){ #>
            </a>
            <# } #>
        </{{{ settings.title_tag }}}>
        <?php
    }
}