<?php
/**
 * Animated Text
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\AnimatedText;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Widget_Base;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-animated-heading';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Animated Text', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-animated-headline';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return ['animated', 'text', 'heading', 'redias-core'];
    }

    public function get_script_depends() {
        return ['redias-animated-text', 'redias-el-script'];
    }

    public function get_style_depends() {
        return ['redias-animated-text'];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_content();
        $this->section_animation_settings();
        $this->section_common_style();
        $this->section_before_text_style();
        $this->section_after_text_style();
        $this->section_animated_text_style();

    }

    /**
     * Content Control
     *
     * @return void
     */
    protected function section_content() {

        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__( 'Content', 'redias-core' ),
            ]
        );

        $this->add_control(
            'animation_type',
            [
                'label'          => esc_html__( 'Animation Type', 'redias-core' ),
                'type'           => Controls_Manager::SELECT,
                'default'        => 'letters type',
                'options'        => [
                    'rotate-1'         => esc_html__( 'Rotate 1', 'redias-core' ),
                    'letters rotate-2' => esc_html__( 'Rotate 2', 'redias-core' ),
                    'letters rotate-3' => esc_html__( 'Rotate 3', 'redias-core' ),
                    'letters type'     => esc_html__( 'Type', 'redias-core' ),
                    'slide'            => esc_html__( 'Slide', 'redias-core' ),
                    'clip'             => esc_html__( 'Clip', 'redias-core' ),
                    'zoom'             => esc_html__( 'Zoom', 'redias-core' ),
                    'letters scale'    => esc_html__( 'Scale', 'redias-core' ),
                    'push'             => esc_html__( 'Push', 'redias-core' ),
                    'loading-bar'      => esc_html__( 'Loading Bar', 'redias-core' ),
                ],
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'before_text',
            [
                'label'       => esc_html__( 'Before Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'ThemeEaster is', 'redias-core' ),
                'placeholder' => esc_html__( 'Before Text', 'redias-core' ),
                'dynamic'     => [
                    'active' => true,
                ],
            ]
        );

        $this->add_control(
            'after_text',
            [
                'label'       => esc_html__( 'After Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '',
                'placeholder' => esc_html__( 'After Text', 'redias-core' ),
                'dynamic'     => [
                    'active' => true,
                ],
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'text', [
                'label'   => esc_html__( 'Text', 'redias-core' ),
                'type'    => Controls_Manager::TEXT,
                'default' => esc_html__( 'Awesome', 'redias-core' ),
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $repeater->add_control(
            'text_customize',
            [
                'label'          => esc_html__( 'Want To Customize Text?', 'redias-core' ),
                'type'           => Controls_Manager::SWITCHER,
                'label_on'       => esc_html__( 'Yes', 'redias-core' ),
                'label_off'      => esc_html__( 'No', 'redias-core' ),
                'return_value'   => 'yes',
                'style_transfer' => true,
            ]
        );

        $repeater->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'           => 'text_typography',
                'label'          => esc_html__( 'Typography', 'redias-core' ),
                'exclude'        => [
                    'font_size',
                    'line_height',
                ],
                'selector'       => '{{WRAPPER}} .dl-animated-text-wrap .dl-animated-text > {{CURRENT_ITEM}}, {{WRAPPER}} .dl-animated-text-wrap .dl-animated-text > {{CURRENT_ITEM}} i, {{WRAPPER}} .dl-animated-text-wrap .dl-animated-text > {{CURRENT_ITEM}} em',
                'condition'      => [
                    'text_customize' => 'yes',
                ],
                'style_transfer' => true,
            ]
        );

        $repeater->add_control(
            'text_color',
            [
                'label'          => esc_html__( 'Color', 'redias-core' ),
                'type'           => Controls_Manager::COLOR,
                'selectors'      => [
                    '{{WRAPPER}} .dl-animated-text-wrap .dl-animated-text > {{CURRENT_ITEM}} '     => 'color: {{VALUE}}; -webkit-background-clip: initial; -webkit-text-fill-color:initial; background: none;',
                    '{{WRAPPER}} .dl-animated-text-wrap .dl-animated-text > {{CURRENT_ITEM}} i'    => 'color: {{VALUE}}; -webkit-background-clip: initial; -webkit-text-fill-color:initial; background: none;',
                    '{{WRAPPER}} .dl-animated-text-wrap .dl-animated-text > {{CURRENT_ITEM}} i em' => 'color: {{VALUE}}; -webkit-background-clip: initial; -webkit-text-fill-color:initial; background: none;',
                ],
                'condition'      => [
                    'text_customize' => 'yes',
                ],
                'style_transfer' => true,
            ]
        );

        $repeater->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'           => 'text_shadow',
                'label'          => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector'       => '{{WRAPPER}} .dl-animated-text > {{CURRENT_ITEM}}',
                'condition'      => [
                    'text_customize' => 'yes',
                ],
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'animated_text',
            [
                'label'       => esc_html__( 'Animated Text', 'redias-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'text' => esc_html__( 'Awesome', 'redias-core' ),
                    ],
                    [
                        'text' => esc_html__( 'Cool', 'redias-core' ),
                    ],
                    [
                        'text' => esc_html__( 'Nice', 'redias-core' ),
                    ],
                ],
                'title_field' => '{{{ text }}}',
            ]
        );

        $this->add_control(
            'hr',
            [
                'type' => Controls_Manager::DIVIDER,
            ]
        );

        $this->add_control(
            'html_tag',
            [
                'label'   => esc_html__( 'HTML Tag', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'h1' => esc_html__( 'H1', 'redias-core' ),
                    'h2' => esc_html__( 'H2', 'redias-core' ),
                    'h3' => esc_html__( 'H3', 'redias-core' ),
                    'h4' => esc_html__( 'H4', 'redias-core' ),
                    'h5' => esc_html__( 'H5', 'redias-core' ),
                    'h6' => esc_html__( 'H6', 'redias-core' ),
                    'p'  => esc_html__( 'P', 'redias-core' ),
                ],
                'default' => 'h2',
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'     => esc_html__( 'Alignment', 'redias-core' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'toggle'    => false,
                'selectors' => [
                    '{{WRAPPER}} .cd-headline' => 'text-align: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Animation Settings
     *
     * @return void
     */
    protected function section_animation_settings() {

        $this->start_controls_section(
            'section_animation_settings',
            [
                'label'      => esc_html__( 'Animation Settings', 'redias-core' ),
                'tab'        => Controls_Manager::TAB_CONTENT,
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'animation_type',
                            'operator' => '!=',
                            'value'    => 'letters type',
                        ],
                        [
                            'name'     => 'animation_type',
                            'operator' => '!=',
                            'value'    => 'loading-bar',
                        ],
                        [
                            'name'     => 'animation_type',
                            'operator' => '!=',
                            'value'    => 'clip',
                        ],
                    ],
                ],
            ]
        );

        $this->add_control(
            'animation_delay',
            [
                'label'              => esc_html__( 'Animation Delay', 'redias-core' ),
                'type'               => Controls_Manager::NUMBER,
                'min'                => 1000,
                'step'               => 100,
                'max'                => 30000,
                'default'            => 2500,
                'description'        => esc_html__( 'Animation Delay in milliseconds. Min 1000 and Max 30000.', 'redias-core' ),
                'frontend_available' => true,
                'conditions'         => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'animation_type',
                            'operator' => '!=',
                            'value'    => 'letters type',
                        ],
                        [
                            'name'     => 'animation_type',
                            'operator' => '!=',
                            'value'    => 'loading-bar',
                        ],
                        [
                            'name'     => 'animation_type',
                            'operator' => '!=',
                            'value'    => 'clip',
                        ],
                    ],
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Common Style Control
     *
     * @return void
     */
    protected function section_common_style() {

        $this->start_controls_section(
            'section_coming_text_style',
            [
                'label' => esc_html__( 'Common Styles', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'common_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'default'  => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .dl-animated-text-wrap, {{WRAPPER}} .dl-animated-text-wrap b, {{WRAPPER}} .dl-animated-text-wrap i, {{WRAPPER}} .dl-animated-text-wrap em',
            ]
        );

        $this->add_control(
            'common_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-animated-text-wrap' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'common_shadow',
                'label'    => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-animated-text-wrap',
            ]
        );

        $this->add_control(
            'loading_bar_color',
            [
                'label'     => esc_html__( 'Loading Bar Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-animated-text-wrap.loading-bar .dl-animated-text::after' => 'background: {{VALUE}}',
                ],
                'condition' => [
                    'animation_type' => 'loading-bar',
                ],
            ]
        );

        $this->add_control(
            'cursor_color',
            [
                'label'      => esc_html__( 'Cursor Color', 'redias-core' ),
                'type'       => Controls_Manager::COLOR,
                'selectors'  => [
                    '{{WRAPPER}} .dl-animated-text-wrap.clip .dl-animated-text::after' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .dl-animated-text-wrap.type .dl-animated-text::after' => 'background-color: {{VALUE}}',
                ],
                'conditions' => [
                    'relation' => 'or',
                    'terms'    => [
                        [
                            'name'     => 'animation_type',
                            'operator' => '==',
                            'value'    => [
                                'clip',
                            ],
                        ],
                        [
                            'name'     => 'animation_type',
                            'operator' => '==',
                            'value'    => [
                                'letters type',
                            ],
                        ],
                    ],
                ],
            ]
        );

        $this->add_control(
            'select_text_color',
            [
                'label'     => esc_html__( 'Select Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-animated-text-wrap.type .dl-animated-text.selected' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'animation_type' => 'letters type',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Before Text Style Control
     *
     * @return void
     */
    protected function section_before_text_style() {

        $this->start_controls_section(
            'section_before_text',
            [
                'label' => esc_html__( 'Before Text', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'before_text_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'exclude'  => [
                    'font_size',
                    'line_height',
                ],
                'selector' => '{{WRAPPER}} .dl-animated-text-wrap .dl-animated-before-text',
            ]
        );

        $this->add_control(
            'before_text_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-animated-text-wrap .dl-animated-before-text' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'before_text_shadow',
                'label'    => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-animated-text-wrap .dl-animated-before-text',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * After Text Style Control
     *
     * @return void
     */
    protected function section_after_text_style() {

        $this->start_controls_section(
            'section_after_text',
            [
                'label' => esc_html__( 'After Text', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'after_text_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'exclude'  => [
                    'font_size',
                    'line_height',
                ],
                'selector' => '{{WRAPPER}} .dl-animated-text-wrap .dl-animated-after-text',
            ]
        );

        $this->add_control(
            'after_text_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-animated-text-wrap .dl-animated-after-text' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'after_text_shadow',
                'label'    => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-animated-text-wrap .dl-animated-after-text',
            ]
        );

        $this->end_controls_section();

    }

    // Animated Text Style
    protected function section_animated_text_style() {

        $this->start_controls_section(
            'section_custom_border',
            [
                'label' => esc_html__( 'Animated Text', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'animated_text_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'exclude'  => [
                    'font_size',
                    'line_height',
                ],
                'selector' => '{{WRAPPER}} .dl-animated-text-wrap .dl-animated-text b,{{WRAPPER}} .dl-animated-text-wrap .dl-animated-text i,{{WRAPPER}} .dl-animated-text-wrap .dl-animated-text em',
            ]
        );

        $this->add_control(
            'animated_text_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-animated-text-wrap .dl-animated-text b,{{WRAPPER}} .dl-animated-text-wrap .dl-animated-text i,{{WRAPPER}} .dl-animated-text-wrap .dl-animated-text em' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'animated_text_shadow',
                'label'    => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-animated-text-wrap b',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings       = $this->get_settings_for_display();
        $animation_type = $settings['animation_type'];
        $this->add_render_attribute( 'dl-animated', 'class',
            [
                'dl-animated-text-wrap',
                'cd-headline',
                $animation_type,
            ]
        );

        if ( $animation_type &&
            'letters type' !== $animation_type &&
            'letters type' !== $animation_type &&
            'clip' !== $animation_type
        ) {
            $this->add_render_attribute( 'dl-animated', 'data-animation-delay', $settings['animation_delay'] );
        }

        $animated_text = '';

        if ( $settings['before_text'] ) {
            $this->add_render_attribute( 'dl-animated', 'class', 'dl-animated-has-before-text' );
            $animated_text .= sprintf( '<span class="dl-animated-before-text">%s</span>', esc_html( $settings['before_text'] ) );
        }

        if ( $settings['animated_text'] && is_array( $settings['animated_text'] ) ) {
            $animated_animation_text = '';

            foreach ( $settings['animated_text'] as $key => $item ) {
                $animated_animation_text .= sprintf(
                    '<b class="elementor-repeater-item-%s">%s</b>',
                    esc_attr( $item['_id'] . ( $key === 0 ? ' is-visible' : '' ) ),
                    esc_html( $item['text'] )
                );
            }

            $animated_text .= sprintf(
                ' <span class="dl-animated-text cd-words-wrapper">%s</span>',
                $animated_animation_text
            );
        }

        if ( $settings['after_text'] ) {
            $this->add_render_attribute( 'dl-animated', 'class', 'dl-animated-has-after-text' );
            $animated_text .= sprintf( ' <span class="dl-animated-after-text">%s</span>', esc_html( $settings['after_text'] ) );
        }

        printf(
            '<%1$s %2$s>%3$s</%1$s>',
            tag_escape( $settings['html_tag'] ),
            $this->get_render_attribute_string( 'dl-animated' ),
            $animated_text
        );

    }
}