<?php
/**
 * Blog
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Blog;

use RediasCore\Classes\Helper;
use RediasCore\Traits\CarouselControls;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Icons_Manager;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    use CarouselControls;

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-blog';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Blog', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-posts-grid';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'blog', 'posts', 'carousel', 'blog carousel', 'post carousel', 'redias' ];
    }

    public function get_style_depends() {
        return [ 'redias-blog', 'redias-keyfram-anim', 'slick', 'elementor-icons-line-awesome-icons' ];
    }

    public function get_script_depends() {
        return [ 'slick', 'redias-el-script' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->layout_section();
        $this->query_section();
        $this->useful_options_section();
        $this->scrolling_animation_section();
        $this->section_controls();
        $this->content_area_style();
        $this->heading_style();
        $this->excerpt_style();
        $this->category_style();
        $this->post_meta_info_style();
        $this->readmore_style();
        $this->pagination_style();
        $this->style_navigation();
        $this->style_pagination();
        
    }

    /**
     * Layout Section
     *
     * @return void
     */
    protected function layout_section() {

        $this->start_controls_section(
			'layout_section',
			[
				'label' => esc_html__( 'Layout', 'redias-core' )
			]
        );

        $this->add_responsive_control(
			'dl_column',
			[
				'label' => esc_html__( 'Column', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => 0,
                        'max' => 4,
                        'step' => 1,
                    ],
				],
                'default' => [
					'size' => 3,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 2,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 1,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .el-blog-items' => 'grid-template-columns: repeat({{SIZE}},1fr);',
                ],
                'condition'    => [
                    'carousel!'    => 'yes',
                ]
			]
		);

        $this->add_responsive_control(
			'grid_gap',
			[
				'label' => esc_html__( 'Grid Gap', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => 0,
                        'max' => 150
                    ],
				],
				'default'    => [
					'unit' => 'px',
					'size' => 30
				],
				'selectors' => [
					'{{WRAPPER}} .el-blog-items' => 'grid-gap: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'carousel!'    => 'yes',
                ],
			]
		);

        $this->add_control(
            'carousel',
            [
                'label'        => esc_html__( 'Carousel', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'no',
                'frontend_available' => true
            ]
        );

        $this->add_control(
            'heading_tag',
            [
                'label'   => esc_html__( 'Heading Tag', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'h3',
                'options' => [
                    'h1'  => esc_html__( 'H1', 'redias-core' ),
                    'h2'  => esc_html__( 'H2', 'redias-core' ),
                    'h3'  => esc_html__( 'H3', 'redias-core' ),
                    'h4'  => esc_html__( 'H4', 'redias-core' ),
                    'h5'  => esc_html__( 'H5', 'redias-core' ),
                    'h6'  => esc_html__( 'H6', 'redias-core' )
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Query Section
     *
     * @return void
     */
    protected function query_section() {
        
        $this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Query', 'redias-core' )
			]
		);

		$this->add_control(
			'source',
			[
				'label' => _x( 'Source', 'Posts Query Control', 'redias-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => esc_html__( 'Show All', 'redias-core' ),
					'by_name' => esc_html__( 'Manual Selection', 'redias-core' ),
				],
				'label_block' => true,
			]
		);

		$this->add_control(
			'post_categories',
			[
				'label'       => esc_html__( 'Categories', 'redias-core' ),
				'type'        => Controls_Manager::SELECT2,
				'options'     => Helper::el_get_terms(),
				'default'     => [],
				'label_block' => true,
				'multiple'    => true,
				'condition'   => [
					'source'    => 'by_name',
				],
			]
		);

		$this->add_control(
			'posts_limit',
			[
				'label'       => esc_html__( 'Posts Limit', 'redias-core' ),
				'type'        => Controls_Manager::NUMBER,
				'desc'		  => esc_html__( 'Choose number of posts you want to show.', 'redias-core' ),
				'default'     => 3
			]
		);

		$this->add_control(
			'img_size',
			[
				'label'       => esc_html__( 'Image Size', 'redias-core' ),
				'type'        => Controls_Manager::SELECT2,
				'options'     => Helper::get_image_sizes(),
				'default'     => 'redias-thumb-grid',
				'label_block' => true,
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'   => esc_html__( 'Order By', 'redias-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'ID' => esc_html__( 'Post Id', 'redias-core' ),
                    'author' => esc_html__( 'Post Author', 'redias-core' ),
                    'title' => esc_html__( 'Title', 'redias-core' ),
                    'date' => esc_html__( 'Date', 'redias-core' ),
                    'modified' => esc_html__( 'Last Modified Date', 'redias-core' ),
                    'parent' => esc_html__( 'Parent Id', 'redias-core' ),
                    'rand' => esc_html__( 'Random', 'redias-core' ),
                    'comment_count' => esc_html__( 'Comment Count', 'redias-core' ),
                    'menu_order' => esc_html__( 'Menu Order', 'redias-core' ),
				],
			]
		);

		$this->add_control(
            'order',
            [
                'label' => __( 'Order', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' => esc_html__( 'Ascending', 'redias-core' ),
                    'desc' => esc_html__( 'Descending', 'redias-core' )
                ],
                'default' => 'desc',
            ]
        );

		$this->end_controls_section();

    }

    /**
	 * Carousel Controls
	 *
	 * @return void
	 */
	protected function section_controls() {

		$this->start_controls_section(
			'section_carousel_settings',
			[
				'label' => esc_html__( 'Carousel Settings', 'redias-core' ),
				'condition'    => [
					'carousel'    => 'yes'
				],
			]
		);

		$slides_per_show = range( 1, 10 );
		$slides_per_show = array_combine( $slides_per_show, $slides_per_show );

		$this->add_responsive_control(
			'slides_per_show',
			[
				'label' => esc_html__( 'Slides to Show', 'elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 3,
				'tablet_default' => 2,
				'mobile_default' => 1,
				'options' => $slides_per_show,
				'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel'    => 'yes',
				],
			]
		);

		$this->add_responsive_control(
			'slides_per_scroll',
			[
				'label' => esc_html__( 'Slides to Scroll', 'elementor' ),
				'type' => Controls_Manager::SELECT,
				'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'elementor' ),
				'default' => 1,
				'tablet_default' => 1,
				'mobile_default' => 1,
				'options' => $slides_per_show,
				'condition' => [
					'carousel'    => 'yes',
					'slides_per_show!' => '1'
				],
				'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

        $this->add_responsive_control(
			'spaceBetween',
			[
				'label'      => esc_html__( 'Space Between', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px', 'em'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 150,
						'step' => 1
					],
					'em'  => [
						'min' => 0,
						'max' => 100
					],
				],
                'default' => [
					'unit' => 'px',
					'size' => 12.5
				],
                'tablet_default' => [
					'unit' => 'px',
					'size' => 12.5
				],
                'mobile_default' => [
					'unit' => 'px',
					'size' => 0
				],
				'selectors'  => [
					'{{WRAPPER}} .slick-list' => 'margin: 0 -{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .slick-slide' => 'margin: 0 {{SIZE}}{{UNIT}};'
				],
				'condition'    => [
					'carousel'    => 'yes',
				],
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'        => esc_html__( 'Autoplay', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel'    => 'yes',
				],
			]
		);

		$this->add_control(
			'autoplay_speed',
			[
				'label'   => esc_html__( 'Autoplay Speed', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 500,
				'max'     => 20000,
				'step'    => 5,
				'default' => 5000,
				'condition' => [
					'carousel' => 'yes',
					'autoplay' => 'yes'
                ],
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'pause_on_hover',
			[
				'label'        => esc_html__( 'Pause on Hover', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'condition' => [
					'carousel' => 'yes',
					'autoplay' => 'yes'
				],
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'infinite_loop',
			[
				'label'        => esc_html__( 'Infinite Loop', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel'    => 'yes'
				],
			]
		);

		$this->add_control(
			'anim_speed',
			[
				'label'   => esc_html__( 'Animation Speed', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 100,
				'max'     => 3000,
				'step'    => 5,
				'default' => 500,
                'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel'    => 'yes'
				],
			]
		);

        $this->add_control(
			'center_mode',
			[
				'label'        => esc_html__( 'Center Mode', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'no',
                'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel'    => 'yes'
				],
			]
		);

        $this->add_responsive_control(
			'center_padding',
			[
				'label'   => esc_html__( 'Center Padding', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 0,
				'max'     => 200,
				'step'    => 1,
				'default' => 50,
				'tablet_default' => 30,
				'mobile_default' => 10,
                'frontend_available' => true,
				'render_type' => 'ui',
                'condition' => [
					'carousel'    => 'yes',
					'center_mode' => 'yes'
				],
			]
		);

		$this->add_control(
			'navigation',
			[
				'label' => esc_html__( 'Navigation', 'redias-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'None', 'redias-core' ),
					'arrow' => esc_html__( 'Arrow', 'redias-core' ),
					'dots' => esc_html__( 'Dots', 'redias-core' ),
					'both' => esc_html__( 'Arrow & Dots', 'redias-core' ),
				],
				'default' => 'none',
				'frontend_available' => true,
				'style_transfer' => true,
				'condition'    => [
					'carousel'    => 'yes'
				],
			]
		);

        $this->add_control(
			'arrow_prev_icon',
			[
				'label' => esc_html__( 'Previous Icon', 'redias-core' ),
				'label_block' => false,
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-long-arrow-alt-left',
					'library' => 'elementor-icons-line-awesome-icons',
				],
				'condition' => [
					'carousel'    => 'yes',
					'navigation' => ['arrow', 'both']
				],
			]
		);

		$this->add_control(
			'arrow_next_icon',
			[
				'label' => esc_html__( 'Next Icon', 'redias-core' ),
				'label_block' => false,
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-long-arrow-alt-right',
					'library' => 'elementor-icons-line-awesome-icons',
				],
				'condition' => [
					'carousel'    => 'yes',
					'navigation' => ['arrow', 'both']
				],
			]
		);

		$this->end_controls_section();

	}

    /**
     * Useful Options Section
     *
     * @return void
     */
    protected function useful_options_section() {
        
        $this->start_controls_section(
			'useful_section',
			[
				'label' => esc_html__( 'Useful Options', 'redias-core' )
			]
        );

        $this->add_control(
            'category',
            [
                'label'        => esc_html__( 'Category', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'redias-core' ),
                'label_off'    => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'meta_info',
            [
                'label'        => esc_html__( 'Meta Info', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'redias-core' ),
                'label_off'    => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
			'title_length',
			[
				'label'   => esc_html__( 'Title Length', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 42,
			]
		);

        $this->add_control(
            'title_suffix',
            [
                'label'       => esc_html__( 'Title Suffix', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '...',
                'placeholder' => esc_html__( 'Suffix...', 'redias-core' ),
            ]
        );

		$this->add_control(
			'show_excerpt',
			[
				'label'   => esc_html__( 'Excerpt', 'redias-core' ),
				'type'    => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'redias-core' ),
                'label_off'    => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'excerpt_length',
			[
				'label'   => esc_html__( 'Excerpt Length', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 100,
				'condition' => [
					'show_excerpt' => 'yes',
				],
			]
		);

        $this->add_control(
            'excerpt_suffix',
            [
                'label'       => esc_html__( 'Excerpt Suffix', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '...',
                'placeholder' => esc_html__( 'Suffix...', 'redias-core' ),
                'condition' => [
					'show_excerpt' => 'yes',
				],
            ]
        );

        $this->add_control(
			'show_readmore',
			[
				'label'   => esc_html__( 'Readmore', 'redias-core' ),
				'type'    => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'redias-core' ),
                'label_off'    => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
				'default' => 'yes',
			]
		);

        $this->add_control(
            'readmore_text',
            [
                'label'       => __( 'Readmore Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Read More', 'redias-core' ),
                'placeholder' => esc_html__( 'Text...', 'redias-core' ),
                'condition'    => [
                    'show_readmore'    => 'yes'
                ],
            ]
        );

		$this->add_control(
			'pagination_control',
			[
				'label' => esc_html__( 'Pagination', 'redias-core' ),
				'type' => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'redias-core' ),
                'label_off'    => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
				'default' => 'no',
                'condition'    => [
                    'carousel!'    => 'yes',
                ],
			]
		);

        $this->end_controls_section();

    }

    /**
     * Scrolling Animation
     *
     * @return void
     */
    protected function scrolling_animation_section() {
        
        $this->start_controls_section(
			'scrolling_animation_section',
			[
				'label' => esc_html__( 'Scrolling Animation', 'redias-core' ),
                'condition' => [
                    'carousel!'    => 'yes',
                ]
			]
        );

        $this->add_control(
            'scroll_anim',
            [
                'label'        => esc_html__( 'Scrolling Animation', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'no',
                'condition' => [
                    'carousel!'    => 'yes'
                ]
            ]
        );

        $this->add_control(
            'anim_effect',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'dl-fadeIn',
                'options' => Helper::get_animation_effects(),
                'condition' => [
                    'scroll_anim' => 'yes',
                    'carousel!'    => 'yes'
				]
            ]
        );

        $this->add_control(
            'anim_offset',
            [
                'label'      => esc_html__( 'Offset', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 2000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 200,
                ],
                'condition' => [
                    'scroll_anim' => 'yes',
                    'carousel!'    => 'yes'
				]
            ]
        );

        $this->add_control(
            'anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 700,
                ],
                'condition' => [
                    'scroll_anim' => 'yes',
                    'carousel!'    => 'yes'
				]
            ]
        );
        
        $this->add_control(
            'anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 400,
                ],
                'condition' => [
                    'scroll_anim' => 'yes',
                    'carousel!'    => 'yes'
				]
            ]
        );

        $this->add_control(
            'anim_delay_interval',
            [
                'label'      => esc_html__( 'Delay Interval', 'redias-core' ),
                'description'      => esc_html__( 'Delay interval between items.', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 100,
                ],
                'condition' => [
                    'scroll_anim' => 'yes',
                    'carousel!'    => 'yes'
				]
            ]
        );

        $this->add_control(
			'entrance_animation',
			[
				'label' => esc_html__( 'Entrance Animation', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
			]
		);

        $this->end_controls_section();

    }

    /**
     * Content Area Section
     *
     * @return void
     */
    protected function content_area_style() {
        
        $this->start_controls_section(
            'content_area_style_section',
            [
                'label' => esc_html__( 'Content Area', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'content_area_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content',
            ]
        );

        $this->add_control(
			'content_divider',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);

        $this->add_responsive_control(
            'content_hover_pattern',
            [
                'label'                => esc_html__( 'Hover Pattern', 'redias-core' ),
                'type'                 => Controls_Manager::CHOOSE,
                'options'              => [
                    'none'   => [
                        'title' => esc_html__( 'None', 'redias-core' ),
                        'icon'  => 'eicon-close',
                    ],
                    'yes' => [
                        'title' => esc_html__( 'Yes', 'redias-core' ),
                        'icon'  => 'eicon-check',
                    ]
                ],
                'default'              => 'yes',
                'toggle'               => false,
                'prefix_class' => 'pattern-',
                'selectors_dictionary' => [
                    'none'   => 'display: none;',
                    'yes' => 'background-repeat: no-repeat;
                    background-position: bottom right;
                    width: 71px;
                    height: 58px;
                    content: "";
                    position: absolute;
                    right: 0;
                    bottom: 0;
                    visibility: hidden;
                    opacity: 0;
                    transition: all 0.2s ease-in-out;',
                ],
                'selectors'            => [
                    '{{WRAPPER}}.pattern-yes .el-blog-item .el-post-content:before' => '{{VALUE}}',
                    '.rtl {{WRAPPER}}.pattern-yes .el-blog-item .el-post-content:before' => 'right: auto; left: 0;',
                    '{{WRAPPER}}.pattern-yes .el-blog-item:hover .el-post-content:before' => 'visibility: visible; opacity: 1; transition: all 0.2s ease-in-out;',
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'content_area_box_shadow',
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-item',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'content_area_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content',
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();
    }

    /**
     * Heading Style
     *
     * @return void
     */
    protected function heading_style() {
        
        $this->start_controls_section(
            'heading_style_section',
            [
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'heading_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content .post-title',
            ]
        );

        $this->add_responsive_control(
            'heading_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-content .post-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-content .post-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs( 'heading_style_tabs' );
        
        $this->start_controls_tab(
            'heading_style_normal',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
            ]
        );

        $this->add_control(
            'heading_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-blog-item .el-post-content .post-title a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'heading_text_shadow',
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content .post-title a',
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'heading_style_hover',
            [
                'label' => esc_html__( 'Hover', 'redias-core' )
            ]
        );

        $this->add_control(
            'title_underline_effect',
            [
                'label'   => esc_html__( 'Line Effect', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'yes'   => [
                        'title' => esc_html__( 'Yes', 'redias-core' ),
                        'icon'  => 'eicon-check',
                    ],
                    'no' => [
                        'title' => esc_html__( 'No', 'redias-core' ),
                        'icon'  => 'eicon-ban',
                    ],
                ],
                'prefix_class' => 'line-effect-',
                'default' => 'yes',
                'toggle'  => false,
            ]
        );

        $this->add_control(
            'heading_hover_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}}.line-effect-yes .el-blog-item .el-post-content .post-title a' => 'background-image: linear-gradient({{VALUE}} 0%, {{VALUE}} 98%);',
                ],
            ]
        );

        $this->add_control(
            'heading_hover_line_color',
            [
                'label'     => esc_html__( 'Line Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}}.line-effect-yes .el-blog-item .el-post-content .post-title a' => 'background-image: linear-gradient({{VALUE}} 0%, {{VALUE}} 98%);',
                ],
                'condition'    => [
                    'title_underline_effect' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'heading_hover_text_shadow',
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content .post-title a:hover',
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->end_controls_section();

    }

    /**
     * Excerpt Style
     *
     * @return void
     */
    protected function excerpt_style() {
        
        $this->start_controls_section(
            'excerpt_style_section',
            [
                'label' => esc_html__( 'Excerpt', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'show_excerpt'    => 'yes',
                ],
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'excerpt_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content p',
                'condition'    => [
                    'show_excerpt'    => 'yes',
                ],
            ]
        );

        $this->add_control(
            'excerpt_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-blog-item .el-post-content p' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'show_excerpt'    => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'excerpt_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-content p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'show_excerpt'    => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'excerpt_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'show_excerpt'    => 'yes',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Category Style
     *
     * @return void
     */
    protected function category_style() {
        
        $this->start_controls_section(
            'category_style_section',
            [
                'label' => esc_html__( 'Category', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );
        
        $this->add_control(
            'cat_position',
            [
                'label'   => esc_html__( 'Position', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'bottom-left',
                'options' => [
                    'top-left'  => esc_html__( 'Top Left', 'redias-core' ),
                    'top-right'  => esc_html__( 'Top Right', 'redias-core' ),
                    'center'  => esc_html__( 'Center', 'redias-core' ),
                    'bottom-left'  => esc_html__( 'Bottom Left', 'redias-core' ),
                    'bottom-right'  => esc_html__( 'Bottom Right', 'redias-core' ),
                    'bottom-center'  => esc_html__( 'Bottom Center', 'redias-core' )
                ],
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );

        $this->add_responsive_control(
            'cat_y_position',
            [
                'label'      => esc_html__( 'Y Position', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => -100,
                        'max'  => 100
                    ],
                ],
                'condition'    => [
                    'cat_position'    => ['bottom-left', 'bottom-right', 'bottom-center']
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-thumb .category' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'cat_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-thumb .category',
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );

        $this->add_responsive_control(
            'category_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-thumb .category' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );

        $this->start_controls_tabs( 'category_style_tabs' );
        
        $this->start_controls_tab(
            'category_style_normal',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'cat_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['gradient'],
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-thumb .category',
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );

        $this->add_control(
            'cat_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .el-blog-item .el-post-thumb .category' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'cat_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-thumb .category',
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );

        $this->add_responsive_control(
            'cat_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-thumb .category' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'category_style_hover',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'cat_hover_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['gradient'],
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-thumb .category:hover',
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );

        $this->add_control(
            'cat_hover_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .el-blog-item .el-post-thumb .category:hover' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'cat_hover_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-thumb .category:hover',
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );

        $this->add_responsive_control(
            'cat_hover_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-thumb .category:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'category'    => 'yes'
                ]
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->end_controls_section();

    }

    /**
     * Post Meta Info Style
     *
     * @return void
     */
    protected function post_meta_info_style() {
        
        $this->start_controls_section(
            'meta_info_style_section',
            [
                'label' => esc_html__( 'Meta Info', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                   'meta_info'    => 'yes'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'meta_info_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-blog-item .post-meta li a',
                'condition'    => [
                    'meta_info'    => 'yes'
                 ],
            ]
        );

        $this->add_responsive_control(
            'meta_info_space_between_item',
            [
                'label'      => esc_html__( 'Space Between Item', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .post-meta li:not(:last-of-type)' => 'margin-right: {{SIZE}}{{UNIT}};',
                    '.rtl {{WRAPPER}} .el-blog-item .post-meta li:not(:last-of-type)' => 'margin-left: {{SIZE}}{{UNIT}}; margin-right: 0;',
                ],
                'condition'    => [
                    'meta_info'    => 'yes'
                 ],
            ]
        );

        $this->add_responsive_control(
            'meta_info_space_between_icon',
            [
                'label'      => esc_html__( 'Space Between Icon', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .post-meta li a i' => 'margin-right: {{SIZE}}{{UNIT}};',
                    '.rtl {{WRAPPER}} .el-blog-item .post-meta li a i' => 'margin-left: {{SIZE}}{{UNIT}}; margin-right: 0;',
                ],
                'condition'    => [
                    'meta_info'    => 'yes'
                 ],
            ]
        );
        
        $this->add_responsive_control(
            'meta_info_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .post-meta' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'meta_info'    => 'yes'
                 ],
            ]
        );

        $this->start_controls_tabs( 'meta_info_style_tabs' );
        
        $this->start_controls_tab(
            'meta_info_style_normal',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
                'condition'    => [
                    'meta_info'    => 'yes'
                 ],
            ]
        );

        $this->add_control(
            'meta_info_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-blog-item .post-meta li a' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'meta_info'    => 'yes'
                 ],
            ]
        );

        $this->add_control(
            'meta_info_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-blog-item .post-meta li a i' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'meta_info'    => 'yes'
                 ],
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'meta_info_style_hover',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
                'condition'    => [
                    'meta_info'    => 'yes'
                 ],
            ]
        );

        $this->add_control(
            'meta_info_hover_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-blog-item .post-meta li a:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .el-blog-item .post-meta li a:hover i' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'meta_info'    => 'yes'
                 ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        
        $this->end_controls_section();
    }

    /**
     * Readmore Style
     *
     * @return void
     */
    protected function readmore_style() {
        
        $this->start_controls_section(
            'readmore_style_section',
            [
                'label' => esc_html__( 'Read More', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'show_readmore'    => 'yes'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'readmore_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content .read-more',
                'condition'    => [
                    'show_readmore'    => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
            'readmore_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-content .read-more' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'show_readmore'    => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
            'readmore_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-content .read-more' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'show_readmore'    => 'yes'
                ],
            ]
        );

        $this->start_controls_tabs( 'readmore_style_tabs' );
        
        $this->start_controls_tab(
            'readmore_style_normal',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'readmore_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'   => ['image'],
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content .read-more',
            ]
        );

        $this->add_control(
            'readmore_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-blog-item .el-post-content .read-more' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'readmore_line_color',
            [
                'label'     => esc_html__( 'Line Color', 'textdomain' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-blog-item .el-post-content .read-more:before' => 'background-color: {{VALUE}}; transition: background-color 0.3s ease-in-out;',
                ],
                'condition'    => [
                    'show_readmore'    => 'yes'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'readmore_text_shadow',
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content .read-more',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'readmore_box_shadow',
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content .read-more',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'readmore_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content .read-more',
            ]
        );

        $this->add_responsive_control(
            'readmore_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-content .read-more' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'readmore_style_hover',
            [
                'label' => esc_html__( 'Hover', 'redias-core' )
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'readmore_hover_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'   => ['image'],
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content .read-more:hover',
            ]
        );

        $this->add_control(
            'readmore_hover_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-blog-item .el-post-content .read-more:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'readmore_hover_line_color',
            [
                'label'     => esc_html__( 'Line Color', 'textdomain' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-blog-item .el-post-content .read-more:hover:before' => 'background-color: {{VALUE}}; transition: background-color 0.3s ease-in-out;',
                ],
                'condition'    => [
                    'show_readmore'    => 'yes'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'readmore_hover_text_shadow',
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content .read-more:hover',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'readmore_hover_box_shadow',
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content .read-more:hover',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'readmore_hover_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-blog-item .el-post-content .read-more:hover',
            ]
        );

        $this->add_responsive_control(
            'readmore_hover_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-blog-item .el-post-content .read-more:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->end_controls_section();

    }

    /**
     * Pagination Style
     *
     * @return void
     */
    protected function pagination_style() {
        
        $this->start_controls_section(
			'section_pagination',
			[
				'label' => esc_html__( 'Pagination', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'pagination_control' => 'yes',
					'carousel!' => 'yes',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'redias-core' ),
				'name' => 'dl_pagination_typography',
				'selector' => '{{WRAPPER}} .el-post-pagination span, {{WRAPPER}} .el-post-pagination a',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->add_responsive_control(
			'pagination_align',
			[
				'label' => esc_html__( 'Alignment', 'redias-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'redias-core' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'redias-core' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'redias-core' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'toggle' => false,
				'default' => 'center',
				'selectors' => [
					'{{WRAPPER}} .el-post-pagination' => 'justify-content: {{VALUE}};',
				],
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->add_responsive_control(
			'pagination_margin',
			[
				'label'      => esc_html__( 'Margin', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-post-pagination' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->add_responsive_control(
			'pagination_space_bw',
			[
				'label' => esc_html__( 'Space Between', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 5,
				],
				'selectors' => [
					'{{WRAPPER}} .el-post-pagination span' => 'margin: 0 {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .el-post-pagination a' => 'margin: 0 {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->add_responsive_control(
			'pagination_item_size',
			[
				'label' => esc_html__( 'Size', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 40,
				],
				'selectors' => [
					'{{WRAPPER}} .el-post-pagination span' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .el-post-pagination a' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

        $this->add_responsive_control(
            'pagi_icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 150
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-post-pagination a i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .el-post-pagination a svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
            ]
        );

        $this->add_control(
            'pagi_prev_icon',
            [
                'label'   => esc_html__( 'Prev Post Icon', 'redias-core' ),
                'type'    => Controls_Manager::ICONS,
                'default' => [
                    'value'   => 'la la-long-arrow-left',
                    'library' => 'elementor-icons-line-awesome-icons',
                ],
                'recommended' => [
					'fa-solid' => [
						'angle-left',
						'arrow-left',
						'chevron-left',
						'long-arrow-alt-left',
					],
					'line-awesome-icons' => [
						'angle-double-left',
						'angle-left',
						'arrow-left',
						'chevron-left',
						'long-arrow-alt-left',
						'long-arrow-left',
					],
				],
                'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
            ]
        );

        $this->add_control(
            'pagi_next_icon',
            [
                'label'   => esc_html__( 'Next Post Icon', 'redias-core' ),
                'type'    => Controls_Manager::ICONS,
                'default' => [
                    'value'   => 'la la-long-arrow-right',
                    'library' => 'elementor-icons-line-awesome-icons',
                ],
                'recommended' => [
					'fa-solid' => [
						'angle-right',
						'arrow-right',
						'chevron-right',
						'long-arrow-alt-right',
					],
					'line-awesome-icons' => [
						'angle-double-right',
						'angle-right',
						'arrow-right',
						'chevron-right',
						'long-arrow-alt-right',
						'long-arrow-right',
					],
				],
                'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
            ]
        );

		$this->add_control(
			'pagination_hr',
			[
				'type' => Controls_Manager::DIVIDER,
				'style' => 'thick',
                'condition' => [
					'pagination_control' => 'yes'
				]
			]
		);

		$this->start_controls_tabs( 'tabs_pagination_style' );

		$this->start_controls_tab(
			'tab_pagination_style_normal',
			[
				'label' => esc_html__( 'Normal', 'redias-core' ),
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->add_control(
			'pagination_bg_color_label',
			[
				'label' => __( 'Background Color', 'redias-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'pagination_bg_color',
				'label' => __( 'Background', 'redias-core' ),
				'types' => [ 'classic', 'gradient' ],
                'exclude' => ['image'],
				'selector' => '{{WRAPPER}} .el-post-pagination a',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->add_control(
			'pagination_color',
			[
				'label' => esc_html__( 'Text Color', 'redias-core' ),
				'type' => Controls_Manager::COLOR,
                'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .el-post-pagination a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .el-post-pagination a svg' => 'fill: {{VALUE}};',
				],
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->add_responsive_control(
			'pagination_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-post-pagination a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .el-post-pagination span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_pagination_style_hover',
			[
				'label' => esc_html__( 'Active / Hover', 'redias-core' ),
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->add_control(
			'pagination_bg_color_hover_label',
			[
				'label' => __( 'Background Color', 'redias-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'pagination_bg_color_hover',
				'label' => __( 'Background', 'redias-core' ),
				'types' => [ 'classic', 'gradient' ],
                'exclude' => ['image'],
				'selector' => '{{WRAPPER}} .el-post-pagination a:hover, {{WRAPPER}} .el-post-pagination span.current',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->add_control(
			'pagination_color_hover',
			[
				'label' => esc_html__( 'Text Color', 'redias-core' ),
				'type' => Controls_Manager::COLOR,
                'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .el-post-pagination a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .el-post-pagination a:hover svg' => 'fill: {{VALUE}};',
					'{{WRAPPER}} .el-post-pagination span.current' => 'color: {{VALUE}};'
				],
				'default' => '#fff',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'pagination_active_box_shadow',
				'label' => __( 'Box Shadow', 'redias-core' ),
				'selector' => '{{WRAPPER}} .el-post-pagination a:hover, {{WRAPPER}} .el-post-pagination span.current',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel!' => 'yes',
				]
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        
        if( 'yes' === $settings['carousel'] ) {
            $this->carousel_layout();
        }else{
            $this->grid_layout();
        }

    }

    /**
     * Carousel Layout
     *
     * @return void
     */
    protected function carousel_layout() {
        $settings = $this->get_settings_for_display();
        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
		$args = array(
            'post_type'   => 'post',
            'post__not_in' => get_option( 'sticky_posts' ),
            'posts_per_page' => $settings['posts_limit'],
            'orderby'	=> $settings['orderby'],
            'order'	=> $settings['order'],
            'post_status' => 'publish',
            'paged' => $paged,
		);

		if ( $settings['source'] === 'by_name'  ) :

			$args['tax_query'][] = array(
				'taxonomy' => 'category',
				'field'    => 'slug',
				'terms'    => $settings['post_categories'],
			);

		endif;
        $wp_query = new \WP_Query( $args );
        $nav_mobile = 'yes' === $settings['dots_hide_mobile'] ? ' dots-none' : '';

		if( 'arrow' === $settings['navigation'] || 'both' === $settings['navigation'] ){
			$nav_style = 'top-right' == $settings['nav_style'] ? ' navi-top-right' : '';
		}else{
			$nav_style = '';
		}
        $this->add_render_attribute(
            'carousel_wrapper',
            [ 
                'class' => [ 'dl-carousel' ]
            ]
        );
        $this->add_render_attribute( 'scrolling-animation', [ 
            'class' => get_post_class('el-blog-item')
        ] );
        ?>
        <div class="el-blog-wrapper<?php echo esc_attr( $nav_style ); ?>">
            <?php if( $wp_query->have_posts() ) : ?>
                <div <?php echo $this->get_render_attribute_string( 'carousel_wrapper' ); ?>>
                    <?php while ( $wp_query->have_posts() ) : $wp_query->the_post(); ?>
                        <div class="slick-slide">
                            <?php $this->post_card($wp_query->ID); ?>
                        </div>
                    <?php endwhile; ?>
                </div>
                <?php if( 'dots' === $settings['navigation'] || 'both' === $settings['navigation'] ) : ?>
                <div class="dl-carousel-dots<?php echo esc_attr( $nav_mobile ); ?>"></div>
                <?php endif; ?>
                <?php if( 'arrow' === $settings['navigation'] || 'both' === $settings['navigation'] ) : ?>
                <div class="dl-carousel-nav <?php echo esc_attr( 'nav-' . $settings['nav_style'] ); ?>"></div>
                <?php if ( ! empty( $settings['arrow_prev_icon']['value'] ) ) : ?>
                    <button type="button" class="slick-prev nav-hidden"><?php Icons_Manager::render_icon( $settings['arrow_prev_icon'], ['aria-hidden' => 'true'] ); ?></button>
                <?php endif; ?>
                <?php if ( ! empty( $settings['arrow_next_icon']['value'] ) ) : ?>
                    <button type="button" class="slick-next nav-hidden"><?php Icons_Manager::render_icon( $settings['arrow_next_icon'], ['aria-hidden' => 'true'] ); ?></button>
                <?php endif; ?>
                <?php endif; ?>
            <?php
            wp_reset_postdata();

            else :
                esc_html_e( 'No posts found!', 'redias-core' );
            endif;
            ?>
        </div>
        <?php
    }

    /**
     * Grid Layout
     *
     * @return void
     */
    protected function grid_layout() {
        $settings = $this->get_settings_for_display();
        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

		$args = array(
            'post_type'   => 'post',
            'post__not_in' => get_option( 'sticky_posts' ),
            'posts_per_page' => $settings['posts_limit'],
            'orderby'	=> $settings['orderby'],
            'order'	=> $settings['order'],
            'post_status' => 'publish',
            'paged' => $paged,
		);

		if ( $settings['source'] === 'by_name'  ) :

			$args['tax_query'][] = array(
				'taxonomy' => 'category',
				'field'    => 'slug',
				'terms'    => $settings['post_categories'],
			);

		endif;
        $wp_query = new \WP_Query( $args );
        $this->add_render_attribute(
            'wrapper',
            [ 
                'class' => [ 'el-blog-items', 'redias-el-blog' ]
            ]
        );
        if( 'yes' === $settings['scroll_anim'] ) {
            $anim_cls = ['wow', 'dl-animation', esc_attr( $settings['anim_effect'] )];
            $this->add_render_attribute( 'scrolling-animation', [ 
                'class' => array_merge(get_post_class('el-blog-item'), $anim_cls),
                'data-wow-offset' => esc_attr( $settings['anim_offset']['size'] ),
                'data-wow-duration' => esc_attr( $settings['anim_duration']['size'] ) . 'ms',
            ] );
        }else{
            $this->add_render_attribute( 'scrolling-animation', [ 
                'class' => get_post_class('el-blog-item')
            ] );
        }
        if( $wp_query->have_posts() ) : ?>
            <div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
            <?php 
            while ( $wp_query->have_posts() ) : $wp_query->the_post();
                $post_index = $wp_query->current_post;
                $this->post_card($wp_query->ID, $post_index);
            endwhile; ?>
            </div>
        <?php
        $this->post_pagination($wp_query->max_num_pages);
        wp_reset_postdata();

        else :
            esc_html_e( 'No posts found!', 'redias-core' );
        endif;
    }

    /**
     * Post Card
     *
     * @param string $post_id
     * @return void
     */
    protected function post_card( $post_id = '', $index = 0){
        $settings = $this->get_settings_for_display();
        $img_placeholder = Utils::get_placeholder_image_src();
        $heading_tag = ! empty( $settings['heading_tag'] ) ? $settings['heading_tag'] : 'h3';

        if( 'yes' === $settings['scroll_anim'] && 'yes' != $settings['carousel'] ) {
            $delay = $settings['anim_delay']['size'] + ( $settings['anim_delay_interval']['size'] * $index );
            $delay_attr = ' data-wow-delay="'. $delay .'ms"';
        }else{
            $delay_attr = '';
        }
        ?>
        <article <?php echo $this->get_render_attribute_string( 'scrolling-animation' ) . $delay_attr; ?>>
            <div class="el-post-item">
                <div class="el-post-thumb">
                    <a href="<?php the_permalink(); ?>" class="el-post-thumb-inner">
                    <?php if( has_post_thumbnail() ) : ?>
                        <?php echo get_the_post_thumbnail( $post_id, $settings['img_size'] ); ?>
                    <?php else: ?>
                        <img src="<?php echo esc_url( $img_placeholder ); ?>" alt="<?php the_title(); ?>">
                    <?php endif; ?>
                    </a>
                    <?php 
                    if( 'yes' === $settings['category'] ) {
                        Helper::get_terms( 'category', 1, true, 'category ' . $settings['cat_position'], false );
                    } ?>
                </div>
                <div class="el-post-content">
                    <?php if( 'yes' === $settings['meta_info'] ) : ?>
                    <ul class="post-meta">
                        <li><a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta('ID') ) ); ?>"><i class="las la-user"></i><?php echo get_the_author_meta('nickname'); ?></a></li>
                        <li><a href="<?php echo esc_url( Helper::get_post_date_link() ); ?>"><i class="las la-calendar"></i><?php echo get_the_date(); ?></a></li>
                    </ul>
                    <?php endif; ?>
                    <<?php echo esc_attr( $heading_tag ); ?> class="post-title">
                        <a href="<?php the_permalink(); ?>"><?php Helper::limit_latter( get_the_title(), $settings['title_length'], $settings['title_suffix'] ); ?></a>
                    </<?php echo esc_attr( $heading_tag ); ?>>
                    <?php
                    $excerpt = get_the_excerpt();
                    if( ! empty( $excerpt ) && 'yes' === $settings['show_excerpt'] ) : ?>
                        <p><?php Helper::limit_latter( $excerpt, $settings['excerpt_length'], $settings['excerpt_suffix'] ); ?></p>
                    <?php endif; ?>
                    <?php if( 'yes' === $settings['show_readmore'] && ! empty( $settings['readmore_text'] ) ) : ?>
                        <a href="<?php the_permalink(); ?>" class="read-more"><?php echo esc_html( $settings['readmore_text'] ); ?></a>
                    <?php endif; ?>
                </div>
            </div>
        </article>
        <?php
    }

    /**
     * Pagination
     */
    protected function post_pagination( $total_pages = '' ){
        $settings = $this->get_settings_for_display();
        if( 'yes' === $settings['pagination_control'] ){
            $prev_pagi_icon = '<i class="la la-long-arrow-left"></i>';
            $next_pagi_icon = '<i class="la la-long-arrow-right"></i>';
            if( ! empty( $settings['pagi_prev_icon']['value'] ) ) {
                if( 'svg' != $settings['pagi_prev_icon']['library'] ) {
                    $prev_pagi_icon = '<i class="'. $settings['pagi_prev_icon']['value'] .'"></i>';
                }else{
                    $prev_pagi_icon = Icons_Manager::render_uploaded_svg_icon( $settings['pagi_prev_icon']['value'] );
                }
            }
            if( ! empty( $settings['pagi_next_icon']['value'] ) ) {
                if( 'svg' != $settings['pagi_next_icon']['library'] ) {
                    $next_pagi_icon = '<i class="'. $settings['pagi_next_icon']['value'] .'"></i>';
                }else{
                    $next_pagi_icon = Icons_Manager::render_uploaded_svg_icon( $settings['pagi_next_icon']['value'] );
                }
            }

			if ( $total_pages > 1 ) {
				$current_page = max( 1, get_query_var( 'paged' ) );
				echo '<div class="el-post-pagination">';
				echo paginate_links( array(
					'base' => get_pagenum_link(1) . '%_%',
					'format' => '/page/%#%',
					'current' => $current_page,
					'total' => $total_pages,
					'prev_text'    => Helper::kses_advance( $prev_pagi_icon ),
					'next_text'    => Helper::kses_advance( $next_pagi_icon ),
				) );
				echo '</div>';
			}
		}
    }

}