<?php
/**
 * Button
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Button;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-button';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Button', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-button';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'button', 'btn', 'redias' ];
    }

    public function get_style_depends() {
        return [ 'redias-button' ];
    }

    public function get_script_depends() {
        return [ 'redias-el-script' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_general();
        $this->section_button();
        $this->section_secondary_button();
        $this->button_style();
        $this->button_secondary_style();

    }

    /**
     * General Control
     *
     * @return void
     */

    protected function section_general() {

        $this->start_controls_section(
			'section_general',
			[
				'label' => esc_html__( 'General', 'redias-core' )
			]
        );

        $this->add_responsive_control(
            'btn_display',
            [
                'label'   => esc_html__( 'Display', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'inline'   => [
                        'title' => esc_html__( 'Inline', 'redias-core' ),
                        'icon'  => 'eicon-ellipsis-h',
                    ],
                    'block' => [
                        'title' => esc_html__( 'Block', 'redias-core' ),
                        'icon'  => 'eicon-ellipsis-v',
                    ],
                ],
                'prefix_class' => 'dl-display-',
                'selectors_dictionary' => [
                    'inline' => 'flex-direction: row',
                    'block' => 'flex-direction: column',
                ],
                'default' => 'inline',
                'selectors' => [
                    '{{WRAPPER}} .dl-el-btn-wrap' => '{{VALUE}}',
                ],
                'toggle'  => false,
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => '',
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'alignment',
            [
                'label'   => esc_html__( 'Alignment', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'prefix_class' => 'dl-align-',
                'default' => 'left',
                'selectors_dictionary' => [
                    'left' => 'justify-content: flex-start',
                    'center' => 'justify-content: center',
                    'right' => 'justify-content: flex-end',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-el-btn-wrap' => '{{VALUE}}',
                    '{{WRAPPER}}.dl-display-block.dl-align-left .dl-el-btn-wrap a' => 'margin-right: auto;',
                    '{{WRAPPER}}.dl-display-block.dl-align-right .dl-el-btn-wrap a' => 'margin-left: auto;',
                ],
                'toggle'  => false,
            ]
        );

        $this->add_responsive_control(
            'spacebetween_btn',
            [
                'label'      => esc_html__( 'Space Between', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200
                    ]
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 15,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-btn-wrap' => 'gap: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => '',
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Button Control
     *
     * @return void
     */

    protected function section_button() {

        $this->start_controls_section(
			'section_button',
			[
				'label' => esc_html__( 'Button', 'redias-core' )
			]
        );

        $this->add_control(
            'btn_text',
            [
                'label'       => esc_html__( 'Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Get Started', 'redias-core' ),
                'placeholder' => esc_html__( 'Text goes here.', 'redias-core' ),
                'dynamic' => [
					'active' => true,
				]
            ]
        );

        $this->add_control(
            'btn_link',
            [
                'label'         => esc_html__( 'Link', 'redias-core' ),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '#',
                    'is_external' => false,
                    'nofollow'    => true
                ],
                'condition'    => [
                    'btn_text!'    => ''
                ],
            ]
        );

        $this->add_control(
            'btn_icon',
            [
                'label'   => esc_html__( 'Icon', 'redias-core' ),
                'type'    => Controls_Manager::ICONS,
                'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'label_block' => false,
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'icon_position',
            [
                'label'   => esc_html__( 'Icon Position', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default' => 'left',
                'toggle'  => false,
                'selectors_dictionary' => [
                    'left' => 'flex-direction: row-reverse',
                    'right' => 'flex-direction: inherit'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-el-btn-wrap .btn-1.has-icon' => '{{VALUE}}'
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => '',
                    'btn_icon[value]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_indent',
            [
                'label'      => esc_html__( 'Icon Spacing', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
					'px' => [
						'max' => 50,
					],
				],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-btn-wrap .btn-1.has-icon' => 'column-gap: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => '',
                    'btn_icon[value]!' => ''
                ],
            ]
        );

        $this->add_control(
			'button_css_id',
			[
				'label' => esc_html__( 'Button ID', 'elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => '',
				'title' => esc_html__( 'Add your custom id WITHOUT the Pound key. e.g: my-id', 'redias-core' ),
				'description' => esc_html__( 'Please make sure the ID is unique and not used elsewhere on the page this form is displayed. This field allows <code>A-z 0-9</code> & underscore chars without spaces.', 'redias-core' ),
				'separator' => 'before',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
			]
		);
        
        $this->end_controls_section();

    }

    /**
     * Secondary Button Control
     *
     * @return void
     */

    protected function section_secondary_button() {

        $this->start_controls_section(
			'section_secondary_button',
			[
				'label' => esc_html__( 'Secondary Button', 'redias-core' )
			]
        );

        $this->add_control(
            'btn_2nd_text',
            [
                'label'       => esc_html__( 'Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '',
                'placeholder' => esc_html__( 'Text goes here.', 'redias-core' ),
                'dynamic' => [
					'active' => true,
				]
            ]
        );

        $this->add_control(
            'btn_2nd_link',
            [
                'label'         => esc_html__( 'Link', 'redias-core' ),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
                'show_external' => true,
                'condition'    => [
                    'btn_2nd_text!'    => ''
                ],
            ]
        );

        $this->add_control(
            'btn_2nd_icon',
            [
                'label'   => esc_html__( 'Icon', 'redias-core' ),
                'type'    => Controls_Manager::ICONS,
                'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'label_block' => false,
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'icon_2nd_position',
            [
                'label'   => esc_html__( 'Icon Position', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default' => 'left',
                'toggle'  => false,
                'selectors_dictionary' => [
                    'left' => 'flex-direction: row-reverse',
                    'right' => 'flex-direction: inherit'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-el-btn-wrap .btn-2.has-icon' => '{{VALUE}}'
                ],
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => '',
                    'btn_2nd_icon[value]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_2nd_indent',
            [
                'label'      => esc_html__( 'Icon Spacing', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
					'px' => [
						'max' => 50,
					],
				],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-btn-wrap .btn-2.has-icon' => 'column-gap: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => '',
                    'btn_2nd_icon[value]!' => ''
                ],
            ]
        );

        $this->add_control(
			'button_2nd_css_id',
			[
				'label' => esc_html__( 'Button ID', 'elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => '',
				'title' => esc_html__( 'Add your custom id WITHOUT the Pound key. e.g: my-id', 'redias-core' ),
				'description' => esc_html__( 'Please make sure the ID is unique and not used elsewhere on the page this form is displayed. This field allows <code>A-z 0-9</code> & underscore chars without spaces.', 'redias-core' ),
				'separator' => 'before',
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
			]
		);
        
        $this->end_controls_section();

    }

    /**
     * Button Style
     *
     * @return void
     */
    protected function button_style() {

        $this->start_controls_section(
            'button_style_section',
            [
                'label' => esc_html__( 'Button', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-el-btn.btn-1',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'text_shadow',
                'selector' => '{{WRAPPER}} .dl-el-btn.btn-1',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->start_controls_tabs( 'btn_normal_style_tabs' );
        
        $this->start_controls_tab(
            'btn_style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'btn_bg_normal',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => [ 'image' ],
                'selector' => '{{WRAPPER}} .btn-1.style-1, {{WRAPPER}} .btn-1.style-2 .blob-dl-btn__inner, {{WRAPPER}} .dl-el-btn.style-3, {{WRAPPER}} .btn-1.style-4',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-el-btn.btn-1' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'btn_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .btn-1.style-1, {{WRAPPER}} .btn-1.style-2 .blob-dl-btn__inner',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .btn-1.style-1' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .btn-1.style-2 .blob-dl-btn__inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'btn_box_shadow',
                'selector' => '{{WRAPPER}} .dl-el-btn.btn-1',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-btn.btn-1' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-btn-wrap .btn-1' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'btn_style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_hover_effect',
            [
                'label'   => esc_html__( 'Hover Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'style-4',
                'options' => [
                    'style-1'  => esc_html__( 'Style 1', 'redias-core' ),
                    'style-2' => esc_html__( 'Style 2', 'redias-core' ),
                    'style-3' => esc_html__( 'Style 3', 'redias-core' ),
                    'style-4' => esc_html__( 'Style 4', 'redias-core' ),
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'btn_bg_hover',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => [ 'image' ],
                'selector' => '{{WRAPPER}} .btn-1.style-1:before, {{WRAPPER}} .btn-1.style-1:after, {{WRAPPER}} .style-2 .blob-dl-btn__blob, {{WRAPPER}} .dl-el-btn.btn-1.style-3 span.btn-ov, {{WRAPPER}} .btn-1.style-4:before',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_text_color_hover',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-el-btn.btn-1:focus, {{WRAPPER}} .dl-el-btn.btn-1:hover' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_pattern',
            [
                'label'        => esc_html__( 'Pattern', 'textdomain' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'textdomain' ),
                'label_off'    => esc_html__( 'Hide', 'textdomain' ),
                'return_value' => 'yes',
                'default'      => 'yes',
                'condition'    => [
                    'btn_hover_effect' => 'style-3',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'btn_hover_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .btn-1.style-1:hover, {{WRAPPER}} .btn-1.style-2:hover .blob-dl-btn__inner',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'box_shadow_hover',
                'selector' => '{{WRAPPER}} .dl-el-btn.btn-1:hover',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_hover_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .btn-1.style-1:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .btn-1.style-2:hover .blob-dl-btn__inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->end_controls_section();

    }

    /**
     * Secondary Button Style
     *
     * @return void
     */
    protected function button_secondary_style() {

        $this->start_controls_section(
            'button_2nd_style_section',
            [
                'label' => esc_html__( 'Secondary Button', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'btn_2nd_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-el-btn.btn-2',
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'text_2nd_shadow',
                'selector' => '{{WRAPPER}} .dl-el-btn.btn-2',
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->start_controls_tabs( 'btn_2nd_normal_style_tabs' );
        
        $this->start_controls_tab(
            'btn_2nd_style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'btn_2nd_bg_normal',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => [ 'image' ],
                'selector' => '{{WRAPPER}} .btn-2.style-1, {{WRAPPER}} .btn-2.style-2 .blob-dl-btn__inner, {{WRAPPER}} .btn-2.style-4',
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_2nd_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-el-btn.btn-2' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'btn_2nd_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .btn-2.style-1, {{WRAPPER}} .btn-2.style-2 .blob-dl-btn__inner',
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_2nd_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .btn-2.style-1' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .btn-2.style-2 .blob-dl-btn__inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'btn_2nd_box_shadow',
                'selector' => '{{WRAPPER}} .dl-el-btn.btn-2',
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_2nd_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-btn.btn-2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_2nd_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-btn-wrap .btn-2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'btn_2nd_style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_2nd_hover_effect',
            [
                'label'   => esc_html__( 'Hover Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'style-4',
                'options' => [
                    'style-1'  => esc_html__( 'Style 1', 'redias-core' ),
                    'style-2' => esc_html__( 'Style 2', 'redias-core' ),
                    'style-3' => esc_html__( 'Style 3', 'redias-core' ),
                    'style-4' => esc_html__( 'Style 4', 'redias-core' ),
                ],
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'btn_2nd_bg_hover',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => [ 'image' ],
                'selector' => '{{WRAPPER}} .btn-2.style-1:before, {{WRAPPER}} .btn-2.style-1:after, {{WRAPPER}} .style-2 .blob-dl-btn__blob, {{WRAPPER}} .dl-el-btn.btn-2.style-3 span.btn-ov, {{WRAPPER}} .btn-2.style-4:before',
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_2nd_text_color_hover',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-el-btn.btn-2:focus, {{WRAPPER}} .dl-el-btn.btn-2:hover' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'btn_2nd_hover_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .btn-2.style-1:hover, {{WRAPPER}} .btn-2.style-2:hover .blob-dl-btn__inner',
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'btn_2nd_box_shadow_hover',
                'selector' => '{{WRAPPER}} .dl-el-btn.btn-2:hover',
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_2nd_hover_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .style-1:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .style-2:hover .blob-dl-btn__inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_2nd_text!'    => '',
                    'btn_2nd_link[url]!' => ''
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        $pattern = 'yes' === $settings['btn_pattern'] ? 'pattern-yes' : '';
        $this->add_render_attribute( 'wrapper', [ 'class' => [ 'dl-el-btn-wrap', $pattern ], 'data-btn-1-style' => $settings['btn_hover_effect'], 'data-btn-2-style' => $settings['btn_2nd_hover_effect'] ] );
        $has_cion = isset( $settings['btn_icon']['value'] ) && ! empty( $settings['btn_icon']['value'] ) ? ' has-icon' : '';
        if ( ! empty( $settings['btn_link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['btn_link'] );
		}
        $this->add_render_attribute( 'button', [ 'class' => [ 'dl-el-btn btn-1', $has_cion, $settings['btn_hover_effect'] ], 'id' => $settings['button_css_id'] ] );
        $this->add_inline_editing_attributes( 'btn_text', 'none' );
        // Secondary Button
        $has_2nd_cion = isset( $settings['btn_2nd_icon']['value'] ) && ! empty( $settings['btn_2nd_icon']['value'] ) ? ' has-icon' : '';
        if ( ! empty( $settings['btn_2nd_link']['url'] ) ) {
			$this->add_link_attributes( 'button_2nd', $settings['btn_2nd_link'] );
		}
        $this->add_render_attribute( 'button_2nd', [ 'class' => [ 'dl-el-btn btn-2', $has_2nd_cion, $settings['btn_2nd_hover_effect'] ], 'id' => $settings['button_2nd_css_id'] ] );
        $this->add_inline_editing_attributes( 'btn_2nd_text', 'none' ); ?>

        <div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
        <?php if( \Elementor\Plugin::$instance->editor->is_edit_mode() ) : ?>
            <a <?php $this->print_render_attribute_string( 'button' ); ?>>
                <span <?php $this->print_render_attribute_string( 'btn_text' ); ?>><?php echo esc_html($settings['btn_text']); ?></span>
                <?php Icons_Manager::render_icon( $settings['btn_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                <?php if( 'style-2' === $settings['btn_hover_effect'] ) : ?>
                <span class="blob-dl-btn__inner">
                    <span class="blob-dl-btn__blobs">
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                    </span>
                </span>
                <?php endif; ?>
            </a>
        <?php else : ?>
        <?php if( ! empty( $settings['btn_text'] && $settings['btn_link']['url'] ) ) : ?>
            <a <?php $this->print_render_attribute_string( 'button' ); ?>>
                <span <?php $this->print_render_attribute_string( 'btn_text' ); ?>><?php echo esc_html($settings['btn_text']); ?></span>
                <?php Icons_Manager::render_icon( $settings['btn_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                <?php if( 'style-2' === $settings['btn_hover_effect'] ) : ?>
                <span class="blob-dl-btn__inner">
                    <span class="blob-dl-btn__blobs">
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                    </span>
                </span>
                <?php endif; ?>
            </a>
        <?php
            endif;
        endif;
        if( ! empty( $settings['btn_2nd_text'] && $settings['btn_2nd_link']['url'] )) : ?>
            <a <?php $this->print_render_attribute_string( 'button_2nd' ); ?>>
                <span <?php $this->print_render_attribute_string( 'btn_2nd_text' ); ?>><?php echo esc_html($settings['btn_2nd_text']); ?></span>
                <?php Icons_Manager::render_icon( $settings['btn_2nd_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                <?php if( 'style-2' === $settings['btn_2nd_hover_effect'] ) : ?>
                <span class="blob-dl-btn__inner">
                    <span class="blob-dl-btn__blobs">
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                    </span>
                </span>
                <?php endif; ?>
            </a>
        <?php endif; ?>
        </div>
        <?php
    }

    /**
     * Render Content Template
     *
     * @return void
     */
    protected function content_template() {
        ?>
        <#
        if( 'yes' == settings.btn_pattern ) {
            var pattern = 'pattern-yes';
        }else{
            var pattern = '';
        }
        var has_icon = settings.btn_icon.value != '' ? 'has-icon' : '';
        view.addRenderAttribute( 'wrapper', 'class', [ 'dl-el-btn-wrap', pattern ] );
        view.addRenderAttribute( 'wrapper', 'data-btn-1-style', settings.btn_hover_effect );
        view.addRenderAttribute( 'wrapper', 'data-btn-2-style', settings.btn_2nd_hover_effect );
        view.addRenderAttribute( 'button', 'class', [ 'dl-el-btn', 'btn-1', has_icon, settings.btn_hover_effect ] );
        view.addRenderAttribute( 'button', 'id', settings.button_css_id );
        view.addInlineEditingAttributes( 'btn_text', 'none' );
        var iconHTML = elementor.helpers.renderIcon( view, settings.btn_icon, { 'aria-hidden': true }, 'i' , 'object' );
        var icon_2ndHTML = elementor.helpers.renderIcon( view, settings.btn_2nd_icon, { 'aria-hidden': true }, 'i' , 'object' );
        
        var has_icon_2nd = settings.btn_2nd_icon.value != '' ? 'has-icon' : '';
        view.addRenderAttribute( 'button_2nd', 'class', [ 'dl-el-btn', 'btn-2', has_icon_2nd, settings.btn_2nd_hover_effect ] );
        view.addRenderAttribute( 'button_2nd', 'id', settings.button_2nd_css_id );
        view.addInlineEditingAttributes( 'btn_2nd_text', 'none' );
        #>
        <div {{{ view.getRenderAttributeString( 'wrapper' ) }}}>
            <a href="{{ settings.btn_link.url }}" {{{ view.getRenderAttributeString( 'button' ) }}} role="button">
                <span {{{ view.getRenderAttributeString( 'btn_text' ) }}}>{{{ settings.btn_text }}}</span>
                <# if( settings.btn_icon.value != '' ) { #>
                    {{{ iconHTML.value }}}
                <# } #>
                <# if( 'style-2' === settings.btn_hover_effect ) { #>
                <span class="blob-dl-btn__inner">
                    <span class="blob-dl-btn__blobs">
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                    </span>
                </span>
                <# } #>
            </a>
            <# if( '' != settings.btn_2nd_text && '' != settings.btn_2nd_link.url ) { #>
            <a href="{{ settings.btn_2nd_link.url }}" {{{ view.getRenderAttributeString( 'button_2nd' ) }}} role="button">
                <span {{{ view.getRenderAttributeString( 'btn_2nd_text' ) }}}>{{{ settings.btn_2nd_text }}}</span>
                <# if( settings.btn_2nd_icon.value != '' ) { #>
                    {{{ icon_2ndHTML.value }}}
                <# } #>
                <# if( 'style-2' === settings.btn_2nd_hover_effect ) { #>
                <span class="blob-dl-btn__inner">
                    <span class="blob-dl-btn__blobs">
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                    </span>
                </span>
                <# } #>
            </a>
            <# } #>
        </div>
        <?php
    }
}