<?php
/**
 * Countdown
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Countdown;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Widget_Base;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-countdown';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Countdown', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-countdown';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'countdown', 'timer', 'coming soon', 'redias' ];
    }

    public function get_script_depends() {
        return [ 'redias-countdown', 'redias-el-script' ];
    }

    public function get_style_depends() {
        return ['redias-countdown'];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_time();
        $this->section_countdown_settings();
        $this->section_end_action();
        $this->common_style();
        $this->days_style();
        $this->hours_style();
        $this->minutes_style();
        $this->seconds_style();

    }

	/**
	 * Section Time
	 *
	 * @return void
	 */
    protected function section_time() {

        $this->start_controls_section(
            '_section_time',
            [
                'label' => esc_html__( 'Set Time', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'due_date',
            [
                'label'       => esc_html__( 'Time', 'redias-core' ),
                'type'        => Controls_Manager::DATE_TIME,
                'default'     => date( "Y-m-d", strtotime( "+ 1 day" ) ),
                'description' => esc_html__( 'Set the due date and time', 'redias-core' ),
            ]
        );

        $this->end_controls_section();

    }

	/**
	 * Section Coundown Settings
	 *
	 * @return void
	 */
    protected function section_countdown_settings() {

        $this->start_controls_section(
            '_section_countdown_settings',
            [
                'label' => esc_html__( 'Settings', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'label_position',
            [
                'label'          => esc_html__( 'Label Position', 'redias-core' ),
                'type'           => Controls_Manager::CHOOSE,
                'label_block'    => false,
                'options'        => [
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                    'bottom' => [
                        'title' => esc_html__( 'Bottom', 'redias-core' ),
                        'icon'  => 'eicon-v-align-bottom',
                    ],
                ],
                'toggle'         => false,
                'default'        => 'bottom',
                'prefix_class'   => 'dl-countdown-label-',
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'label_space',
            [
                'label'          => esc_html__( 'Label Space', 'redias-core' ),
                'type'           => Controls_Manager::POPOVER_TOGGLE,
                'condition'      => [
                    'label_position' => 'right',
                ],
                'style_transfer' => true,
            ]
        );

        $this->start_popover();

        $this->add_control(
            'label_space_top',
            [
                'label'          => esc_html__( 'Label Space Top', 'redias-core' ),
                'type'           => Controls_Manager::SLIDER,
                'size_units'     => ['px'],
                'range'          => [
                    'px' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'selectors'      => [
                    '{{WRAPPER}}.dl-countdown-label-right .dl-countdown-item .dl-countdown-label' => 'top: {{SIZE || 0}}{{UNIT}};',
                ],
                'condition'      => [
                    'label_position' => 'right',
                ],
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'label_space_left',
            [
                'label'          => esc_html__( 'Label Space Left', 'redias-core' ),
                'type'           => Controls_Manager::SLIDER,
                'size_units'     => ['px'],
                'range'          => [
                    'px' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'selectors'      => [
                    '{{WRAPPER}}.dl-countdown-label-right .dl-countdown-item .dl-countdown-label' => 'left: {{SIZE || 0}}{{UNIT}};',
                ],
                'condition'      => [
                    'label_position' => 'right',
                ],
                'style_transfer' => true,
            ]
        );

        $this->end_popover(); //End Prover

        $this->add_control(
            'show_label_days',
            [
                'label'          => esc_html__( 'Show Label Days?', 'redias-core' ),
                'type'           => Controls_Manager::SWITCHER,
                'return_value'   => 'yes',
                'default'        => 'yes',
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'label_days',
            [
                'label'       => esc_html__( 'Label Days', 'redias-core' ),
                'description' => esc_html__( 'Set the label for days.', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Days', 'redias-core' ),
                'default'     => 'Days',
                'condition'   => [
                    'show_label_days' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'show_label_hours',
            [
                'label'          => esc_html__( 'Show Label Hours?', 'redias-core' ),
                'type'           => Controls_Manager::SWITCHER,
                'return_value'   => 'yes',
                'default'        => 'yes',
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'label_hours',
            [
                'label'       => esc_html__( 'Label Hours', 'redias-core' ),
                'description' => esc_html__( 'Set the label for hours.', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Hours', 'redias-core' ),
                'default'     => 'Hours',
                'condition'   => [
                    'show_label_hours' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'show_label_minutes',
            [
                'label'          => esc_html__( 'Show Label Minutes?', 'redias-core' ),
                'type'           => Controls_Manager::SWITCHER,
                'return_value'   => 'yes',
                'default'        => 'yes',
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'label_minutes',
            [
                'label'       => esc_html__( 'Label Minutes', 'redias-core' ),
                'description' => esc_html__( 'Set the label for minutes.', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Minutes', 'redias-core' ),
                'default'     => 'Minutes',
                'condition'   => [
                    'show_label_minutes' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'show_label_seconds',
            [
                'label'          => esc_html__( 'Show Label Seconds?', 'redias-core' ),
                'type'           => Controls_Manager::SWITCHER,
                'return_value'   => 'yes',
                'default'        => 'yes',
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'label_seconds',
            [
                'label'       => esc_html__( 'Label Seconds', 'redias-core' ),
                'description' => esc_html__( 'Set the label for seconds.', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Seconds', 'redias-core' ),
                'default'     => 'Seconds',
                'condition'   => [
                    'show_label_seconds' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'     => esc_html__( 'Alignment', 'redias-core' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'toggle'    => false,
                'selectors' => [
                    '{{WRAPPER}} .elementor-widget-container' => 'text-align: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'show_separator',
            [
                'label'          => esc_html__( 'Show Separator?', 'redias-core' ),
                'type'           => Controls_Manager::SWITCHER,
                'return_value'   => 'on',
                'default'        => '',
                'separator'      => 'before',
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'separator',
            [
                'label'     => esc_html__( 'Separator', 'redias-core' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => ':',
                'condition' => [
                    'show_separator' => 'on',
                ],
            ]
        );

        $this->add_control(
            'separator_color',
            [
                'label'          => esc_html__( 'Separator Color', 'redias-core' ),
                'type'           => Controls_Manager::COLOR,
                'selectors'      => [
                    '{{WRAPPER}} .dl-countdown-item.dl-countdown-separator-on .dl-countdown-separator' => 'color: {{VALUE}}',
                ],
                'condition'      => [
                    'show_separator' => 'on',
                ],
                'style_transfer' => true,
            ]
        );

        $this->add_responsive_control(
            'separator_font',
            [
                'label'          => esc_html__( 'Separator Font Size', 'redias-core' ),
                'type'           => Controls_Manager::SLIDER,
                'size_units'     => ['px'],
                'selectors'      => [
                    '{{WRAPPER}} .dl-countdown-item.dl-countdown-separator-on .dl-countdown-separator' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition'      => [
                    'show_separator' => 'on',
                ],
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'separator_position',
            [
                'label'          => esc_html__( 'Separator Position', 'redias-core' ),
                'type'           => Controls_Manager::POPOVER_TOGGLE,
                'condition'      => [
                    'show_separator' => 'on',
                ],
                'style_transfer' => true,
            ]
        );

        $this->start_popover();

        $this->add_control(
            'separator_position_top',
            [
                'label'          => esc_html__( 'Position Top', 'redias-core' ),
                'type'           => Controls_Manager::SLIDER,
                'size_units'     => ['px'],
                'range'          => [
                    'px' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'selectors'      => [
                    '{{WRAPPER}} .dl-countdown-item.dl-countdown-separator-on .dl-countdown-separator' => 'top: {{SIZE}}{{UNIT}};',
                ],
                'condition'      => [
                    'show_separator' => 'on',
                ],
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'separator_position_right',
            [
                'label'          => esc_html__( 'Position Right', 'redias-core' ),
                'type'           => Controls_Manager::SLIDER,
                'size_units'     => ['px'],
                'range'          => [
                    'px' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'selectors'      => [
                    '{{WRAPPER}} .dl-countdown-item.dl-countdown-separator-on .dl-countdown-separator' => 'right: {{SIZE || -16}}{{UNIT}};',
                ],
                'condition'      => [
                    'show_separator' => 'on',
                ],
                'style_transfer' => true,
            ]
        );

        $this->end_popover();

        $this->end_controls_section();
    }

	/**
	 * Section End Action
	 *
	 * @return void
	 */
    protected function section_end_action() {

        $this->start_controls_section(
            '_section_end_action',
            [
                'label' => esc_html__( 'Countdown End Action', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'end_action_type',
            [
                'label'       => esc_html__( 'End Action Type', 'redias-core' ),
                'label_block' => false,
                'type'        => Controls_Manager::SELECT,
                'description' => esc_html__( 'Choose which action you want to at the end of countdown.', 'redias-core' ),
                'options'     => [
                    'none'    => esc_html__( 'None', 'redias-core' ),
                    'message' => esc_html__( 'Message', 'redias-core' ),
                    'url'     => esc_html__( 'Redirection Link', 'redias-core' ),
                    'img'     => esc_html__( 'Image', 'redias-core' ),
                ],
                'default'     => 'none',
            ]
        );

        $this->add_control(
            'end_message',
            [
                'label'       => esc_html__( 'Countdown End Message', 'redias-core' ),
                'type'        => Controls_Manager::WYSIWYG,
                'default'     => esc_html__( 'Countdown End!', 'redias-core' ),
                'placeholder' => esc_html__( 'Type your message here', 'redias-core' ),
                'condition'   => [
                    'end_action_type' => 'message',
                ],
            ]
        );

        $this->add_control(
            'end_redirect_link',
            [
                'label'       => esc_html__( 'Redirection Link', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'https://dynamiclayers.net/', 'redias-core' ),
                'condition'   => [
                    'end_action_type' => 'url',
                ],
            ]
        );

        $this->add_control(
            'end_image',
            [
                'label'     => esc_html__( 'Image', 'redias-core' ),
                'type'      => Controls_Manager::MEDIA,
                'default'   => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'end_action_type' => 'img',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'      => 'end_image_size',
                'default'   => 'large',
                'separator' => 'none',
                'condition' => [
                    'end_action_type' => 'img',
                ],
            ]
        );

        $this->end_controls_section();

    }

	/**
	 * Common Style
	 *
	 * @return void
	 */
    protected function common_style() {

        $this->start_controls_section(
            '_section_common_style',
            [
                'label' => esc_html__( 'Common Style', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'box_width',
            [
                'label'      => esc_html__( 'Box Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 300,
                        'step' => 1,
                    ],
                    '%'  => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-countdown-item' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'box_height',
            [
                'label'      => esc_html__( 'Box Height', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 300,
                        'step' => 1,
                    ],
                    '%'  => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-countdown-item' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'common_box_bg',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-countdown-item',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'      => 'box_border',
                'label'     => esc_html__( 'Box Border', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-countdown-item',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'box_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-countdown-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'box_box_shadow',
                'label'    => esc_html__( 'Box Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-countdown-item',
            ]
        );

        $this->add_control(
            'common_box_time_color',
            [
                'label'     => esc_html__( 'Time Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-countdown-time' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'common_box_time_typography',
                'label'    => esc_html__( 'Time Typography', 'redias-core' ),
                'exclude'  => [
                    'line_height',
                ],
                'default'  => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .dl-countdown-time',
            ]
        );

        $this->add_control(
            'common_box_label_color',
            [
                'label'     => esc_html__( 'Label Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-countdown-label' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'common_box_label_typography',
                'label'    => esc_html__( 'Label Typography', 'redias-core' ),
                'exclude'  => [
                    'line_height',
                ],
                'default'  => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .dl-countdown-label',
            ]
        );

        $this->add_responsive_control(
            'common_box_spacing',
            [
                'label'      => esc_html__( 'Spacing Between Box', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-countdown-item' => 'margin-left: {{SIZE}}{{UNIT}}; margin-right: {{SIZE}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

        $this->add_responsive_control(
            'box_padding',
            [
                'label'      => esc_html__( 'Box Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-countdown-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

	/**
	 * Days Style
	 *
	 * @return void
	 */
    protected function days_style() {

        $this->start_controls_section(
            '_section_days_style',
            [
                'label' => esc_html__( 'Days', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'days_bg',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-countdown-item.dl-countdown-item-days',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'      => 'days_border',
                'label'     => esc_html__( 'Box Border', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-countdown-item.dl-countdown-item-days',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'days_time_color',
            [
                'label'     => esc_html__( 'Time Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-countdown-item-days .dl-countdown-time' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'days_time_typography',
                'label'    => esc_html__( 'Time Typography', 'redias-core' ),
                'exclude'  => [
                    'line_height',
                ],
                'default'  => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .dl-countdown-item-days .dl-countdown-time',
            ]
        );

        $this->add_control(
            'days_label_color',
            [
                'label'     => esc_html__( 'Label Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-countdown-item-days .dl-countdown-label' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'days_label_typography',
                'label'    => esc_html__( 'Label Typography', 'redias-core' ),
                'exclude'  => [
                    'line_height',
                ],
                'default'  => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .dl-countdown-item-days .dl-countdown-label',
            ]
        );

        $this->end_controls_section();

    }

	/**
	 * Hours Style
	 *
	 * @return void
	 */
    protected function hours_style() {

        $this->start_controls_section(
            '_section_hours_style',
            [
                'label' => esc_html__( 'Hours', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'hours_bg',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-countdown-item.dl-countdown-item-hours',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'      => 'hours_border',
                'label'     => esc_html__( 'Box Border', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-countdown-item.dl-countdown-item-hours',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'hours_time_color',
            [
                'label'     => esc_html__( 'Time Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-countdown-item-hours .dl-countdown-time' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'hours_time_typography',
                'label'    => esc_html__( 'Time Typography', 'redias-core' ),
                'exclude'  => [
                    'line_height',
                ],
                'default'  => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .dl-countdown-item-hours .dl-countdown-time',
            ]
        );

        $this->add_control(
            'hours_label_color',
            [
                'label'     => esc_html__( 'Label Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-countdown-item-hours .dl-countdown-label' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'hours_label_typography',
                'label'    => esc_html__( 'Label Typography', 'redias-core' ),
                'exclude'  => [
                    'line_height',
                ],
                'default'  => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .dl-countdown-item-hours .dl-countdown-label',
            ]
        );

        $this->end_controls_section();

    }

	/**
	 * Minutes Style
	 *
	 * @return void
	 */
    protected function minutes_style() {

        $this->start_controls_section(
            '_section_minutes_style',
            [
                'label' => esc_html__( 'Minutes', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'minutes_bg',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-countdown-item.dl-countdown-item-minutes',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'      => 'minutes_border',
                'label'     => esc_html__( 'Box Border', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-countdown-item.dl-countdown-item-minutes',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'minutes_time_color',
            [
                'label'     => esc_html__( 'Time Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-countdown-item-minutes .dl-countdown-time' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'minutes_time_typography',
                'label'    => esc_html__( 'Time Typography', 'redias-core' ),
                'exclude'  => [
                    'line_height',
                ],
                'default'  => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .dl-countdown-item-minutes .dl-countdown-time',
            ]
        );

        $this->add_control(
            'minutes_label_color',
            [
                'label'     => esc_html__( 'Label Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-countdown-item-minutes .dl-countdown-label' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'minutes_label_typography',
                'label'    => esc_html__( 'Label Typography', 'redias-core' ),
                'exclude'  => [
                    'line_height',
                ],
                'default'  => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .dl-countdown-item-minutes .dl-countdown-label',
            ]
        );

        $this->end_controls_section();

    }

	/**
	 * Seconds Style
	 *
	 * @return void
	 */
    protected function seconds_style() {

        $this->start_controls_section(
            '_section_seconds_style',
            [
                'label' => esc_html__( 'Seconds', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'seconds_bg',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-countdown-item.dl-countdown-item-seconds',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'      => 'seconds_border',
                'label'     => esc_html__( 'Box Border', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-countdown-item.dl-countdown-item-seconds',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'seconds_time_color',
            [
                'label'     => esc_html__( 'Time Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-countdown-item-seconds .dl-countdown-time' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'seconds_time_typography',
                'label'    => esc_html__( 'Time Typography', 'redias-core' ),
                'exclude'  => [
                    'line_height',
                ],
                'default'  => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .dl-countdown-item-seconds .dl-countdown-time',
            ]
        );

        $this->add_control(
            'seconds_label_color',
            [
                'label'     => esc_html__( 'Label Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-countdown-item-seconds .dl-countdown-label' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'seconds_label_typography',
                'label'    => esc_html__( 'Label Typography', 'redias-core' ),
                'exclude'  => [
                    'line_height',
                ],
                'default'  => [
                    'font_size' => [''],
                ],
                'selector' => '{{WRAPPER}} .dl-countdown-item-seconds .dl-countdown-label',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

		$settings = $this->get_settings_for_display();
		$due_date = date("M d Y G:i:s", strtotime($settings['due_date']));
		$this->add_render_attribute('dl-countdown', 'class', 'dl-countdown');
		$this->add_render_attribute('dl-countdown', 'data-date', esc_attr($due_date));
		$this->add_render_attribute('dl-countdown', 'data-end-action', esc_attr($settings['end_action_type']));
		if ('url' === $settings['end_action_type'] && $settings['end_redirect_link']) {
			$this->add_render_attribute('dl-countdown', 'data-redirect-link', esc_url($settings['end_redirect_link']));
		}
		$this->add_render_attribute('days', 'class', 'dl-countdown-item dl-countdown-item-days');
		$this->add_render_attribute('hours', 'class', 'dl-countdown-item dl-countdown-item-hours');
		$this->add_render_attribute('minutes', 'class', 'dl-countdown-item dl-countdown-item-minutes');
		$this->add_render_attribute('seconds', 'class', 'dl-countdown-item dl-countdown-item-seconds');
		if ('on' == $settings['show_separator']) {
			$this->add_render_attribute('days', 'class', 'dl-countdown-separator-on');
			$this->add_render_attribute('hours', 'class', 'dl-countdown-separator-on');
			$this->add_render_attribute('minutes', 'class', 'dl-countdown-separator-on');
			$this->add_render_attribute('seconds', 'class', 'dl-countdown-separator-on');
		}
		?>
		<?php if ( ! empty( $due_date ) ) : ?>
			<div class="dl-countdown-wrap">
				<div <?php $this->print_render_attribute_string('dl-countdown'); ?>>
					<div <?php $this->print_render_attribute_string('days'); ?>>
						<span data-days class="dl-countdown-time dl-countdown-days">0</span>
						<?php if ('yes' == $settings['show_label_days'] && !empty($settings['label_days'])): ?>
							<span
								class="dl-countdown-label dl-countdown-label-days"><?php echo esc_html($settings['label_days']); ?></span>
						<?php endif; ?>
						<?php if ('on' == $settings['show_separator'] && !empty($settings['separator'])): ?>
							<span class="dl-countdown-separator"><?php echo esc_attr($settings['separator']); ?></span>
						<?php endif; ?>
					</div>
					<div <?php $this->print_render_attribute_string('hours'); ?>>
						<span class="dl-countdown-time dl-countdown-hours" data-hours>0</span>
						<?php if ('yes' == $settings['show_label_hours'] && !empty($settings['label_hours'])): ?>
							<span
								class="dl-countdown-label dl-countdown-label-hours"><?php echo esc_html($settings['label_hours']); ?></span>
						<?php endif; ?>
						<?php if ('on' == $settings['show_separator'] && !empty($settings['separator'])): ?>
							<span class="dl-countdown-separator"><?php echo esc_attr($settings['separator']); ?></span>
						<?php endif; ?>
					</div>
					<div <?php $this->print_render_attribute_string('minutes'); ?>>
						<span class="dl-countdown-time dl-countdown-minutes" data-minutes>0</span>
						<?php if ('yes' == $settings['show_label_minutes'] && !empty($settings['label_minutes'])): ?>
							<span
								class="dl-countdown-label dl-countdown-label-minutes"><?php echo esc_html($settings['label_minutes']); ?></span>
						<?php endif; ?>
						<?php if ('on' == $settings['show_separator'] && !empty($settings['separator'])): ?>
							<span class="dl-countdown-separator"><?php echo esc_attr($settings['separator']); ?></span>
						<?php endif; ?>
					</div>
					<div <?php $this->print_render_attribute_string('seconds'); ?>>
						<span class="dl-countdown-time dl-countdown-seconds" data-seconds>0</span>
						<?php if ('yes' == $settings['show_label_seconds'] && !empty($settings['label_seconds'])): ?>
							<span
								class="dl-countdown-label dl-countdown-label-seconds"><?php echo esc_html($settings['label_seconds']); ?></span>
						<?php endif; ?>
					</div>
					<!--End action markup-->
					<?php if ('none' != $settings['end_action_type'] && !empty($settings['end_action_type'])): ?>
						<div class="dl-countdown-end-action">
							<?php if ('message' == $settings['end_action_type'] && $settings['end_message']) :
								echo '<div class="dl-countdown-end-message">' . wpautop(wp_kses_post($settings['end_message'])) . '</div>';
							endif; ?>
							<?php if ('img' == $settings['end_action_type'] && ($settings['end_image']['url'] || $settings['end_image']['id'])) :
								$this->add_render_attribute('image', 'src', $settings['end_image']['url']);
								$this->add_render_attribute('image', 'alt', Control_Media::get_image_alt($settings['end_image']));
								$this->add_render_attribute('image', 'title', Control_Media::get_image_title($settings['end_image']));
								?>
								<figure class="dl-countdown-end-action-image">
									<?php echo Group_Control_Image_Size::get_attachment_image_html($settings, 'end_image_size', 'end_image'); ?>
								</figure>
							<?php endif; ?>
						</div>
					<?php endif; ?>
				</div>
			</div>
		<?php endif;

    }

}