<?php
/**
 * Counter
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Counter;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Icons_Manager;
use Elementor\Utils;
use Elementor\Widget_Base;

use RediasCore\Classes\Helper;
use RediasCore\Elementor\Controls\Foreground;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-counter';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Counter', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-number-field';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return ['counter', 'number', 'redias'];
    }

    public function get_script_depends() {
        return ['waypoints', 'odometer', 'redias-el-script'];
    }

    public function get_style_depends() {
        return ['odometer', 'redias-counter'];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_counter_content();
        $this->section_divider();
        $this->section_settings();
        $this->counter_style();
        $this->icon_style();
        $this->number_style();
        $this->prefix_style();
        $this->suffix_style();
        $this->title_style();

    }

    /**
     * Section Counter Content
     *
     * @return void
     */
    protected function section_counter_content() {

        $this->start_controls_section(
            'section_counter',
            [
                'label' => esc_html__( 'Counter', 'redias-core' ),
            ]
        );

        $this->add_control(
            'dl_icon_type',
            [
                'label'       => esc_html__( 'Icon Type', 'redias-core' ),
                'type'        => Controls_Manager::CHOOSE,
                'label_block' => false,
                'options'     => [
                    'none'  => [
                        'title' => esc_html__( 'None', 'redias-core' ),
                        'icon'  => 'eicon-ban',
                    ],
                    'icon'  => [
                        'title' => esc_html__( 'Icon', 'redias-core' ),
                        'icon'  => 'eicon-info-circle',
                    ],
                    'image' => [
                        'title' => esc_html__( 'Image', 'redias-core' ),
                        'icon'  => 'eicon-image',
                    ],
                ],
                'default'     => 'none',
                'condition'    => [
                    'counter_layout!' => 'layout-7',
                ],
            ]
        );

        $this->add_control(
            'counter_icon',
            [
                'label'            => esc_html__( 'Icon', 'redias-core' ),
                'type'             => Controls_Manager::ICONS,
                'default'          => [
                    'value'   => 'fas fa-star',
                    'library' => 'solid',
                ],
                'fa4compatibility'  => 'icon',
                'skin'              => 'inline',
                'exclude_inline_options'  => ['svg'],
                'condition'        => [
                    'dl_icon_type' => 'icon',
                    'counter_layout!' => 'layout-7',
                ],
            ]
        );

        $this->add_control(
            'icon_image',
            [
                'label'     => esc_html__( 'Image', 'redias-core' ),
                'type'      => Controls_Manager::MEDIA,
                'default'   => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'dl_icon_type' => 'image',
                    'counter_layout!' => 'layout-7',
                ],
            ]
        );

        $this->add_control(
            'ending_number',
            [
                'label'     => esc_html__( 'Number', 'redias-core' ),
                'type'      => Controls_Manager::NUMBER,
                'dynamic'   => [
                    'active' => true,
                ],
                'default'   => esc_html__( '250', 'redias-core' ),
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'number_prefix',
            [
                'label'   => esc_html__( 'Number Prefix', 'redias-core' ),
                'type'    => Controls_Manager::TEXT,
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $this->add_control(
            'number_suffix',
            [
                'label'   => esc_html__( 'Number Suffix', 'redias-core' ),
                'type'    => Controls_Manager::TEXT,
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $this->add_control(
            'counter_title',
            [
                'label'     => esc_html__( 'Title', 'redias-core' ),
                'type'      => Controls_Manager::TEXT,
                'label_block' => true,
                'dynamic'   => [
                    'active' => true,
                ],
                'default'   => esc_html__( 'Counter Title', 'redias-core' ),
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'title_html_tag',
            [
                'label'   => esc_html__( 'Title HTML Tag', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'div',
                'options' => [
                    'h1'   => esc_html__( 'H1', 'redias-core' ),
                    'h2'   => esc_html__( 'H2', 'redias-core' ),
                    'h3'   => esc_html__( 'H3', 'redias-core' ),
                    'h4'   => esc_html__( 'H4', 'redias-core' ),
                    'h5'   => esc_html__( 'H5', 'redias-core' ),
                    'h6'   => esc_html__( 'H6', 'redias-core' ),
                    'div'  => esc_html__( 'div', 'redias-core' ),
                    'span' => esc_html__( 'span', 'redias-core' ),
                    'p'    => esc_html__( 'p', 'redias-core' ),
                ],
            ]
        );

        $this->add_control(
            'counter_layout',
            [
                'label'     => esc_html__( 'Layout', 'redias-core' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'layout-8',
                'options'   => [
                    'layout-1' => esc_html__( 'Layout 1', 'redias-core' ),
                    'layout-2' => esc_html__( 'Layout 2', 'redias-core' ),
                    'layout-3' => esc_html__( 'Layout 3', 'redias-core' ),
                    'layout-4' => esc_html__( 'Layout 4', 'redias-core' ),
                    'layout-5' => esc_html__( 'Layout 5', 'redias-core' ),
                    'layout-6' => esc_html__( 'Layout 6', 'redias-core' ),
                    'layout-7' => esc_html__( 'Layout 7', 'redias-core' ),
                    'layout-8' => esc_html__( 'Layout 8', 'redias-core' ),
                ],
                'separator' => 'before',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Section Divider
     *
     * @return void
     */
    protected function section_divider() {

        $this->start_controls_section(
            'section_counter_separators',
            [
                'label' => esc_html__( 'Dividers', 'redias-core' ),
                'condition'    => [
                    'counter_layout!' => ['layout-7', 'layout-8' ]
                ],
            ]
        );

        $this->add_control(
            'icon_divider',
            [
                'label'        => esc_html__( 'Icon Divider', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'default'      => 'no',
                'label_on'     => esc_html__( 'On', 'redias-core' ),
                'label_off'    => esc_html__( 'Off', 'redias-core' ),
                'return_value' => 'yes',
                'condition'    => [
                    'dl_icon_type!' => 'none',
                    'counter_layout!' => ['layout-7', 'layout-8' ]
                ],
            ]
        );

        $this->add_control(
            'num_divider',
            [
                'label'        => esc_html__( 'Number Divider', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'default'      => 'no',
                'label_on'     => esc_html__( 'On', 'redias-core' ),
                'label_off'    => esc_html__( 'Off', 'redias-core' ),
                'return_value' => 'yes',
                'condition'    => [
                    'counter_layout!' => ['layout-7', 'layout-8' ]
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Section Settings
     *
     * @return void
     */
    protected function section_settings() {

        $this->start_controls_section(
            'section_counter_settings',
            [
                'label' => esc_html__( 'Settings', 'redias-core' ),
            ]
        );

        $this->add_control(
            'counter_speed',
            [
                'label'      => esc_html__( 'Counting Speed', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'default'    => ['size' => 1500],
                'range'      => [
                    'px' => [
                        'min'  => 100,
                        'max'  => 3000
                    ],
                ],
                'size_units' => '',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Counter Style
     *
     * @return void
     */
    protected function counter_style() {

        $this->start_controls_section(
            'section_style',
            [
                'label' => esc_html__( 'Counter', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'counter_layout!' => ['layout-7', 'layout-8']
                ],
            ]
        );

        $this->add_responsive_control(
            'counter_align',
            [
                'label'        => esc_html__( 'Alignment', 'redias-core' ),
                'type'         => Controls_Manager::CHOOSE,
                'options'      => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'default'      => 'center',
                'prefix_class' => 'counter-',
                'selectors'    => [
                    '{{WRAPPER}} .dl-counter-container' => 'text-align: {{VALUE}};',
                ],
                'toggle'  => false,
                'condition'    => [
                    'counter_layout!' => ['layout-7', 'layout-8']
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Icon Style
     *
     * @return void
     */
    protected function icon_style() {

        $this->start_controls_section(
            'section_counter_icon_style',
            [
                'label'     => esc_html__( 'Icon', 'redias-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'dl_icon_type!' => 'none',
                    'counter_layout!' => 'layout-7',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_box_width',
            [
                'label'      => esc_html__( 'Width', 'textdomain' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 30,
                        'max'  => 300,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-layout-8' => 'grid-template-columns: {{SIZE}}{{UNIT}} 1fr;',
                    '{{WRAPPER}} .dl-counter-layout-8 .dl-counter-icon' => 'width: {{SIZE}}{{UNIT}}',
                ],
                'condition' => [
                    'dl_icon_type!' => 'none',
                    'counter_layout' => 'layout-8',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_box_height',
            [
                'label'      => esc_html__( 'Height', 'textdomain' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 30,
                        'max'  => 300,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-layout-8 .dl-counter-icon' => 'height: {{SIZE}}{{UNIT}}',
                ],
                'condition' => [
                    'dl_icon_type!' => 'none',
                    'counter_layout' => 'layout-8',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_spacebetween_content',
            [
                'label'      => esc_html__( 'Space Between', 'textdomain' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-layout-8' => 'gap: {{SIZE}}{{UNIT}}',
                ],
                'condition' => [
                    'dl_icon_type!' => 'none',
                    'counter_layout' => 'layout-8',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'      => 'counter_icon_bg',
                'label'     => esc_html__( 'Background', 'redias-core' ),
                'types'     => ['none', 'classic', 'gradient'],
                'exclude'   => ['image'],
                'condition' => [
                    'dl_icon_type!' => 'none',
                    'counter_layout!' => 'layout-7',
                ],
                'selector'  => '{{WRAPPER}} .dl-counter-icon',
            ]
        );

        $this->add_control(
			'counter_icon_hr',
			[
				'type' => Controls_Manager::DIVIDER,
                'condition' => [
                    'counter_layout!' => 'layout-8',
                ],
			]
		);

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'counter_icon_color',
                'label'    => esc_html__( 'Icon Color', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-counter-icon i',
                'condition' => [
                    'dl_icon_type' => 'icon',
                    'counter_layout!' => 'layout-7',
                ],
            ]
        );

        $this->add_control(
            'icon_box_hover_h',
            [
                'label' => esc_html__( 'Icon Hover', 'redias-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'dl_icon_type!' => 'none',
                    'counter_layout' => 'layout-8',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'      => 'counter_icon_bg_hover',
                'label'     => esc_html__( 'Background', 'redias-core' ),
                'types'     => ['none', 'classic', 'gradient'],
                'exclude'   => ['image'],
                'condition' => [
                    'dl_icon_type!' => 'none',
                    'counter_layout' => 'layout-8',
                ],
                'selector'  => '{{WRAPPER}} .dl-counter-layout-8:hover .dl-counter-icon',
            ]
        );

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'counter_icon_hover_color',
                'label'    => esc_html__( 'Icon Color', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-counter-layout-8:hover .dl-counter-icon i',
                'condition' => [
                    'dl_icon_type' => 'icon',
                    'counter_layout' => 'layout-8',
                ],
            ]
        );

        $this->add_responsive_control(
            'counter_icon_size',
            [
                'label'      => esc_html__( 'Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'separator'  => 'before',
                'range'      => [
                    'px' => [
                        'min'  => 5,
                        'max'  => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-icon'     => 'font-size: {{SIZE}}{{UNIT}}',
                    '{{WRAPPER}} .dl-counter-icon svg' => 'width: {{SIZE}}{{UNIT}}; height: auto;',
                ],
                'condition'  => [
                    'dl_icon_type' => 'icon',
                    'counter_layout!' => 'layout-7',
                ],
            ]
        );

        $this->add_responsive_control(
            'counter_icon_img_width',
            [
                'label'      => esc_html__( 'Image Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'separator' => 'before',
                'range'      => [
                    'px' => [
                        'min'  => 10,
                        'max'  => 500,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', '%'],
                'condition'  => [
                    'dl_icon_type' => 'image',
                    'counter_layout!' => 'layout-7',
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-icon img' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'counter_icon_rotation',
            [
                'label'      => esc_html__( 'Rotation', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 360,
                        'step' => 1,
                    ],
                ],
                'size_units' => '',
                'condition'  => [
                    'dl_icon_type!' => 'none',
                    'counter_layout!' => 'layout-7',
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-icon i, {{WRAPPER}} .dl-counter-icon svg, {{WRAPPER}} .dl-counter-icon img' => 'transform: rotate( {{SIZE}}deg );',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'        => 'counter_icon_border',
                'label'       => esc_html__( 'Border', 'redias-core' ),
                'placeholder' => '1px',
                'default'     => '1px',
                'selector'    => '{{WRAPPER}} .dl-counter-icon',
                'condition'   => [
                    'dl_icon_type!' => 'none',
                    'counter_layout!' => ['layout-7', 'layout-8']
                ],
            ]
        );

        $this->add_control(
            'counter_icon_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'dl_icon_type!' => 'none',
                    'counter_layout!' => ['layout-7', 'layout-8']
                ],
            ]
        );

        $this->add_responsive_control(
            'counter_icon_padding',
            [
                'label'       => esc_html__( 'Padding', 'redias-core' ),
                'type'        => Controls_Manager::DIMENSIONS,
                'size_units'  => ['px', '%'],
                'placeholder' => [
                    'top'    => '',
                    'right'  => '',
                    'bottom' => '',
                    'left'   => '',
                ],
                'selectors'   => [
                    '{{WRAPPER}} .dl-counter-icon' => 'padding-top: {{TOP}}{{UNIT}}; padding-left: {{LEFT}}{{UNIT}}; padding-right: {{RIGHT}}{{UNIT}}; padding-bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition'   => [
                    'dl_icon_type!' => 'none',
                    'counter_layout!' => ['layout-7', 'layout-8']
                ],
            ]
        );

        $this->add_responsive_control(
            'counter_icon_margin',
            [
                'label'       => esc_html__( 'Margin', 'redias-core' ),
                'type'        => Controls_Manager::DIMENSIONS,
                'size_units'  => ['px', '%'],
                'placeholder' => [
                    'top'    => '',
                    'right'  => '',
                    'bottom' => '',
                    'left'   => '',
                ],
                'selectors'   => [
                    '{{WRAPPER}} .dl-counter-icon-wrap' => 'margin-top: {{TOP}}{{UNIT}}; margin-left: {{LEFT}}{{UNIT}}; margin-right: {{RIGHT}}{{UNIT}}; margin-bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition'   => [
                    'dl_icon_type!' => 'none',
                    'counter_layout!' => ['layout-7', 'layout-8']
                ],
            ]
        );

        $this->add_control(
            'icon_divider_heading',
            [
                'label'     => esc_html__( 'Icon Divider', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'dl_icon_type!' => 'none',
                    'icon_divider'  => 'yes',
                    'counter_layout!' => ['layout-7', 'layout-8']
                ],
            ]
        );

        $this->add_control(
            'icon_divider_type',
            [
                'label'     => esc_html__( 'Divider Type', 'redias-core' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'solid',
                'options'   => [
                    'solid'  => esc_html__( 'Solid', 'redias-core' ),
                    'double' => esc_html__( 'Double', 'redias-core' ),
                    'dotted' => esc_html__( 'Dotted', 'redias-core' ),
                    'dashed' => esc_html__( 'Dashed', 'redias-core' ),
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-counter-icon-divider' => 'border-bottom-style: {{VALUE}}',
                ],
                'condition' => [
                    'dl_icon_type!' => 'none',
                    'icon_divider'  => 'yes',
                    'counter_layout!' => ['layout-7', 'layout-8']
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_divider_height',
            [
                'label'      => esc_html__( 'Height', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'default'    => [
                    'size' => 2,
                ],
                'range'      => [
                    'px' => [
                        'min'  => 1,
                        'max'  => 20,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-icon-divider' => 'border-bottom-width: {{SIZE}}{{UNIT}}',
                ],
                'condition'  => [
                    'dl_icon_type!' => 'none',
                    'icon_divider'  => 'yes',
                    'counter_layout!' => ['layout-7', 'layout-8']
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_divider_width',
            [
                'label'      => esc_html__( 'Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'default'    => [
                    'size' => 30,
                ],
                'range'      => [
                    'px' => [
                        'min'  => 1,
                        'max'  => 1000,
                        'step' => 1,
                    ],
                    '%'  => [
                        'min'  => 1,
                        'max'  => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-icon-divider' => 'width: {{SIZE}}{{UNIT}}',
                ],
                'condition'  => [
                    'dl_icon_type!' => 'none',
                    'icon_divider'  => 'yes',
                    'counter_layout!' => ['layout-7', 'layout-8']
                ],
            ]
        );

        $this->add_control(
            'icon_divider_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .dl-counter-icon-divider' => 'border-bottom-color: {{VALUE}}',
                ],
                'condition' => [
                    'dl_icon_type!' => 'none',
                    'icon_divider'  => 'yes',
                    'counter_layout!' => ['layout-7', 'layout-8']
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_divider_margin',
            [
                'label'      => esc_html__( 'Spacing', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100,
                        'step' => 1,
                    ],
                    '%'  => [
                        'min'  => 0,
                        'max'  => 30,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-icon-divider-wrap' => 'margin-bottom: {{SIZE}}{{UNIT}}',
                ],
                'condition'  => [
                    'dl_icon_type!' => 'none',
                    'icon_divider'  => 'yes',
                    'counter_layout!' => ['layout-7', 'layout-8']
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Number Style
     *
     * @return void
     */
    protected function number_style() {

        $this->start_controls_section(
            'section_counter_num_style',
            [
                'label' => esc_html__( 'Number', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'counter_num_color',
            [
                'label'     => esc_html__( 'Number Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .dl-counter:not(.dl-counter-layout-7) .dl-counter-number' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .dl-counter-layout-7 .dl-counter-number,{{WRAPPER}} .dl-counter-layout-7 .dl-counter-number-wrap .dl-counter-number-prefix, {{WRAPPER}} .dl-counter-layout-7 .dl-counter-number-wrap .dl-counter-number-suffix' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .dl-counter-layout-8 .dl-counter-number-wrap,{{WRAPPER}} .dl-counter-layout-8 .dl-counter-number-wrap span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'counter_num_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-counter:not(.dl-counter-layout-7) .dl-counter-number-wrap .dl-counter-number, {{WRAPPER}} .dl-counter-layout-7 .dl-counter-number,{{WRAPPER}} .dl-counter-layout-7 .dl-counter-number-wrap .dl-counter-number-prefix, {{WRAPPER}} .dl-counter-layout-7 .dl-counter-number-wrap .dl-counter-number-suffix, {{WRAPPER}} .dl-counter-layout-8 .dl-counter-number-wrap, {{WRAPPER}} .dl-counter-layout-8 .dl-counter-number-wrap span',
            ]
        );

        $this->add_responsive_control(
            'counter_number_wrap_with',
            [
                'label'      => esc_html__( 'Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 50,
                        'max'  => 200
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-layout-7' => 'grid-template-columns: {{SIZE}}{{UNIT}} 1fr;',
                ],
                'condition'    => [
                    'counter_layout' => 'layout-7',
                ],
            ]
        );

        $this->add_responsive_control(
            'counter_number_space_between',
            [
                'label'      => esc_html__( 'Space Between', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-layout-7' => 'grid-column-gap: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'counter_layout' => 'layout-7',
                ],
            ]
        );

        $this->add_responsive_control(
            'counter_num_margin',
            [
                'label'       => esc_html__( 'Margin', 'redias-core' ),
                'type'        => Controls_Manager::DIMENSIONS,
                'size_units'  => ['px', '%'],
                'placeholder' => [
                    'top'    => '',
                    'right'  => '',
                    'bottom' => '',
                    'left'   => '',
                ],
                'selectors'   => [
                    '{{WRAPPER}} .dl-counter-number-wrap' => 'margin-top: {{TOP}}{{UNIT}}; margin-left: {{LEFT}}{{UNIT}}; margin-right: {{RIGHT}}{{UNIT}}; margin-bottom: {{BOTTOM}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'num_divider_heading',
            [
                'label'     => esc_html__( 'Number Divider', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'num_divider' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'num_divider_type',
            [
                'label'     => esc_html__( 'Divider Type', 'redias-core' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'solid',
                'options'   => [
                    'solid'  => esc_html__( 'Solid', 'redias-core' ),
                    'double' => esc_html__( 'Double', 'redias-core' ),
                    'dotted' => esc_html__( 'Dotted', 'redias-core' ),
                    'dashed' => esc_html__( 'Dashed', 'redias-core' ),
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-counter-num-divider' => 'border-bottom-style: {{VALUE}}',
                ],
                'condition' => [
                    'num_divider' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'num_divider_height',
            [
                'label'      => esc_html__( 'Height', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'default'    => [
                    'size' => 2,
                ],
                'range'      => [
                    'px' => [
                        'min'  => 1,
                        'max'  => 20,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-num-divider' => 'border-bottom-width: {{SIZE}}{{UNIT}}',
                ],
                'condition'  => [
                    'num_divider' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'num_divider_width',
            [
                'label'      => esc_html__( 'Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'default'    => [
                    'size' => 30,
                ],
                'range'      => [
                    'px' => [
                        'min'  => 1,
                        'max'  => 1000,
                        'step' => 1,
                    ],
                    '%'  => [
                        'min'  => 1,
                        'max'  => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-num-divider' => 'width: {{SIZE}}{{UNIT}}',
                ],
                'condition'  => [
                    'num_divider' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'num_divider_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .dl-counter-num-divider' => 'border-bottom-color: {{VALUE}}',
                ],
                'condition' => [
                    'num_divider' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'num_divider_margin',
            [
                'label'      => esc_html__( 'Spacing', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100,
                        'step' => 1,
                    ],
                    '%'  => [
                        'min'  => 0,
                        'max'  => 30,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-counter-num-divider-wrap' => 'margin-bottom: {{SIZE}}{{UNIT}}',
                ],
                'condition'  => [
                    'num_divider' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Prefix Style
     *
     * @return void
     */
    protected function prefix_style() {

        $this->start_controls_section(
            'section_number_prefix_style',
            [
                'label'     => esc_html__( 'Prefix', 'redias-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'number_prefix!' => '',
                    'counter_layout!' => 'layout-7',
                ],
            ]
        );

        $this->add_control(
            'number_prefix_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .dl-counter-number-prefix' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'number_prefix!' => '',
                    'counter_layout!' => 'layout-7',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'number_prefix_typography',
                'label'     => esc_html__( 'Typography', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-counter-number-prefix',
                'condition' => [
                    'number_prefix!' => '',
                    'counter_layout!' => 'layout-7',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Suffix Style
     *
     * @return void
     */
    protected function suffix_style() {

        $this->start_controls_section(
            'section_number_suffix_style',
            [
                'label'     => esc_html__( 'Suffix', 'redias-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'number_suffix!' => '',
                    'counter_layout!' => 'layout-7',
                ],
            ]
        );

        $this->add_control(
            'section_number_suffix_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .dl-counter-number-suffix' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'number_suffix!' => '',
                    'counter_layout!' => 'layout-7',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'section_number_suffix_typography',
                'label'     => esc_html__( 'Typography', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-counter-number-suffix',
                'condition' => [
                    'number_suffix!' => '',
                    'counter_layout!' => 'layout-7',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Title Style
     *
     * @return void
     */
    protected function title_style() {

        $this->start_controls_section(
            'section_counter_title_style',
            [
                'label'     => esc_html__( 'Title', 'redias-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'counter_title!' => '',
                ],
            ]
        );

        $this->add_control(
            'counter_title_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .dl-counter-title' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'counter_title!' => '',
                ],
            ]
        );

        $this->add_control(
            'counter_title_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .dl-counter-title' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'counter_title!' => '',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'counter_title_typography',
                'label'     => esc_html__( 'Typography', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-counter-title',
                'condition' => [
                    'counter_title!' => '',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'title_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-counter-layout-7 .dl-icon-title-wrap',
                'condition'    => [
                    'counter_layout' => 'layout-7',
                ],
            ]
        );

        $this->add_responsive_control(
            'counter_title_margin',
            [
                'label'       => esc_html__( 'Margin', 'redias-core' ),
                'type'        => Controls_Manager::DIMENSIONS,
                'size_units'  => ['px', '%'],
                'placeholder' => [
                    'top'    => '',
                    'right'  => '',
                    'bottom' => '',
                    'left'   => '',
                ],
                'selectors'   => [
                    '{{WRAPPER}} .dl-counter-title' => 'margin-top: {{TOP}}{{UNIT}}; margin-left: {{LEFT}}{{UNIT}}; margin-right: {{RIGHT}}{{UNIT}}; margin-bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition'   => [
                    'counter_title!' => '',
                ],
            ]
        );

        $this->add_responsive_control(
            'counter_title_padding',
            [
                'label'       => esc_html__( 'Padding', 'redias-core' ),
                'type'        => Controls_Manager::DIMENSIONS,
                'size_units'  => ['px', '%'],
                'placeholder' => [
                    'top'    => '',
                    'right'  => '',
                    'bottom' => '',
                    'left'   => '',
                ],
                'selectors'   => [
                    '{{WRAPPER}} .dl-counter-title' => 'padding-top: {{TOP}}{{UNIT}}; padding-left: {{LEFT}}{{UNIT}}; padding-right: {{RIGHT}}{{UNIT}}; padding-bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition'   => [
                    'counter_title!' => '',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        
        $this->add_render_attribute( 'counter', 'class', 'dl-counter dl-counter-'.esc_attr( $this->get_id() ) );
        
        if ( $settings['counter_layout'] ) {
            $this->add_render_attribute( 'counter', 'class', 'dl-counter-' . $settings['counter_layout'] );
        }
        
        $this->add_render_attribute( 'counter', 'data-target', '.dl-counter-number-'.esc_attr( $this->get_id() ) );
        
        $this->add_render_attribute( 'counter-number', 'class', 'dl-counter-number dl-counter-number-'.esc_attr( $this->get_id() ) );
        
        if ( $settings['ending_number'] != '' ) {
            $this->add_render_attribute( 'counter-number', 'data-to', $settings['ending_number'] );
        }
        
        if ( $settings['counter_speed']['size'] != '' ) {
            $this->add_render_attribute( 'counter-number', 'data-speed', $settings['counter_speed']['size'] );
        }
        
        $this->add_inline_editing_attributes( 'counter_title', 'none' );
        $this->add_render_attribute( 'counter_title', 'class', 'dl-counter-title' );
        ?>
        <div class="dl-counter-container">
            <div <?php echo $this->get_render_attribute_string( 'counter' ); ?>>
                <?php if ( $settings['counter_layout'] == 'layout-1' || $settings['counter_layout'] == 'layout-5' || $settings['counter_layout'] == 'layout-6' ) { ?>
                    <?php
                        // Counter icon
                        $this->render_icon();
                    ?>
                
                    <div class="dl-counter-number-title-wrap">
                        <div class="dl-counter-number-wrap">
                            <?php
                                if ( $settings['number_prefix'] != '' ) {
                                    printf( '<span class="dl-counter-number-prefix">%1$s</span>', $settings['number_prefix'] );
                                }
                            ?>
                            <div <?php echo $this->get_render_attribute_string( 'counter-number' ); ?>>
                                0
                            </div>
                            <?php
                                if ( $settings['number_suffix'] != '' ) {
                                    printf( '<span class="dl-counter-number-suffix">%1$s</span>', $settings['number_suffix'] );
                                }
                            ?>
                        </div>

                        <?php if ( $settings['num_divider'] == 'yes' ) { ?>
                            <div class="dl-counter-num-divider-wrap">
                                <span class="dl-counter-num-divider"></span>
                            </div>
                        <?php } ?>

                        <?php
                            if ( !empty( $settings['counter_title'] ) ) {
                                printf( '<%1$s %2$s>', $settings['title_html_tag'], $this->get_render_attribute_string( 'counter_title' ) );
                                    echo Helper::kses_basic( $settings['counter_title'] );
                                printf( '</%1$s>', $settings['title_html_tag'] );
                            }
                        ?>
                    </div>
                <?php } elseif ( $settings['counter_layout'] == 'layout-2' ) { ?>
                    <?php
                        // Counter icon
                        $this->render_icon();

                        if ( !empty( $settings['counter_title'] ) ) {
                            printf( '<%1$s %2$s>', $settings['title_html_tag'], $this->get_render_attribute_string( 'counter_title' ) );
                                echo Helper::kses_basic( $settings['counter_title'] );
                            printf( '</%1$s>', $settings['title_html_tag'] );
                        }
                    ?>
                
                    <div class="dl-counter-number-wrap">
                        <?php
                            if ( $settings['number_prefix'] != '' ) {
                                printf( '<span class="dl-counter-number-prefix">%1$s</span>', $settings['number_prefix'] );
                            }
                        ?>
                        <div <?php echo $this->get_render_attribute_string( 'counter-number' ); ?>>
                            0
                        </div>
                        <?php
                            if ( $settings['number_suffix'] != '' ) {
                                printf( '<span class="dl-counter-number-suffix">%1$s</span>', $settings['number_suffix'] );
                            }
                        ?>
                    </div>

                    <?php if ( $settings['num_divider'] == 'yes' ) { ?>
                        <div class="dl-counter-num-divider-wrap">
                            <span class="dl-counter-num-divider"></span>
                        </div>
                    <?php } ?>
                <?php } elseif ( $settings['counter_layout'] == 'layout-3' ) { ?>
                    <div class="dl-counter-number-wrap">
                        <?php
                            if ( $settings['number_prefix'] != '' ) {
                                printf( '<span class="dl-counter-number-prefix">%1$s</span>', $settings['number_prefix'] );
                            }
                        ?>
                        <div <?php echo $this->get_render_attribute_string( 'counter-number' ); ?>>
                            0
                        </div>
                        <?php
                            if ( $settings['number_suffix'] != '' ) {
                                printf( '<span class="dl-counter-number-suffix">%1$s</span>', $settings['number_suffix'] );
                            }
                        ?>
                    </div>

                    <?php if ( $settings['num_divider'] == 'yes' ) { ?>
                        <div class="dl-counter-num-divider-wrap">
                            <span class="dl-counter-num-divider"></span>
                        </div>
                    <?php } ?>
                
                    <div class="dl-icon-title-wrap">
                        <?php
                            // Counter icon
                            $this->render_icon();

                            if ( !empty( $settings['counter_title'] ) ) {
                                printf( '<%1$s %2$s>', $settings['title_html_tag'], $this->get_render_attribute_string( 'counter_title' ) );
                                    echo Helper::kses_basic( $settings['counter_title'] );
                                printf( '</%1$s>', $settings['title_html_tag'] );
                            }
                        ?>
                    </div>
                <?php } elseif ( $settings['counter_layout'] == 'layout-4' ) { ?>
                    <div class="dl-icon-title-wrap">
                        <?php
                            // Counter icon
                            $this->render_icon();

                            if ( !empty( $settings['counter_title'] ) ) {
                                printf( '<%1$s %2$s>', $settings['title_html_tag'], $this->get_render_attribute_string( 'counter_title' ) );
                                    echo Helper::kses_basic( $settings['counter_title'] );
                                printf( '</%1$s>', $settings['title_html_tag'] );
                            }
                        ?>
                    </div>
                
                    <div class="dl-counter-number-wrap">
                        <?php
                            if ( $settings['number_prefix'] != '' ) {
                                printf( '<span class="dl-counter-number-prefix">%1$s</span>', $settings['number_prefix'] );
                            }
                        ?>
                        <div <?php echo $this->get_render_attribute_string( 'counter-number' ); ?>>
                            0
                        </div>
                        <?php
                            if ( $settings['number_suffix'] != '' ) {
                                printf( '<span class="dl-counter-number-suffix">%1$s</span>', $settings['number_suffix'] );
                            }
                        ?>
                    </div>

                    <?php if ( $settings['num_divider'] == 'yes' ) { ?>
                        <div class="dl-counter-num-divider-wrap">
                            <span class="dl-counter-num-divider"></span>
                        </div>
                    <?php } ?>
                <?php } elseif( $settings['counter_layout'] == 'layout-7' ){ ?>

                    <div class="dl-counter-number-wrap">
                        <?php
                            if ( $settings['number_prefix'] != '' ) {
                                printf( '<span class="dl-counter-number-prefix">%1$s</span>', $settings['number_prefix'] );
                            }
                        ?>
                        <div <?php echo $this->get_render_attribute_string( 'counter-number' ); ?>>
                            0
                        </div>
                        <?php
                            if ( $settings['number_suffix'] != '' ) {
                                printf( '<span class="dl-counter-number-suffix">%1$s</span>', $settings['number_suffix'] );
                            }
                        ?>
                    </div>

                    <div class="dl-icon-title-wrap">
                        <?php
                            if ( !empty( $settings['counter_title'] ) ) {
                                printf( '<%1$s %2$s>', $settings['title_html_tag'], $this->get_render_attribute_string( 'counter_title' ) );
                                    echo Helper::kses_basic( $settings['counter_title'] );
                                printf( '</%1$s>', $settings['title_html_tag'] );
                            }
                        ?>
                    </div>
                    
                <?php } elseif ( $settings['counter_layout'] == 'layout-8' ) { ?>
                    <div class="dl-icon-title-wrap">
                        <?php
                            // Counter icon
                            $this->render_icon();
                        ?>
                    </div>

                    <div class="dl-counter-content">
                        <div class="dl-counter-number-wrap">
                            <?php
                                if ( $settings['number_prefix'] != '' ) {
                                    printf( '<span class="dl-counter-number-prefix">%1$s</span>', $settings['number_prefix'] );
                                }
                            ?>
                            <div <?php echo $this->get_render_attribute_string( 'counter-number' ); ?>>
                                0
                            </div>
                            <?php
                                if ( $settings['number_suffix'] != '' ) {
                                    printf( '<span class="dl-counter-number-suffix">%1$s</span>', $settings['number_suffix'] );
                                }
                            ?>
                        </div>
                        <?php
                        if ( !empty( $settings['counter_title'] ) ) {
                            printf( '<%1$s %2$s>', $settings['title_html_tag'], $this->get_render_attribute_string( 'counter_title' ) );
                                echo Helper::kses_basic( $settings['counter_title'] );
                            printf( '</%1$s>', $settings['title_html_tag'] );
                        }
                        ?>
                    </div>
                <?php } ?>
            </div>
        </div><!-- .dl-counter-container -->
        <?php
    }

    /**
	 * Render counter icon output on the frontend.
     */
    private function render_icon() {
        $settings = $this->get_settings_for_display();
        
        if ( $settings['dl_icon_type'] == 'icon' ) {
            if ( ! empty( $settings['icon'] ) ) {
                $this->add_render_attribute( 'icon', 'class', $settings['icon'] );
                $this->add_render_attribute( 'icon', 'aria-hidden', 'true' );
            }
            $migrated = isset( $settings['__fa4_migrated']['counter_icon'] );
            $is_new = empty( $settings['icon'] ) && Icons_Manager::is_migration_allowed();
            if ( !empty( $settings['counter_icon'] ) ) { ?>
                <span class="dl-counter-icon-wrap">
                    <span class="dl-counter-icon">
                    <?php if ( $is_new || $migrated ) :
                        Icons_Manager::render_icon( $settings['counter_icon'], [ 'aria-hidden' => 'true' ] );
                    else : ?>
                        <span <?php echo $this->get_render_attribute_string( 'icon' ); ?>></i>
                    <?php endif; ?>
                    </span>
                </span>
            <?php }
        } elseif ( $settings['dl_icon_type'] == 'image' ) {
            $image = $settings['icon_image'];
            if ( $image['url'] ) {
            ?>
                <span class="dl-counter-icon-wrap">
                    <span class="dl-counter-icon dl-counter-icon-img">
                        <img src="<?php echo esc_url( $image['url'] ); ?>" alt="<?php echo esc_attr(get_post_meta($image['id'], '_wp_attachment_image_alt', true)); ?>">
                    </span>
                </span>
            <?php }
        }

        if ( $settings['icon_divider'] == 'yes' ) {
            if ( $settings['counter_layout'] == 'layout-1' || $settings['counter_layout'] == 'layout-2' ) { ?>
                <div class="dl-counter-icon-divider-wrap">
                    <span class="dl-counter-icon-divider"></span>
                </div>
                <?php
            }
        }
    }

    /**
	 * Render counter icon output in the editor.
	 */
    protected function _icon_template() {
        ?>
        <# if ( settings.dl_icon_type == 'icon' ) { #>
            <# if ( settings.counter_icon != '' ) { 
                
                var iconHTML = elementor.helpers.renderIcon( view, settings.counter_icon, { 'aria-hidden': true }, 'i' , 'object' ),
				migrated = elementor.helpers.isIconMigrated( settings, 'counter_icon' );
                #>
                <span class="dl-counter-icon-wrap">
                    <span class="dl-counter-icon">
                        <# if ( iconHTML && iconHTML.rendered && ( ! settings.icon || migrated ) ) { #>
                            {{{ iconHTML.value }}}
                        <# } else { #>
                            <span class="{{ settings.icon }}" aria-hidden="true"></span>
                        <# } #>
                    </span>
                </span>
            <# } #>
        <# } else if ( settings.dl_icon_type == 'image' ) { #>
            <# if ( settings.icon_image.url != '' ) { #>
                <span class="dl-counter-icon-wrap">
                    <span class="dl-counter-icon dl-counter-icon-img">
                        <img src="{{ settings.icon_image.url }}">
                    </span>
                </span>
            <# } #>
        <# } #>

        <# if ( settings.icon_divider == 'yes' ) { #>
            <# if ( settings.counter_layout == 'layout-1' || settings.counter_layout == 'layout-2' ) { #>
                <div class="dl-counter-icon-divider-wrap">
                    <span class="dl-counter-icon-divider"></span>
                </div>
            <# } #>
        <# } #>
        <?php
    }

    /**
	 * Render counter number output in the editor.
	 */
    protected function _number_template() {
        ?>
        <div class="dl-counter-number-wrap">
            <#
                if ( settings.number_prefix != '' ) {
                    var prefix = settings.number_prefix;

                    view.addRenderAttribute( 'prefix', 'class', 'dl-counter-number-prefix' );

                    var prefix_html = '<span' + ' ' + view.getRenderAttributeString( 'prefix' ) + '>' + prefix + '</span>';

                    print( prefix_html );
                }
            #>
            <div class="dl-counter-number" data-to="{{ settings.ending_number }}" data-speed="{{ settings.counter_speed.size }}">
                0
            </div>
            <#
                if ( settings.number_suffix != '' ) {
                    var suffix = settings.number_suffix;

                    view.addRenderAttribute( 'suffix', 'class', 'dl-counter-number-suffix' );

                    var suffix_html = '<span' + ' ' + view.getRenderAttributeString( 'suffix' ) + '>' + suffix + '</span>';

                    print( suffix_html );
                }
            #>
        </div>
        <?php
    }

    /**
	 * Render counter title output in the editor.
	 */
    protected function _title_template() {
        ?>
        <#
            if ( settings.counter_title != '' ) {
                var title = settings.counter_title;

                view.addRenderAttribute( 'counter_title', 'class', 'dl-counter-title' );

                view.addInlineEditingAttributes( 'counter_title' );

                var title_html = '<' + settings.title_html_tag  + ' ' + view.getRenderAttributeString( 'counter_title' ) + '>' + title + '</' + settings.title_html_tag + '>';

                print( title_html );
            }
        #>
        <?php
    }

    /**
     * Elementor content template function
     *
     * @return void
     */
    protected function content_template() {

        ?>
        <div class="dl-counter-container">
            <div class="dl-counter dl-counter-{{ settings.counter_layout }}" data-target=".dl-counter-number">
                <# if ( settings.counter_layout == 'layout-1' || settings.counter_layout == 'layout-5' || settings.counter_layout == 'layout-6' ) { #>
                    <?php
                        // Counter icon
                        $this->_icon_template();
                    ?>
                
                    <div class="dl-counter-number-title-wrap">
                        <?php
                            // Counter number
                            $this->_number_template();
                        ?>

                        <# if ( settings.num_divider == 'yes' ) { #>
                            <div class="dl-counter-num-divider-wrap">
                                <span class="dl-counter-num-divider"></span>
                            </div>
                        <# } #>

                        <?php
                            // Title number
                            $this->_title_template();
                        ?>
                    </div>
                <# } else if ( settings.counter_layout == 'layout-2' ) { #>
                    <?php
                        // Counter icon
                        $this->_icon_template();
        
                        // Title number
                        $this->_title_template();
        
                        // Counter number
                        $this->_number_template();
                    ?>

                    <# if ( settings.num_divider == 'yes' ) { #>
                        <div class="dl-counter-num-divider-wrap">
                            <span class="dl-counter-num-divider"></span>
                        </div>
                    <# } #>
                <# } else if ( settings.counter_layout == 'layout-3' ) { #>
                    <?php
                        // Counter number
                        $this->_number_template();
                    ?>

                    <# if ( settings.num_divider == 'yes' ) { #>
                        <div class="dl-counter-num-divider-wrap">
                            <span class="dl-counter-num-divider"></span>
                        </div>
                    <# } #>
                
                    <div class="dl-icon-title-wrap">
                        <?php
                            // Counter icon
                            $this->_icon_template();
        
                            // Title number
                            $this->_title_template();
                        ?>
                    </div>
                <# } else if ( settings.counter_layout == 'layout-4' ) { #>
                    <div class="dl-icon-title-wrap">
                        <?php
                            // Counter icon
                            $this->_icon_template();

                            // Title number
                            $this->_title_template();
                        ?>
                    </div>
                
                    <?php
                        // Counter number
                        $this->_number_template();
                    ?>

                    <# if ( settings.num_divider == 'yes' ) { #>
                        <div class="dl-counter-num-divider-wrap">
                            <span class="dl-counter-num-divider"></span>
                        </div>
                    <# } #>
                <# } else if ( settings.counter_layout == 'layout-7' ) { #>
                    <?php
                        // Counter number
                        $this->_number_template();
                    ?>
                    <div class="dl-icon-title-wrap">
                        <?php
                            // Title number
                            $this->_title_template();
                        ?>
                    </div>
                <# } else if ( settings.counter_layout == 'layout-8' ) { #>
                    <div class="dl-icon-title-wrap">
                        <?php
                            // Counter icon
                            $this->_icon_template();
                        ?>
                    </div>

                    <div class="dl-counter-content">
                        <?php
                            // Counter number
                            $this->_number_template();
                            // Title number
                            $this->_title_template();
                        ?>
                    </div>
                <# } #>
            </div>
        </div>
        <?php

    }

}