<?php
/**
 * Flip Box
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\FlipBox;

use RediasCore\Classes\Helper;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Widget_Base;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-flipbox';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Flip Box', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-flip-box';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'flip', 'box', 'flip', 'info', 'content', 'animation', 'redias' ];
    }

    public function get_style_depends() {
        return ['redias-flip-box'];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_front_side();
        $this->section_back_side();
        $this->section_settings();
        $this->common_style();
        $this->front_side_style();
        $this->back_side_style();

    }

    /**
     * Section Front Side
     *
     * @return void
     */
    protected function section_front_side() {
        
        $this->start_controls_section(
			'section_front_side',
			[
				'label' => esc_html__( 'Front Side', 'redias-core' )
			]
		);

		$this->add_control(
            'front_icon_type',
            [
                'label' => esc_html__( 'Media Type', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => false,
                'default' => 'icon',
                'options' => [
                    'none' => [
                        'title' => esc_html__( 'None', 'redias-core' ),
                        'icon' => 'eicon-close',
                    ],
                    'icon' => [
                        'title' => esc_html__( 'Icon', 'redias-core' ),
                        'icon' => 'eicon-star',
                    ],
                    'image' => [
                        'title' => esc_html__( 'Image', 'redias-core' ),
                        'icon' => 'eicon-image',
                    ],
                ],
                'toggle' => false,
            ]
        );

        $this->add_control(
			'front_icon',
			[
				'label' => esc_html__( 'Icon', 'redias-core' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
                'condition' => [
                    'front_icon_type' => 'icon'
                ]
			]
		);

        $this->add_control(
            'front_icon_image',
            [
                'label' => esc_html__( 'Image', 'redias-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'front_icon_type' => 'image'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'front_icon_thumbnail',
                'default' => 'thumbnail',
                'exclude' => [
                    'full',
                    'shop_catalog',
                    'shop_single',
                ],
                'condition' => [
                    'front_icon_type' => 'image'
                ]
            ]
        );

        $this->add_control(
            'front_title',
            [
                'label' => esc_html__( 'Title', 'redias-core' ),
                'label_block' => true,
                'separator' => 'before',
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Start Marketing', 'redias-core' ),
                'placeholder' => esc_html__( 'Type Flip Box Title', 'redias-core' ),
            ]
        );

        $this->add_control(
            'front_description',
            [
                'label' => esc_html__( 'Description', 'redias-core' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __( 'consectetur adipiscing elit, sed do<br>eiusmod Lorem ipsum dolor sit amet,<br> consectetur.', 'redias-core' ),
                'placeholder' => esc_html__( 'Description', 'redias-core' ),
            ]
        );

        $this->add_control(
            'front_text_align',
            [
                'label' => esc_html__( 'Alignment', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front-inner .icon-wrap' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .dl-flip-box-front-inner .dl-text' => 'text-align: {{VALUE}};'
                ],
                'toggle' => false
            ]
        );

		$this->end_controls_section();

    }

    /**
     * Section Back Side
     *
     * @return void
     */
    protected function section_back_side() {
        
        $this->start_controls_section(
			'section_back_side',
			[
				'label' => esc_html__( 'Back Side', 'redias-core' )
			]
		);

		$this->add_control(
            'back_icon_type',
            [
                'label' => esc_html__( 'Media Type', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => false,
                'default' => 'none',
                'options' => [
                    'none' => [
                        'title' => esc_html__( 'None', 'redias-core' ),
                        'icon' => 'eicon-close',
                    ],
                    'icon' => [
                        'title' => esc_html__( 'Icon', 'redias-core' ),
                        'icon' => 'eicon-star',
                    ],
                    'image' => [
                        'title' => esc_html__( 'Image', 'redias-core' ),
                        'icon' => 'eicon-image',
                    ],
                ],
                'toggle' => false,
            ]
        );

        $this->add_control(
            'back_icon_image',
            [
                'label' => esc_html__( 'Image', 'redias-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'back_icon_type' => 'image'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'back_icon_thumbnail',
                'default' => 'thumbnail',
                'exclude' => [
                    'full',
                    'shop_catalog',
                    'shop_single',
                ],
                'condition' => [
                    'back_icon_type' => 'image'
                ]
            ]
        );

        $this->add_control(
			'back_icon',
			[
				'label' => esc_html__( 'Icon', 'redias-core' ),
				'type' => \Elementor\Controls_Manager::ICONS,
                'condition' => [
                    'back_icon_type' => 'icon'
                ]
			]
		);

        $this->add_control(
            'back_title',
            [
                'label' => esc_html__( 'Title', 'redias-core' ),
                'label_block' => true,
                'separator' => 'before',
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Start Marketing', 'redias-core' ),
                'placeholder' => esc_html__( 'Type Flip Box Title', 'redias-core' ),
            ]
        );

        $this->add_control(
            'back_description',
            [
                'label' => esc_html__( 'Description', 'redias-core' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXTAREA,
                'default' => __( 'consectetur adipiscing elit, sed do<br>eiusmod Lorem ipsum dolor sit amet.', 'redias-core' ),
                'placeholder' => esc_html__( 'Description', 'redias-core' ),
            ]
        );

        $this->add_control(
            'back_text_align',
            [
                'label' => esc_html__( 'Alignment', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back-inner .icon-wrap' => 'text-align: {{VALUE}}',
                    '{{WRAPPER}} .dl-flip-box-back-inner .dl-text' => 'text-align: {{VALUE}}',
                    '{{WRAPPER}} .dl-flip-box-back-inner .button-wrap' => 'text-align: {{VALUE}}',
                ],
                'toggle' => false
            ]
        );

		$this->end_controls_section();

    }

    /**
     * Section Settings
     *
     * @return void
     */
    protected function section_settings() {
        
        $this->start_controls_section(
			'section_settings',
			[
				'label' => esc_html__( 'Settings', 'redias-core' )
			]
		);

		$this->add_control(
            'flip_position',
            [
                'label' => esc_html__( 'Flip Direction', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'default' => 'right',
                'label_block' => false,
                'options' => [
                    'up' => [
                        'title' => esc_html__( 'Bottom To Top', 'redias-core' ),
                        'icon' => 'eicon-v-align-top',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Left To Right', 'redias-core' ),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'toggle' => false,
            ]
        );

		$this->end_controls_section();

    }

    /**
     * Common Style
     *
     * @return void
     */
    protected function common_style() {
        
        $this->start_controls_section(
			'section_common',
			[
				'label' => esc_html__( 'Common', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE
			]
		);

		$this->add_responsive_control(
            'height',
            [
                'label' => esc_html__( 'Height', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 100,
                        'max' => 1000,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front' => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-flip-box-back' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'content_area_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'separator' => 'after',
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .dl-flip-box-front:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .dl-flip-box-back' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .dl-flip-box-back:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		$this->end_controls_section();

    }

    /**
     * Front Side Style
     *
     * @return void
     */
    protected function front_side_style() {
        
        $this->start_controls_section(
			'section_front_style',
			[
				'label' => esc_html__( 'Front Side', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE
			]
		);

		$this->add_responsive_control(
            'front_content_padding',
            [
                'label' => esc_html__( 'Padding', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'front_border',
                'selector' => '{{WRAPPER}} .dl-flip-box-front',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'front_box_shadow',
                'selector' => '{{WRAPPER}} .dl-flip-box-front',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'front_background_image',
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .dl-flip-box-front',
            ]
        );

        $this->add_control(
            'front_background_overlay',
            [
                'label' => esc_html__( 'Background Overlay', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'front_background_image_image[url]!' => ''
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-wrap .dl-flip-box .dl-flip-box-front:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'front_background_color',
            [
                'label' => esc_html__( 'Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#fff',
                'condition' => [
                    'front_background_type' => 'color',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'front_icon_heading',
            [
                'label' => esc_html__( 'Media Type - Icon', 'redias-core' ),
                'type' => Controls_Manager::HEADING,
                'condition' => [
                    'front_icon_type' => 'icon'
                ],
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'front_icon_heading_image',
            [
                'label' => esc_html__( 'Media Type - Image', 'redias-core' ),
                'type' => Controls_Manager::HEADING,
                'condition' => [
                    'front_icon_type' => 'image'
                ],
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'front_icon_spacing',
            [
                'label' => esc_html__( 'Bottom Spacing', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front .dl-flip-icon' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'front_icon_image_size',
            [
                'label' => esc_html__( 'Resize Image', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'condition' => [
                    'front_icon_type' => 'image'
                ],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 500,
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front-inner .icon-wrap .dl-flip-icon img' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'front_icon_image_fit',
            [
                'label' => esc_html__( 'Image Fit', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'contain'  => esc_html__( 'Contain', 'redias-core' ),
                    'cover' => esc_html__( 'Cover', 'redias-core' ),
                ],
                'condition' => [
                    'front_icon_type' => 'image'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front-inner .icon-wrap .dl-flip-icon img' => 'object-fit: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'front_icon_font_size',
            [
                'label' => esc_html__( 'Icon Size', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em'],
                'condition' => [
                    'front_icon_type' => 'icon'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front-inner .dl-flip-icon' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-flip-box-front-inner .dl-flip-icon svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'front_icon_background_size',
            [
                'label' => esc_html__( 'Icon Box Size', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'condition' => [
                    'front_icon_type' => [ 'icon', 'image' ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front-inner .icon-wrap .dl-flip-icon' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'front_icon_border',
                'condition' => [
                    'front_icon_type' => [ 'icon', 'image' ],
                ],
                'selector' => '{{WRAPPER}} .dl-flip-box-front-inner .icon-wrap .dl-flip-icon',
            ]
        );

        $this->add_control(
            'front_icon_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'condition' => [
                    'front_icon_type' => [ 'icon', 'image' ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front-inner .icon-wrap .dl-flip-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'front_icon_box_shadow',
                'selector' => '{{WRAPPER}} .dl-flip-box-front-inner .dl-flip-icon',
                'condition' => [
                    'front_icon_type' => [ 'icon', 'image' ],
                ],
            ]
        );

        $this->add_control(
            'front_icon_color',
            [
                'label' => esc_html__( 'Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'front_icon_type' => 'icon'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front-inner .icon-wrap .dl-flip-icon i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .dl-flip-box-front-inner .icon-wrap .dl-flip-icon svg' => 'fill: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'front_icon_background_color',
            [
                'label' => esc_html__( 'Background Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'front_icon_type' => [ 'icon', 'image' ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front-inner .icon-wrap .dl-flip-icon' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'front_text',
            [
                'label' => esc_html__( 'Title & Description', 'redias-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs( '_tabs_front_text' );

        $this->start_controls_tab(
            '_tab_front_title',
            [
                'label' => esc_html__( 'Title', 'redias-core' ),
            ]
        );

        $this->add_control(
            'front_title_color',
            [
                'label' => esc_html__( 'Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front-inner .dl-flip-box-heading' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'front_title_typography',
                'label' => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-flip-box-front-inner .dl-flip-box-heading',
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'front_title_text_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-flip-box-front-inner .dl-flip-box-heading',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            '_tab_front_description',
            [
                'label' => esc_html__( 'Description', 'redias-core' ),
            ]
        );

        $this->add_responsive_control(
            'front_description_space',
            [
                'label' => esc_html__( 'Spacing', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front-inner .dl-text p' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'front_description_color',
            [
                'label' => esc_html__( 'Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-front-inner .dl-text p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'front_description_typography',
                'label' => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-flip-box-front-inner .dl-text p',
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'front_description_text_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-flip-box-front-inner .dl-text p',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

		$this->end_controls_section();

    }

    /**
     * Back Side Style
     *
     * @return void
     */
    protected function back_side_style() {
        
        $this->start_controls_section(
			'section_back_style',
			[
				'label' => esc_html__( 'Back Side', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE
			]
		);

		$this->add_responsive_control(
            'back_content_padding',
            [
                'label' => esc_html__( 'Padding', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'back_border',
                'selector' => '{{WRAPPER}} .dl-flip-box-back',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'back_box_shadow',
                'selector' => '{{WRAPPER}} .dl-flip-box-back',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'back_background_image',
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .dl-flip-box-back',
            ]
        );

        $this->add_control(
            'back_background_overlay',
            [
                'label' => esc_html__( 'Background Overlay', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => 'rgba(0,0,0,0.27)',
                'condition' => [
                    'back_background_image_background' => 'classic'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-wrap .dl-flip-box .dl-flip-box-back:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'back_background_color',
            [
                'label' => esc_html__( 'Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#27374c',
                'condition' => [
                    'back_background_type' => 'color'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'back_icon_heading',
            [
                'label' => esc_html__( 'Media Type - Icon', 'redias-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'back_icon_type' => 'icon'
                ],
            ]
        );

        $this->add_control(
            'back_icon_heading_image',
            [
                'label' => esc_html__( 'Media Type - Image', 'redias-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'back_icon_type' => 'image'
                ],
            ]
        );

        $this->add_responsive_control(
            'back_icon_spacing',
            [
                'label' => esc_html__( 'Bottom Spacing', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%'],
                'condition' => [
                    'back_icon_type' => [ 'icon', 'image' ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back-inner .dl-flip-icon' => 'margin-bottom: {{SIZE}}{{UNIT}};'
                ],
            ]
        );

        $this->add_responsive_control(
            'back_icon_image_size',
            [
                'label' => esc_html__( 'Resize Image', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'condition' => [
                    'back_icon_type' => 'image'
                ],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 500,
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back-inner .dl-flip-icon img' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'back_icon_image_fit',
            [
                'label' => esc_html__( 'Image Fit', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'contain'  => esc_html__( 'Contain', 'redias-core' ),
                    'cover' => esc_html__( 'Cover', 'redias-core' ),
                ],
                'condition' => [
                    'back_icon_type' => 'image'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back-inner .icon-wrap .dl-flip-icon img' => 'object-fit: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'back_icon_font_size',
            [
                'label' => esc_html__( 'Icon Size', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em'],
                'condition' => [
                    'back_icon_type' => 'icon'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back-inner .dl-flip-icon' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-flip-box-back-inner .dl-flip-icon svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'back_icon_padding',
            [
                'label' => esc_html__( 'Icon Box Size', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'condition' => [
                    'back_icon_type' => [ 'icon', 'image' ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back-inner .icon-wrap .dl-flip-icon' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'back_icon_border',
                'condition' => [
                    'back_icon_type' => [ 'icon', 'image' ],
                ],
                'selector' => '{{WRAPPER}} .dl-flip-box-back-inner .icon-wrap .dl-flip-icon',
            ]
        );

        $this->add_control(
            'back_icon_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'condition' => [
                    'back_icon_type' => [ 'icon', 'image']
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back-inner .icon-wrap .dl-flip-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .dl-flip-box-back-inner .dl-flip-icon img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'back_icon_box_shadow',
                'condition' => [
                    'back_icon_type' => [ 'icon', 'image']
                ],
                'selector' => '{{WRAPPER}} .dl-flip-box-back-inner .dl-flip-icon',
            ]
        );

        $this->add_control(
            'back_icon_color',
            [
                'label' => esc_html__( 'Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'back_icon_type' => 'icon'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back-inner .dl-flip-icon i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .dl-flip-box-back-inner .dl-flip-icon svg' => 'fill: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'back_icon_background_color',
            [
                'label' => esc_html__( 'Background Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'back_icon_type' => [ 'icon', 'image' ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back-inner .icon-wrap .dl-flip-icon' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'back_text',
            [
                'label' => esc_html__( 'Title & Description', 'redias-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs( '_tabs_back_text' );

        $this->start_controls_tab(
            '_tab_back_title',
            [
                'label' => esc_html__( 'Title', 'redias-core' ),
            ]
        );

        $this->add_control(
            'back_title_color',
            [
                'label' => esc_html__( 'Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back-inner .dl-flip-box-heading-back' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'back_title_typography',
                'label' => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-flip-box-back-inner .dl-flip-box-heading-back',
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'back_title_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-flip-box-back-inner .dl-flip-box-heading-back',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            '_tab_back_description',
            [
                'label' => esc_html__( 'Description', 'redias-core' ),
            ]
        );

        $this->add_responsive_control(
            'back_description_space',
            [
                'label' => esc_html__( 'Spacing', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back-inner .dl-text p' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'back_description_color',
            [
                'label' => esc_html__( 'Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-flip-box-back-inner .dl-text p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'back_description_typography',
                'label' => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-flip-box-back-inner .dl-text p',
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'back_description_text_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-flip-box-back-inner .dl-text p',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

		$this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

		$settings = $this->get_settings_for_display();
		// icon/image
        if ( ! empty( $settings['front_icon_image']['id'] ) && isset( $settings['front_icon_image']['url'] ) ) {
            $this->add_render_attribute( 'front_icon_image', 'src', $settings['front_icon_image']['url'] );
            $this->add_render_attribute( 'front_icon_image', 'alt', Control_Media::get_image_alt( $settings['front_icon_image'] ) );
            $this->add_render_attribute( 'front_icon_image', 'title', Control_Media::get_image_title( $settings['front_icon_image'] ) );
        }

        // title & description
        $this->add_render_attribute( 'front_title', 'class', 'dl-flip-box-heading' );
        $this->add_render_attribute( 'back_title', 'class', 'dl-flip-box-heading-back' );
        $this->add_render_attribute( 'front_description', 'class', 'dl-desc' );
        $this->add_render_attribute( 'back_description', 'class', 'dl-desc' );
        $this->add_inline_editing_attributes( 'back_description', 'basic' );

        // display type
        $this->add_render_attribute( 'display', 'class', 'dl-flip-box-container dl-flip-effect-classic' );

        // flip position
        $this->add_render_attribute( 'flip-position', 'class', 'dl-flip-box-inner' );
        if ( $settings['flip_position'] === 'up' ) {
            $this->add_render_attribute( 'flip-position', 'class', 'dl-flip-up' );
        } elseif ( $settings['flip_position'] === 'right' ) {
            $this->add_render_attribute( 'flip-position', 'class', 'dl-flip-right' );
        }
        ?>

        <div <?php echo $this->get_render_attribute_string( 'display' ); ?>>
            <div <?php echo $this->get_render_attribute_string( 'flip-position' ); ?>>
                <div class="dl-flip-box-inner-wrapper">
                    <div class="dl-flip-box-front">
                        <div class="dl-flip-box-front-inner">
                            <div class="icon-wrap">
                                <?php if ( $settings['front_icon'] ) : ?>
                                    <div class="dl-flip-icon icon">
                                        <?php \Elementor\Icons_Manager::render_icon( $settings['front_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                                    </div>
                                <?php endif; ?>
                                <?php if ( $settings['front_icon_image'] ) : ?>
                                    <div class="dl-flip-icon">
                                        <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'front_icon_thumbnail', 'front_icon_image' ); ?>
                                    </div>
                                <?php endif; ?>
                            </div>

                            <div class="dl-text">
                                <?php if ( $settings['front_title'] ) : ?>
                                    <h2 <?php echo $this->get_render_attribute_string( 'front_title' ); ?>><?php echo esc_html( $settings['front_title'] ); ?></h2>
                                <?php endif; ?>

                                <?php if ( $settings['front_description'] ) : ?>
                                    <p <?php echo $this->get_render_attribute_string( 'front_description' ); ?>><?php echo Helper::kses_advance( $settings['front_description'] ); ?></p>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>

                    <div class="dl-flip-box-back">
                        <div class="dl-flip-box-back-inner">
                            <div class="icon-wrap">
                                <?php if ( $settings['back_icon'] ) : ?>
                                    <div class="dl-flip-icon icon">
                                        <?php \Elementor\Icons_Manager::render_icon( $settings['back_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                                    </div>
                                <?php endif; ?>
                                <?php if ( $settings['back_icon_image'] ) : ?>
                                    <div class="dl-flip-icon">
                                        <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'back_icon_thumbnail', 'back_icon_image' ); ?>
                                    </div>
                                <?php endif; ?>
                            </div>

                            <div class="dl-text">
                                <?php if ( $settings['back_title'] ) : ?>
                                    <h2 <?php echo $this->get_render_attribute_string( 'back_title' ); ?>><?php echo esc_html( $settings['back_title'] ); ?></h2>
                                <?php endif; ?>

                                <?php if ( $settings['back_description'] ) : ?>
                                    <p <?php echo $this->get_render_attribute_string( 'back_description' ) ?>><?php echo Helper::kses_advance( $settings['back_description'] ); ?></p>
                                <?php endif; ?>
                            </div>

                        </div>
                    </div>
                </div>
            </div>
        </div>
    <?php

    }

}