<?php
/**
 * Hero
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Hero;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;

use RediasCore\Classes\Helper;
use RediasCore\Elementor\Controls\Foreground;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-hero';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Hero', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-single-page';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'hero', 'banner', 'redias' ];
    }

    public function get_style_depends() {
        return [ 'redias-hero', 'redias-button', 'redias-play-button', 'elementor-icons-line-awesome-icons' ];
    }

    public function get_script_depends() {
        return [ 'redias-el-script' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_general();
        $this->section_sub_heading();
        $this->section_heading();
        $this->section_description();
        $this->wrapper_style();
        $this->sub_heading_style();
        $this->heading_style();
        $this->description_style();
        $this->section_brands_circle();
        $this->section_button();
        $this->section_play_button();
        $this->button_style();
        $this->play_button_style();
        $this->arrow_symbol_style();

    }

    /**
     * General Control
     *
     * @return void
     */
    protected function section_general() {

        $this->start_controls_section(
			'section_general',
			[
				'label' => esc_html__( 'General', 'redias-core' )
			]
        );

        $this->add_responsive_control(
			'button_group_spaceing',
			[
				'label' => esc_html__( 'Button Group Spacing', 'textdomain' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => -100,
						'max' => 100,
						'step' => 1
					]
				],
				'selectors' => [
					'{{WRAPPER}} .btn-holder' => 'margin-top: {{SIZE}}{{UNIT}};',
				],
			]
		);

        $this->add_responsive_control(
			'button_spacebetween',
			[
				'label' => esc_html__( 'Space Between Button', 'textdomain' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					]
				],
				'selectors' => [
					'{{WRAPPER}} .btn-holder' => 'column-gap: {{SIZE}}{{UNIT}};',
				],
			]
		);
        
        $this->end_controls_section();

    }

    /**
     * Sub Heading Control
     *
     * @return void
     */
    protected function section_sub_heading() {

        $this->start_controls_section(
			'section_sub_heading',
			[
				'label' => esc_html__( 'Sub Heading', 'redias-core' )
			]
        );

        $this->add_control(
            'sub_heading',
            [
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__( 'Trusted Digital Agency!', 'redias-core' ),
                'placeholder' => esc_html__( 'Text goes here...', 'redias-core' ),
                'rows'        => 4,
				'dynamic' => [
					'active' => true,
				]
            ]
        );

        $this->add_control(
            'sub_heading_tag',
            [
                'label' => esc_html__( 'HTML Tag', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'default' => 'h4',
                'options' => [
                    'h1'  => [
                        'title' => esc_html__( 'H1', 'redias-core' ),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2'  => [
                        'title' => esc_html__( 'H2', 'redias-core' ),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3'  => [
                        'title' => esc_html__( 'H3', 'redias-core' ),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4'  => [
                        'title' => esc_html__( 'H4', 'redias-core' ),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5'  => [
                        'title' => esc_html__( 'H5', 'redias-core' ),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6'  => [
                        'title' => esc_html__( 'H6', 'redias-core' ),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'toggle' => false,
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_control(
            'sub_heading_icon',
            [
                'label'   => esc_html__( 'Icon', 'redias-core' ),
                'type'    => Controls_Manager::ICONS,
                'skin'    => 'inline',
                'exclude_inline_options' => ['svg'],
                'default' => [
                    'value'   => 'la la-bolt',
                    'library' => 'elementor-icons-line-awesome-icons',
                ],
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Heading Control
     *
     * @return void
     */
    protected function section_heading() {

        $this->start_controls_section(
			'section_heading',
			[
				'label' => esc_html__( 'Heading', 'redias-core' )
			]
        );

        $this->add_control(
            'heading',
            [
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__( 'Smart Ideas For Your Brands Are Here!', 'redias-core' ),
                'placeholder' => esc_html__( 'Text goes here...', 'redias-core' ),
                'rows'        => 4,
				'dynamic' => [
					'active' => true,
				]
            ]
        );

        $this->add_control(
            'heading_tag',
            [
                'label' => esc_html__( 'HTML Tag', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'default' => 'h2',
                'options' => [
                    'h1'  => [
                        'title' => esc_html__( 'H1', 'redias-core' ),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2'  => [
                        'title' => esc_html__( 'H2', 'redias-core' ),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3'  => [
                        'title' => esc_html__( 'H3', 'redias-core' ),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4'  => [
                        'title' => esc_html__( 'H4', 'redias-core' ),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5'  => [
                        'title' => esc_html__( 'H5', 'redias-core' ),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6'  => [
                        'title' => esc_html__( 'H6', 'redias-core' ),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'toggle' => false,
                'condition' => [
					'heading!' => ''
				],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Description Control
     *
     * @return void
     */
    protected function section_description() {

        $this->start_controls_section(
			'section_desc',
			[
				'label' => esc_html__( 'Description', 'redias-core' )
			]
        );

        $this->add_control(
            'desc',
            [
                'label' => esc_html__( 'Description', 'redias-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => 'Our success in creating business solutions is due in large part to <br>our talented and highly committed team.',
                'placeholder' => esc_html__( 'Text goes here...', 'redias-core' ),
                'rows'        => 4,
				'dynamic' => [
					'active' => true,
				]
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Brands Circle Control
     *
     * @return void
     */
    protected function section_brands_circle() {

        $this->start_controls_section(
			'section_brands_circle',
			[
				'label' => esc_html__( 'Brands/Image', 'redias-core' )
			]
        );
        
        $this->add_control(
			'bc_content_type',
			[
				'label' => esc_html__( 'Content Type', 'textdomain' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'brands' => [
						'title' => esc_html__( 'Brands', 'textdomain' ),
						'icon' => 'eicon-social-icons',
					],
					'image' => [
						'title' => esc_html__( 'Image', 'textdomain' ),
						'icon' => 'eicon-image-bold',
					]
				],
				'default' => 'brands',
				'toggle' => false
			]
		);

        $this->add_control(
            'brands_circle_color',
            [
                'label'     => esc_html__( 'Circle Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .brands-circle' => '--brands-circle-color: {{VALUE}};',
                ],
                'condition' => [
                    'bc_content_type' => 'brands'
                ],
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'icon',
            [
                'label'   => esc_html__( 'Icon', 'redias-core' ),
                'type'    => Controls_Manager::ICONS,
                'skin'    => 'inline',
                'exclude_inline_options' => ['svg'],
                'default' => [
                    'value'   => 'la la-hubspot',
                    'library' => 'elementor-icons-line-awesome-icons'
                ],
            ]
        );

        $repeater->add_control(
            'customize',
            [
                'label'        => esc_html__( 'Want To Customize?', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'description'  => esc_html__( 'You can customize the style from here.', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'customize' => 'yes',
                    'icon[value]!' => ''
                ]
            ]
        );

        $repeater->add_control(
            'icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'customize' => 'yes',
                    'icon[value]!' => ''
                ]
            ]
        );
        
        $this->add_control(
            'brands_icons',
            [
                'label'       => esc_html__( 'Brands Icons', 'redias-core' ),
                'description'  => esc_html__( 'First 7 icon only show in the frontend.', 'redias-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'icon'   => [
                            'value'   => 'la la-hubspot',
                            'library' => 'elementor-icons-line-awesome-icons',
                        ]
                    ],
                    [
                        'icon'   => [
                            'value'   => 'la la-dribbble',
                            'library' => 'elementor-icons-line-awesome-icons',
                        ]
                    ],
                    [
                        'icon'   => [
                            'value'   => 'la la-earlybirds',
                            'library' => 'elementor-icons-line-awesome-icons',
                        ]
                    ],
                    [
                        'icon'   => [
                            'value'   => 'la la-behance',
                            'library' => 'elementor-icons-line-awesome-icons',
                        ]
                    ],
                    [
                        'icon'   => [
                            'value'   => 'la la-gitlab',
                            'library' => 'elementor-icons-line-awesome-icons',
                        ]
                    ],
                    [
                        'icon'   => [
                            'value'   => 'la la-itunes-note',
                            'library' => 'elementor-icons-line-awesome-icons',
                        ]
                    ],
                    [
                        'icon'   => [
                            'value'   => 'la la-slack',
                            'library' => 'elementor-icons-line-awesome-icons',
                        ]
                    ],
                ],
                'title_field' => '{{{ elementor.helpers.renderIcon( this, icon, {}, "i", "panel" ) }}}',
                'condition' => [
                    'bc_content_type' => 'brands'
                ],
            ]
        );

        $this->add_control(
			'brands_image',
			[
				'label' => esc_html__( 'Choose Image', 'textdomain' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
                'condition' => [
                    'bc_content_type' => 'image'
                ],
			]
		);

        $this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' => 'brands_image',
				'default' => 'large',
				'separator' => 'none',
                'condition' => [
                    'bc_content_type' => 'image',
                    'brands_image[url]!' => ''
                ]
			]
		);

        $this->add_responsive_control(
			'brands_image_width',
			[
				'label' => esc_html__( 'Width', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'unit' => '%',
				],
				'tablet_default' => [
					'unit' => '%',
				],
				'mobile_default' => [
					'unit' => '%',
				],
				'size_units' => [ '%', 'px', 'vw' ],
				'range' => [
					'%' => [
						'min' => 1,
						'max' => 100,
					],
					'px' => [
						'min' => 1,
						'max' => 1000,
					],
					'vw' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .image-wrap img' => 'width: {{SIZE}}{{UNIT}};',
				],
                'condition' => [
                    'bc_content_type' => 'image',
                    'brands_image[url]!' => ''
                ]
			]
		);

		$this->add_responsive_control(
			'brands_image_max_width',
			[
				'label' => esc_html__( 'Max Width', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'unit' => '%',
				],
				'tablet_default' => [
					'unit' => '%',
				],
				'mobile_default' => [
					'unit' => '%',
				],
				'size_units' => [ '%', 'px', 'vw' ],
				'range' => [
					'%' => [
						'min' => 1,
						'max' => 100,
					],
					'px' => [
						'min' => 1,
						'max' => 1000,
					],
					'vw' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .image-wrap img' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'bc_content_type' => 'image',
                    'brands_image[url]!' => ''
                ]
			]
		);
        
        $this->end_controls_section();

    }

    /**
     * Button Control
     *
     * @return void
     */
    protected function section_button() {

        $this->start_controls_section(
			'section_button',
			[
				'label' => esc_html__( 'Button', 'redias-core' )
			]
        );

        $this->add_control(
            'btn_text',
            [
                'label'       => esc_html__( 'Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Get Started', 'redias-core' ),
                'placeholder' => esc_html__( 'Text goes here.', 'redias-core' ),
                'dynamic' => [
					'active' => true,
				]
            ]
        );

        $this->add_control(
            'btn_link',
            [
                'label'         => esc_html__( 'Link', 'redias-core' ),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '#',
                    'is_external' => false,
                    'nofollow'    => true
                ],
                'condition'    => [
                    'btn_text!'    => ''
                ],
            ]
        );

        $this->add_control(
            'btn_icon',
            [
                'label'   => esc_html__( 'Icon', 'redias-core' ),
                'type'    => Controls_Manager::ICONS,
                'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'label_block' => false,
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'icon_position',
            [
                'label'   => esc_html__( 'Icon Position', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default' => 'left',
                'toggle'  => false,
                'selectors_dictionary' => [
                    'left' => 'flex-direction: row-reverse',
                    'right' => 'flex-direction: inherit'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-el-btn-wrap .btn-1.has-icon' => '{{VALUE}}'
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => '',
                    'btn_icon[value]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_indent',
            [
                'label'      => esc_html__( 'Icon Spacing', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
					'px' => [
						'max' => 50,
					],
				],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-btn-wrap .btn-1.has-icon' => 'column-gap: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => '',
                    'btn_icon[value]!' => ''
                ],
            ]
        );

        $this->add_control(
			'button_css_id',
			[
				'label' => esc_html__( 'Button ID', 'elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => '',
				'title' => esc_html__( 'Add your custom id WITHOUT the Pound key. e.g: my-id', 'redias-core' ),
				'description' => esc_html__( 'Please make sure the ID is unique and not used elsewhere on the page this form is displayed. This field allows <code>A-z 0-9</code> & underscore chars without spaces.', 'redias-core' ),
				'separator' => 'before',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
			]
		);
        
        $this->end_controls_section();

    }

    /**
     * Play Button Control
     *
     * @return void
     */

    protected function section_play_button() {

        $this->start_controls_section(
			'section_play_button',
			[
				'label' => esc_html__( 'Play Button', 'redias-core' )
			]
        );

        $this->add_control(
            'play_btn_text',
            [
                'label'       => esc_html__( 'Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Watch Video', 'redias-core' ),
                'placeholder' => esc_html__( 'Text goes here.', 'redias-core' ),
                'dynamic' => [
					'active' => true,
				]
            ]
        );

        $this->add_control(
			'play_btn_type',
			[
				'label' => esc_html__( 'Type', 'textdomain' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'lightbox',
				'options' => [
					'lightbox' => esc_html__( 'Lightbox', 'textdomain' ),
					'link'  => esc_html__( 'Link', 'textdomain' ),
				],
                'condition'    => [
                    'play_btn_text!'    => ''
                ],
			]
		);

        $this->add_control(
            'play_btn_link',
            [
                'label'         => esc_html__( 'Link', 'redias-core' ),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '#',
                    'is_external' => false,
                    'nofollow'    => true
                ],
                'condition'    => [
                    'play_btn_type'    => 'link',
                    'play_btn_text!'    => ''
                ],
            ]
        );

        $this->add_control(
			'play_video_url',
			[
				'label' => esc_html__( 'Video URL', 'textdomain' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'YouTube or Vimeo url goes here', 'textdomain' ),
                'condition'    => [
                    'play_btn_type' => 'lightbox',
                    'play_btn_text!'     => ''
                ],
			]
		);

        $this->add_responsive_control(
            'play_icon_indent',
            [
                'label'      => esc_html__( 'Icon Spacing', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
					'px' => [
						'max' => 50,
					],
				],
                'selectors'  => [
                    '{{WRAPPER}} .play-btn' => 'column-gap: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'play_btn_text!'    => ''
                ],
            ]
        );

        $this->add_control(
			'play_button_css_id',
			[
				'label' => esc_html__( 'Button ID', 'elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => '',
				'title' => esc_html__( 'Add your custom id WITHOUT the Pound key. e.g: my-id', 'redias-core' ),
				'description' => esc_html__( 'Please make sure the ID is unique and not used elsewhere on the page this form is displayed. This field allows <code>A-z 0-9</code> & underscore chars without spaces.', 'redias-core' ),
				'separator' => 'before',
                'condition'    => [
                    'play_btn_text!'    => ''
                ],
			]
		);
        
        $this->end_controls_section();

    }

    /**
     * Wrapper Style
     *
     * @return void
     */
    protected function wrapper_style() {

        $this->start_controls_section(
            'wrapper_section',
            [
                'label' => esc_html__( 'Wrapper', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'wrapper_background',
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .hero-wrapper',
			]
		);

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'wrapper_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .hero-wrapper'
            ]
        );

        $this->add_responsive_control(
            'wrapper_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .hero-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );

        $this->add_responsive_control(
            'wrapper_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .hero-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Sub Heading Style Control
     *
     * @return void
     */
    protected function sub_heading_style() {

        $this->start_controls_section(
			'section_sub_heading_text',
			[
                'label' => esc_html__( 'Sub Heading', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
					'sub_heading!' => ''
				],
			]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'sub_heading_text_background',
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .sub-heading',
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'sub_heading_text_typography',
                'selector' => '{{WRAPPER}} .sub-heading',
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'sub_heading_color_type',
                'label'    => esc_html__( 'Text Color Type', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .sub-heading',
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .sub-heading i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'sub_heading!' => '',
					'sub_heading_icon[value]!' => ''
                ],
            ]
        );

        $this->add_control(
            'sub_heading_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sub-heading i' => 'color: {{VALUE}}',
                ],
                'condition' => [
					'sub_heading!' => '',
					'sub_heading_icon[value]!' => ''
				]
            ]
        );

        $this->add_responsive_control(
            'sub_heading_icon_specing',
            [
                'label'      => esc_html__( 'Icon Specing', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 50
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .sub-heading i' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'sub_heading!' => '',
					'sub_heading_icon[value]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'sub_heading_text_border',
                'selector' => '{{WRAPPER}} .sub-heading',
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_control(
            'sub_heading_text_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .sub-heading' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'sub_heading_text_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .sub-heading',
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_text_padding',
            [
                'label' => esc_html__( 'Padding', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .sub-heading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_text_margin',
            [
                'label' => esc_html__( 'Margin', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .sub-heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Heading Style Control
     *
     * @return void
     */
    protected function heading_style() {

        $this->start_controls_section(
			'section_heading_text',
			[
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
					'heading!' => ''
				],
			]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'heading_text_background',
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .heading',
                'condition' => [
					'heading!' => ''
				],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_text_typography',
                'selector' => '{{WRAPPER}} .heading',
                'condition' => [
					'heading!' => ''
				],
            ]
        );

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'heading_color_type',
                'label'    => esc_html__( 'Text Color Type', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .heading',
                'condition' => [
					'heading!' => ''
				],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'heading_text_border',
                'selector' => '{{WRAPPER}} .heading',
                'condition' => [
					'heading!' => ''
				],
            ]
        );

        $this->add_control(
            'heading_text_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .heading' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
					'heading!' => ''
				],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'heading_text_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .heading',
                'condition' => [
					'heading!' => ''
				],
            ]
        );

        $this->add_responsive_control(
            'heading_text_padding',
            [
                'label' => esc_html__( 'Padding', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .heading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
					'heading!' => ''
				],
            ]
        );

        $this->add_responsive_control(
            'heading_text_margin',
            [
                'label' => esc_html__( 'Margin', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
					'heading!' => ''
				],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Description Style Control
     *
     * @return void
     */
    protected function description_style() {

        $this->start_controls_section(
			'section_desc_text',
			[
                'label' => esc_html__( 'Description', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
					'desc!' => ''
				],
			]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'desc_text_typography',
                'selector' => '{{WRAPPER}} .desc',
                'condition' => [
					'desc!' => ''
				],
            ]
        );

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'desc_color_type',
                'label'    => esc_html__( 'Text Color Type', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .desc',
                'condition' => [
					'desc!' => ''
				],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'desc_text_border',
                'selector' => '{{WRAPPER}} .desc',
                'condition' => [
					'desc!' => ''
				],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'desc_text_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .desc',
                'condition' => [
					'desc!' => ''
				],
            ]
        );

        $this->add_responsive_control(
            'desc_text_padding',
            [
                'label' => esc_html__( 'Padding', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
					'desc!' => ''
				],
            ]
        );

        $this->add_responsive_control(
            'desc_text_margin',
            [
                'label' => esc_html__( 'Margin', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
					'desc!' => ''
				],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Button Style
     *
     * @return void
     */
    protected function button_style() {

        $this->start_controls_section(
            'button_style_section',
            [
                'label' => esc_html__( 'Button', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-el-btn.btn-1',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'text_shadow',
                'selector' => '{{WRAPPER}} .dl-el-btn.btn-1',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->start_controls_tabs( 'btn_normal_style_tabs' );
        
        $this->start_controls_tab(
            'btn_style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'btn_bg_normal',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => [ 'image' ],
                'selector' => '{{WRAPPER}} .btn-1.style-1, {{WRAPPER}} .btn-1.style-2 .blob-dl-btn__inner, {{WRAPPER}} .dl-el-btn.style-3',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-el-btn.btn-1' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'btn_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .btn-1.style-1, {{WRAPPER}} .btn-1.style-2 .blob-dl-btn__inner',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .btn-1.style-1' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .btn-1.style-2 .blob-dl-btn__inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'btn_box_shadow',
                'selector' => '{{WRAPPER}} .dl-el-btn.btn-1',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-btn.btn-1' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-btn-wrap .btn-1' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'btn_style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_hover_effect',
            [
                'label'   => esc_html__( 'Hover Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'style-4',
                'options' => [
                    'style-1'  => esc_html__( 'Style 1', 'redias-core' ),
                    'style-2' => esc_html__( 'Style 2', 'redias-core' ),
                    'style-3' => esc_html__( 'Style 3', 'redias-core' ),
                    'style-4' => esc_html__( 'Style 4', 'redias-core' ),
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'btn_bg_hover',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => [ 'image' ],
                'selector' => '{{WRAPPER}} .btn-1.style-1:before, {{WRAPPER}} .btn-1.style-1:after, {{WRAPPER}} .style-2 .blob-dl-btn__blob, {{WRAPPER}} .dl-el-btn.style-3 span.btn-ov, {{WRAPPER}} .btn-1.style-4:before',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_text_color_hover',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-el-btn.btn-1:focus, {{WRAPPER}} .dl-el-btn.btn-1:hover' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_pattern',
            [
                'label'        => esc_html__( 'Pattern', 'textdomain' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'textdomain' ),
                'label_off'    => esc_html__( 'Hide', 'textdomain' ),
                'return_value' => 'yes',
                'default'      => 'yes',
                'condition'    => [
                    'btn_hover_effect' => 'style-3',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'btn_hover_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .btn-1.style-1:hover, {{WRAPPER}} .btn-1.style-2:hover .blob-dl-btn__inner',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'box_shadow_hover',
                'selector' => '{{WRAPPER}} .dl-el-btn.btn-1:hover',
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_hover_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .btn-1.style-1:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .btn-1.style-2:hover .blob-dl-btn__inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'btn_text!'    => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->end_controls_section();

    }

    /**
     * Play Button Style
     *
     * @return void
     */
    protected function play_button_style() {

        $this->start_controls_section(
            'play_button_style_section',
            [
                'label' => esc_html__( 'Play Button', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'play_btn_text!'    => ''
                ],
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'play_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .play-btn .play-btn-txt',
            ]
        );

        $this->add_control(
            'play_btn_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .play-btn .play-btn-txt' => 'color: {{VALUE}}',
                ]
            ]
        );

        $this->add_control(
            'play_btn_text_color_hover',
            [
                'label'     => esc_html__( 'Hover Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .play-btn:hover .play-btn-txt' => 'color: {{VALUE}}',
                ]
            ]
        );

        $this->add_control(
			'play_btn_icon_style',
			[
				'label' => esc_html__( 'Play Icon', 'textdomain' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->start_controls_tabs( 'play_btn_normal_style_tabs' );
        
        $this->start_controls_tab(
            'play_btn_style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'play_btn_bg_normal',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => [ 'image' ],
                'selector' => '{{WRAPPER}} .play-btn .play-icon'
            ]
        );

        $this->add_control(
			'play_btn_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'textdomain' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .play-btn .play-icon' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_responsive_control(
			'play_btn_circle_size',
			[
				'label' => esc_html__( 'Circle Size', 'textdomain' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1
					]
				],
				'selectors' => [
					'{{WRAPPER}} .play-btn .play-icon' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
				],
			]
		);

        $this->add_responsive_control(
			'play_btn_icon_size',
			[
				'label' => esc_html__( 'Icon Size', 'textdomain' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1
					]
				],
				'selectors' => [
					'{{WRAPPER}} .play-btn .play-icon svg' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'play_btn_style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'hover_play_btn_bg_normal',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => [ 'image' ],
                'selector' => '{{WRAPPER}} .play-btn:hover .play-icon'
            ]
        );

        $this->add_control(
			'hover_play_btn_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'textdomain' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .play-btn:hover .play-icon' => 'color: {{VALUE}}',
				],
			]
		);
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->end_controls_section();

    }

    /**
     * Arrow Symbol Style
     *
     * @return void
     */
    protected function arrow_symbol_style() {

        $this->start_controls_section(
            'arrow_symbol_section',
            [
                'label' => esc_html__( 'Arrow Symbol', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_control(
			'arrow_symbol',
			[
				'label' => esc_html__( 'Arrow Symbol', 'textdomain' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'textdomain' ),
				'label_off' => esc_html__( 'Hide', 'textdomain' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

        $this->add_responsive_control(
			'arrow_symbol_size',
			[
				'label' => esc_html__( 'Size', 'textdomain' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .hero-arrow' => 'width: {{SIZE}}{{UNIT}};',
				],
                'condition'    => [
                    'arrow_symbol' => 'yes'
                ],
			]
		);

        $this->add_control(
			'arrow_symbol_color',
			[
				'label' => esc_html__( 'Symbol Color', 'textdomain' ),
				'type' => Controls_Manager::COLOR,
                'alpha' => false,
				'condition'    => [
                    'arrow_symbol' => 'yes'
                ],
			]
		);
        
        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="hero-wrapper">
            <div class="container">
                <div class="hero-inner">
                    <div class="hero-content">
                        <?php 
                            $this->get_sub_heading();
                            $this->get_heading();
                            $this->get_description();
                        ?>
                        <div class="btn-holder">
                            <?php
                            if( ! empty( $settings['btn_text'] && $settings['btn_link']['url'] ) ) {
                                $this->get_button();
                            }
                            $this->get_play_button();
                            if( 'yes' === $settings['arrow_symbol'] ) {
                                $arrow_color = ! empty( $settings['arrow_symbol_color'] ) ? $settings['arrow_symbol_color'] : '#ff6a32';
                                echo '<img class="hero-arrow" src="'. Helper::get_img_color( REDIASCORE_ASSETS . '/img/arrow-img.png', $arrow_color ) .'" alt="Hero Arrow">';
                            }
                            ?>
                        </div>
                    </div>
                    <?php if( 'brands' === $settings['bc_content_type'] ) : 
                        $brands_icons = $settings['brands_icons'];
                    ?>
                    <div class="brands-circle">
                        <div class="inner-icon">
                            <?php
                            if( isset($brands_icons[0]) && ! empty( $brands_icons[0]['icon']['value'] )) {
                                echo '<i class="elementor-repeater-item-'. $brands_icons[0]['_id'] .' '. esc_attr( $brands_icons[0]['icon']['value'] ) .'"></i>';
                            }
                            if( isset($brands_icons[1]) && ! empty( $brands_icons[1]['icon']['value'] )) {
                                echo '<i class="elementor-repeater-item-'. $brands_icons[1]['_id'] .' '. esc_attr( $brands_icons[1]['icon']['value'] ) .'"></i>';
                            }
                            ?>
                        </div>
                        <div class="center-icon">
                            <?php
                            if( isset($brands_icons[2]) && ! empty( $brands_icons[2]['icon']['value'] )) {
                                echo '<i class="elementor-repeater-item-'. $brands_icons[2]['_id'] .' '. esc_attr( $brands_icons[2]['icon']['value'] ) .'"></i>';
                            }
                            ?>
                        </div>
                        <div class="outer-icon">
                            <?php
                            if( isset($brands_icons[3]) && ! empty( $brands_icons[3]['icon']['value'] )) {
                                echo '<i class="elementor-repeater-item-'. $brands_icons[3]['_id'] .' '. esc_attr( $brands_icons[3]['icon']['value'] ) .'"></i>';
                            }
                            if( isset($brands_icons[4]) && ! empty( $brands_icons[4]['icon']['value'] )) {
                                echo '<i class="elementor-repeater-item-'. $brands_icons[4]['_id'] .' '. esc_attr( $brands_icons[4]['icon']['value'] ) .'"></i>';
                            }
                            if( isset($brands_icons[5]) && ! empty( $brands_icons[5]['icon']['value'] )) {
                                echo '<i class="elementor-repeater-item-'. $brands_icons[5]['_id'] .' '. esc_attr( $brands_icons[5]['icon']['value'] ) .'"></i>';
                            }
                            if( isset($brands_icons[6]) && ! empty( $brands_icons[6]['icon']['value'] )) {
                                echo '<i class="elementor-repeater-item-'. $brands_icons[6]['_id'] .' '. esc_attr( $brands_icons[6]['icon']['value'] ) .'"></i>';
                            }
                            ?>
                        </div>
                    </div>
                    <?php else: 
                        if( ! empty( $settings['brands_image']['url'] ) ) {
                            echo '<div class="image-wrap">';
                            echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'brands_image', 'brands_image' );
                            echo '</div>';
                        }
                    ?>
                    
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <?php
    }

    /**
     * Sub Heading Layout
     */
    protected function get_sub_heading() {
        $settings = $this->get_settings_for_display();
        if( empty( $settings[ 'sub_heading' ] ) ) return;
        $this->add_inline_editing_attributes( 'sub_heading', 'none' );
        if( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
            <<?php echo esc_attr( $settings['sub_heading_tag'] ); ?> class="sub-heading">
            <?php if( ! empty( $settings['sub_heading_icon']['value'] ) ) { echo '<i class="'. esc_attr( $settings['sub_heading_icon']['value'] ) .'"></i>'; } ?>
            <span <?php echo $this->get_render_attribute_string( 'sub_heading' ); ?>><?php echo Helper::kses_basic( $settings[ 'sub_heading' ] ); ?></span></<?php echo esc_attr( $settings['sub_heading_tag'] ); ?>>
        <?php }else{  ?>
            <<?php echo esc_attr( $settings['sub_heading_tag'] ); ?> class="sub-heading">
            <?php if( ! empty( $settings['sub_heading_icon']['value'] ) ) { echo '<i class="'. esc_attr( $settings['sub_heading_icon']['value'] ) .'"></i>'; } ?>
            <?php echo Helper::kses_basic( $settings[ 'sub_heading' ] ); ?></<?php echo esc_attr( $settings['sub_heading_tag'] ); ?>>
        <?php }
    }

    /**
     * Heading Layout
     */
    protected function get_heading() {
        $settings = $this->get_settings_for_display();
        if( empty( $settings[ 'heading' ] ) ) return;
        $this->add_render_attribute( 'heading', [ 'class' => 'heading' ] );
        $this->add_inline_editing_attributes( 'heading', 'none' );
        ?>
        <<?php echo esc_attr( $settings['heading_tag'] ); ?> <?php echo $this->get_render_attribute_string( 'heading' ); ?>><?php echo Helper::kses_basic( $settings[ 'heading' ] ); ?></<?php echo esc_attr( $settings['heading_tag'] ); ?>>
        <?php
    }

    /**
     * Description Layout
     */
    protected function get_description() {
        $settings = $this->get_settings_for_display();
        if( empty( $settings[ 'desc' ] ) ) return;
        $this->add_render_attribute( 'desc', [ 'class' => 'desc' ] );
        $this->add_inline_editing_attributes( 'desc', 'none' );
        ?>
        <p <?php echo $this->get_render_attribute_string( 'desc' ); ?>><?php echo Helper::kses_basic( $settings[ 'desc' ] ); ?></p>
        <?php
    }

    /**
     * Button Layout
     */
    protected function get_button() {
        $settings = $this->get_settings_for_display();
        $pattern = 'yes' === $settings['btn_pattern'] ? 'pattern-yes' : '';
        $this->add_render_attribute( 'btn_wrapper', [ 'class' => [ 'dl-el-btn-wrap', $pattern ], 'data-btn-1-style' => $settings['btn_hover_effect'] ] );
        $has_cion = isset( $settings['btn_icon']['value'] ) && ! empty( $settings['btn_icon']['value'] ) ? ' has-icon' : '';
        if ( ! empty( $settings['btn_link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['btn_link'] );
		}
        $this->add_render_attribute( 'button', [ 'class' => [ 'dl-el-btn btn-1', $has_cion, $settings['btn_hover_effect'] ], 'id' => $settings['button_css_id'] ] );
        $this->add_inline_editing_attributes( 'btn_text', 'none' );
        ?>
        <div <?php $this->print_render_attribute_string( 'btn_wrapper' ); ?>>
            <?php if( \Elementor\Plugin::$instance->editor->is_edit_mode() ) : ?>
            <a <?php $this->print_render_attribute_string( 'button' ); ?>>
                <span <?php $this->print_render_attribute_string( 'btn_text' ); ?>><?php echo esc_html($settings['btn_text']); ?></span>
                <?php Icons_Manager::render_icon( $settings['btn_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                <?php if( 'style-2' === $settings['btn_hover_effect'] ) : ?>
                <span class="blob-dl-btn__inner">
                    <span class="blob-dl-btn__blobs">
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                    </span>
                </span>
                <?php endif; ?>
            </a>
            <?php else : ?>
            <?php if( ! empty( $settings['btn_text'] && $settings['btn_link']['url'] ) ) : ?>
            <a <?php $this->print_render_attribute_string( 'button' ); ?>>
                <span <?php $this->print_render_attribute_string( 'btn_text' ); ?>><?php echo esc_html($settings['btn_text']); ?></span>
                <?php Icons_Manager::render_icon( $settings['btn_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                <?php if( 'style-2' === $settings['btn_hover_effect'] ) : ?>
                <span class="blob-dl-btn__inner">
                    <span class="blob-dl-btn__blobs">
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                        <span class="blob-dl-btn__blob"></span>
                    </span>
                </span>
                <?php endif; ?>
            </a>
            <?php
            endif;
            endif; ?>
        </div>
        <?php
    }

    /**
     * Play Button Layout
     */
    protected function get_play_button() {
        $settings = $this->get_settings_for_display();
        $play_btn_link = isset( $settings['play_btn_link']['url'] ) ? $settings['play_btn_link']['url'] : '';
        if( 'lightbox' === $settings['play_btn_type'] ) {
            $this->add_render_attribute( 'play_button', [ 'class' => [ 'play-btn', 'dl-video-popup' ], 'data-vbtype' => 'video', 'href' => $settings['play_video_url'] ] );
        }else{
            if ( ! empty( $settings['play_btn_link']['url'] ) ) {
                $this->add_link_attributes( 'play_button', $settings['play_btn_link'] );
                $this->add_render_attribute( 'play_button', [ 'class' => [ 'play-btn' ], 'id' => $settings['play_button_css_id'] ] );
            }
        }
        $this->add_inline_editing_attributes( 'play_btn_text', 'none' );
        $this->add_render_attribute( 'play_btn_text', [ 'class' => [ 'play-btn-txt' ] ] );

        if ( ! empty( $settings['play_video_url'] || $play_btn_link ) ) {
            ?>
            <a <?php $this->print_render_attribute_string( 'play_button' ); ?>>
                <span class="play-icon"><svg aria-hidden="true" focusable="false" role="img" width="12" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512">
                        <path fill="currentColor" d="M424.4 214.7L72.4 6.6C43.8-10.3 0 6.1 0 47.9V464c0 37.5 40.7 60.1 72.4 41.3l352-208c31.4-18.5 31.5-64.1 0-82.6z"></path>
                    </svg></span>
                <span <?php $this->print_render_attribute_string( 'play_btn_text' ); ?>><?php echo esc_html( $settings['play_btn_text'] ); ?></span>
            </a>
            <?php
        }
    }

}