<?php
/**
 * Icon Boxes
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\IconBoxes;

use RediasCore\Classes\Helper;
use Elementor\Controls_Manager;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Widget_Base;
use RediasCore\Elementor\Controls\Foreground;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-icon-boxes';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Icon Boxes', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-testimonial-carousel';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'icon', 'boxes', 'icon boxes', 'promo', 'redias' ];
    }

    public function get_style_depends() {
        return [ 'redias-icon-boxes', 'elementor-icons-dl-business-icons' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_general();
        $this->section_items();
        $this->box_style();
        $this->icon_style();
        $this->heading_style();
        $this->description_style();
        $this->readmore_icon_style();

    }

    /**
	 * General Controls
	 *
	 * @return void
	 */
	protected function section_general() {

		$this->start_controls_section(
			'section_general',
			[
				'label' => esc_html__( 'General', 'redias-core' )
			]
		);

		$this->add_responsive_control(
			'dl_column',
			[
				'label' => esc_html__( 'Column', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => 0,
                        'max' => 4,
                        'step' => 1,
                    ],
				],
                'default' => [
					'size' => 4,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 2,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 1,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .el-icon-box-items' => 'grid-template-columns: repeat({{SIZE}},1fr);',
                ],
			]
		);

        $this->add_responsive_control(
			'grid_gap',
			[
				'label' => esc_html__( 'Grid Gap', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 150
					],
				],
				'default'    => [
					'unit' => 'px',
					'size' => 30
				],
				'selectors' => [
					'{{WRAPPER}} .el-icon-box-items' => 'grid-gap: {{SIZE}}{{UNIT}};',
                ]
			]
		);

		$this->add_responsive_control(
            'alignment',
            [
                'label' => esc_html__( 'Alignment', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon' => 'eicon-text-align-right',
                    ]
                ],
                'default' => 'left',
                'toggle' => false,
                'prefix_class' => 'icon-box-align-',
                'selectors' => [
                    '{{WRAPPER}} .el-icon-box-item' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}}.icon-box-align-center .el-icon-box-item .box-icon' => 'margin-left: auto; margin-right: auto;',
                    '{{WRAPPER}}.icon-box-align-right .el-icon-box-item .box-icon' => 'margin-left: auto;'
                ]
            ]
        );

        $this->end_controls_section();

	}

    /**
     * Icon Items
     *
     * @return void
     */
    protected function section_items() {

        $this->start_controls_section(
            'section_items',
            [
                'label' => esc_html__( 'Items', 'redias-core' ),
            ]
        );

        $repeater = new Repeater();

		$repeater->add_control(
			'icon',
			[
				'label'   => esc_html__( 'Icon', 'redias-core' ),
				'type'    => Controls_Manager::ICONS,
				'skin'	  => 'inline',
				'exclude_inline_options' => ['svg'],
				'default' => [
					'value'   => 'dl dl-presentation',
					'library' => 'elementor-icons-dl-business-icons',
				],
			]
		);

        $repeater->add_control(
            'heading',
            [
                'label'       => esc_html__( 'Heading', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Financial Money Audit Consultants', 'redias-core' ),
                'placeholder' => esc_html__( 'Heading...', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'description',
            [
                'label'       => esc_html__( 'Discription', 'redias-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'rows'        => 5,
                'default'     => esc_html__( 'Our approach thrives intersection between data-driven market.', 'redias-core' ),
                'placeholder' => esc_html__( 'Description...', 'redias-core' ),
            ]
        );

		$repeater->add_control(
			'readmore_link',
			[
				'label'         => esc_html__( 'Read More Link', 'redias-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'nofollow'    => true,
				]
			]
		);

        $this->add_control(
            'icon_box_items',
            [
                'label'   => esc_html__( 'Items', 'redias-core' ),
                'type'    => Controls_Manager::REPEATER,
                'fields'  => $repeater->get_controls(),
                'title_field'  => '{{{ heading }}}',
                'default' => [
                    [
                        'icon' => [
                            'value'   => 'dl dl-presentation',
							'library' => 'elementor-icons-dl-business-icons',
                        ],
                        'heading' =>  esc_html__( 'Financial Money Audit Consultants', 'redias-core' ),
                        'description' =>  esc_html__( 'Our approach thrives intersection between data-driven market.', 'redias-core' ),
                        'readmore_link' =>  [
							'url'	=> '#'
						],
                    ],
					[
                        'icon' => [
                            'value'   => 'dl dl-analysis-1',
							'library' => 'elementor-icons-dl-business-icons',
                        ],
                        'heading' =>  esc_html__( 'Brand Development Strategy Ltd', 'redias-core' ),
                        'description' =>  esc_html__( 'Our approach thrives intersection between data-driven market.', 'redias-core' ),
                        'readmore_link' =>  [
							'url'	=> '#'
						],
                    ],
					[
                        'icon' => [
                            'value'   => 'dl dl-success',
							'library' => 'elementor-icons-dl-business-icons',
                        ],
                        'heading' =>  esc_html__( 'Marketing And Creative Tech Solution', 'redias-core' ),
                        'description' =>  esc_html__( 'Our approach thrives intersection between data-driven market.', 'redias-core' ),
                        'readmore_link' =>  [
							'url'	=> '#'
						],
                    ],
					[
                        'icon' => [
                            'value'   => 'dl dl-startup',
							'library' => 'elementor-icons-dl-business-icons',
                        ],
                        'heading' =>  esc_html__( 'Crypto & IOS UI Techno Package Deisgn
						', 'redias-core' ),
                        'description' =>  esc_html__( 'Our approach thrives intersection between data-driven market.', 'redias-core' ),
                        'readmore_link' =>  [
							'url'	=> '#'
						],
                    ],
                    
                ],
            ]
        );

		$this->end_controls_section();

    }

	/**
	 * Box Style
	 *
	 * @return void
	 */
	protected function box_style() {

		$this->start_controls_section(
			'box_style_section',
			[
				'label' => esc_html__( 'Box', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'box_background',
				'label'    => esc_html__( 'Background', 'redias-core' ),
				'types'    => ['classic', 'gradient'],
				'exclude'  => ['image'],
				'selector' => '{{WRAPPER}} .el-icon-box-item',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'box_border',
				'label'    => esc_html__( 'Border', 'redias-core' ),
				'selector' => '{{WRAPPER}} .el-icon-box-item',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'testi_box_shadow',
				'selector' => '{{WRAPPER}} .el-icon-box-item',
			]
		);

		$this->add_responsive_control(
			'box_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'box_padding',
			[
				'label'      => esc_html__( 'Padding', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->end_controls_section();

	}

	/**
	 * Icon Style
	 *
	 * @return void
	 */
	protected function icon_style() {

		$this->start_controls_section(
			'icon_style_section',
			[
				'label' => esc_html__( 'Icon', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
			'icon_box_size',
			[
				'label'      => esc_html__( 'Box Size', 'textdomain' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range'      => [
					'px' => [
						'min'  => 5,
						'max'  => 200,
						'step' => 1
					]
				],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item .box-icon' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'icon_size',
			[
				'label'      => esc_html__( 'Icon Size', 'textdomain' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range'      => [
					'px' => [
						'min'  => 10,
						'max'  => 200,
						'step' => 1
					]
				],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item .box-icon' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'icon_bg_background',
				'label'    => esc_html__( 'Background', 'textdomain' ),
				'types'    => ['classic', 'gradient'],
				'exclude'  => ['image'],
				'selector' => '{{WRAPPER}} .el-icon-box-item .box-icon',
			]
		);

		$this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'icon_color',
                'label'    => esc_html__( 'Icon Color Type', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .el-icon-box-item .box-icon i',
            ]
        );

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'icon_border',
				'label'    => esc_html__( 'Border', 'textdomain' ),
				'selector' => '{{WRAPPER}} .el-icon-box-item .box-icon',
			]
		);

		$this->add_responsive_control(
			'icon_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'textdomain' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item .box-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'icon_box_shadow',
				'selector' => '{{WRAPPER}} .el-icon-box-item .box-icon',
			]
		);

		$this->add_responsive_control(
			'icon_bottom_spacing',
			[
				'label'      => esc_html__( 'Bottom Spacing', 'textdomain' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 200,
						'step' => 1
					]
				],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item .box-icon' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		$this->end_controls_section();
		
	}

	/**
	 * Heading Style
	 *
	 * @return void
	 */
	protected function heading_style() {

		$this->start_controls_section(
			'heading_style_section',
			[
				'label' => esc_html__( 'Heading', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'heading_typography',
				'label'    => esc_html__( 'Typography', 'redias-core' ),
				'selector' => '{{WRAPPER}} .el-icon-box-item h3',
			]
		);

		$this->add_control(
			'heading_color',
			[
				'label'     => esc_html__( 'Text Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .el-icon-box-item h3' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'heading_margin',
			[
				'label'      => esc_html__( 'Margin', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->end_controls_section();
		
	}

	/**
	 * Description Style
	 *
	 * @return void
	 */
	protected function description_style() {

		$this->start_controls_section(
			'description_style_section',
			[
				'label' => esc_html__( 'Description', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'desc_typography',
				'label'    => esc_html__( 'Typography', 'redias-core' ),
				'selector' => '{{WRAPPER}} .el-icon-box-item p',
			]
		);

		$this->add_control(
			'desc_color',
			[
				'label'     => esc_html__( 'Text Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .el-icon-box-item p' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'desc_margin',
			[
				'label'      => esc_html__( 'Margin', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->end_controls_section();
		
	}

	/**
	 * Read more icon style
	 *
	 * @return void
	 */
	protected function readmore_icon_style() {

		$this->start_controls_section(
			'readmore_style_section',
			[
				'label' => esc_html__( 'Read More Icon', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'readmore_icon',
			[
				'label'   => esc_html__( 'Read More Icon', 'redias-core' ),
				'type'    => Controls_Manager::ICONS,
				'skin'	  => 'inline',
				'exclude_inline_options' => ['svg'],
				'default' => [
					'value'   => 'la la-arrow-right',
					'library' => 'elementor-icons-line-awesome-icons',
				],
			]
		);

		$this->add_responsive_control(
			'readmore_icon_size',
			[
				'label'      => esc_html__( 'Icon Size', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range'      => [
					'px' => [
						'min'  => 5,
						'max'  => 150,
						'step' => 1
					]
				],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item a' => 'font-size: {{SIZE}}{{UNIT}};',
				],
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);

		$this->add_responsive_control(
			'readmore_icon_padding',
			[
				'label'      => esc_html__( 'Padding', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);

		$this->add_responsive_control(
			'readmore_icon_margin',
			[
				'label'      => esc_html__( 'Margin', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);

		$this->start_controls_tabs( 'readmore_icon_style_tabs' );
		
		$this->start_controls_tab(
			'readmore_icon_style_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'redias-core' ),
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);

		$this->add_control(
			'readmore_icon_bg_color',
			[
				'label'     => esc_html__( 'Background Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .el-icon-box-item a' => 'background-color: {{VALUE}}',
				],
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);

		$this->add_control(
			'readmore_icon_color',
			[
				'label'     => esc_html__( 'Icon Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .el-icon-box-item a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'readmore_icon_border',
				'label'    => esc_html__( 'Border', 'redias-core' ),
				'selector' => '{{WRAPPER}} .el-icon-box-item a',
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'readmore_icon_box_shadow',
				'selector' => '{{WRAPPER}} .el-icon-box-item a',
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);

		$this->add_responsive_control(
			'readmore_icon_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);
		
		$this->end_controls_tab();

		$this->start_controls_tab(
			'readmore_icon_style_hover_tab',
			[
				'label' => esc_html__( 'Hover', 'redias-core' ),
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);

		$this->add_control(
			'readmore_icon_hover_bg_color',
			[
				'label'     => esc_html__( 'Background Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .el-icon-box-item a:hover' => 'background-color: {{VALUE}}',
				],
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);

		$this->add_control(
			'readmore_icon_hover_color',
			[
				'label'     => esc_html__( 'Icon Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .el-icon-box-item a:hover' => 'color: {{VALUE}}',
				],
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'readmore_icon_hover_border',
				'label'    => esc_html__( 'Border', 'redias-core' ),
				'selector' => '{{WRAPPER}} .el-icon-box-item a:hover',
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'readmore_icon_hover_box_shadow',
				'selector' => '{{WRAPPER}} .el-icon-box-item a:hover',
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);

		$this->add_responsive_control(
			'readmore_icon_hover_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-icon-box-item a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition'    => [
					'readmore_icon[value]!' => ''
				]
			]
		);
		
		$this->end_controls_tab();
		
		$this->end_controls_tabs();

		$this->end_controls_section();
		
	}

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

		$settings = $this->get_settings_for_display();

		$items = $settings['icon_box_items'];

		$this->add_render_attribute(
			'wrapper',
			[ 
				'class' => [ 'el-icon-box-items' ],
			]
		);

		if( $items ) {
			?>
			<div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
				<?php foreach( $items as $index => $item ) : 
					$repeater_setting_key_heading = $this->get_repeater_setting_key( 'heading', 'icon_box_items', $index );
					$repeater_setting_key_desc = $this->get_repeater_setting_key( 'description', 'icon_box_items', $index );
					$this->add_inline_editing_attributes( $repeater_setting_key_heading );
					$this->add_inline_editing_attributes( $repeater_setting_key_desc );
					$this->add_link_attributes( 'readmore_link', $item['readmore_link'] );
					if( ! empty( $item['heading'] || $item['description'] ) ) : ?>
					<div class="el-icon-box-item">
						<?php
						if( ! empty( $item['icon']['value'] ) ) {
							echo '<div class="box-icon">';
								Icons_Manager::render_icon( $item['icon'], ['aria-hidden' => 'true'] );
							echo '</div>';
						}
						if( ! empty( $item['heading'] ) ) {
							echo '<h3 '. $this->get_render_attribute_string( $repeater_setting_key_heading ) .'>'. Helper::kses_basic( $item['heading'] ) .'</h3>';
						}
						if( ! empty( $item['description'] ) ) {
							echo '<p '. $this->get_render_attribute_string( $repeater_setting_key_desc ) .'>'. Helper::kses_basic( $item['description'] ) .'</p>';
						}
						if( ! empty( $settings['readmore_icon']['value'] && $item['readmore_link']['url'] ) ) {
							echo '<a '. $this->get_render_attribute_string( 'readmore_link' ) .'>';
								Icons_Manager::render_icon( $settings['readmore_icon'], ['aria-hidden' => 'true'] );
							echo '</a>';
						}
						?>
					</div>
				<?php
					endif;
				endforeach; ?>
			</div>
			<?php
		}else{
			echo esc_html__( 'No items fund!', 'redias-core' );
		}
    }

}