<?php
/**
 * Instagram Feed
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Instagram;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Group_Control_Background;
use RediasCore\Traits\CarouselControls;
use RediasCore\Classes\Instagram\Feed;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    use CarouselControls;

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-instagram';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Instagram Feed', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-instagram-post';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'instagram', 'feed', 'social feed', 'redias' ];
    }

    public function get_style_depends() {
        return [ 'slick', 'elementor-icons-line-awesome-icons' ];
    }

    public function get_script_depends() {
        return [ 'slick', 'redias-el-script' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_settings();
        $this->section_controls();
        $this->style_pagination();

    }

    /**
     * Settings
     *
     * @return void
     */
    protected function section_settings() {

        $this->start_controls_section(
			'section_settings',
			[
				'label' => esc_html__( 'Settings', 'redias-core' )
			]
        );
        
        $this->add_control(
            'token',
            [
                'label'        => esc_html__( 'Access Token', 'redias-core' ),
                'type'         => Controls_Manager::TEXT,
                'label_block'  => true,
                'default'      => '',
                'placeholder'  => esc_html__( 'Access token goes here...', 'redias-core' ),
                'description'  => esc_html__( 'To get access token follow this step by step instruction.', 'redias-core' ) . '<a href="https://wpsocialninja.com/instagram-access-token/" target="_blank">'. esc_html__( 'Click here to read the instruction') .'</a>.'
            ]
        );

        $this->add_control(
            'limit',
            [
                'label' => esc_html__( 'Post Limit', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 5,
                        'max' => 20,
                        'step' => 1
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 10
                ],
                'condition' => [
                    'token!' => ''
                ]
            ]
        );

		$this->add_responsive_control(
			'img_height',
			[
				'label' => esc_html__( 'Image Height', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 100,
						'max' => 600,
						'step' => 1
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 180
				],
				'selectors' => [
					'{{WRAPPER}} .feed-item' => 'height: {{SIZE}}{{UNIT}}!important;'
				],
				'condition' => [
                    'token!' => ''
                ]
			]
		);

		$this->add_control(
			'img_radius',
			[
				'label' => esc_html__( 'Border Radius', 'redias-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .feed-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'overlay_bg',
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .feed-item a',
				'condition' => [
                    'token!' => ''
                ]
			]
		);

		$this->add_control(
			'lightbox',
			[
				'label' => esc_html__( 'Lightbox', 'redias-core' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'redias-core' ),
				'label_off' => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
                    'token!' => ''
                ]
			]
		);
        
        $this->end_controls_section();

    }

    /**
	 * Carousel Controls
	 *
	 * @return void
	 */
	protected function section_controls() {

		$this->start_controls_section(
			'section_carousel_settings',
			[
				'label' => esc_html__( 'Carousel Settings', 'redias-core' )
			]
		);

        $this->add_control(
			'carousel',
			[
				'label' => esc_html__( 'Carousel', 'redias-core' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'yes',
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$slides_per_show = range( 1, 10 );
		$slides_per_show = array_combine( $slides_per_show, $slides_per_show );

		$this->add_responsive_control(
			'slides_per_show',
			[
				'label' => esc_html__( 'Slides to Show', 'redias-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 6,
				'tablet_default' => 4,
				'mobile_default' => 2,
				'options' => $slides_per_show,
				'frontend_available' => true,
				'render_type' => 'ui',
			]
		);

		$this->add_responsive_control(
			'slides_per_scroll',
			[
				'label' => esc_html__( 'Slides to Scroll', 'redias-core' ),
				'type' => Controls_Manager::SELECT,
				'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'redias-core' ),
				'default' => 3,
				'tablet_default' => 2,
				'mobile_default' => 1,
				'options' => $slides_per_show,
				'condition' => [
					'slides_per_show!' => '1'
				],
				'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

        $this->add_responsive_control(
			'spaceBetween',
			[
				'label'      => esc_html__( 'Space Between', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px', 'em'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 150,
						'step' => 1
					],
					'em'  => [
						'min' => 0,
						'max' => 100
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .slick-list' => 'margin: 0 -{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .slick-slide' => 'margin: 0 {{SIZE}}{{UNIT}};'
				],
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'        => esc_html__( 'Autoplay', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'autoplay_speed',
			[
				'label'   => esc_html__( 'Autoplay Speed', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 500,
				'max'     => 20000,
				'step'    => 5,
				'default' => 5000,
				'condition' => [
					'autoplay' => 'yes'
                ],
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'pause_on_hover',
			[
				'label'        => esc_html__( 'Pause on Hover', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'condition' => [
					'autoplay' => 'yes'
				],
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'infinite_loop',
			[
				'label'        => esc_html__( 'Infinite Loop', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'anim_speed',
			[
				'label'   => esc_html__( 'Animation Speed', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 100,
				'max'     => 3000,
				'step'    => 5,
				'default' => 500,
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

        $this->add_control(
			'center_mode',
			[
				'label'        => esc_html__( 'Center Mode', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'no',
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

        $this->add_responsive_control(
			'center_padding',
			[
				'label'   => esc_html__( 'Center Padding', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 0,
				'max'     => 200,
				'step'    => 1,
				'default' => 50,
				'tablet_default' => 30,
				'mobile_default' => 10,
                'frontend_available' => true,
				'render_type' => 'ui',
                'condition' => [
					'center_mode' => 'yes'
				],
			]
		);

		$this->add_control(
			'navigation',
			[
				'label' => esc_html__( 'Navigation', 'redias-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'None', 'redias-core' ),
					'dots' => esc_html__( 'Dots', 'redias-core' ),
				],
				'default' => 'none',
				'frontend_available' => true,
				'style_transfer' => true
			]
		);

		$this->end_controls_section();

	}

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        if( ! empty( $settings['token'] ) ) :
            $nav_mobile = 'yes' === $settings['dots_hide_mobile'] ? ' dots-none' : '';
            $this->add_render_attribute(
                'carousel_wrapper',
                [ 
                    'class' => [ 'dl-carousel' ],
                ]
            );
			if( 'yes' === $settings['lightbox'] ) {
				$this->add_render_attribute(
					'insta_link',
					[ 
						'class' => [ 'elementor-clickable' ],
						'data-elementor-open-lightbox' => 'yes',
						'data-elementor-lightbox-slideshow' => 'insta-' . $this->get_id()
					]
				);
			}else{
				$this->add_render_attribute(
					'insta_link',
					[ 
						'class' => [ 'insta-link' ],
						'target' => '_blank'
					]
				);
			}
            $feed = new Feed(
                $settings['token']
            );
            $feedItems = $feed->getFeed('media_type,media_url,permalink', $settings['limit']['size'] );
            if( ! empty( $feedItems ) ) :
        ?>
            <div <?php echo $this->get_render_attribute_string( 'carousel_wrapper' ); ?>>
                <?php foreach( $feedItems as $feedItem ) : 
                    if( 'IMAGE' === $feedItem['media_type'] ) { 
					$link = 'yes' === $settings['lightbox'] ? $feedItem['media_url'] : $feedItem['permalink']; ?>
                    <div class="slick-slide">
                        <div class="feed-item">
                            <img src="<?php echo esc_url( $feedItem['media_url'] ); ?>" alt="<?php esc_attr_e( 'Instagram Feed', 'redias-core' ); ?>">
							<a <?php echo $this->get_render_attribute_string( 'insta_link' ); ?> href="<?php echo esc_url( $link ); ?>"><i class="la la-instagram"></i></a>
                        </div>
                    </div>
                <?php }
                endforeach; 
				echo '<div class="carousel-preloader"><div class="dot-flashing"></div></div>'; ?>
            </div>
			<?php if( 'dots' === $settings['navigation'] ) : ?>
			<div class="dl-carousel-dots<?php echo esc_attr( $nav_mobile ); ?>"></div>
			<?php endif; ?>
        <?php
            else:
                echo esc_html__( 'No feed available to display.', 'redias-core' );
            endif;
        else: 
            echo esc_html__( 'Please enter your access token to get the Instagram feeds.', 'redias-core' );
        endif;
        
    }

}