<?php
/**
 * MailChimp for WP
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\MailChimp;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Widget_Base;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-mailchimp';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'MailChimp', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-mailchimp';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return ['newsletter', 'mc', 'mailchimp', 'redias'];
    }

    public function get_style_depends() {
        return ['redias-mailchimp'];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_mailchimp();
        $this->style_box();
        $this->style_input();
        $this->style_button();

    }

    /**
     * MailChimp Settings
     *
     * @return void
     */
    protected function section_mailchimp() {
        
        $this->start_controls_section(
            'dl_mailchimp',
            [
                'label' => esc_html__( 'Mailchimp', 'redias-core' ),
            ]
        );

        $this->add_control(
            'dl_mailchimp_form_style',
            [
                'label'   => esc_html__( 'Style', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '4',
                'options' => [
                    '1' => esc_html__( 'Style One', 'redias-core' ),
                    '2' => esc_html__( 'Style Two', 'redias-core' ),
                    '3' => esc_html__( 'Style Three', 'redias-core' ),
                    '4' => esc_html__( 'Style Four', 'redias-core' )
                ],
            ]
        );

        $this->add_control(
            'dl_mailchimp_id',
            [
                'label'       => esc_html__( 'Mailchimp ID', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( '250', 'redias-core' ),
                'description' => esc_html__( 'For show ID <a href="admin.php?page=mailchimp-for-wp-forms" target="_blank"> Click here </a>', 'redias-core' ),
                'label_block' => true,
                'separator'   => 'before',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Box Area Style
     *
     * @return void
     */
    protected function style_box() {
        
        // Style tab section
        $this->start_controls_section(
            'dl_mailchimp_section_style',
            [
                'label' => esc_html__( 'Box', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'dl_mailchimp_section_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-input-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

        $this->add_responsive_control(
            'dl_mailchimp_section_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-input-box' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'dl_mailchimp_section_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-input-box',
            ]
        );

        $this->add_responsive_control(
            'dl_mailchimp_section_align',
            [
                'label'     => esc_html__( 'Alignment', 'redias-core' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'    => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center'  => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'   => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-input-box' => 'text-align: {{VALUE}};',
                ],
                'default'   => 'center',
                'separator' => 'before',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Input Style
     *
     * @return void
     */
    protected function style_input() {
        
        $this->start_controls_section(
            'dl_mailchimp_input_style',
            [
                'label' => esc_html__( 'Input Field', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'dl_input_box_height',
            [
                'label'     => esc_html__( 'Height', 'redias-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 150,
                    ],
                ],
                'default'   => [
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} .mc4wp-form input[type*="text"]'  => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .mc4wp-form input[type*="email"]' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'dl_input_box_typography',
                'selector' => '{{WRAPPER}} .mc4wp-form input[type*="email"]',
            ]
        );

        $this->add_control(
            'dl_input_box_background',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mc4wp-form input[type*="text"]'          => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .mc4wp-form input[type*="email"]'         => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .mc4wp-form select[name*="_mc4wp_lists"]' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'dl_input_box_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mc4wp-form input[type*="text"]'  => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mc4wp-form input[type*="email"]' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'dl_input_box_placeholder_color',
            [
                'label'     => esc_html__( 'Placeholder Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mc4wp-form input[type*="text"]::-webkit-input-placeholder'  => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mc4wp-form input[type*="text"]::-moz-placeholder'           => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mc4wp-form input[type*="text"]:-ms-input-placeholder'       => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mc4wp-form input[type*="email"]::-webkit-input-placeholder' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mc4wp-form input[type*="email"]::-moz-placeholder'          => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mc4wp-form input[type*="email"]:-ms-input-placeholder'      => 'color: {{VALUE}};',
                    '{{WRAPPER}} .mc4wp-form select[name*="_mc4wp_lists"]'                    => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'dl_input_box_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .mc4wp-form input[type*="email"]',
            ]
        );

        $this->add_responsive_control(
            'dl_input_box_border_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'redias-core' ),
                'type'      => Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mc4wp-form input[type*="text"]'  => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                    '{{WRAPPER}} .mc4wp-form input[type*="email"]' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'dl_input_box_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .mc4wp-form input[type*="text"]'  => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .mc4wp-form input[type*="email"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

        $this->add_responsive_control(
            'dl_input_box_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .mc4wp-form input[type*="text"]'  => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .mc4wp-form input[type*="email"]' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

        $this->add_control(
			'fh_style_heading',
			[
				'label' => esc_html__( 'Hover/Focus Style', 'redias-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'text_fh_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .mc4wp-form input[type*="text"]:hover, {{WRAPPER}} .mc4wp-form input[type*="text"]:focus, {{WRAPPER}} .mc4wp-form input[type*="email"]:hover, {{WRAPPER}} .mc4wp-form input[type*="email"]:focus',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'text_fh_box_shadow',
                'selector' => '{{WRAPPER}} .mc4wp-form input[type*="text"]:hover, {{WRAPPER}} .mc4wp-form input[type*="text"]:focus, {{WRAPPER}} .mc4wp-form input[type*="email"]:hover, {{WRAPPER}} .mc4wp-form input[type*="email"]:focus',
            ]
        );

        $this->add_responsive_control(
            'text_fh_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .mc4wp-form input[type*="text"]:hover, {{WRAPPER}} .mc4wp-form input[type*="text"]:focus, {{WRAPPER}} .mc4wp-form input[type*="email"]:hover, {{WRAPPER}} .mc4wp-form input[type*="email"]:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function style_button() {
        
        $this->start_controls_section(
            'dl_mailchimp_inputsubmit_style',
            [
                'label' => esc_html__( 'Button', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs( 'dl_submit_style_tabs' );

        // Button Normal tab start
        $this->start_controls_tab(
            'dl_submit_style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
            ]
        );

        $this->add_responsive_control(
            'dl_input_submit_width',
            [
                'label'     => esc_html__( 'Width', 'redias-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 150,
                    ],
                ],
                'default'   => [
                    'size' => 60,
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-mailchimp-style-4 .mc4wp-form input[type*="submit"]' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'dl_mailchimp_form_style'    => '4',
                ],
            ]
        );

        $this->add_responsive_control(
            'dl_input_submit_height',
            [
                'label'     => esc_html__( 'Height', 'redias-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 150,
                    ],
                ],
                'default'   => [
                    'size' => 40,
                ],
                'selectors' => [
                    '{{WRAPPER}} .mc4wp-form input[type*="submit"]' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'dl_input_submit_icon_size',
            [
                'label'     => esc_html__( 'Icon Size', 'redias-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 150,
                    ],
                ],
                'default'   => [
                    'size' => 15,
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-mailchimp-style-4 .mc4wp-form input[type*="submit"]' => 'background-size: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'dl_mailchimp_form_style'    => '4',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'dl_input_submit_typography',
                'selector' => '{{WRAPPER}} .mc4wp-form input[type*="submit"]',
            ]
        );

        $this->add_control(
            'dl_input_submit_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mc4wp-form input[type*="submit"]' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'dl_input_submit_background_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mc4wp-form input[type*="submit"]' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'dl_input_submit_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .mc4wp-form input[type*="submit"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

        $this->add_responsive_control(
            'dl_input_submit_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .mc4wp-form input[type*="submit"]' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'  => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'dl_input_submit_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .mc4wp-form input[type*="submit"]',
            ]
        );

        $this->add_responsive_control(
            'dl_input_submit_border_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'redias-core' ),
                'type'      => Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .mc4wp-form input[type*="submit"]' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'dl_input_submit_box_shadow',
                'label'    => esc_html__( 'Box Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .mc4wp-form input[type*="submit"]',
            ]
        );

        $this->end_controls_tab();

        // Button Hover tab start
        $this->start_controls_tab(
            'dl_submit_style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
            ]
        );

        $this->add_control(
            'dl_input_submithover_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mc4wp-form input[type*="submit"]:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'dl_input_submithover_background_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mc4wp-form input[type*="submit"]:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'dl_input_submithover_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .mc4wp-form input[type*="submit"]:hover',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

		$settings = $this->get_settings_for_display();

        $this->add_render_attribute( 'mailchimp_area_attr', 'class', 'dl-mailchimp' );
        $this->add_render_attribute( 'mailchimp_area_attr', 'class', 'dl-mailchimp-style-' . $settings['dl_mailchimp_form_style'] );

        ?>
        <div <?php echo $this->get_render_attribute_string( 'mailchimp_area_attr' ); ?> >
            <div class="dl-input-box">
                <?php 
                echo do_shortcode( '[mc4wp_form  id="' . $settings['dl_mailchimp_id'] . '"]' );
                ?>
            </div>
        </div>
        <?php

    }

}