<?php
/**
 * PieChart
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\PieChart;

use RediasCore\Classes\Helper;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-piecharts';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Pie Chart', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-counter-circle';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return ['pie chart', 'chart', 'redias'];
    }

    public function get_script_depends() {
        return ['easypiechart', 'waypoints', 'redias-el-script'];
    }

    public function get_style_depends() {
        return ['redias-piechart'];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_piechart();
        $this->section_piechart_settings();
        $this->percentage_style();
        $this->heading_style();
        $this->sub_heading_style();
        $this->description_style();

    }

    /**
     * Pie Chart Content
     *
     * @return void
     */
    protected function section_piechart() {

        $this->start_controls_section(
            'section_general',
            [
                'label' => esc_html__( 'Content', 'redias-core' ),
            ]
        );

        $this->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Layout', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'style-1',
                'options' => [
                    'style-1' => esc_html__( 'Style 1', 'redias-core' ),
                    'style-2' => esc_html__( 'Style 2', 'redias-core' ),
                ],
            ]
        );

        $this->add_responsive_control(
            'circle_align',
            [
                'label'                => esc_html__( 'Alignment', 'redias-core' ),
                'type'                 => Controls_Manager::CHOOSE,
                'options'              => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'default'              => 'center',
                'toggle'               => false,
                'selectors_dictionary' => [
                    'left'   => 'margin-right: auto; text-align: left',
                    'center' => 'margin: 0 auto; text-align: center',
                    'right'  => 'margin-left: auto; text-align: right',
                ],
                'selectors'            => [
                    '{{WRAPPER}} .dl-chart.style-1 .percentage, {{WRAPPER}} .dl-chart.style-1' => '{{VALUE}}',
                ],
                'condition'            => [
                    'layout' => 'style-1',
                ],
            ]
        );

        $this->add_responsive_control(
            'space_between',
            [
                'label'      => esc_html__( 'Space Between', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 20,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .style-1 .chart-content' => 'margin-top: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .style-2'                => 'grid-gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'dl_sub_heading',
            [
                'label'       => esc_html__( 'Sub Heading', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Completed', 'redias-core' ),
                'label_block' => true,
                'placeholder' => esc_html__( 'Sub heading...', 'redias-core' ),
                'condition'   => [
                    'layout' => 'style-2',
                ],
            ]
        );

        $this->add_control(
            'dl_heading',
            [
                'label'       => esc_html__( 'Heading', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Design Process', 'redias-core' ),
                'label_block' => true,
                'placeholder' => esc_html__( 'Heading...', 'redias-core' ),
            ]
        );

        $this->add_control(
            'dl_desc',
            [
                'label'       => esc_html__( 'Description', 'redias-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'rows'        => 5,
                'placeholder' => esc_html__( 'Description goes here...', 'redias-core' ),
            ]
        );

        $this->add_control(
            'percentage_value',
            [
                'label'      => esc_html__( 'Percentage Value', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['%'],
                'range'      => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => '%',
                    'size' => 50,
                ],

            ]
        );

        $this->end_controls_section();

    }

    /**
     * Pie Chart Settings
     *
     * @return void
     */
    protected function section_piechart_settings() {

        $this->start_controls_section(
            'section_piechart_settings',
            [
                'label' => esc_html__( 'Settings', 'redias-core' ),
            ]
        );

        $this->add_control(
            'wt_circle_size',
            [
                'label'       => esc_html__( 'Circle Size', 'redias-core' ),
                'type'        => Controls_Manager::NUMBER,
                'min'         => 1,
                'step'        => 1,
                'default'     => 150,
                'description' => esc_html__( 'Circle size increase or decrease from here.', 'redias-core' ),
            ]
        );

        $this->add_control(
            'wt_animate',
            [
                'label'       => esc_html__( 'Animate', 'redias-core' ),
                'type'        => Controls_Manager::NUMBER,
                'min'         => 1,
                'step'        => 1,
                'default'     => 2000,
                'description' => esc_html__( 'Animate time in milliseconds for a eased animation.', 'redias-core' ),
            ]
        );

        $this->add_control(
            'wt_line_width',
            [
                'label'       => esc_html__( 'Line Width', 'redias-core' ),
                'type'        => Controls_Manager::NUMBER,
                'min'         => 1,
                'step'        => 1,
                'default'     => 3,
                'description' => esc_html__( 'Width of the bar line in px.', 'redias-core' ),
            ]
        );

        $this->add_control(
            'wt_line_cap',
            [
                'label'              => esc_html__( 'Line Cap', 'redias-core' ),
                'type'               => Controls_Manager::SELECT,
                'default'            => 'round',
                'options'            => [
                    'butt'   => 'Butt',
                    'round'  => 'Round',
                    'square' => 'Square',
                ],
                'frontend_available' => true,
                'description'        => esc_html__( 'Defines how the ending of the bar line looks like.', 'redias-core' ),
            ]
        );

        $this->add_control(
            'wt_bar_color',
            [
                'label'       => esc_html__( 'Bar Color', 'redias-core' ),
                'type'        => Controls_Manager::COLOR,
                'default'     => '#ff6a32',
                'description' => esc_html__( 'The color of the circle bar.', 'redias-core' ),
            ]
        );

        $this->add_control(
            'wt_track_color',
            [
                'label'       => esc_html__( 'Track Color', 'redias-core' ),
                'type'        => Controls_Manager::COLOR,
                'default'     => '#dddddd',
                'description' => esc_html__( 'The color of the track for the bar.', 'redias-core' ),
            ]
        );

        $this->add_control(
            'wt_scale_coolor_control',
            [
                'label'        => esc_html__( 'Scale Color', 'redias-core' ),
                'description'  => esc_html__( 'Enable scale color for bar. Default is false', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'no',
            ]
        );

        $this->add_control(
            'wt_scale_color',
            [
                'label'       => esc_html__( 'Pick Scale Color', 'redias-core' ),
                'type'        => Controls_Manager::COLOR,
                'default'     => '#eeeeee',
                'description' => esc_html__( 'Choose scale color from this color picker.', 'redias-core' ),
                'condition'   => [
                    'wt_scale_coolor_control' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Percentage Style
     *
     * @return void
     */
    protected function percentage_style() {

        $this->start_controls_section(
            'wt_piechert_percentage_style',
            [
                'label' => esc_html__( 'Percentage', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'name'     => 'wt_percentage_typo',
                'selector' => '{{WRAPPER}} .dl-chart .percentage .count-number span',
            ]
        );

        $this->add_control(
            'wt_percentage_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-chart .percentage .count-number span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Symbol Typography', 'redias-core' ),
                'name'     => 'wt_percentage_symbol_typo',
                'selector' => '{{WRAPPER}} .dl-chart .percentage .count-number span:after',
            ]
        );

        $this->add_control(
            'symbol_color',
            [
                'label'     => esc_html__( 'Symbol Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-chart .percentage .count-number span:after' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'symbol_position',
            [
                'label'      => esc_html__( 'Symbol Position', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => -200,
                        'max'  => 200,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => -10,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-chart .percentage .count-number span:after' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Heading Style
     *
     * @return void
     */
    protected function heading_style() {

        $this->start_controls_section(
            'wt_piechert_heading_style',
            [
                'label'     => esc_html__( 'Heading', 'redias-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'dl_heading!' => '',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'     => esc_html__( 'Typography', 'redias-core' ),
                'name'      => 'wt_piechert_heading_typography',
                'selector'  => '{{WRAPPER}} .dl-chart .dl-label',
                'condition' => [
                    'dl_heading!' => '',
                ],
            ]
        );

        $this->add_control(
            'wt_piechert_heading_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-chart .dl-label' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'dl_heading!' => '',
                ],
            ]
        );

        $this->add_responsive_control(
            'wt_piechert_heading_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-chart .dl-label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'dl_heading!' => '',
                ],
            ]
        );

        $this->add_responsive_control(
            'wt_piechert_heading_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-chart .dl-label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'dl_heading!' => '',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Sub Heading Style
     *
     * @return void
     */
    protected function sub_heading_style() {

        $this->start_controls_section(
            'sub_heading_style',
            [
                'label'     => esc_html__( 'Sub Heading', 'redias-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout'          => 'style-2',
                    'dl_sub_heading!' => '',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'     => esc_html__( 'Typography', 'redias-core' ),
                'name'      => 'sub_heading_typography',
                'selector'  => '{{WRAPPER}} .chart-content .dl-sub',
                'condition' => [
                    'layout'          => 'style-2',
                    'dl_sub_heading!' => '',
                ],
            ]
        );

        $this->add_control(
            'sub_heading_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .chart-content .dl-sub' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'layout'          => 'style-2',
                    'dl_sub_heading!' => '',
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chart-content .dl-sub' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'layout'          => 'style-2',
                    'dl_sub_heading!' => '',
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chart-content .dl-sub' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'layout'          => 'style-2',
                    'dl_sub_heading!' => '',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Description Style
     *
     * @return void
     */
    protected function description_style() {

        $this->start_controls_section(
            'desc_style',
            [
                'label'     => esc_html__( 'Description', 'redias-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'dl_desc!' => '',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label'     => esc_html__( 'Typography', 'redias-core' ),
                'name'      => 'desc_typography',
                'selector'  => '{{WRAPPER}} .chart-content p',
                'condition' => [
                    'dl_desc!' => '',
                ],
            ]
        );

        $this->add_control(
            'desc_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .chart-content p' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'dl_desc!' => '',
                ],
            ]
        );

        $this->add_responsive_control(
            'desc_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chart-content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'dl_desc!' => '',
                ],
            ]
        );

        $this->add_responsive_control(
            'desc_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .chart-content p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'dl_desc!' => '',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

		$settings = $this->get_settings_for_display();
        $percent = ! empty( $settings['percentage_value']['size'] ) ? round( $settings['percentage_value']['size'] ) : 50;
        $data = [
            'percent' => $percent,
            'barColor' => !empty( $settings['wt_bar_color'] ) ? $settings['wt_bar_color'] : '#6ec1e4',
            'trackColor' => ! empty( $settings['wt_track_color'] ) ? $settings['wt_track_color'] : '#eeeeee',
            'scaleColor' => 'yes' === $settings['wt_scale_coolor_control'] ? $settings['wt_scale_color'] : false,
            'animate' => ! empty( $settings['wt_animate'] ) ? round( $settings['wt_animate'] ) : false,
            'lineWidth' => ! empty( $settings['wt_line_width'] ) ? $settings['wt_line_width'] : 10,
            'lineCap' => ! empty( $settings['wt_line_cap'] ) ? $settings['wt_line_cap'] : 'round',
            'size' => ! empty( $settings['wt_circle_size'] ) ? $settings['wt_circle_size'] : 175,
        ];
		
        $this->add_render_attribute( 'wrapper', [ 
            'class' => [ 'dl-chart', $settings['layout'] ], 
            'data-settings' => wp_json_encode( $data )
        ]);

        if( 'style-2' === $settings['layout'] ) {
            $this->add_render_attribute( 'wrapper', [ 
                'style'=> 'grid-template-columns:' . $settings['wt_circle_size'] . 'px 1fr;' 
            ]);
        }

        $this->add_render_attribute( 'dl_heading', [ 'class' => 'dl-label' ] );
        $this->add_inline_editing_attributes( 'dl_heading', 'none' );
        $this->add_render_attribute( 'dl_sub_heading', [ 'class' => 'dl-sub' ] );
        $this->add_inline_editing_attributes( 'dl_sub_heading', 'none' );
        $this->add_inline_editing_attributes( 'dl_desc', 'none' );

		?>
        <div <?php $this->print_render_attribute_string('wrapper'); ?>>
            <div class="percentage" data-percent="<?php echo esc_attr( $percent ); ?>">
                <div class="count-number">
                    <span><?php echo esc_html( $percent ); ?></span>
                </div>
            </div>
            <?php
            if( '' != $settings['dl_heading'] || '' != $settings['dl_sub_heading'] || '' != $settings['dl_desc'] ) {
                echo '<div class="chart-content">';
                if( '' != $settings['dl_sub_heading'] && 'style-2' === $settings['layout'] ) {
                    echo '<div '. $this->get_render_attribute_string( 'dl_sub_heading' ) .'>'. esc_html( $settings['dl_sub_heading'] ) .'</div>';
                }
                if( '' != $settings['dl_heading'] ) {
                    echo '<div '. $this->get_render_attribute_string( 'dl_heading' ) .'>'. esc_html( $settings['dl_heading'] ) .'</div>';
                }
                if( '' != $settings['dl_desc'] ) {
                    echo '<p '. $this->get_render_attribute_string( 'dl_desc' ) .'>'. Helper::kses_advance( $settings['dl_desc'] ) .'</p>';
                }
                echo '</div>';
            }
            ?>
        </div>
		<?php

    }

}