<?php
/**
 * Play Button
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\PlayButton;

use Elementor\Modules\DynamicTags\Module as TagsModule;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Embed;
use Elementor\Widget_Base;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-play-button';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Play Button', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-play-o';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return ['play button', 'play', 'video', 'button', 'redias'];
    }

    public function get_style_depends() {
        return ['redias-play-button'];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_video();
        $this->section_button_style();
        $this->play_button_style();
        $this->lightbox_style();

    }

    /**
     * Section Video
     *
     * @return void
     */
    protected function section_video() {

        $this->start_controls_section(
            'video_box',
            [
                'label' => esc_html__( 'Video', 'redias-core' ),
            ]
        );

        $this->add_control(
            'link_type',
            [
                'label'   => esc_html__( 'Link Type', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'lightbox',
                'options' => [
                    'lightbox'    => esc_html__( 'Lightbox', 'redias-core' ),
                    'custom_link' => esc_html__( 'Custom Link', 'redias-core' ),
                ],
            ]
        );

        $this->add_control(
            'custom_link',
            [
                'label'         => esc_html__( 'Custom Link', 'redias-core' ),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '',
                    'is_external' => false,
                    'nofollow'    => true,
                ],
                'condition'     => [
                    'link_type' => 'custom_link',
                ],
            ]
        );

        $this->add_control(
            'video_type',
            [
                'label'     => esc_html__( 'Source', 'redias-core' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'youtube',
                'options'   => [
                    'youtube'     => esc_html__( 'YouTube', 'redias-core' ),
                    'vimeo'       => esc_html__( 'Vimeo', 'redias-core' ),
                    'dailymotion' => esc_html__( 'Dailymotion', 'redias-core' ),
                ],
                'condition' => [
                    'link_type' => 'lightbox',
                ],
            ]
        );

        $this->add_control(
            'youtube_url',
            [
                'label'       => esc_html__( 'Link', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'dynamic'     => [
                    'active'     => true,
                    'categories' => [
                        TagsModule::POST_META_CATEGORY,
                        TagsModule::URL_CATEGORY,
                    ],
                ],
                'placeholder' => esc_html__( 'Enter your URL', 'redias-core' ) . ' (YouTube)',
                'default'     => 'https://www.youtube.com/watch?v=XHOmBV4js_E',
                'label_block' => true,
                'condition'   => [
                    'link_type'  => 'lightbox',
                    'video_type' => 'youtube',
                ],
            ]
        );

        $this->add_control(
            'vimeo_url',
            [
                'label'       => esc_html__( 'Link', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'dynamic'     => [
                    'active'     => true,
                    'categories' => [
                        TagsModule::POST_META_CATEGORY,
                        TagsModule::URL_CATEGORY,
                    ],
                ],
                'placeholder' => esc_html__( 'Enter your URL', 'redias-core' ) . ' (Vimeo)',
                'default'     => 'https://vimeo.com/235215203',
                'label_block' => true,
                'condition'   => [
                    'link_type'  => 'lightbox',
                    'video_type' => 'vimeo',
                ],
            ]
        );

        $this->add_control(
            'dailymotion_url',
            [
                'label'       => esc_html__( 'Link', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'dynamic'     => [
                    'active'     => true,
                    'categories' => [
                        TagsModule::POST_META_CATEGORY,
                        TagsModule::URL_CATEGORY,
                    ],
                ],
                'placeholder' => esc_html__( 'Enter your URL', 'redias-core' ) . ' (Dailymotion)',
                'default'     => 'https://www.dailymotion.com/video/x6tqhqb',
                'label_block' => true,
                'condition'   => [
                    'link_type'  => 'lightbox',
                    'video_type' => 'dailymotion',
                ],
            ]
        );

        $this->add_control(
            'start',
            [
                'label'       => esc_html__( 'Start Time', 'redias-core' ),
                'type'        => Controls_Manager::NUMBER,
                'description' => esc_html__( 'Specify a start time (in seconds)', 'redias-core' ),
                'condition'   => [
                    'loop' => '',
                ],
            ]
        );

        $this->add_control(
            'end',
            [
                'label'       => esc_html__( 'End Time', 'redias-core' ),
                'type'        => Controls_Manager::NUMBER,
                'description' => esc_html__( 'Specify an end time (in seconds)', 'redias-core' ),
                'condition'   => [
                    'link_type'  => 'lightbox',
                    'loop'       => '',
                    'video_type' => ['youtube', 'hosted'],
                ],
            ]
        );

        $this->add_control(
            'video_options',
            [
                'label'     => esc_html__( 'Video Options', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'link_type' => 'lightbox',
                ],
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label'     => esc_html__( 'Autoplay', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'condition' => [
                    'link_type' => 'lightbox',
                ],
            ]
        );

        $this->add_control(
            'play_on_mobile',
            [
                'label'     => esc_html__( 'Play On Mobile', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'condition' => [
                    'link_type' => 'lightbox',
                    'autoplay'  => 'yes',
                ],
            ]
        );

        $this->add_control(
            'mute',
            [
                'label'     => esc_html__( 'Mute', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'condition' => [
                    'link_type' => 'lightbox',
                ],
            ]
        );

        $this->add_control(
            'loop',
            [
                'label'     => esc_html__( 'Loop', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'condition' => [
                    'link_type'   => 'lightbox',
                    'video_type!' => 'dailymotion',
                ],
            ]
        );

        $this->add_control(
            'aspect_ratio',
            [
                'label'              => esc_html__( 'Aspect Ratio', 'redias-core' ),
                'type'               => Controls_Manager::SELECT,
                'options'            => [
                    '169' => '16:9',
                    '219' => '21:9',
                    '43'  => '4:3',
                    '32'  => '3:2',
                    '11'  => '1:1',
                    '916' => '9:16',
                ],
                'default'            => '169',
                'prefix_class'       => 'elementor-aspect-ratio-',
                'frontend_available' => true,
                'condition'          => [
                    'link_type' => 'lightbox',
                ],
            ]
        );

        $this->add_control(
            'controls',
            [
                'label'     => esc_html__( 'Player Controls', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'label_on'  => esc_html__( 'Show', 'redias-core' ),
                'default'   => 'yes',
                'condition' => [
                    'link_type'   => 'lightbox',
                    'video_type!' => 'vimeo',
                ],
            ]
        );

        $this->add_control(
            'showinfo',
            [
                'label'     => esc_html__( 'Video Info', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'label_on'  => esc_html__( 'Show', 'redias-core' ),
                'default'   => 'yes',
                'condition' => [
                    'link_type'  => 'lightbox',
                    'video_type' => ['dailymotion'],
                ],
            ]
        );

        $this->add_control(
            'modestbranding',
            [
                'label'     => esc_html__( 'Modest Branding', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'condition' => [
                    'link_type'  => 'lightbox',
                    'video_type' => ['youtube'],
                    'controls'   => 'yes',
                ],
            ]
        );

        $this->add_control(
            'logo',
            [
                'label'     => esc_html__( 'Logo', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'label_on'  => esc_html__( 'Show', 'redias-core' ),
                'default'   => 'yes',
                'condition' => [
                    'link_type'  => 'lightbox',
                    'video_type' => ['dailymotion'],
                ],
            ]
        );

        // YouTube.
        $this->add_control(
            'yt_privacy',
            [
                'label'       => esc_html__( 'Privacy Mode', 'redias-core' ),
                'type'        => Controls_Manager::SWITCHER,
                'description' => esc_html__( 'When you turn on privacy mode, YouTube won\'t store information about visitors on your website unless they play the video.', 'redias-core' ),
                'condition'   => [
                    'link_type'  => 'lightbox',
                    'video_type' => 'youtube',
                ],
            ]
        );

        $this->add_control(
            'rel',
            [
                'label'     => esc_html__( 'Suggested Videos', 'redias-core' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    ''    => esc_html__( 'Current Video Channel', 'redias-core' ),
                    'yes' => esc_html__( 'Any Video', 'redias-core' ),
                ],
                'condition' => [
                    'link_type'  => 'lightbox',
                    'video_type' => 'youtube',
                ],
            ]
        );

        // Vimeo.
        $this->add_control(
            'vimeo_title',
            [
                'label'     => esc_html__( 'Intro Title', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'label_on'  => esc_html__( 'Show', 'redias-core' ),
                'default'   => 'yes',
                'condition' => [
                    'link_type'  => 'lightbox',
                    'video_type' => 'vimeo',
                ],
            ]
        );

        $this->add_control(
            'vimeo_portrait',
            [
                'label'     => esc_html__( 'Intro Portrait', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'label_on'  => esc_html__( 'Show', 'redias-core' ),
                'default'   => 'yes',
                'condition' => [
                    'link_type'  => 'lightbox',
                    'video_type' => 'vimeo',
                ],
            ]
        );

        $this->add_control(
            'vimeo_byline',
            [
                'label'     => esc_html__( 'Intro Byline', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'label_on'  => esc_html__( 'Show', 'redias-core' ),
                'default'   => 'yes',
                'condition' => [
                    'link_type'  => 'lightbox',
                    'video_type' => 'vimeo',
                ],
            ]
        );

        $this->add_control(
            'color',
            [
                'label'     => esc_html__( 'Controls Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'condition' => [
                    'link_type'  => 'lightbox',
                    'video_type' => ['vimeo', 'dailymotion'],
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Section Button Style
     *
     * @return void
     */
    protected function section_button_style() {

        $this->start_controls_section(
            'video_box_play_icon',
            [
                'label' => esc_html__( 'Play Button Style', 'redias-core' ),
            ]
        );

        $this->add_control(
            'video_box_play_btn_style',
            [
                'label'   => esc_html__( 'Play Button Style', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'style1' => esc_html__( 'Style 1', 'redias-core' ),
                    'style2' => esc_html__( 'Style 2', 'redias-core' ),
                ],
                'default' => 'style1',
            ]
        );

        $this->add_responsive_control(
            'btn_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'textdomain' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-play-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'button_align',
            [
                'label'                => esc_html__( 'Alignment', 'redias-core' ),
                'type'                 => Controls_Manager::CHOOSE,
                'options'              => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'default'              => 'center',
                'toggle'               => false,
                'selectors_dictionary' => [
                    'left'   => 'margin: 0;',
                    'center' => 'margin: 0 auto;',
                    'right'  => 'margin-left: auto',
                ],
                'selectors'            => [
                    '{{WRAPPER}} .dl-play-btn' => '{{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'video_box_play_btn_style1_width',
            [
                'label'      => esc_html__( 'Width / Height', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 50,
                        'max'  => 200,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 100,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-vb-2'                                                                                  => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-vb-2 .ripple, {{WRAPPER}} .dl-vb-2 .ripple:before, {{WRAPPER}} .dl-vb-2 .ripple:after' => 'width: calc({{SIZE}}{{UNIT}} - 2px); height: calc({{SIZE}}{{UNIT}} - 2px);',
                ],
                'condition'  => [
                    'video_box_play_btn_style' => 'style1',
                ],
            ]
        );

        $this->add_responsive_control(
            'video_box_play_btn_style1_icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 10,
                        'max'  => 80,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 24,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-vb-2' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'video_box_play_btn_style' => 'style1',
                ],
            ]
        );

        $this->add_responsive_control(
            'video_box_play_btn_style2_width',
            [
                'label'      => esc_html__( 'Width / Height', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 50,
                        'max'  => 200,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 70,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-vb-3' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'video_box_play_btn_style' => 'style2',
                ],
            ]
        );

        $this->add_responsive_control(
            'video_box_play_btn_style2_icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 15,
                        'max'  => 80,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 30,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-vb-3 svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'video_box_play_btn_style' => 'style2',
                ],
            ]
        );

        $this->add_responsive_control(
            'video_box_play_btn_style2_icon_pos_x',
            [
                'label'     => esc_html__( 'Icon Position X', 'redias-core' ),
                'type'      => Controls_Manager::NUMBER,
                'step'      => 1,
                'default'   => 5,
                'selectors' => [
                    '{{WRAPPER}} .dl-vb-3 svg' => 'margin-left: {{VALUE}}px;',
                ],
                'condition' => [
                    'video_box_play_btn_style' => 'style2',
                ],
            ]
        );

        $this->add_responsive_control(
            'video_box_play_btn_style2_icon_pos_y',
            [
                'label'     => esc_html__( 'Icon Position Y', 'redias-core' ),
                'type'      => Controls_Manager::NUMBER,
                'step'      => 1,
                'default'   => 5,
                'selectors' => [
                    '{{WRAPPER}} .dl-vb-3 svg' => 'margin-bottom: {{VALUE}}px;',
                ],
                'condition' => [
                    'video_box_play_btn_style' => 'style2',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Play Button Style
     *
     * @return void
     */
    protected function play_button_style() {

        $this->start_controls_section(
            'section_style',
            [
                'label' => esc_html__( 'Play Button', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs( 'tab_box_style' );

        $this->start_controls_tab(
            'tab_box_normal',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
            ]
        );

        // Start play button 1 style
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'      => 'pbtn_style_1_bg_color',
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'types'     => ['classic', 'gradient'],
                'selector'  => '{{WRAPPER}} .dl-vb-2',
                'condition' => [
                    'video_box_play_btn_style' => 'style1',
                ],
            ]
        );

        $this->add_control(
            'pbtn_style_1_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-vb-2' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'video_box_play_btn_style' => 'style1',
                ],
            ]
        );
        // End play button 1 style

        // Start play button 2 style
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'      => 'pbtn_style_2_bg_color',
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'types'     => ['classic', 'gradient'],
                'selector'  => '{{WRAPPER}} .dl-vb-3',
                'condition' => [
                    'video_box_play_btn_style' => 'style2',
                ],
            ]
        );

        $this->add_control(
            'pbtn_style_2_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-vb-3 svg' => 'fill: {{VALUE}}',
                ],
                'condition' => [
                    'video_box_play_btn_style' => 'style2',
                ],
            ]
        );
        // End play button 2 style

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_box_hover',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
            ]
        );

        // Start play button 1 hover style
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'      => 'pbtn_style_1_bg_hover_color',
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'types'     => ['classic', 'gradient'],
                'selector'  => '{{WRAPPER}} .dl-vb-2:hover',
                'condition' => [
                    'video_box_play_btn_style' => 'style1',
                ],
            ]
        );

        $this->add_control(
            'pbtn_style_1_icon_hover_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-vb-2:hover' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'video_box_play_btn_style' => 'style1',
                ],
            ]
        );
        // End play button 1 hover style

        // Start play button 2 hover style
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'      => 'pbtn_style_2_bg_hover_color',
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'types'     => ['classic', 'gradient'],
                'selector'  => '{{WRAPPER}} .dl-vb-3:hover',
                'condition' => [
                    'video_box_play_btn_style' => 'style2',
                ],
            ]
        );

        $this->add_control(
            'pbtn_style_2_icon_hover_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-vb-3:hover svg' => 'fill: {{VALUE}}',
                ],
                'condition' => [
                    'video_box_play_btn_style' => 'style2',
                ],
            ]
        );
        // End play button 2 hover style

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

    }

    /**
     * Lightbox Style
     *
     * @return void
     */
    protected function lightbox_style() {

        $this->start_controls_section(
            'section_lightbox_style',
            [
                'label'     => esc_html__( 'Lightbox', 'redias-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'link_type' => 'lightbox',
                ],
            ]
        );

        $this->add_control(
            'lightbox_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '#elementor-lightbox-{{ID}}' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'link_type' => 'lightbox',
                ],
            ]
        );

        $this->add_control(
            'lightbox_ui_color',
            [
                'label'     => esc_html__( 'UI Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '#elementor-lightbox-{{ID}} .dialog-lightbox-close-button' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'link_type' => 'lightbox',
                ],
            ]
        );

        $this->add_control(
            'lightbox_ui_color_hover',
            [
                'label'     => esc_html__( 'UI Hover Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '#elementor-lightbox-{{ID}} .dialog-lightbox-close-button:hover' => 'color: {{VALUE}}',
                ],
                'separator' => 'after',
                'condition' => [
                    'link_type' => 'lightbox',
                ],
            ]
        );

        $this->add_control(
            'lightbox_video_width',
            [
                'label'     => esc_html__( 'Content Width', 'redias-core' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'unit' => '%',
                ],
                'range'     => [
                    '%' => [
                        'min' => 30,
                    ],
                ],
                'selectors' => [
                    '(desktop+)#elementor-lightbox-{{ID}} .elementor-video-container' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'link_type' => 'lightbox',
                ],
            ]
        );

        $this->add_control(
            'lightbox_content_position',
            [
                'label'                => esc_html__( 'Content Position', 'redias-core' ),
                'type'                 => Controls_Manager::SELECT,
                'frontend_available'   => true,
                'options'              => [
                    ''    => esc_html__( 'Center', 'redias-core' ),
                    'top' => esc_html__( 'Top', 'redias-core' ),
                ],
                'selectors'            => [
                    '#elementor-lightbox-{{ID}} .elementor-video-container' => '{{VALUE}}; transform: translateX(-50%);',
                ],
                'selectors_dictionary' => [
                    'top' => 'top: 60px',
                ],
                'condition'            => [
                    'link_type' => 'lightbox',
                ],
            ]
        );

        $this->add_responsive_control(
            'lightbox_content_animation',
            [
                'label'              => esc_html__( 'Entrance Animation', 'redias-core' ),
                'type'               => Controls_Manager::ANIMATION,
                'frontend_available' => true,
                'condition'          => [
                    'link_type' => 'lightbox',
                ],
            ]
        );

        $this->end_controls_section();

    }
    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings = $this->get_settings_for_display();

        $custtom_url = ! empty( $settings['custom_link']['url'] ) ? $settings['custom_link']['url'] : '';
		$play_btn_style = $settings['video_box_play_btn_style'];
		
		$target = ! empty( $settings['custom_link']['is_external'] ) ? ' target="_blank"' : '';
		$nofollow = ! empty( $settings['custom_link']['nofollow'] ) ? ' rel="nofollow"' : '';

		$this->add_render_attribute( 'wrapper', 'class', 'dl-video-box-wrap' );
		if( 'lightbox' === $settings['link_type'] ) {
			$video_url = $settings[ $settings['video_type'] . '_url' ];
			$lightbox_url = '';
			$embed_params = $this->get_embed_params();
			$embed_options = $this->get_embed_options();
			if ( 'hosted' === $settings['video_type'] ) {
				$lightbox_url = $video_url;
			} else {
				$lightbox_url = Embed::get_embed_url( $video_url, $embed_params, $embed_options );
			}
			$lightbox_options = [
				'type' => 'video',
				'videoType' => $settings['video_type'],
				'url' => $lightbox_url,
				'modalOptions' => [
					'id' => 'elementor-lightbox-' . $this->get_id(),
					'entranceAnimation' => $settings['lightbox_content_animation'],
					'entranceAnimation_tablet' => $settings['lightbox_content_animation_tablet'],
					'entranceAnimation_mobile' => $settings['lightbox_content_animation_mobile'],
					'videoAspectRatio' => $settings['aspect_ratio'],
				],
			];
			$this->add_render_attribute( 'video-link', [
				'data-elementor-open-lightbox' => 'yes',
				'class' => 'el-lightbox',
				'data-elementor-lightbox' => wp_json_encode( $lightbox_options ),
			] );
		}
        
        ?>
		<?php if( 'custom_link' === $settings['link_type'] ) : ?>
			<a href="<?php echo esc_url( $custtom_url ); ?>" <?php echo esc_attr( $target ) . ' ' . esc_attr( $nofollow ); ?>>
		<?php else : ?>
			<div <?php echo $this->get_render_attribute_string( 'video-link' ); ?>>
		<?php endif; ?>
			<?php if( 'style1' === $play_btn_style ) : ?>
				<div class="dl-vb-2 dl-play-btn">
					<i class="fa fa-play"></i>
					<div class="ripple"></div>
				</div>
			<?php elseif( 'style2' === $play_btn_style ) : ?>
				<div class="dl-vb-3 dl-play-btn">
					<svg enable-background="new 0 0 41.999 41.999" version="1.1" width="12" viewBox="0 0 41.999 41.999" xml:space="preserve" xmlns="http://www.w3.org/2000/svg">
						<path d="M36.068,20.176l-29-20C6.761-0.035,6.363-0.057,6.035,0.114C5.706,0.287,5.5,0.627,5.5,0.999v40  c0,0.372,0.206,0.713,0.535,0.886c0.146,0.076,0.306,0.114,0.465,0.114c0.199,0,0.397-0.06,0.568-0.177l29-20  c0.271-0.187,0.432-0.494,0.432-0.823S36.338,20.363,36.068,20.176z M7.5,39.095V2.904l26.239,18.096L7.5,39.095z"/>
					</svg>
				</div>
			<?php endif; ?>
		<?php if( 'custom_link' === $settings['link_type'] ) : ?>
			</a>
		<?php else: ?>
			</div>
		<?php endif; ?>
        <?php

    }

    /**
	 * Get embed params.
	 *
	 * Retrieve video widget embed parameters.
	 *
	 * @since 1.5.0
	 * @access public
	 *
	 * @return array Video embed parameters.
	 */
	public function get_embed_params() {
		$settings = $this->get_settings_for_display();

		$params = [];

		if ( $settings['autoplay'] ) {
			$params['autoplay'] = '1';

			if ( $settings['play_on_mobile'] ) {
				$params['playsinline'] = '1';
			}
		}

		$params_dictionary = [];

		if ( 'youtube' === $settings['video_type'] ) {
			$params_dictionary = [
				'loop',
				'controls',
				'mute',
				'rel',
				'modestbranding',
			];

			if ( $settings['loop'] ) {
				$video_properties = Embed::get_video_properties( $settings['youtube_url'] );

				$params['playlist'] = $video_properties['video_id'];
			}

			$params['start'] = $settings['start'];

			$params['end'] = $settings['end'];

			$params['wmode'] = 'opaque';
		} elseif ( 'vimeo' === $settings['video_type'] ) {
			$params_dictionary = [
				'loop',
				'mute' => 'muted',
				'vimeo_title' => 'title',
				'vimeo_portrait' => 'portrait',
				'vimeo_byline' => 'byline',
			];

			$params['color'] = str_replace( '#', '', $settings['color'] );

			$params['autopause'] = '0';
		} elseif ( 'dailymotion' === $settings['video_type'] ) {
			$params_dictionary = [
				'controls',
				'mute',
				'showinfo' => 'ui-start-screen-info',
				'logo' => 'ui-logo',
			];

			$params['ui-highlight'] = str_replace( '#', '', $settings['color'] );

			$params['start'] = $settings['start'];

			$params['endscreen-enable'] = '0';
		}

		foreach ( $params_dictionary as $key => $param_name ) {
			$setting_name = $param_name;

			if ( is_string( $key ) ) {
				$setting_name = $key;
			}

			$setting_value = $settings[ $setting_name ] ? '1' : '0';

			$params[ $param_name ] = $setting_value;
		}

		return $params;
	}

	/**
	 * @since 2.1.0
	 * @access private
	 */
	private function get_embed_options() {
		$settings = $this->get_settings_for_display();

		$embed_options = [];

		if ( 'youtube' === $settings['video_type'] ) {
			$embed_options['privacy'] = $settings['yt_privacy'];
		} elseif ( 'vimeo' === $settings['video_type'] ) {
			$embed_options['start'] = $settings['start'];
		}

		$embed_options['lazy_load'] = ! empty( $settings['lazy_load'] );

		return $embed_options;
	}

}