<?php
/**
 * Pricing Table
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\PricingTable;

use RediasCore\Classes\Helper;
use RediasCore\Elementor\Controls\Foreground;
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Icons_Manager;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-pricing-table';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Pricing Table', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-price-table';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'pricing', 'table', 'pricing table', 'redias' ];
    }

    public function get_style_depends() {
        return [ 'redias-pricing-table', 'elementor-icons-line-awesome-icons' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->content_section();
        $this->box_style();
        $this->icon_style();
        $this->title_style();
        $this->price_style();
        $this->features_style();
        $this->button_style();
        
    }

    /**
     * Pricing Plan
     *
     * @return void
     */
    protected function content_section() {

        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__( 'Pricing Plan', 'redias-core' )
            ]
        );

        $this->add_responsive_control(
            'content_align',
            [
                'label' => esc_html__( 'Alignment', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon' => 'eicon-text-align-right',
                    ]
                ],
                'default' => 'left',
                'toggle' => false,
                'prefix_class' => 'pricing-align-',
                'selectors' => [
                    '{{WRAPPER}} .el-pricing-table' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}}.pricing-align-center .el-pricing-table .pricing-head .pt-icon' => 'margin-left: auto; margin-right: auto;',
                    '{{WRAPPER}}.pricing-align-right .el-pricing-table .pricing-head .pt-icon' => 'margin-left: auto;',
                    '{{WRAPPER}}.pricing-align-center .el-pricing-table .pricing-features li' => 'padding: 0;',
                    '{{WRAPPER}}.pricing-align-center .el-pricing-table .pricing-features li:before' => 'display: none;',
                    '{{WRAPPER}}.pricing-align-right .el-pricing-table .pricing-features li' => 'padding-left: 0; padding-right: 15px;',
                    '{{WRAPPER}}.pricing-align-right .el-pricing-table .pricing-features li:before' => 'left: auto; right: 0;',
                ]
            ]
        );

        $this->add_control(
            'plan_name',
            [
                'label'       => esc_html__( 'Plan Name', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Basic Plan', 'redias-core' ),
                'placeholder' => esc_html__( 'Plan name...', 'redias-core' ),
                'label_block' => true
            ]
        );

        $this->add_control(
			'plan_icon',
			[
				'label' => esc_html__( 'Plan Icon', 'redias-core' ),
				'type' => Controls_Manager::ICONS,
                'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'la la-rocket',
					'library' => 'elementor-icons-line-awesome-icons',
				]
			]
		);

        $this->add_control(
            'plan_price',
            [
                'label'       => esc_html__( 'Plan Price', 'redias-core' ),
                'type'        => Controls_Manager::NUMBER,
                'default'     => 25
            ]
        );

        $this->add_control(
            'price_currency',
            [
                'label'       => esc_html__( 'Price Currency', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '$',
                'placeholder' => esc_html__( 'Symbol', 'redias-core' ),
                'condition' => [
                    'plan_price!' => ''
                ],
            ]
        );

        $this->add_control(
            'plan_period',
            [
                'label'       => esc_html__( 'Plan Period', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( '/month', 'redias-core' ),
                'placeholder' => esc_html__( 'Plan period...', 'redias-core' ),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'feature',
            [
                'label'       => esc_html__( 'Feature', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Support Your Business', 'redias-core' ),
                'placeholder' => esc_html__( 'Feature goes here..', 'redias-core' ),
                'label_block' => true
            ]
        );
        
        $this->add_control(
            'pricing_features',
            [
                'label'       => esc_html__( 'Features', 'redias-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [ 'feature' => esc_html__( 'Support Your Business', 'redias-core' ) ],
                    [ 'feature' => esc_html__( 'Custom Design & Features', 'redias-core' ) ],
                    [ 'feature' => esc_html__( 'Unlimited Domains', 'redias-core' ) ],
                    [ 'feature' => esc_html__( '6 Months Premium Support', 'redias-core' ) ],
                    [ 'feature' => esc_html__( 'Lifetime updates', 'redias-core' ) ]
                    
                ],
                'title_field' => '{{{ feature }}}',
            ]
        );

        $this->add_control(
            'plan_btn',
            [
                'label'       => esc_html__( 'Button Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Purchase Now', 'redias-core' ),
                'placeholder' => esc_html__( 'Button text..', 'redias-core' ),
                'label_block' => true
            ]
        );

        $this->add_control(
            'btn_link',
            [
                'label'         => esc_html__( 'Button Link', 'redias-core' ),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '',
                    'is_external' => true,
                    'nofollow'    => true,
                ],
                'condition' => [
                    'plan_btn!' => ''
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Box Style
     *
     * @return void
     */
    protected function box_style() {

        $this->start_controls_section(
            'box_style',
            [
                'label' => esc_html__( 'Box', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'content_box_bg',
                'label'   => esc_html__('Background', 'Text-domain'),
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .el-pricing-table',
            ]
        );

        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'content_box_border',
				'label'    => esc_html__( 'Border', 'redias-core' ),
				'selector' => '{{WRAPPER}} .el-pricing-table',
			]
		);

        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'content_box_shadow',
				'selector' => '{{WRAPPER}} .el-pricing-table',
			]
		);

		$this->add_responsive_control(
			'box_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-pricing-table' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

        $this->add_responsive_control(
			'content_box_padding',
			[
				'label'      => esc_html__( 'Padding', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-pricing-table' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);

        $this->add_responsive_control(
			'content_box_margin',
			[
				'label'      => esc_html__( 'Margin', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-pricing-table' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
        
        $this->end_controls_section();

    }

    /**
     * Icon Style
     *
     * @return void
     */
    protected function icon_style() {

        $this->start_controls_section(
            'icon_style',
            [
                'label' => esc_html__( 'Icon', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'plan_icon[value]!' => ''
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'icon_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'   => ['image'],
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-head .pt-icon',
                'condition'    => [
                    'plan_icon[value]!' => ''
                ]
            ]
        );

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'icon_color',
                'label'    => esc_html__( 'Icon Color Type', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-head i',
                'condition'    => [
                    'plan_icon[value]!' => ''
                ]
            ]
        );

        $this->add_responsive_control(
            'icon_box_size',
            [
                'label'      => esc_html__( 'Box Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 15,
                        'max'  => 250,
                        'step' => 1
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-pricing-table .pricing-head .pt-icon' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};'
                ],
                'condition'    => [
                    'plan_icon[value]!' => ''
                ]
            ]
        );

        $this->add_responsive_control(
            'icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 10,
                        'max'  => 250,
                        'step' => 1
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-pricing-table .pricing-head .pt-icon' => 'font-size: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};'
                ],
                'condition'    => [
                    'plan_icon[value]!' => ''
                ]
            ]
        );

        $this->add_responsive_control(
            'icon_bottom_spacing',
            [
                'label'      => esc_html__( 'Bottom Spacing', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-pricing-table .pricing-head .pt-icon' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'plan_icon[value]!' => ''
                ]
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Title Style
     *
     * @return void
     */
    protected function title_style() {

        $this->start_controls_section(
            'title_style',
            [
                'label' => esc_html__( 'Title', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'position_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-head h3',
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-pricing-table .pricing-head h3' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'title_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-pricing-table .pricing-head h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Price Style
     *
     * @return void
     */
    protected function price_style() {

        $this->start_controls_section(
            'price_style',
            [
                'label' => esc_html__( 'Price', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'price_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-head .plan-price',
            ]
        );

        $this->add_control(
            'price_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-pricing-table .pricing-head .plan-price' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'price_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-pricing-table .pricing-head .plan-price' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'plan_period_heading',
            [
                'label' => esc_html__( 'Plan Period', 'redias-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'plan_period_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-head .plan-price span',
            ]
        );

        $this->add_control(
            'plan_period_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-pricing-table .pricing-head .plan-price span' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'plan_period_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-pricing-table .pricing-head .plan-price span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Features Style
     *
     * @return void
     */
    protected function features_style() {

        $this->start_controls_section(
            'features_style',
            [
                'label' => esc_html__( 'Features', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'feature_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-features li',
            ]
        );

        $this->add_control(
            'feature_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-pricing-table .pricing-features li' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'feature_bullet_color',
            [
                'label'     => esc_html__( 'Bullet Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-pricing-table .pricing-features li:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'feature_item_space_between',
            [
                'label'      => esc_html__( 'Space Between Item', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100,
                        'step' => 1
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-pricing-table .pricing-features li:not(:last-of-type)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'features_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-pricing-table .pricing-features' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Button Style
     *
     * @return void
     */
    protected function button_style() {

        $this->start_controls_section(
            'button_style',
            [
                'label' => esc_html__( 'Button', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'btn_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-footer a',
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-pricing-table .pricing-footer a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'button_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-pricing-table .pricing-footer' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->start_controls_tabs( 'btn_style_tabs' );
        
        $this->start_controls_tab(
            'btn_style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'btn_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-footer a',
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .el-pricing-table .pricing-footer a' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'btn_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-footer a',
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'btn_box_shadow',
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-footer a',
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-pricing-table .pricing-footer a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'btn_style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'btn_hover_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-footer a:before',
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_control(
            'btn_hover_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .el-pricing-table .pricing-footer a:hover' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'btn_hover_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-footer a:hover',
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'btn_hover_box_shadow',
                'selector' => '{{WRAPPER}} .el-pricing-table .pricing-footer a:hover',
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_hover_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-pricing-table .pricing-footer a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'plan_btn!' => '',
                    'btn_link[url]!' => ''
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        $pricing_features = $settings['pricing_features'];

        $this->add_render_attribute(
			'wrapper', [ 'class' => [ 'el-pricing-table' ] ]
		);

        $this->add_inline_editing_attributes( 'plan_name', 'none' );
        $this->add_inline_editing_attributes( 'plan_price', 'none' );
        $this->add_inline_editing_attributes( 'plan_period', 'none' );
        $this->add_inline_editing_attributes( 'plan_btn', 'none' );
        $this->add_link_attributes( 'button_link', $settings['btn_link'] );
        ?>
        <div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
            <div class="pricing-head">
            <?php 
                if ( ! empty( $settings['plan_icon']['value'] ) ) {
                    echo '<div class="pt-icon">';
                        Icons_Manager::render_icon( $settings['plan_icon'], ['aria-hidden' => 'true'] ); 
                    echo '</div>';
                }
                if( ! empty( $settings['plan_name'] ) ) {
                    echo '<h3 '. $this->get_render_attribute_string( 'plan_name' ) .'>'. esc_html( $settings['plan_name'] ) .'</h3>';
                }
                if( ! empty( $settings['plan_price'] ) ) {
                    echo '<div class="plan-price">';
                    echo ! empty( $settings['price_currency'] ) ? esc_html( $settings['price_currency'] ) : '';
                    echo Helper::is_el_edit_mode() === true ? '<div '. $this->get_render_attribute_string( 'plan_price' ) .'>'. esc_html( $settings['plan_price'] ) .'</div>' : esc_html( $settings['plan_price'] );
                    echo ! empty( $settings['plan_period'] ) ? '<span '. $this->get_render_attribute_string( 'plan_period' ) .'>'. esc_html( $settings['plan_period'] ) .'</span>' : '';
                    echo '</div>';
                }
            ?>
            </div>
            <?php if($pricing_features) : ?>
            <ul class="pricing-features">
            <?php
                foreach( $pricing_features as $index => $pricing_feature ){
                    $repeater_setting_key_feature = $this->get_repeater_setting_key( 'feature', 'pricing_features', $index );
                    $this->add_inline_editing_attributes( $repeater_setting_key_feature );
                    echo '<li '. $this->get_render_attribute_string( $repeater_setting_key_feature ) .'>'. Helper::kses_basic( $pricing_feature['feature'] ) .'</li>';
                }
            ?>
            </ul>
            <?php endif; 
            if( ! empty( $settings['plan_btn'] && $settings['btn_link']['url'] ) ) : ?>
            <div class="pricing-footer">
                <a <?php $this->print_render_attribute_string( 'button_link' ); ?>><?php echo esc_html( $settings['plan_btn'] ); ?></a>
            </div>
            <?php endif; ?>
        </div>
        <?php
    }

    protected function content_template(){}

}