<?php
/**
 * Projects
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Projects;

use RediasCore\Classes\Helper;
use RediasCore\Traits\CarouselControls;
use RediasCore\Elementor\Controls\BorderBottom;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    use CarouselControls;

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-projects';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Projects', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-posts-grid';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'project', 'portfolio', 'works', 'redias' ];
    }

    public function get_style_depends() {
        return [ 'redias-project', 'slick', 'elementor-icons-line-awesome-icons' ];
    }

    public function get_script_depends() {
        return [ 'isotope', 'imagesloaded', 'slick', 'redias-el-script' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->layout_section();
        $this->query_section();
        $this->section_controls();
        $this->useful_options_section();
        $this->card_style();
        $this->heading_style();
        $this->category_style();
        $this->readmore_style();
        $this->filter_style();
        $this->pagination_style();
        $this->style_navigation('carousel_status');
        $this->style_pagination('carousel_status');
    }

    /**
     * Layout Section
     *
     * @return void
     */
    protected function layout_section() {

        $this->start_controls_section(
			'layout_section',
			[
				'label' => esc_html__( 'Layout', 'redias-core' )
			]
        );

		$this->add_control(
			'card_style',
			[
				'label' => esc_html__( 'Card Style', 'redias-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => esc_html__( 'Style 1', 'redias-core' ),
					'2' => esc_html__( 'Style 2', 'redias-core' )
				]
			]
		);

		$this->add_responsive_control(
			'card_height',
			[
				'label' => esc_html__( 'Card Height', 'textdomain' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					]
				],
				'default' => [
					'unit' => 'px',
					'size' => 350
				],
				'selectors' => [
					'{{WRAPPER}} .style-2.el-project-card img' => 'height: {{SIZE}}{{UNIT}};'
				],
				'condition' => [
					'card_style' => '2'
				]
			]
		);

        $this->add_control(
            'carousel_status',
            [
                'label' => esc_html__( 'Enable Carousel', 'redias-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'redias-core' ),
                'label_off' => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default' => 'no'
            ]
        );

		$this->add_control(
			'carousel',
			[
				'label' => esc_html__( 'Carousel Status', 'redias-core' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'yes',
				'frontend_available' => true,
				'render_type' => 'ui',
				'condition' => [
					'carousel_status' => 'yes'
				]
			]
		);

        $this->add_responsive_control(
            'carousel_width',
            [
                'label' => esc_html__( 'Carousel Width', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'container_width' => [
                        'title' => esc_html__( 'Container Width', 'redias-core' ),
                        'icon' => 'eicon-container',
                    ],
                    'full_width' => [
                        'title' => esc_html__( 'Full Width', 'redias-core' ),
                        'icon' => ' eicon-slides',
                    ]
                ],
                'toggle' => false,
				'prefix_class' => 'carousel-',
                'selectors_dictionary' => [
                    'container_width' => 'overflow: hidden',
                    'full_width' => 'overflow: inherit',
                ],
                'default' => 'container_width',
                'selectors' => [
                    '{{WRAPPER}}' => 'overflow: hidden',
                    '{{WRAPPER}} .el-project-wrapper' => '{{VALUE}}',
                    '{{WRAPPER}} .el-project-wrapper .dl-carousel' => '{{VALUE}}',
                    '{{WRAPPER}} .el-project-wrapper .dl-carousel .slick-list' => '{{VALUE}}',
                    '(desktop){{WRAPPER}}.center-mode-yes.carousel-full_width.slide-per-show-1 .el-project-wrapper .dl-carousel' => 'width: 60%; margin: 0 auto;',
                    '(tablet){{WRAPPER}}.center-mode-yes.carousel-full_width.slide-per-show-1 .el-project-wrapper .dl-carousel' => 'width: 100%;',
                    '(mobile){{WRAPPER}}.center-mode-yes.carousel-full_width.slide-per-show-1 .el-project-wrapper .dl-carousel' => 'width: 100%;',
				],
				'condition' => [
					'carousel_status' => 'yes'
				]
            ]
        );

        $this->add_responsive_control(
            'project_column',
            [
                'label' => esc_html__( 'Columns', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 6,
                        'step' => 1
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 3
                ],
                'tablet_default' => [
                    'unit' => 'px',
                    'size' => 2
                ],
                'mobile_default' => [
                    'unit' => 'px',
                    'size' => 1
                ],
                'selectors' => [
                    '{{WRAPPER}} .el-project-items .el-project-card' => 'width: calc(100% / {{SIZE}});'
                ],
                'condition' => [
					'carousel_status!' => 'yes'
				]
            ]
        );

        $this->add_responsive_control(
            'column-gap',
            [
                'label' => esc_html__( 'Column Gap', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 15
                ],
                'selectors' => [
                    '{{WRAPPER}} .el-project-items' => 'margin: -{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .el-project-items .el-project-card' => 'padding: {{SIZE}}{{UNIT}};'
                ],
                'condition' => [
					'carousel_status!' => 'yes'
				]
            ]
        );

        $this->add_control(
			'filter_control',
			[
				'label' => esc_html__( 'Enable Filter', 'redias-core' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'condition' => [
					'carousel_status!' => 'yes',
				]
			]
		);

        $this->add_control(
            'view_all',
            [
                'label'        => esc_html__( 'Filter View All Text', 'redias-core' ),
                'type'         => Controls_Manager::TEXT,
                'label_block'  => true,
                'default'      => esc_html__( 'View All', 'redias-core' ),
                'placeholder'  => esc_html__( 'Text goes here...', 'redias-core' ),
                'condition' => [
					'carousel_status!' => 'yes',
					'filter_control' => 'yes'
				]
            ]
        );

        $this->add_control(
			'pagination_control',
			[
				'label' => esc_html__( 'Pagination', 'redias-core' ),
				'type' => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'redias-core' ),
                'label_off'    => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
				'default' => 'no',
                'condition'    => [
                    'carousel_status!'    => 'yes',
                ],
			]
		);

        $this->add_control(
            'heading_tag',
            [
                'label'   => esc_html__( 'Heading Tag', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'h3',
                'options' => [
                    'h1'  => esc_html__( 'H1', 'redias-core' ),
                    'h2'  => esc_html__( 'H2', 'redias-core' ),
                    'h3'  => esc_html__( 'H3', 'redias-core' ),
                    'h4'  => esc_html__( 'H4', 'redias-core' ),
                    'h5'  => esc_html__( 'H5', 'redias-core' ),
                    'h6'  => esc_html__( 'H6', 'redias-core' )
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Query Section
     *
     * @return void
     */
    protected function query_section() {
        
        $this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Projects Query', 'redias-core' )
			]
		);

		$this->add_control(
			'source',
			[
				'label' => _x( 'Source', 'Projects Query Control', 'redias-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => esc_html__( 'Show All', 'redias-core' ),
					'by_name' => esc_html__( 'Manual Selection', 'redias-core' ),
				],
				'label_block' => true,
			]
		);

		$this->add_control(
			'categories',
			[
				'label'       => esc_html__( 'Categories', 'redias-core' ),
				'type'        => Controls_Manager::SELECT2,
				'options'     => Helper::el_get_terms('project-category'),
				'default'     => [],
				'label_block' => true,
				'multiple'    => true,
				'condition'   => [
					'source'    => 'by_name',
				],
			]
		);

		$this->add_control(
			'limit',
			[
				'label'       => esc_html__( 'Projects Limit', 'redias-core' ),
				'type'        => Controls_Manager::NUMBER,
				'desc'		  => esc_html__( 'Choose number of projects you want to show.', 'redias-core' ),
				'default'     => 6
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'   => esc_html__( 'Order By', 'redias-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'ID' => esc_html__( 'Post Id', 'redias-core' ),
                    'author' => esc_html__( 'Post Author', 'redias-core' ),
                    'title' => esc_html__( 'Title', 'redias-core' ),
                    'date' => esc_html__( 'Date', 'redias-core' ),
                    'modified' => esc_html__( 'Last Modified Date', 'redias-core' ),
                    'parent' => esc_html__( 'Parent Id', 'redias-core' ),
                    'rand' => esc_html__( 'Random', 'redias-core' ),
                    'comment_count' => esc_html__( 'Comment Count', 'redias-core' ),
                    'menu_order' => esc_html__( 'Menu Order', 'redias-core' ),
				],
			]
		);

		$this->add_control(
            'order',
            [
                'label' => __( 'Order', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' => esc_html__( 'Ascending', 'redias-core' ),
                    'desc' => esc_html__( 'Descending', 'redias-core' )
                ],
                'default' => 'desc',
            ]
        );

		$this->end_controls_section();

    }

    /**
	 * Carousel Controls
	 *
	 * @return void
	 */
	protected function section_controls() {

		$this->start_controls_section(
			'section_carousel_settings',
			[
				'label' => esc_html__( 'Carousel Settings', 'redias-core' ),
				'condition'    => [
					'carousel'    => 'yes'
				],
			]
		);

		$slides_per_show = range( 1, 10 );
		$slides_per_show = array_combine( $slides_per_show, $slides_per_show );

		$this->add_responsive_control(
			'slides_per_show',
			[
				'label' => esc_html__( 'Slides to Show', 'elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 1,
				'tablet_default' => 1,
				'mobile_default' => 1,
				'options' => $slides_per_show,
				'frontend_available' => true,
				'render_type' => 'ui',
				'prefix_class' => 'slide-per-show-',
				'condition'    => [
					'carousel_status'    => 'yes',
				],
			]
		);

		$this->add_responsive_control(
			'slides_per_scroll',
			[
				'label' => esc_html__( 'Slides to Scroll', 'elementor' ),
				'type' => Controls_Manager::SELECT,
				'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'elementor' ),
				'default' => 1,
				'tablet_default' => 1,
				'mobile_default' => 1,
				'options' => $slides_per_show,
				'condition' => [
					'carousel_status'    => 'yes',
					'slides_per_show!' => '1'
				],
				'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

        $this->add_responsive_control(
			'spaceBetween',
			[
				'label'      => esc_html__( 'Space Between', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px', 'em'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 150,
						'step' => 1
					],
					'em'  => [
						'min' => 0,
						'max' => 100
					],
				],
                'default' => [
					'unit' => 'px',
					'size' => 30
				],
                'tablet_default' => [
					'unit' => 'px',
					'size' => 30
				],
                'mobile_default' => [
					'unit' => 'px',
					'size' => 0
				],
				'selectors'  => [
					'{{WRAPPER}} .slick-list' => 'margin: 0 -{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .slick-slide' => 'margin: 0 {{SIZE}}{{UNIT}};'
				],
				'condition'    => [
					'carousel_status'    => 'yes',
				],
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'        => esc_html__( 'Autoplay', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel_status' => 'yes',
				],
			]
		);

		$this->add_control(
			'autoplay_speed',
			[
				'label'   => esc_html__( 'Autoplay Speed', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 500,
				'max'     => 20000,
				'step'    => 5,
				'default' => 5000,
				'condition' => [
					'carousel_status' => 'yes',
					'autoplay' => 'yes'
                ],
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'pause_on_hover',
			[
				'label'        => esc_html__( 'Pause on Hover', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'condition' => [
					'carousel_status' => 'yes',
					'autoplay' => 'yes'
				],
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'infinite_loop',
			[
				'label'        => esc_html__( 'Infinite Loop', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel_status'    => 'yes'
				],
			]
		);

		$this->add_control(
			'anim_speed',
			[
				'label'   => esc_html__( 'Animation Speed', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 100,
				'max'     => 3000,
				'step'    => 5,
				'default' => 500,
                'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel_status'    => 'yes'
				],
			]
		);

        $this->add_control(
			'center_mode',
			[
				'label'        => esc_html__( 'Center Mode', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'no',
				'prefix_class' => 'center-mode-',
                'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel_status'    => 'yes'
				],
			]
		);

        $this->add_responsive_control(
			'center_padding',
			[
				'label'   => esc_html__( 'Center Padding', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 0,
				'max'     => 200,
				'step'    => 1,
				'default' => 50,
				'tablet_default' => 30,
				'mobile_default' => 10,
                'frontend_available' => true,
				'render_type' => 'ui',
                'condition' => [
					'carousel_status'    => 'yes',
					'center_mode' => 'yes'
				],
			]
		);

		$this->add_control(
			'navigation',
			[
				'label' => esc_html__( 'Navigation', 'redias-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'None', 'redias-core' ),
					'arrow' => esc_html__( 'Arrow', 'redias-core' ),
					'dots' => esc_html__( 'Dots', 'redias-core' ),
					'both' => esc_html__( 'Arrow & Dots', 'redias-core' ),
				],
				'default' => 'none',
				'frontend_available' => true,
				'style_transfer' => true,
				'condition'    => [
					'carousel_status'    => 'yes'
				],
			]
		);

        $this->add_control(
			'arrow_prev_icon',
			[
				'label' => esc_html__( 'Previous Icon', 'redias-core' ),
				'label_block' => false,
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-long-arrow-alt-left',
					'library' => 'elementor-icons-line-awesome-icons',
				],
				'condition' => [
					'carousel_status'    => 'yes',
					'navigation' => ['arrow', 'both']
				],
			]
		);

		$this->add_control(
			'arrow_next_icon',
			[
				'label' => esc_html__( 'Next Icon', 'redias-core' ),
				'label_block' => false,
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-long-arrow-alt-right',
					'library' => 'elementor-icons-line-awesome-icons',
				],
				'condition' => [
					'carousel_status'    => 'yes',
					'navigation' => ['arrow', 'both']
				],
			]
		);

		$this->end_controls_section();

	}

    /**
     * Useful Options Section
     *
     * @return void
     */
    protected function useful_options_section() {
        
        $this->start_controls_section(
			'useful_section',
			[
				'label' => esc_html__( 'Useful Options', 'redias-core' )
			]
        );

        $this->add_control(
            'image_size',
            [
                'label' => esc_html__( 'Image Size', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'redias-project-410x300',
                'options' => Helper::get_image_sizes()
            ]
        );

        $this->add_control(
			'heading_length',
			[
				'label'   => esc_html__( 'Heading Length', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 42,
			]
		);

        $this->add_control(
            'heading_suffix',
            [
                'label'       => esc_html__( 'Heading Suffix', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '...',
                'placeholder' => esc_html__( 'Suffix...', 'redias-core' ),
            ]
        );

        $this->add_control(
			'show_readmore',
			[
				'label'   => esc_html__( 'Readmore', 'redias-core' ),
				'type'    => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'redias-core' ),
                'label_off'    => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
					'card_style' => '1'
				]
			]
		);

        $this->add_control(
            'readmore_text',
            [
                'label'       => esc_html__( 'Readmore Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Read More', 'redias-core' ),
                'placeholder' => esc_html__( 'Text...', 'redias-core' ),
                'condition'    => [
                    'show_readmore'    => 'yes',
					'card_style' => '1'
                ],
            ]
        );

        $this->add_control(
			'readmore_icon',
			[
				'label' => esc_html__( 'Readmore Icon', 'redias-core' ),
				'label_block' => false,
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-long-arrow-alt-right',
					'library' => 'elementor-icons-line-awesome-icons',
				],
				'condition'    => [
                    'show_readmore'    => 'yes',
					'card_style' => '1'
                ],
			]
		);

        $this->end_controls_section();

    }

    /**
     * Card Style
     *
     * @return void
     */
    protected function card_style() {
        
        $this->start_controls_section(
            'card_style_section',
            [
                'label' => esc_html__( 'Card', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'wrapper_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .style-1 .el-project-card-inner, {{WRAPPER}} .style-2.el-project-card .project-content',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'wrapper_box_shadow',
                'selector' => '{{WRAPPER}} .style-1 .el-project-card-inner, {{WRAPPER}} .style-2.el-project-card .project-content',
            ]
        );

        $this->add_group_control(
            BorderBottom::get_type(),
            [
                'name'     => 'wrapper_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .style-1.el-project-card .el-project-card-inner, {{WRAPPER}} .style-2.el-project-card .project-content'
            ]
        );

        $this->add_responsive_control(
            'wrapper_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .style-1.el-project-card .el-project-card-inner,{{WRAPPER}} .style-2.el-project-card .project-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'wrapper_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-project-card .project-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'circle_color',
            [
                'label' => esc_html__( 'Circle Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .style-1.el-project-card .project-content:before' => 'border-color: {{VALUE}}',
                ],
				'condition' => [
					'card_style' => '1'
				]
            ]
        );

        $this->add_control(
            'circle_hover_color',
            [
                'label' => esc_html__( 'Circle Hover Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .style-1.el-project-card:hover .project-content:before' => 'border-color: {{VALUE}}',
                ],
				'condition' => [
					'card_style' => '1'
				]
            ]
        );

		$this->add_control(
            'square_dot_color',
            [
                'label' => esc_html__( 'Square Dot Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .style-2.el-project-card .project-content:before' => 'background-color: {{VALUE}}',
                ],
				'condition' => [
					'card_style' => '2'
				]
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Heading Style
     *
     * @return void
     */
    protected function heading_style() {
        
        $this->start_controls_section(
            'heading_style_section',
            [
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'heading_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-project-card .project-content .project-title',
            ]
        );

        $this->add_control(
            'heading_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-project-card .project-content .project-title a' => 'color: {{VALUE}}'
                ],
            ]
        );

        $this->add_control(
            'heading_hover_color',
            [
                'label'     => esc_html__( 'Text Hover Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-project-card .project-content .project-title a:hover' => 'color: {{VALUE}}'
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-project-card .project-content .project-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Category Style
     *
     * @return void
     */
    protected function category_style() {
        
        $this->start_controls_section(
            'category_style_section',
            [
                'label' => esc_html__( 'Category', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'cat_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-project-card .project-content .project-cat'
            ]
        );

        $this->add_control(
            'cat_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-project-card .project-content .project-cat' => 'color: {{VALUE}}'
                ]
            ]
        );

        $this->add_control(
            'cat_hover_color',
            [
                'label'     => esc_html__( 'Hover Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-project-card .project-content .project-cat:hover' => 'color: {{VALUE}}'
                ]
            ]
        );

        $this->add_responsive_control(
            'cat_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-project-card .project-content .project-cat' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Readmore Style
     *
     * @return void
     */
    protected function readmore_style() {

        $this->start_controls_section(
            'readmore_style_section',
            [
                'label' => esc_html__( 'Readmore', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'readmore_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-project-card .project-content .read-more',
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );

        $this->add_responsive_control(
            'rm_icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-project-card .project-content .read-more i' => 'font-size: {{SIZE}}{{UNIT}};'
                ],
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );

        $this->add_responsive_control(
            'rm_spacebetween_icon',
            [
                'label'      => esc_html__( 'Space Between Icon', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-project-card .project-content .read-more' => 'column-gap: {{SIZE}}{{UNIT}};'
                ],
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );

        $this->add_responsive_control(
            'readmore_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-project-card .project-content .read-more' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );

        $this->add_responsive_control(
            'readmore_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-project-card .project-content .read-more' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );

        $this->start_controls_tabs( 'readmore_style_tabs' );
        
        $this->start_controls_tab(
            'readmore_style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );

        $this->add_control(
            'rm_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-project-card .project-content .read-more' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );

        $this->add_control(
            'rm_txt_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-project-card .project-content .read-more' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );

        $this->add_control(
            'rm_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-project-card .project-content .read-more i' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'readmore_style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );

        $this->add_control(
            'rm_bg_h_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-project-card .project-content .read-more:hover' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );

        $this->add_control(
            'rm_txt_h_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-project-card .project-content .read-more:hover' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );

        $this->add_control(
            'rm_icon_h_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-project-card .project-content .read-more:hover i' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show_readmore' => 'yes',
					'card_style' => '1'
                ]
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->end_controls_section();
    }

    /**
     * Filter Style
     *
     * @return void
     */
    protected function filter_style() {

		$this->start_controls_section(
			'section_filter_style',
			[
				'label' => esc_html__( 'Filter', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_responsive_control(
			'filter_alignment',
			[
				'label'   => esc_html__( 'Alignment', 'redias-core' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start'   => [
						'title' => esc_html__( 'Left', 'redias-core' ),
						'icon'  => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'redias-core' ),
						'icon'  => 'eicon-text-align-center',
					],
					'flex-end'  => [
						'title' => esc_html__( 'Right', 'redias-core' ),
						'icon'  => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'toggle'  => false,
				'selectors' => [
					'{{WRAPPER}} .dl-project-filter' => 'justify-content: {{VALUE}};',
				],
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_responsive_control(
			'filter_vertical_spacing',
			[
				'label'      => esc_html__( 'Vertical Spacing', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'allowed_dimensions' => 'vertical',
				'selectors'  => [
					'{{WRAPPER}} .dl-project-filter' => 'margin: {{TOP}}{{UNIT}} 0 {{BOTTOM}}{{UNIT}} 0;',
				],
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_responsive_control(
			'filter_space_between_item',
			[
				'label'      => esc_html__( 'Space Between Item', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 300,
						'step' => 1,
					]
				],
				'selectors'  => [
					'{{WRAPPER}} .dl-project-filter' => 'column-gap: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->start_controls_tabs( 'filter_style_tabs' );
		
		$this->start_controls_tab(
			'filter_style_normal_tab',
			[
				'label' => __( 'Normal', 'redias-core' ),
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'filter_typography',
				'label'    => esc_html__( 'Typography', 'redias-core' ),
				'selector' => '{{WRAPPER}} .dl-project-filter li',
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'filter_normal_background',
				'label'    => esc_html__( 'Background', 'redias-core' ),
				'types'    => ['classic', 'gradient'],
                'exlude'   => ['image'],
				'selector' => '{{WRAPPER}}  .dl-project-filter li',
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_control(
			'filter_normal_color',
			[
				'label'     => esc_html__( 'Text Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}  .dl-project-filter li' => 'color: {{VALUE}}',
				],
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'filter_normal_border',
				'label'    => esc_html__( 'Border', 'redias-core' ),
				'selector' => '{{WRAPPER}} .dl-project-filter li',
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'filter_normal_box_shadow',
				'selector' => '{{WRAPPER}} .dl-project-filter li',
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_responsive_control(
			'filter_normal_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .dl-project-filter li' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_responsive_control(
			'filter_btn_padding',
			[
				'label'      => esc_html__( 'Padding', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .dl-project-filter li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_responsive_control(
			'filter_btn_margin',
			[
				'label'      => esc_html__( 'Margin', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .dl-project-filter li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);
				
		$this->end_controls_tab();
		
		$this->start_controls_tab(
			'filter_style_hover_tab',
			[
				'label' => __( 'Hover/Active', 'redias-core' ),
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'filter_hover_background',
				'label'    => esc_html__( 'Background', 'redias-core' ),
				'types'    => ['classic', 'gradient'],
				'selector' => '{{WRAPPER}} .dl-project-filter li:hover, {{WRAPPER}} .dl-project-filter li.active',
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_control(
			'filter_hover_color',
			[
				'label'     => esc_html__( 'Text Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dl-project-filter li:hover, {{WRAPPER}} .dl-project-filter li.active' => 'color: {{VALUE}}',
				],
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'filter_hover_border',
				'label'    => esc_html__( 'Border', 'redias-core' ),
				'selector' => '{{WRAPPER}} .dl-project-filter li:hover, {{WRAPPER}} .dl-project-filter li.active',
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'filter_hover_box_shadow',
				'selector' => '{{WRAPPER}} .dl-project-filter li:hover, {{WRAPPER}} .dl-project-filter li.active',
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);

		$this->add_responsive_control(
			'filter_hover_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .dl-project-filter li:hover, {{WRAPPER}} .dl-project-filter li.active' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'filter_control' => 'yes',
					'carousel_status!' => 'yes'
				]
			]
		);
		
		$this->end_controls_tab();
		
		$this->end_controls_tabs();

		$this->end_controls_section();

	}

    /**
     * Pagination Style
     *
     * @return void
     */
    protected function pagination_style() {
        
        $this->start_controls_section(
			'section_pagination',
			[
				'label' => esc_html__( 'Pagination', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'pagination_control' => 'yes',
					'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'redias-core' ),
				'name' => 'dl_pagination_typography',
				'selector' => '{{WRAPPER}} .el-post-pagination span, {{WRAPPER}} .el-post-pagination a',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_responsive_control(
			'pagination_align',
			[
				'label' => esc_html__( 'Alignment', 'redias-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'redias-core' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'redias-core' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'redias-core' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'toggle' => false,
				'default' => 'center',
				'selectors' => [
					'{{WRAPPER}} .el-post-pagination' => 'justify-content: {{VALUE}};',
				],
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_responsive_control(
			'pagination_margin',
			[
				'label'      => esc_html__( 'Margin', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-post-pagination' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_responsive_control(
			'pagination_space_bw',
			[
				'label' => esc_html__( 'Space Between', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 5,
				],
				'selectors' => [
					'{{WRAPPER}} .el-post-pagination span' => 'margin: 0 {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .el-post-pagination a' => 'margin: 0 {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_responsive_control(
			'pagination_item_size',
			[
				'label' => esc_html__( 'Size', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 40,
				],
				'selectors' => [
					'{{WRAPPER}} .el-post-pagination span' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .el-post-pagination a' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

        $this->add_responsive_control(
            'pagi_icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 150
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-post-pagination a i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .el-post-pagination a svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
            ]
        );

        $this->add_control(
            'pagi_prev_icon',
            [
                'label'   => esc_html__( 'Prev Post Icon', 'redias-core' ),
                'type'    => Controls_Manager::ICONS,
                'default' => [
                    'value'   => 'la la-long-arrow-left',
                    'library' => 'elementor-icons-line-awesome-icons',
                ],
                'recommended' => [
					'fa-solid' => [
						'angle-left',
						'arrow-left',
						'chevron-left',
						'long-arrow-alt-left',
					],
					'line-awesome-icons' => [
						'angle-double-left',
						'angle-left',
						'arrow-left',
						'chevron-left',
						'long-arrow-alt-left',
						'long-arrow-left',
					],
				],
                'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
            ]
        );

        $this->add_control(
            'pagi_next_icon',
            [
                'label'   => esc_html__( 'Next Post Icon', 'redias-core' ),
                'type'    => Controls_Manager::ICONS,
                'default' => [
                    'value'   => 'la la-long-arrow-right',
                    'library' => 'elementor-icons-line-awesome-icons',
                ],
                'recommended' => [
					'fa-solid' => [
						'angle-right',
						'arrow-right',
						'chevron-right',
						'long-arrow-alt-right',
					],
					'line-awesome-icons' => [
						'angle-double-right',
						'angle-right',
						'arrow-right',
						'chevron-right',
						'long-arrow-alt-right',
						'long-arrow-right',
					],
				],
                'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
            ]
        );

		$this->add_control(
			'pagination_hr',
			[
				'type' => Controls_Manager::DIVIDER,
				'style' => 'thick',
                'condition' => [
					'pagination_control' => 'yes'
				]
			]
		);

		$this->start_controls_tabs( 'tabs_pagination_style' );

		$this->start_controls_tab(
			'tab_pagination_style_normal',
			[
				'label' => esc_html__( 'Normal', 'redias-core' ),
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_control(
			'pagination_bg_color_label',
			[
				'label' => __( 'Background Color', 'redias-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'pagination_bg_color',
				'label' => __( 'Background', 'redias-core' ),
				'types' => [ 'classic', 'gradient' ],
                'exclude' => ['image'],
				'selector' => '{{WRAPPER}} .el-post-pagination a',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_control(
			'pagination_color',
			[
				'label' => esc_html__( 'Text Color', 'redias-core' ),
				'type' => Controls_Manager::COLOR,
                'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .el-post-pagination a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .el-post-pagination a svg' => 'fill: {{VALUE}};',
				],
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_responsive_control(
			'pagination_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-post-pagination a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .el-post-pagination span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_pagination_style_hover',
			[
				'label' => esc_html__( 'Active / Hover', 'redias-core' ),
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_control(
			'pagination_bg_color_hover_label',
			[
				'label' => __( 'Background Color', 'redias-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'pagination_bg_color_hover',
				'label' => __( 'Background', 'redias-core' ),
				'types' => [ 'classic', 'gradient' ],
                'exclude' => ['image'],
				'selector' => '{{WRAPPER}} .el-post-pagination a:hover, {{WRAPPER}} .el-post-pagination span.current',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_control(
			'pagination_color_hover',
			[
				'label' => esc_html__( 'Text Color', 'redias-core' ),
				'type' => Controls_Manager::COLOR,
                'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .el-post-pagination a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .el-post-pagination a:hover svg' => 'fill: {{VALUE}};',
					'{{WRAPPER}} .el-post-pagination span.current' => 'color: {{VALUE}};'
				],
				'default' => '#fff',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'pagination_active_box_shadow',
				'label' => __( 'Box Shadow', 'redias-core' ),
				'selector' => '{{WRAPPER}} .el-post-pagination a:hover, {{WRAPPER}} .el-post-pagination span.current',
				'condition' => [
					'pagination_control' => 'yes',
                    'carousel_status!' => 'yes',
				]
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        $carousel = 'yes' === $settings['carousel_status'] ? 'yes' : 'no';
        $filter = 'yes' === $settings['filter_control'] ? 'yes' : 'no';
        $data = [
            'carousel'=> $carousel, 
            'filter' => $filter
        ];
        $this->add_render_attribute( 'project-wrapper', [ 'class' => [ 'el-project-wrapper' ], 'data-settings' => wp_json_encode( $data ) ] );
        echo '<div '. $this->get_render_attribute_string( 'project-wrapper' ) .'>';
        if( 'yes' === $settings['carousel_status'] ) {
            $this->carousel_layout();
        }else{
            $this->grid_layout();
        }

        echo '</div>';
    }

    /**
     * Carousel Layout
     *
     * @return void
     */
    protected function carousel_layout(){
        $settings = $this->get_settings_for_display();
        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

		$args = array(
            'post_type'   => 'dl-project',
            'post__not_in' => get_option( 'sticky_posts' ),
            'posts_per_page' => $settings['limit'],
            'orderby'	=> $settings['orderby'],
            'order'	=> $settings['order'],
            'post_status' => 'publish',
            'paged' => $paged,
		);

		if ( $settings['source'] === 'by_name'  ) {
            $args['tax_query'][] = array(
				'taxonomy' => 'project-category',
				'field'    => 'slug',
				'terms'    => $settings['categories']
			);
        }

        $wp_query = new \WP_Query( $args );
        $nav_mobile = 'yes' === $settings['dots_hide_mobile'] ? ' dots-none' : '';
        if( 'arrow' === $settings['navigation'] || 'both' === $settings['navigation'] ){
			$nav_style = 'top-right' == $settings['nav_style'] ? ' navi-top-right' : '';
		}else{
			$nav_style = '';
		}

        $this->add_render_attribute(
            'carousel_wrapper',
            [ 
                'class' => [ 'dl-carousel' ]
            ]
        );
        ?>
        <div class="<?php echo esc_attr( $nav_style ); ?>">
            <?php if( $wp_query->have_posts() ) : ?>
                <div <?php echo $this->get_render_attribute_string( 'carousel_wrapper' ); ?>>
                    <?php while ( $wp_query->have_posts() ) : $wp_query->the_post(); ?>
                        <div class="slick-slide">
                            <?php $this->get_project_card(); ?>
                        </div>
                    <?php endwhile; ?>
                </div>
                <?php if( 'dots' === $settings['navigation'] || 'both' === $settings['navigation'] ) : ?>
                <div class="dl-carousel-dots<?php echo esc_attr( $nav_mobile ); ?>"></div>
                <?php endif; ?>
                <?php if( 'arrow' === $settings['navigation'] || 'both' === $settings['navigation'] ) : ?>
                <div class="dl-carousel-nav <?php echo esc_attr( 'nav-' . $settings['nav_style'] ); ?>"></div>
                <?php if ( ! empty( $settings['arrow_prev_icon']['value'] ) ) : ?>
                    <button type="button" class="slick-prev nav-hidden"><?php Icons_Manager::render_icon( $settings['arrow_prev_icon'], ['aria-hidden' => 'true'] ); ?></button>
                <?php endif; ?>
                <?php if ( ! empty( $settings['arrow_next_icon']['value'] ) ) : ?>
                    <button type="button" class="slick-next nav-hidden"><?php Icons_Manager::render_icon( $settings['arrow_next_icon'], ['aria-hidden' => 'true'] ); ?></button>
                <?php endif; ?>
                <?php endif; ?>
            <?php
            wp_reset_postdata();
            else :
                esc_html_e( 'No projects found!', 'redias-core' );
            endif;
            ?>
        </div>
        <?php
    }

    /**
     * Grid Layout
     *
     * @return void
     */
    protected function grid_layout() {
        $settings = $this->get_settings_for_display();
        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

		$args = array(
            'post_type'   => 'dl-project',
            'post__not_in' => get_option( 'sticky_posts' ),
            'posts_per_page' => $settings['limit'],
            'orderby'	=> $settings['orderby'],
            'order'	=> $settings['order'],
            'post_status' => 'publish',
            'paged' => $paged,
		);

		if ( $settings['source'] === 'by_name'  ) {
            $args['tax_query'][] = array(
				'taxonomy' => 'project-category',
				'field'    => 'slug',
				'terms'    => $settings['categories']
			);
        }

        $wp_query = new \WP_Query( $args );
        $this->add_render_attribute(
            'wrapper',
            [ 
                'class' => [ 'el-project-items' ]
            ]
        );
        if( 'yes' === $settings['filter_control'] ) {
			$filter_items = [];
			if( ! empty( $settings['post_categories'] ) ) {
				$filter_items = $settings['post_categories'];
			}else{
				$filter_items = wp_list_pluck( get_terms( 'project-category','orderby=name&hide_empty=1'), 'slug' );
			}
			Helper::get_filter_layout( $filter_items, 'project-category', $settings['view_all'], 'dl-project-filter' );
		}

        if( $wp_query->have_posts() ) : ?>
            <div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
            <?php 
            while ( $wp_query->have_posts() ) : $wp_query->the_post();
                $this->get_project_card();
            endwhile; ?>
            </div>
        <?php
        $this->post_pagination($wp_query->max_num_pages);
        wp_reset_postdata();

        else :
            esc_html_e( 'No posts found!', 'redias-core' );
        endif;

    }

    /**
     * Project Card
     *
     * @return void
     */
    protected function get_project_card(){
        $settings = $this->get_settings_for_display();
        $h_tag = ! empty( $settings['heading_tag'] ) ? $settings['heading_tag'] : 'h3';
        $heading = get_the_title();
        if( ! has_post_thumbnail() ) { return; }
        $img_size = ! empty( $settings['image_size'] ) ? $settings['image_size'] : 'redias-project-410x300';
        ?>
        <article id="project-<?php the_ID(); ?>" <?php post_class( [ 'el-project-card', 'style-' . $settings['card_style'] ] ); ?>>
            <div class="el-project-card-inner">
                <div class="project-thumb">
                    <a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( $img_size ); ?></a>
                </div>
                <div class="project-content">
                    <?php Helper::get_terms( 'project-category', 1, true, 'project-cat', false ); ?>
                    <<?php echo esc_attr( $h_tag ); ?> class="project-title"><a href="<?php the_permalink(); ?>"><?php Helper::limit_latter( $heading, $settings['heading_length'], $settings['heading_suffix']) ?></a></<?php echo esc_attr( $h_tag ); ?>>
                    <?php if( 'yes' === $settings['show_readmore'] && ! empty( $settings['readmore_text'] ) && '1' === $settings['card_style'] ) : ?>
                    <a href="<?php the_permalink(); ?>" class="read-more"><?php echo esc_html( $settings['readmore_text'] ); ?> <?php if( ! empty( $settings['readmore_icon']['value'] ) ){ Icons_Manager::render_icon( $settings['readmore_icon'], ['aria-hidden' => 'true'] ); } ?></a>
                    <?php endif; ?>
                </div>
            </div>
        </article>
        <?php
    }

    /**
     * Pagination
     */
    protected function post_pagination( $total_pages = '' ){
        $settings = $this->get_settings_for_display();
        if( 'yes' === $settings['pagination_control'] ){
            $prev_pagi_icon = '<i class="la la-long-arrow-left"></i>';
            $next_pagi_icon = '<i class="la la-long-arrow-right"></i>';
            if( ! empty( $settings['pagi_prev_icon']['value'] ) ) {
                if( 'svg' != $settings['pagi_prev_icon']['library'] ) {
                    $prev_pagi_icon = '<i class="'. $settings['pagi_prev_icon']['value'] .'"></i>';
                }else{
                    $prev_pagi_icon = Icons_Manager::render_uploaded_svg_icon( $settings['pagi_prev_icon']['value'] );
                }
            }
            if( ! empty( $settings['pagi_next_icon']['value'] ) ) {
                if( 'svg' != $settings['pagi_next_icon']['library'] ) {
                    $next_pagi_icon = '<i class="'. $settings['pagi_next_icon']['value'] .'"></i>';
                }else{
                    $next_pagi_icon = Icons_Manager::render_uploaded_svg_icon( $settings['pagi_next_icon']['value'] );
                }
            }

			if ( $total_pages > 1 ) {
				$current_page = max( 1, get_query_var( 'paged' ) );
				echo '<div class="el-post-pagination">';
				echo paginate_links( array(
					'base' => get_pagenum_link(1) . '%_%',
					'format' => '/page/%#%',
					'current' => $current_page,
					'total' => $total_pages,
					'prev_text'    => Helper::kses_advance( $prev_pagi_icon ),
					'next_text'    => Helper::kses_advance( $next_pagi_icon ),
				) );
				echo '</div>';
			}
		}
    }

}