<?php
/**
 * Section Heading
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\SectionHeading;

use RediasCore\Classes\Helper;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Widget_Base;
use RediasCore\Elementor\Controls\Foreground;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-section-heading';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Section Heading', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-form-horizontal';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'section', 'heading', 'title', 'redias' ];
    }

    public function get_style_depends() {
        return [ 'redias-keyfram-anim', 'redias-section-heading' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_general();
        $this->section_sub_heading();
        $this->section_heading();
        $this->section_description();
        $this->sub_heading_style();
        $this->heading_style();
        $this->description_style();

    }

    /**
     * General Control
     *
     * @return void
     */
    protected function section_general() {

        $this->start_controls_section(
			'section_heading_general',
			[
				'label' => esc_html__( 'General', 'redias-core' )
			]
        );

        $this->add_responsive_control(
            'dl_section_text_align',
            [
                'label' => esc_html__( 'Alignment', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon' => 'eicon-text-align-right',
                    ]
                ],
                'default' => 'center',
                'toggle' => false,
                'prefix_class' => 'dl-align-',
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading' => 'text-align: {{VALUE}};',
                    '.rtl {{WRAPPER}}.dl-align-left .dl-section-heading' => 'text-align: right;',
                ]
            ]
        );

        $this->add_responsive_control(
            'section_margin',
            [
                'label'      => esc_html__( 'Section Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'allowed_dimensions' => 'vertical',
                'selectors'  => [
                    '{{WRAPPER}} .dl-section-heading' => 'margin: {{TOP}}{{UNIT}} 0 {{BOTTOM}}{{UNIT}} 0;',
                ],
            ]
        );

        $this->add_responsive_control(
            'section_padding',
            [
                'label'      => esc_html__( 'Section Padding', 'textdomain' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-section-heading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Sub Heading Control
     *
     * @return void
     */
    protected function section_sub_heading() {

        $this->start_controls_section(
			'section_sub_heading',
			[
				'label' => esc_html__( 'Sub Heading', 'redias-core' )
			]
        );

        $this->add_control(
            'sub_heading',
            [
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => '',
                'placeholder' => esc_html__( 'Text goes here...', 'redias-core' ),
                'rows'        => 4,
				'dynamic' => [
					'active' => true,
				]
            ]
        );


        $this->add_control(
            'sub_heading_tag',
            [
                'label' => esc_html__( 'HTML Tag', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'default' => 'h4',
                'options' => [
                    'h1'  => [
                        'title' => esc_html__( 'H1', 'redias-core' ),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2'  => [
                        'title' => esc_html__( 'H2', 'redias-core' ),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3'  => [
                        'title' => esc_html__( 'H3', 'redias-core' ),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4'  => [
                        'title' => esc_html__( 'H4', 'redias-core' ),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5'  => [
                        'title' => esc_html__( 'H5', 'redias-core' ),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6'  => [
                        'title' => esc_html__( 'H6', 'redias-core' ),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'toggle' => false,
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_position',
            [
                'label' => esc_html__( 'Display', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'inline' => [
                        'title' => esc_html__( 'Inline', 'redias-core' ),
                        'icon' => 'eicon-ellipsis-h',
                    ],
                    'block' => [
                        'title' => esc_html__( 'Block', 'redias-core' ),
                        'icon' => 'eicon-menu-bar',
                    ]
                ],
                'toggle' => false,
                'selectors_dictionary' => [
                    'inline' => 'display: inline-block',
                    'block' => 'display: block',
                ],
                'default' => 'inline',
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-sub-heading' => '{{VALUE}}',
                ],
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_control(
            'sub_heading_anim',
            [
                'label'        => esc_html__( 'Scrolling Animation', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'no',
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_control(
            'sub_h_anim_effect',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'dl-fadeIn',
                'options' => Helper::get_animation_effects(),
                'condition' => [
                    'sub_heading!' => '',
                    'sub_heading_anim' => 'yes'
				]
            ]
        );

        $this->add_control(
            'sub_heading_anim_popover',
            [
                'label' => esc_html__( 'Animation Settings', 'redias-core' ),
                'type' => Controls_Manager::POPOVER_TOGGLE,
                'label_off' => esc_html__( 'Default', 'redias-core' ),
                'label_on' => esc_html__( 'Custom', 'redias-core' ),
                'return_value' => 'yes',
                'condition' => [
                    'sub_heading!' => '',
                    'sub_heading_anim' => 'yes'
				],
            ]
        );
        
        $this->start_popover();

        $this->add_control(
            'sub_h_anim_offset',
            [
                'label'      => esc_html__( 'Offset', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 2000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 200,
                ],
                'condition' => [
                    'sub_heading!' => '',
                    'sub_heading_anim' => 'yes'
				]
            ]
        );
        
        $this->add_control(
            'sub_h_anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 400,
                ],
                'condition' => [
                    'sub_heading!' => '',
                    'sub_heading_anim' => 'yes'
				]
            ]
        );

        $this->add_control(
            'sub_h_anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 700,
                ],
                'condition' => [
                    'sub_heading!' => '',
                    'sub_heading_anim' => 'yes'
				]
            ]
        );

        $this->end_popover();
        
        $this->end_controls_section();

    }

    /**
     * Heading Control
     *
     * @return void
     */
    protected function section_heading() {

        // Heading
		$this->start_controls_section(
			'section_heading',
			[
				'label' => esc_html__( 'Heading', 'redias-core' )
			]
		);

        $this->add_control(
            'heading_text',
            [
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__( 'Section Heading', 'redias-core' ),
                'description' => esc_html__( 'Use this format {{Business}} to highlight the text.', 'redias-core' ),
                'placeholder' => esc_html__( 'Text goes here...', 'redias-core' ),
                'label_block' => true,
                'rows' => 4,
				'dynamic' => [
					'active' => true,
				]
            ]
        );

        $this->add_control(
            'heading_tag',
            [
                'label' => esc_html__( 'HTML Tag', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'default' => 'h2',
                'options' => [
                    'h1'  => [
                        'title' => esc_html__( 'H1', 'redias-core' ),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2'  => [
                        'title' => esc_html__( 'H2', 'redias-core' ),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3'  => [
                        'title' => esc_html__( 'H3', 'redias-core' ),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4'  => [
                        'title' => esc_html__( 'H4', 'redias-core' ),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5'  => [
                        'title' => esc_html__( 'H5', 'redias-core' ),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6'  => [
                        'title' => esc_html__( 'H6', 'redias-core' ),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'toggle' => false,
                'condition' => [
					'heading_text!' => ''
				],
            ]
        );

		$this->add_control(
			'show_background_text',
			[
				'label' => esc_html__( 'Background Text', 'redias-core' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'redias-core' ),
				'label_off' => esc_html__( 'Hide', 'redias-core' ),
				'return_value' => 'yes',
				'default' => 'no',
                'separator' => 'before',
                'style_transfer' => true,
                'condition' => [
					'heading_text!' => ''
				],
			]
		);

		$this->add_control(
			'background_text',
			[
				'label' => esc_html__( 'Text', 'redias-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Background', 'redias-core' ),
				'placeholder' => esc_html__( 'Text goes here...', 'redias-core' ),
				'separator' => 'after',
				'condition' => [
                    'heading_text!' => '',
					'show_background_text' => 'yes'
				],
				'dynamic' => [
					'active' => true,
				]
			]
		);

        $this->add_responsive_control(
            'heading_display',
            [
                'label' => esc_html__( 'Display', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'inline' => [
                        'title' => esc_html__( 'Inline', 'redias-core' ),
                        'icon' => 'eicon-ellipsis-h',
                    ],
                    'block' => [
                        'title' => esc_html__( 'Block', 'redias-core' ),
                        'icon' => 'eicon-menu-bar',
                    ]
                ],
                'toggle' => false,
                'selectors_dictionary' => [
                    'inline' => 'display: inline-block',
                    'block' => 'display: block',
                ],
                'default' => 'block',
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-heading' => '{{VALUE}}',
                ],
                'condition' => [
					'heading_text!' => ''
				],
            ]
        );

        $this->add_control(
            'heading_anim',
            [
                'label'        => esc_html__( 'Scrolling Animation', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'no',
                'condition' => [
					'heading_text!' => ''
				],
            ]
        );

        $this->add_control(
            'heading_anim_effect',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'fadeIn',
                'options' => Helper::get_animation_effects(),
                'condition' => [
                    'heading_text!' => '',
                    'heading_anim' => 'yes'
				]
            ]
        );

        $this->add_control(
            'heading_anim_popover',
            [
                'label' => esc_html__( 'Animation Settings', 'redias-core' ),
                'type' => Controls_Manager::POPOVER_TOGGLE,
                'label_off' => esc_html__( 'Default', 'redias-core' ),
                'label_on' => esc_html__( 'Custom', 'redias-core' ),
                'return_value' => 'yes',
                'condition' => [
                    'heading_text!' => '',
                    'heading_anim' => 'yes'
				],
            ]
        );
        
        $this->start_popover();

        $this->add_control(
            'heading_anim_offset',
            [
                'label'      => esc_html__( 'Offset', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 2000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 200,
                ],
                'condition' => [
                    'heading_text!' => '',
                    'heading_anim' => 'yes'
				]
            ]
        );
        
        $this->add_control(
            'heading_anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 400,
                ],
                'condition' => [
                    'heading_text!' => '',
                    'heading_anim' => 'yes'
				]
            ]
        );

        $this->add_control(
            'heading_anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 700,
                ],
                'condition' => [
                    'heading_text!' => '',
                    'heading_anim' => 'yes'
				]
            ]
        );

        $this->end_popover();

        $this->end_controls_section();

    }

    /**
     * Description Control
     *
     * @return void
     */
    protected function section_description() {

        $this->start_controls_section(
			'section_desc',
			[
				'label' => esc_html__( 'Description', 'redias-core' )
			]
        );

        $this->add_control(
            'desc',
            [
                'label'       => esc_html__( 'Description', 'redias-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'rows'        => 5,
                'default'     => '',
                'placeholder' => esc_html__( 'Description...', 'redias-core' ),
            ]
        );

        $this->add_control(
            'desc_anim',
            [
                'label'        => esc_html__( 'Scrolling Animation', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'no',
                'condition'    => [
                    'desc!'    => ''
                ],
            ]
        );

        $this->add_control(
            'desc_anim_effect',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'fadeIn',
                'options' => Helper::get_animation_effects(),
                'condition' => [
                    'desc!'    => '',
                    'desc_anim' => 'yes'
				]
            ]
        );

        $this->add_control(
            'desc_anim_popover',
            [
                'label' => esc_html__( 'Animation Settings', 'redias-core' ),
                'type' => Controls_Manager::POPOVER_TOGGLE,
                'label_off' => esc_html__( 'Default', 'redias-core' ),
                'label_on' => esc_html__( 'Custom', 'redias-core' ),
                'return_value' => 'yes',
                'condition' => [
                    'desc!'    => '',
                    'desc_anim' => 'yes'
				],
            ]
        );
        
        $this->start_popover();

        $this->add_control(
            'desc_anim_offset',
            [
                'label'      => esc_html__( 'Offset', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 2000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 200,
                ],
                'condition' => [
                    'desc!'    => '',
                    'desc_anim' => 'yes'
				]
            ]
        );
        
        $this->add_control(
            'desc_anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 400,
                ],
                'condition' => [
                    'desc!'    => '',
                    'desc_anim' => 'yes'
				]
            ]
        );

        $this->add_control(
            'desc_anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 700,
                ],
                'condition' => [
                    'desc!'    => '',
                    'desc_anim' => 'yes'
				]
            ]
        );

        $this->end_popover();
        
        $this->end_controls_section();

    }

    /**
     * Sub Heading Style Control
     *
     * @return void
     */
    protected function sub_heading_style() {

        $this->start_controls_section(
			'section_sub_heading_text',
			[
                'label' => esc_html__( 'Sub Heading', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
					'sub_heading!' => ''
				],
			]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'sub_heading_text_typography',
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-sub-heading',
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'sub_heading_color_type',
                'label'    => esc_html__( 'Text Color Type', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-sub-heading span',
            ]
        );

        $this->add_responsive_control(
            'sub_heading_text_padding',
            [
                'label' => esc_html__( 'Padding', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-sub-heading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_text_margin',
            [
                'label' => esc_html__( 'Margin', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-sub-heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'sub_heading_text_border',
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-sub-heading',
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_control(
            'sub_heading_text_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-sub-heading' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'sub_heading_text_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-sub-heading',
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'sub_heading_text_background',
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-sub-heading',
                'condition' => [
					'sub_heading!' => ''
				],
            ]
        );

        $this->add_control(
            'subheading_custom_border',
            [
                'label'        => esc_html__( 'Custom Border', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'no', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'no',
                'condition' => [
                    'sub_heading!'    => ''
                ],
            ]
        );

        $this->add_control(
            'sub_heading_bd_direction',
            [
                'label'   => esc_html__( 'Border Direction', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default' => 'left',
                'toggle'  => false,
                'condition' => [
                    'sub_heading!'    => '',
                    'subheading_custom_border'    => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_bd_spacing',
            [
                'label'      => esc_html__( 'Spacing Between Text', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100,
                        'step' => 1
                    ]
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 10
                ],
                'render_type' => 'ui',
                'condition' => [
                    'sub_heading!'    => '',
                    'subheading_custom_border'    => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_bd_length',
            [
                'label'      => esc_html__( 'Border Length', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 20,
                        'step' => 1
                    ]
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 60
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-sub-heading > span.custom-border:before' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-sub-heading > span.custom-border:after' => 'left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-sub-heading > span.custom-border.right:after' => 'left: auto; right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-sub-heading > span.custom-border.left' => 'padding-left: calc({{SIZE}}{{UNIT}} + {{sub_heading_bd_spacing.SIZE}}px);',
                    '{{WRAPPER}} .dl-sub-heading > span.custom-border.right' => 'padding-right: calc({{SIZE}}{{UNIT}} + {{sub_heading_bd_spacing.SIZE}}px);',
                ],
                'condition' => [
                    'sub_heading!'    => '',
                    'subheading_custom_border'    => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_bd_height',
            [
                'label'      => esc_html__( 'Border Thickness', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 10,
                        'step' => 1
                    ]
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 2
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-sub-heading > span.custom-border:before' => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-sub-heading > span.custom-border:after' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'sub_heading!'    => '',
                    'subheading_custom_border'    => 'yes'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'subheading_border_color',
                'label'    => esc_html__( 'Border Color', 'redias-core' ),
                'show_label'    => true,
                'types'    => ['classic', 'gradient'],
                'exclude'   => ['image'],
                'selector' => '{{WRAPPER}} .dl-sub-heading > span.custom-border:before, {{WRAPPER}} .dl-sub-heading > span.custom-border:after',
                'condition' => [
                    'sub_heading!'    => '',
                    'subheading_custom_border'    => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_h_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-sub-heading > span.custom-border:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .dl-sub-heading > span.custom-border:after' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'sub_heading!'    => '',
                    'subheading_custom_border'    => 'yes'
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Heading Style Control
     *
     * @return void
     */
    protected function heading_style() {

        $this->start_controls_section(
			'section_heading_text',
			[
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'heading_text!'    => ''
                ],
			]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_text_typography',
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-heading',
                'condition'    => [
                    'heading_text!'    => ''
                ],
            ]
        );

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'heading_color_type',
                'label'    => esc_html__( 'Text Color Type', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-heading',
            ]
        );

        $this->add_responsive_control(
            'heading_text_padding',
            [
                'label' => esc_html__( 'Padding', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-heading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'heading_text!'    => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_text_margin',
            [
                'label' => esc_html__( 'Margin', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'heading_text!'    => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'heading_text_border',
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-heading',
                'condition'    => [
                    'heading_text!'    => ''
                ],
            ]
        );

        $this->add_control(
            'heading_text_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-heading' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'heading_text!'    => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'heading_text_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-heading',
                'condition'    => [
                    'heading_text!'    => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'heading_text_background',
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-heading',
                'condition'    => [
                    'heading_text!'    => ''
                ],
            ]
        );

        $this->add_control(
            'heading_text_blend_mode',
            [
                'label' => esc_html__( 'Blend Mode', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'separator' => 'inherit',
                'options' => [
                    'inherit' => esc_html__( 'Normal', 'redias-core' ),
                    'multiply' => 'Multiply',
                    'screen' => 'Screen',
                    'overlay' => 'Overlay',
                    'darken' => 'Darken',
                    'lighten' => 'Lighten',
                    'color-dodge' => 'Color Dodge',
                    'saturation' => 'Saturation',
                    'color' => 'Color',
                    'difference' => 'Difference',
                    'exclusion' => 'Exclusion',
                    'hue' => 'Hue',
                    'luminosity' => 'Luminosity',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-heading' => 'mix-blend-mode: {{VALUE}}',
                ],
                'condition'    => [
                    'heading_text!'    => ''
                ],
            ]
        );

        $this->add_control(
			'heading_bg_text_style',
			[
				'label' => esc_html__( 'Background Text', 'redias-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition'    => [
                    'heading_text!'    => '',
                    'show_background_text' => 'yes'
                ],
			]
		);

        $this->add_control(
            'background_text_color',
            [
                'label' => esc_html__( 'Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'separator' => 'before',
                'condition' => [
                    'heading_text!'    => '',
                    'show_background_text' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-heading:before' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'background_text_typography',
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-heading:before',
                'condition' => [
                    'heading_text!'    => '',
                    'show_background_text' => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
            'background_rotaion',
            [
                'label' => esc_html__( 'Text Rotation', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'deg' ],
                'default' => [
                    'unit' => 'deg',
                ],
                'range' => [
                    'deg' => [
                        'min' => -360,
                        'max' => 360,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-heading:before' => '-webkit-transform: translateY(-50%) rotate({{SIZE}}{{UNIT}}); -ms-transform: translateY(-50%) rotate({{SIZE}}{{UNIT}}); transform: translateY(-50%) rotate({{SIZE}}{{UNIT}});',
                ],
                'condition' => [
                    'heading_text!'    => '',
                    'show_background_text' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'background_offset_toggle',
            [
                'label' => esc_html__( 'Offset', 'redias-core' ),
                'type' => Controls_Manager::POPOVER_TOGGLE,
                'label_off' => esc_html__( 'None', 'redias-core' ),
                'label_on' => esc_html__( 'Custom', 'redias-core' ),
                'return_value' => 'yes',
                'condition' => [
                    'heading_text!'    => '',
                    'show_background_text' => 'yes'
                ],
            ]
        );

        $this->start_popover();

        $this->add_responsive_control(
            'background_horizontal_position',
            [
                'label' => esc_html__( 'Horizontal Position', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'default' => [
                    'unit' => '%',
                ],
                'range' => [
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'condition' => [
                    'heading_text!'    => '',
                    'show_background_text' => 'yes',
                    'background_offset_toggle' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-heading:before' => 'left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'background_vertical_position',
            [
                'label' => esc_html__( 'Vertical Position', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'default' => [
                    'unit' => '%',
                ],
                'range' => [
                    '%' => [
                        'min' => -100,
                        'max' => 200,
                    ],
                ],
                'condition' => [
                    'heading_text!'    => '',
                    'show_background_text' => 'yes',
                    'background_offset_toggle' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-heading:before' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_popover();

        $this->add_control(
			'heading_mark_text_title',
			[
				'label' => esc_html__( 'Mark Text', 'redias-core' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'mark_text_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-heading mark',
            ]
        );

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'mark_text_color',
                'label'    => esc_html__( 'Mark Text Color', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-heading mark',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Description Style
     *
     * @return void
     */
    protected function description_style() {

        $this->start_controls_section(
			'section_desc_text',
			[
                'label' => esc_html__( 'Description', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'desc!'    => ''
                ],
			]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'desc_text_typography',
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-desc',
                'condition'    => [
                    'desc!'    => ''
                ],
            ]
        );

        $this->add_control(
            'desc_text_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-desc' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'desc!'    => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'desc_text_padding',
            [
                'label' => esc_html__( 'Padding', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'desc!'    => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'desc_text_margin',
            [
                'label' => esc_html__( 'Margin', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'desc!'    => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'desc_text_border',
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-desc',
                'condition'    => [
                    'desc!'    => ''
                ],
            ]
        );

        $this->add_control(
            'desc_text_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'redias-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-desc' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'desc!'    => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name' => 'desc_text_shadow',
                'label' => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-desc',
                'condition'    => [
                    'desc!'    => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'desc_text_background',
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .dl-section-heading .dl-desc',
                'condition'    => [
                    'desc!'    => ''
                ],
            ]
        );

        $this->add_control(
            'desc_text_blend_mode',
            [
                'label' => esc_html__( 'Blend Mode', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'separator' => 'inherit',
                'options' => [
                    'inherit' => esc_html__( 'Normal', 'redias-core' ),
                    'multiply' => 'Multiply',
                    'screen' => 'Screen',
                    'overlay' => 'Overlay',
                    'darken' => 'Darken',
                    'lighten' => 'Lighten',
                    'color-dodge' => 'Color Dodge',
                    'saturation' => 'Saturation',
                    'color' => 'Color',
                    'difference' => 'Difference',
                    'exclusion' => 'Exclusion',
                    'hue' => 'Hue',
                    'luminosity' => 'Luminosity',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-section-heading .dl-desc' => 'mix-blend-mode: {{VALUE}}',
                ],
                'condition'    => [
                    'desc!'    => ''
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        $this->add_render_attribute( 'sub_heading_wrap', [ 'class' => 'dl-sub-heading' ] );
        $this->add_render_attribute( 'desc', [ 'class' => 'dl-desc' ] );
        $this->add_inline_editing_attributes( 'sub_heading', 'none' );
        $this->add_inline_editing_attributes( 'desc', 'none' );
        // Animation
        if( 'yes' === $settings['heading_anim'] ){
            $this->add_render_attribute( 'heading_anim_handler', [ 
                'class' => 'dl-heading wow dl-animation '. esc_attr( $settings['heading_anim_effect'] ) .'',
                'data-wow-offset' => esc_attr( $settings['heading_anim_offset']['size'] ),
                'data-wow-delay' => esc_attr( $settings['heading_anim_delay']['size'] ) . 'ms',
                'data-wow-duration' => esc_attr( $settings['heading_anim_duration']['size'] ) . 'ms',
            ] );
        }else{
            $this->add_render_attribute( 'heading_anim_handler', [ 'class' => 'dl-heading' ] );
        }
        if( 'yes' === $settings['sub_heading_anim'] ){
            $this->add_render_attribute( 'sub_heading_wrap', [ 
                'class' => 'wow dl-animation '. esc_attr( $settings['sub_h_anim_effect'] ) .'',
                'data-wow-offset' => esc_attr( $settings['sub_h_anim_offset']['size'] ),
                'data-wow-delay' => esc_attr( $settings['sub_h_anim_delay']['size'] ) . 'ms',
                'data-wow-duration' => esc_attr( $settings['sub_h_anim_duration']['size'] ) . 'ms',
            ] );
        }
        if( 'yes' === $settings['desc_anim'] ){
            $this->add_render_attribute( 'desc', [ 
                'class' => 'wow dl-animation '. esc_attr( $settings['desc_anim_effect'] ) .'',
                'data-wow-offset' => esc_attr( $settings['desc_anim_offset']['size'] ),
                'data-wow-delay' => esc_attr( $settings['desc_anim_delay']['size'] ) . 'ms',
                'data-wow-duration' => esc_attr( $settings['desc_anim_duration']['size'] ) . 'ms',
            ] );
        }
        if( 'yes' === $settings['subheading_custom_border'] ) {
            $this->add_render_attribute( 'sub_heading', [ 'class' => [ 'custom-border', $settings['sub_heading_bd_direction'] ] ] );
        }
        $heading_text = Helper::get_highlighted_text( $settings[ 'heading_text' ] );
        ?>
        <div class="dl-section-heading">
            <?php if( ! empty( $settings[ 'sub_heading' ] ) ) : ?>
                <<?php echo esc_attr( $settings['sub_heading_tag'] ); ?> <?php echo $this->get_render_attribute_string( 'sub_heading_wrap' ); ?>>
                <span <?php echo $this->get_render_attribute_string( 'sub_heading' ); ?>><?php echo Helper::kses_basic( $settings[ 'sub_heading' ] ); ?></span>
            </<?php echo esc_attr( $settings['sub_heading_tag'] ); ?>>
            <?php endif;?>
            <?php if( ! empty( $settings[ 'heading_text' ] ) ) : ?>
            <<?php echo esc_attr( $settings['heading_tag'] ); ?> <?php echo $this->get_render_attribute_string( 'heading_anim_handler' ); ?> data-bg-text="<?php echo esc_attr( $settings['background_text'] ); ?>">
                <?php echo Helper::kses_basic( $heading_text ); ?>
            </<?php echo esc_attr( $settings['heading_tag'] ); ?>>
            <?php endif; ?>
            <?php if( ! empty( $settings['desc'] ) ) : ?>
                <p <?php echo $this->get_render_attribute_string( 'desc' ); ?>><?php echo Helper::kses_basic( $settings[ 'desc' ] ); ?></p>
            <?php endif; ?>
        </div>
        <?php

    }

}