<?php
/**
 * Service
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Service;

use RediasCore\Classes\Helper;
use RediasCore\Elementor\Controls\BorderBottom;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use RediasCore\Elementor\Controls\Foreground;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-service';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Service', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-form-horizontal';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'feature', 'service', 'promo', 'redias' ];
    }

    public function get_style_depends() {
        return [ 'redias-service', 'redias-keyfram-anim', 'elementor-icons-line-awesome-icons', 'elementor-icons-dl-business-icons' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->layout_section();
        $this->query_section();
        $this->useful_options_section();
        $this->scrolling_animation_section();
        $this->wrapper_style();
        $this->icon_style();
        $this->heading_style();
        $this->description_style();
        $this->readmore_style();

    }

    /**
     * Layout Section
     *
     * @return void
     */
    protected function layout_section() {

        $this->start_controls_section(
			'layout_section',
			[
				'label' => esc_html__( 'Layout', 'redias-core' )
			]
        );

        $this->add_control(
            'card_style',
            [
                'label'   => esc_html__( 'Card Style', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'style-1',
                'options' => [
                    'style-1' => esc_html__( 'Style 1', 'redias-core' ),
                    'style-2' => esc_html__( 'Style 2', 'redias-core' ),
                    'style-3' => esc_html__( 'Style 3', 'redias-core' )
                ],
            ]
        );

        $this->add_responsive_control(
            'alignment',
            [
                'label' => esc_html__( 'Alignment', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon' => 'eicon-text-align-right',
                    ]
                ],
                'default' => 'center',
                'toggle' => false,
                'prefix_class' => 'service-align-',
                'selectors' => [
                    '{{WRAPPER}} .style-1 .service-item' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}}.service-align-left .style-1 .service-item .readmore' => 'justify-content: flex-start;',
                    '{{WRAPPER}}.service-align-right .style-1 .service-item .readmore' => 'justify-content: flex-end;',
                    '{{WRAPPER}}.service-align-center .style-1 .service-item .service-icon' => 'margin-left: auto; margin-right: auto;',
                    '{{WRAPPER}}.service-align-right .style-1 .service-item .service-icon' => 'margin-left: auto;',
                    '{{WRAPPER}}.service-align-right .style-1 .service-item:before' => 'right: auto; left: 0; transform: rotateY(180deg);'
                ],
                'condition'    => [
                    'card_style'    => 'style-1'
                ],
            ]
        );

        $this->add_responsive_control(
			'dl_column',
			[
				'label' => esc_html__( 'Column', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => 0,
                        'max' => 4,
                        'step' => 1,
                    ],
				],
                'default' => [
					'size' => 3,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 2,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 1,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .service-items' => 'grid-template-columns: repeat({{SIZE}},1fr);',
                ]
			]
		);

        $this->add_responsive_control(
			'grid_gap',
			[
				'label' => esc_html__( 'Grid Gap', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => 0,
                        'max' => 150
                    ],
				],
				'default'    => [
					'unit' => 'px',
					'size' => 30
				],
				'selectors' => [
					'{{WRAPPER}} .service-items' => 'grid-gap: {{SIZE}}{{UNIT}};',
                ]
			]
		);

        $this->add_control(
            'heading_tag',
            [
                'label'   => esc_html__( 'Heading Tag', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'h3',
                'options' => [
                    'h1'  => esc_html__( 'H1', 'redias-core' ),
                    'h2'  => esc_html__( 'H2', 'redias-core' ),
                    'h3'  => esc_html__( 'H3', 'redias-core' ),
                    'h4'  => esc_html__( 'H4', 'redias-core' ),
                    'h5'  => esc_html__( 'H5', 'redias-core' ),
                    'h6'  => esc_html__( 'H6', 'redias-core' )
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Query Section
     *
     * @return void
     */
    protected function query_section() {
        
        $this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Service Query', 'redias-core' )
			]
		);

		$this->add_control(
			'source',
			[
				'label' => _x( 'Source', 'Service Query Control', 'redias-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => esc_html__( 'Show All', 'redias-core' ),
					'by_name' => esc_html__( 'Manual Selection', 'redias-core' ),
				],
				'label_block' => true,
			]
		);

		$this->add_control(
			'service_categories',
			[
				'label'       => esc_html__( 'Categories', 'redias-core' ),
				'type'        => Controls_Manager::SELECT2,
				'options'     => Helper::el_get_terms('service-category'),
				'default'     => [],
				'label_block' => true,
				'multiple'    => true,
				'condition'   => [
					'source'    => 'by_name',
				],
			]
		);

		$this->add_control(
			'service_limit',
			[
				'label'       => esc_html__( 'Services Limit', 'redias-core' ),
				'type'        => Controls_Manager::NUMBER,
				'desc'		  => esc_html__( 'Choose number of services you want to show.', 'redias-core' ),
				'default'     => 3
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'   => esc_html__( 'Order By', 'redias-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'ID' => esc_html__( 'Post Id', 'redias-core' ),
                    'author' => esc_html__( 'Post Author', 'redias-core' ),
                    'title' => esc_html__( 'Title', 'redias-core' ),
                    'date' => esc_html__( 'Date', 'redias-core' ),
                    'modified' => esc_html__( 'Last Modified Date', 'redias-core' ),
                    'parent' => esc_html__( 'Parent Id', 'redias-core' ),
                    'rand' => esc_html__( 'Random', 'redias-core' ),
                    'comment_count' => esc_html__( 'Comment Count', 'redias-core' ),
                    'menu_order' => esc_html__( 'Menu Order', 'redias-core' ),
				],
			]
		);

		$this->add_control(
            'order',
            [
                'label' => __( 'Order', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' => esc_html__( 'Ascending', 'redias-core' ),
                    'desc' => esc_html__( 'Descending', 'redias-core' )
                ],
                'default' => 'desc',
            ]
        );

		$this->end_controls_section();

    }

    /**
     * Useful Options Section
     *
     * @return void
     */
    protected function useful_options_section() {
        
        $this->start_controls_section(
			'useful_section',
			[
				'label' => esc_html__( 'Useful Options', 'redias-core' )
			]
        );

        $this->add_control(
			'heading_length',
			[
				'label'   => esc_html__( 'Heading Length', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 42,
			]
		);

        $this->add_control(
            'heading_suffix',
            [
                'label'       => esc_html__( 'Heading Suffix', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '...',
                'placeholder' => esc_html__( 'Suffix...', 'redias-core' ),
            ]
        );

		$this->add_control(
			'show_excerpt',
			[
				'label'   => esc_html__( 'Excerpt', 'redias-core' ),
				'type'    => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'redias-core' ),
                'label_off'    => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'excerpt_length',
			[
				'label'   => esc_html__( 'Excerpt Length', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 100,
				'condition' => [
					'show_excerpt' => 'yes',
				],
			]
		);

        $this->add_control(
            'excerpt_suffix',
            [
                'label'       => esc_html__( 'Excerpt Suffix', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '...',
                'placeholder' => esc_html__( 'Suffix...', 'redias-core' ),
                'condition' => [
					'show_excerpt' => 'yes',
				],
            ]
        );

        $this->add_control(
			'show_readmore',
			[
				'label'   => esc_html__( 'Readmore', 'redias-core' ),
				'type'    => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'redias-core' ),
                'label_off'    => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
				'default' => 'yes',
			]
		);

        $this->add_control(
            'readmore_text',
            [
                'label'       => esc_html__( 'Readmore Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Explore Services', 'redias-core' ),
                'placeholder' => esc_html__( 'Text...', 'redias-core' ),
                'condition'    => [
                    'show_readmore'    => 'yes'
                ],
            ]
        );

        $this->add_control(
			'readmore_icon',
			[
				'label' => esc_html__( 'Readmore Icon', 'redias-core' ),
				'label_block' => false,
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-long-arrow-alt-right',
					'library' => 'elementor-icons-line-awesome-icons',
				],
				'condition'    => [
                    'show_readmore'    => 'yes'
                ],
			]
		);

        $this->end_controls_section();

    }

    /**
     * Scrolling Animation
     *
     * @return void
     */
    protected function scrolling_animation_section() {
        
        $this->start_controls_section(
			'scrolling_animation_section',
			[
				'label' => esc_html__( 'Scrolling Animation', 'redias-core' )
			]
        );

        $this->add_control(
            'scroll_anim',
            [
                'label'        => esc_html__( 'Scrolling Animation', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'no'
            ]
        );

        $this->add_control(
            'anim_effect',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'dl-fadeIn',
                'options' => Helper::get_animation_effects(),
                'condition' => [
                    'scroll_anim' => 'yes'
				]
            ]
        );

        $this->add_control(
            'anim_offset',
            [
                'label'      => esc_html__( 'Offset', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 2000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 200,
                ],
                'condition' => [
                    'scroll_anim' => 'yes'
				]
            ]
        );

        $this->add_control(
            'anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 700,
                ],
                'condition' => [
                    'scroll_anim' => 'yes'
				]
            ]
        );
        
        $this->add_control(
            'anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 400,
                ],
                'condition' => [
                    'scroll_anim' => 'yes'
				]
            ]
        );

        $this->add_control(
            'anim_delay_interval',
            [
                'label'      => esc_html__( 'Delay Interval', 'redias-core' ),
                'description'      => esc_html__( 'Delay interval between items.', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['ms'],
                'range'      => [
                    'ms' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'ms',
                    'size' => 100,
                ],
                'condition' => [
                    'scroll_anim' => 'yes'
				]
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Wrapper Style
     *
     * @return void
     */
    protected function wrapper_style() {
        
        $this->start_controls_section(
            'wrapper_style_section',
            [
                'label' => esc_html__( 'Wrapper', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'wrapper_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .service-item',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'wrapper_box_shadow',
                'selector' => '{{WRAPPER}} .service-item',
            ]
        );

        $this->add_group_control(
            BorderBottom::get_type(),
            [
                'name'     => 'wrapper_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .service-item',
                'condition'    => [
                    'card_style!' => 'style-3'
                ],
            ]
        );

        $this->add_control(
            'wrapper_hover_bd_color',
            [
                'label'     => esc_html__( 'Hover Border Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .style-3 .service-item' => '--redias-service-bd-color: {{VALUE}};'
                ],
                'condition'    => [
                    'card_style' => 'style-3'
                ],
            ]
        );

        $this->add_responsive_control(
            'wrapper_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .service-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'wrapper_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .service-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'wrapper_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .service-item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Icon Style
     *
     * @return void
     */
    protected function icon_style() {
        
        $this->start_controls_section(
            'icon_style_section',
            [
                'label' => esc_html__( 'Icon', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_responsive_control(
            'si_width',
            [
                'label'      => esc_html__( 'Box Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .style-1 .service-icon' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'card_style'    => 'style-1'
                ],
            ]
        );

        $this->add_responsive_control(
            'si_height',
            [
                'label'      => esc_html__( 'Box Height', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .style-1 .service-icon' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'card_style'    => 'style-1'
                ],
            ]
        );

        $this->add_responsive_control(
            'si_box_size',
            [
                'label'      => esc_html__( 'Box Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .service-items:not(.style-1) .service-head' => '--redias-icon-box-size: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'card_style!'    => 'style-1'
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1,
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .service-item .service-icon' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'si_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-items:not(.style-1) .service-item .service-icon' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .style-1 .service-item .service-icon:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'si_color',
                'label'    => esc_html__( 'Icon Color Type', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .service-item .service-icon i',
            ]
        );

        $this->add_control(
            'si_hover_bg_color',
            [
                'label'     => esc_html__( 'Background Hover Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'separator'  => 'before',
                'selectors' => [
                    '{{WRAPPER}} .style-1 .service-item:hover .service-icon:before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .style-2 .service-item:hover .service-icon' => 'background-color: {{VALUE}}',
                ],
                'condition'    => [
                    'card_style!'    => 'style-3'
                ],
            ]
        );

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'si_hover_color',
                'label'    => esc_html__( 'Icon Hover Color Type', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .service-items:not(.style-3) .service-item:hover .service-icon i',
                'condition'    => [
                    'card_style!'    => 'style-3'
                ],
            ]
        );

        $this->add_responsive_control(
            'si_space_between_item',
            [
                'label'      => esc_html__( 'Space Between', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'separator'  => 'before',
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1,
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .service-items:not(.style-1) .service-item .service-head' => 'grid-gap: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'card_style!'    => 'style-1'
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_margin_bottom',
            [
                'label'      => esc_html__( 'Bottom Spacing', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1,
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .style-1 .service-item .service-icon' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-item .service-head' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        
        
        $this->end_controls_section();

    }

    /**
     * Heading Style
     *
     * @return void
     */
    protected function heading_style() {
        
        $this->start_controls_section(
            'heading_style_section',
            [
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'heading_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .service-item .service-heading',
            ]
        );

        $this->add_control(
            'heading_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-item .service-heading' => 'color: {{VALUE}}'
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .service-item .service-heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Description Style
     *
     * @return void
     */
    protected function description_style() {
        
        $this->start_controls_section(
            'description_style_section',
            [
                'label' => esc_html__( 'Description', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'show_excerpt' => 'yes'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'desc_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .service-item p',
                'condition'    => [
                    'show_excerpt' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'desc_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-item p' => 'color: {{VALUE}}'
                ],
                'condition'    => [
                    'show_excerpt' => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
            'desc_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .service-item p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'show_excerpt' => 'yes'
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Readmore Style
     *
     * @return void
     */
    protected function readmore_style() {

        $this->start_controls_section(
            'readmore_style_section',
            [
                'label' => esc_html__( 'Readmore', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'readmore_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .service-item .readmore',
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
            'rm_icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .style-1 .service-item .readmore i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .service-items:not(.style-1) .service-item .readmore span i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
            'rm_spacebetween_icon',
            [
                'label'      => esc_html__( 'Space Between Icon', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .service-item .readmore' => 'column-gap: {{SIZE}}{{UNIT}};'
                ],
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
            'readmore_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .service-item .readmore' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
            'readmore_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .service-item .readmore' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->start_controls_tabs( 'readmore_style_tabs' );
        
        $this->start_controls_tab(
            'readmore_style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'rm_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-item .readmore' => 'background-color: {{VALUE}}',
                ],
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'rm_txt_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-item .readmore' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'rm_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-item .readmore i' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'rm_circle_color',
            [
                'label'     => esc_html__( 'Circle Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-items:not(.style-1) .readmore span:before' => 'background-color: {{VALUE}}',
                ],
                'condition'    => [
                    'card_style!'    => 'style-1',
                    'show_readmore' => 'yes'
                ],
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'readmore_style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'rm_bg_h_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-item .readmore:hover' => 'background-color: {{VALUE}}',
                ],
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'rm_txt_h_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-item .readmore:hover' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'rm_icon_h_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-item .readmore:hover i' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'show_readmore' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'rm_circle_h_color',
            [
                'label'     => esc_html__( 'Circle Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .service-items:not(.style-1) .readmore:hover span:before' => 'background-color: {{VALUE}}',
                ],
                'condition'    => [
                    'card_style!' => 'style-1',
                    'show_readmore' => 'yes'
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->end_controls_section();
    }
    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings = $this->get_settings_for_display();

        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

		$args = array(
            'post_type'   => 'dl-service',
            'post__not_in' => get_option( 'sticky_posts' ),
            'posts_per_page' => $settings['service_limit'],
            'orderby'	=> $settings['orderby'],
            'order'	=> $settings['order'],
            'post_status' => 'publish',
            'paged' => $paged,
		);

		if ( $settings['source'] === 'by_name'  ) {
            $args['tax_query'][] = array(
				'taxonomy' => 'service-category',
				'field'    => 'slug',
				'terms'    => $settings['service_categories'],
			);
        }

        $wp_query = new \WP_Query( $args );

        $this->add_render_attribute( 'wrapper', [ 'class' => [ 'service-items', $settings['card_style'] ] ] );
        if( 'yes' === $settings['scroll_anim'] ) {
            $this->add_render_attribute( 'scrolling-animation', [ 
                'class' => 'service-item wow dl-animation '. esc_attr( $settings['anim_effect'] ) .'',
                'data-wow-offset' => esc_attr( $settings['anim_offset']['size'] ),
                'data-wow-duration' => esc_attr( $settings['anim_duration']['size'] ) . 'ms',
            ] );
        }else{
            $this->add_render_attribute( 'scrolling-animation', [ 
                'class' => 'service-item'
            ] );
        }
        ?>
        <div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
            <?php
            if( $wp_query->have_posts() ) :
                
                while ( $wp_query->have_posts() ) : $wp_query->the_post();
                $post_index = $wp_query->current_post;
                if( 'style-1' === $settings['card_style'] ) {
                    $this->style_1($post_index);
                }elseif( 'style-2' === $settings['card_style'] ) {
                    $this->style_2($post_index);
                }else{
                    $this->style_3($post_index);
                }
                endwhile;
            
            wp_reset_postdata();

            else :
                esc_html_e( 'No services found!', 'redias-core' );
            endif;
            ?>
        </div>
        <?php
    }

    /**
     * Style 1
     *
     * @return void
     */
    protected function style_1($index = 0){
        $settings = $this->get_settings_for_display();
        $h_tag = ! empty( $settings['heading_tag'] ) ? $settings['heading_tag'] : 'h3';
        $heading = get_the_title();
        $excerpt = get_the_excerpt();
        $icon = Helper::get_field_by_id('service_icon', get_the_ID());
        if( 'yes' === $settings['scroll_anim'] ) {
            $delay = $settings['anim_delay']['size'] + ( $settings['anim_delay_interval']['size'] * $index );
            $delay_attr = ' data-wow-delay="'. $delay .'ms"';
        }else{
            $delay_attr = '';
        }
        ?>
        <div <?php echo $this->get_render_attribute_string( 'scrolling-animation' ) . $delay_attr; ?>>
            <?php if( ! empty( $icon ) ) : ?>
            <div class="service-icon">
                <i class="<?php echo esc_attr( $icon ); ?>"></i>
            </div>
            <?php endif; ?>
            <<?php echo esc_attr( $h_tag ); ?> class="service-heading"><?php Helper::limit_latter( $heading, $settings['heading_length'], $settings['heading_suffix']) ?></<?php echo esc_attr( $h_tag ); ?>>
            <?php if( ! empty( $excerpt ) && 'yes' === $settings['show_excerpt'] ) : ?>
            <p><?php Helper::limit_latter( $excerpt, $settings['excerpt_length'], $settings['excerpt_suffix'] ); ?></p>
            <?php endif; ?>
            <?php if( 'yes' === $settings['show_readmore'] && ! empty( $settings['readmore_text'] ) ) : ?>
            <a href="<?php the_permalink(); ?>" class="readmore"><?php echo esc_html( $settings['readmore_text'] ); ?> <?php if( ! empty( $settings['readmore_icon']['value'] ) ){ Icons_Manager::render_icon( $settings['readmore_icon'], ['aria-hidden' => 'true'] ); } ?></a>
            <?php endif; ?>
        </div>
        <?php
    }

    /**
     * Style 2
     *
     * @return void
     */
    protected function style_2($index = 0){
        $settings = $this->get_settings_for_display();
        if( 'yes' === $settings['scroll_anim'] ) {
            $delay = $settings['anim_delay']['size'] + ( $settings['anim_delay_interval']['size'] * $index );
            $delay_attr = ' data-wow-delay="'. $delay .'ms"';
        }else{
            $delay_attr = '';
        }
        $h_tag = ! empty( $settings['heading_tag'] ) ? $settings['heading_tag'] : 'h3';
        $heading = get_the_title();
        $excerpt = get_the_excerpt();
        $icon = Helper::get_field_by_id('service_icon', get_the_ID());
        ?>
        <div <?php echo $this->get_render_attribute_string( 'scrolling-animation' ) . $delay_attr; ?>>
            <div class="service-head">
                <?php if( ! empty( $icon ) ) : ?>
                <div class="service-icon">
                    <i class="<?php echo esc_attr( $icon ); ?>"></i>
                </div>
                <?php endif; ?>
                <<?php echo esc_attr( $h_tag ); ?> class="service-heading"><?php Helper::limit_latter( $heading, $settings['heading_length'], $settings['heading_suffix']) ?></<?php echo esc_attr( $h_tag ); ?>>
            </div>
            <?php if( ! empty( $excerpt ) && 'yes' === $settings['show_excerpt'] ) : ?>
            <p><?php Helper::limit_latter( $excerpt, $settings['excerpt_length'], $settings['excerpt_suffix'] ); ?></p>
            <?php endif; ?>
            <?php if( 'yes' === $settings['show_readmore'] && ! empty( $settings['readmore_text'] ) ) : ?>
            <a href="<?php the_permalink(); ?>" class="readmore"><?php echo esc_html( $settings['readmore_text'] ); ?> <?php if( ! empty( $settings['readmore_icon']['value'] ) ){ echo '<span>'; Icons_Manager::render_icon( $settings['readmore_icon'], ['aria-hidden' => 'true'] ); echo '</span>';} ?></a>
            <?php endif; ?>
        </div>
        <?php
    }

    /**
     * Style 3
     *
     * @return void
     */
    protected function style_3($index = 0){
        $settings = $this->get_settings_for_display();
        if( 'yes' === $settings['scroll_anim'] ) {
            $delay = $settings['anim_delay']['size'] + ( $settings['anim_delay_interval']['size'] * $index );
            $delay_attr = ' data-wow-delay="'. $delay .'ms"';
        }else{
            $delay_attr = '';
        }
        $h_tag = ! empty( $settings['heading_tag'] ) ? $settings['heading_tag'] : 'h3';
        $heading = get_the_title();
        $excerpt = get_the_excerpt();
        $icon = Helper::get_field_by_id('service_icon', get_the_ID());
        ?>
        <div <?php echo $this->get_render_attribute_string( 'scrolling-animation' ) . $delay_attr; ?>>
            <div class="service-head">
                <<?php echo esc_attr( $h_tag ); ?> class="service-heading"><?php Helper::limit_latter( $heading, $settings['heading_length'], $settings['heading_suffix']) ?></<?php echo esc_attr( $h_tag ); ?>>
                <?php if( ! empty( $icon ) ) : ?>
                <div class="service-icon">
                    <i class="<?php echo esc_attr( $icon ); ?>"></i>
                </div>
                <?php endif; ?>
            </div>
            <?php if( ! empty( $excerpt ) && 'yes' === $settings['show_excerpt'] ) : ?>
            <p><?php Helper::limit_latter( $excerpt, $settings['excerpt_length'], $settings['excerpt_suffix'] ); ?></p>
            <?php endif; ?>
            <?php if( 'yes' === $settings['show_readmore'] && ! empty( $settings['readmore_text'] ) ) : ?>
            <a href="<?php the_permalink(); ?>" class="readmore"><?php echo esc_html( $settings['readmore_text'] ); ?> <?php if( ! empty( $settings['readmore_icon']['value'] ) ){ echo '<span>'; Icons_Manager::render_icon( $settings['readmore_icon'], ['aria-hidden' => 'true'] ); echo '</span>';} ?></a>
            <?php endif; ?>
        </div>
        <?php
    }

}