<?php
/**
 * Slider
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Slider;

use RediasCore\Classes\SliderHelper;
use RediasCore\Traits\SliderControls;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    use SliderControls;

	public function get_name() {
        return 'redias-slider';
    }

    public function get_title() {
        return esc_html__( 'Slider', 'redias-core' );
    }

    public function get_icon() {
        return 'redias-icon eicon-slides';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_style_depends() {
        return ['splitting', 'redias-slider', 'elementor-icons-line-awesome-icons'];
    }

    public function get_script_depends() {
        return [ 'splitting', 'redias-slider' ];
    }

	public function get_keywords() {
        return [ 'slider', 'image slider', 'carousel', 'animated slider', 'redias' ];
    }

    protected function register_controls() {

        $this->section_slider_settings();
        $this->section_slides();
        $this->section_slider_controls();
        $this->section_slider_shape();
        $this->section_image_settings();
        $this->style_sub_heading();
        $this->style_heading();
        $this->style_description();
        $this->style_button();
        $this->style_secondary_button();
        $this->style_play_button();
        $this->style_navigation();
        $this->style_pagination();

    }

	/**
     * Sub Heading Controls
     *
     * @return void
     */
    private function style_sub_heading() {

        $this->start_controls_section(
            'style_sub_heading',
            [
                'label' => esc_html__( 'Sub Heading', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'sub_heading_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-caption.sub-heading',
            ]
        );

        $this->start_controls_tabs( 'sub_heading_style_tabs' );

        $this->start_controls_tab(
            'style_subheading_tab',
            [
                'label' => esc_html__( 'Style', 'redias-core' ),
            ]
        );

        $this->add_control(
            'sub_heading_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.sub-heading .dl-cap' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sub_heading_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.sub-heading' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sh_text_stroke',
            [
                'label'        => esc_html__( 'Text Stroke', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
            ]
        );

        $this->add_control(
            'popover_sh_text_stroke',
            [
                'label'        => esc_html__( 'Stroke Options', 'redias-core' ),
                'type'         => Controls_Manager::POPOVER_TOGGLE,
                'label_off'    => esc_html__( 'Default', 'redias-core' ),
                'label_on'     => esc_html__( 'Custom', 'redias-core' ),
                'return_value' => 'yes',
                'condition'    => [
                    'sh_text_stroke' => 'yes',
                ],
            ]
        );

        $this->start_popover();

        $this->add_responsive_control(
            'sh_text_stroke_width',
            [
                'label'      => esc_html__( 'Stroke Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 50,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.sub-heading' => '-webkit-text-stroke-width: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'sh_text_stroke' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'sh_text_stroke_color',
            [
                'label'     => esc_html__( 'Stroke Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.sub-heading' => '-webkit-text-stroke-color: {{VALUE}}',
                ],
                'condition' => [
                    'sh_text_stroke' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'sh_text_fill_color',
            [
                'label'     => esc_html__( 'Fill Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.sub-heading' => '-webkit-text-fill-color: {{VALUE}}',
                ],
                'condition' => [
                    'sh_text_stroke' => 'yes',
                ],
            ]
        );

        $this->end_popover();

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'sub_heading_text_shadow',
                'selector' => '{{WRAPPER}} .dl-caption.sub-heading',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'sub_heading_box_shadow',
                'selector' => '{{WRAPPER}} .dl-caption.sub-heading .dl-cap',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'sub_heading_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-caption.sub-heading .dl-cap',
            ]
        );

        $this->add_responsive_control(
            'sub_heading_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.sub-heading .dl-cap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.sub-heading .dl-cap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.sub-heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'stylesh_hl_text_tab',
            [
                'label' => esc_html__( 'Mark Text', 'redias-core' ),
            ]
        );

        $this->add_control(
            'sh_hl_style',
            [
                'label'        => esc_html__( 'Custom Style', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
            ]
        );

        $this->add_responsive_control(
            'sh_hl_layout',
            [
                'label'     => esc_html__( 'Layout', 'redias-core' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'inline-block' => [
                        'title' => esc_html__( 'Inline', 'redias-core' ),
                        'icon'  => 'eicon-ellipsis-h',
                    ],
                    'block'        => [
                        'title' => esc_html__( 'Block', 'redias-core' ),
                        'icon'  => 'eicon-menu-bar',
                    ],
                ],
                'default'   => 'inline-block',
                'toggle'    => false,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.sub-heading mark' => 'display: {{VALUE}};',
                ],
                'condition' => [
                    'sh_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'sub_heading_hl_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.sub-heading mark' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'sh_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'sub_heading_hl_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.sub-heading mark' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'sh_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'sh_hl_text_stroke',
            [
                'label'        => esc_html__( 'Text Stroke', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'condition'    => [
                    'sh_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'popover_sh_hl_text_stroke',
            [
                'label'        => esc_html__( 'Stroke Options', 'redias-core' ),
                'type'         => Controls_Manager::POPOVER_TOGGLE,
                'label_off'    => esc_html__( 'Default', 'redias-core' ),
                'label_on'     => esc_html__( 'Custom', 'redias-core' ),
                'return_value' => 'yes',
                'condition'    => [
                    'sh_hl_text_stroke' => 'yes',
                    'sh_hl_style'       => 'yes',
                ],
            ]
        );

        $this->start_popover();

        $this->add_responsive_control(
            'sh_hl_text_stroke_width',
            [
                'label'      => esc_html__( 'Stroke Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 50,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.sub-heading mark' => '-webkit-text-stroke-width: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'sh_hl_text_stroke' => 'yes',
                    'sh_hl_style'       => 'yes',
                ],
            ]
        );

        $this->add_control(
            'sh_hl_text_stroke_color',
            [
                'label'     => esc_html__( 'Stroke Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.sub-heading mark' => '-webkit-text-stroke-color: {{VALUE}}',
                ],
                'condition' => [
                    'sh_hl_text_stroke' => 'yes',
                    'sh_hl_style'       => 'yes',
                ],
            ]
        );

        $this->add_control(
            'sh_hl_text_fill_color',
            [
                'label'     => esc_html__( 'Fill Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.sub-heading mark' => '-webkit-text-fill-color: {{VALUE}}',
                ],
                'condition' => [
                    'sh_hl_text_stroke' => 'yes',
                    'sh_hl_style'       => 'yes',
                ],
            ]
        );

        $this->end_popover();

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'      => 'sub_heading_hl_text_shadow',
                'selector'  => '{{WRAPPER}} .dl-caption.sub-heading mark',
                'condition' => [
                    'sh_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'      => 'sub_heading_hl_box_shadow',
                'selector'  => '{{WRAPPER}} .dl-caption.sub-heading mark',
                'condition' => [
                    'sh_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'      => 'sub_heading_hl_border',
                'label'     => esc_html__( 'Border', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-caption.sub-heading mark',
                'condition' => [
                    'sh_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_hl_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.sub-heading mark' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'sh_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_hl_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.sub-heading mark' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'sh_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_hl_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.sub-heading mark' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'sh_hl_style' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

    }

    /**
     * Heading Controls
     *
     * @return void
     */
    private function style_heading() {

        $this->start_controls_section(
            'style_heading',
            [
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'heading_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-caption.heading',
            ]
        );

        $this->start_controls_tabs( 'heading_style_tabs' );

        $this->start_controls_tab(
            'style_heading_tab',
            [
                'label' => esc_html__( 'Style', 'redias-core' ),
            ]
        );

        $this->add_control(
            'heading_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.heading .dl-cap' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'heading_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.heading' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'h_text_stroke',
            [
                'label'        => esc_html__( 'Text Stroke', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
            ]
        );

        $this->add_control(
            'popover_h_text_stroke',
            [
                'label'        => esc_html__( 'Stroke Options', 'redias-core' ),
                'type'         => Controls_Manager::POPOVER_TOGGLE,
                'label_off'    => esc_html__( 'Default', 'redias-core' ),
                'label_on'     => esc_html__( 'Custom', 'redias-core' ),
                'return_value' => 'yes',
                'condition'    => [
                    'h_text_stroke' => 'yes',
                ],
            ]
        );

        $this->start_popover();

        $this->add_responsive_control(
            'h_text_stroke_width',
            [
                'label'      => esc_html__( 'Stroke Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 50,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.heading' => '-webkit-text-stroke-width: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'h_text_stroke' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'h_text_stroke_color',
            [
                'label'     => esc_html__( 'Stroke Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.heading' => '-webkit-text-stroke-color: {{VALUE}}',
                ],
                'condition' => [
                    'h_text_stroke' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'h_text_fill_color',
            [
                'label'     => esc_html__( 'Fill Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.heading' => '-webkit-text-fill-color: {{VALUE}}',
                ],
                'condition' => [
                    'h_text_stroke' => 'yes',
                ],
            ]
        );

        $this->end_popover();

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'heading_text_shadow',
                'selector' => '{{WRAPPER}} .dl-caption.heading',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'heading_box_shadow',
                'selector' => '{{WRAPPER}} .dl-caption.heading .dl-cap',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'heading_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-caption.heading .dl-cap',
            ]
        );

        $this->add_responsive_control(
            'heading_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.heading .dl-cap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.heading .dl-cap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_h_hl_text_tab',
            [
                'label' => esc_html__( 'Mark Text', 'redias-core' ),
            ]
        );

        $this->add_control(
            'h_hl_style',
            [
                'label'        => esc_html__( 'Custom Style', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
            ]
        );

        $this->add_responsive_control(
            'h_hl_layout',
            [
                'label'     => esc_html__( 'Layout', 'redias-core' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'inline-block' => [
                        'title' => esc_html__( 'Inline', 'redias-core' ),
                        'icon'  => 'eicon-ellipsis-h',
                    ],
                    'block'        => [
                        'title' => esc_html__( 'Block', 'redias-core' ),
                        'icon'  => 'eicon-menu-bar',
                    ],
                ],
                'default'   => 'inline-block',
                'toggle'    => false,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.heading mark' => 'display: {{VALUE}};',
                ],
                'condition' => [
                    'h_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'heading_hl_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.heading mark' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'h_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'heading_hl_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.heading mark' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'h_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'h_hl_text_stroke',
            [
                'label'        => esc_html__( 'Text Stroke', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'condition'    => [
                    'h_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'popover_h_hl_text_stroke',
            [
                'label'        => esc_html__( 'Stroke Options', 'redias-core' ),
                'type'         => Controls_Manager::POPOVER_TOGGLE,
                'label_off'    => esc_html__( 'Default', 'redias-core' ),
                'label_on'     => esc_html__( 'Custom', 'redias-core' ),
                'return_value' => 'yes',
                'condition'    => [
                    'h_hl_text_stroke' => 'yes',
                    'h_hl_style'       => 'yes',
                ],
            ]
        );

        $this->start_popover();

        $this->add_responsive_control(
            'h_hl_text_stroke_width',
            [
                'label'      => esc_html__( 'Stroke Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 50,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.heading mark' => '-webkit-text-stroke-width: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'h_hl_text_stroke' => 'yes',
                    'h_hl_style'       => 'yes',
                ],
            ]
        );

        $this->add_control(
            'h_hl_text_stroke_color',
            [
                'label'     => esc_html__( 'Stroke Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.heading mark' => '-webkit-text-stroke-color: {{VALUE}}',
                ],
                'condition' => [
                    'h_hl_text_stroke' => 'yes',
                    'h_hl_style'       => 'yes',
                ],
            ]
        );

        $this->add_control(
            'h_hl_text_fill_color',
            [
                'label'     => esc_html__( 'Fill Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.heading mark' => '-webkit-text-fill-color: {{VALUE}}',
                ],
                'condition' => [
                    'h_hl_text_stroke' => 'yes',
                    'h_hl_style'       => 'yes',
                ],
            ]
        );

        $this->end_popover();

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'      => 'heading_hl_text_shadow',
                'selector'  => '{{WRAPPER}} .dl-caption.heading mark',
                'condition' => [
                    'h_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'      => 'heading_hl_box_shadow',
                'selector'  => '{{WRAPPER}} .dl-caption.heading mark',
                'condition' => [
                    'h_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'      => 'heading_hl_border',
                'label'     => esc_html__( 'Border', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-caption.heading mark',
                'condition' => [
                    'h_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_hl_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.heading mark' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'h_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_hl_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.heading mark' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'h_hl_style' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_hl_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.heading mark' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'h_hl_style' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

    }

    /**
     * Description Controls
     *
     * @return void
     */
    private function style_description() {

        $this->start_controls_section(
            'style_description',
            [
                'label' => esc_html__( 'Description', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'desc_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-caption.desc',
            ]
        );

        $this->add_control(
            'desc_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.desc .dl-cap' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'desc_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-caption.desc' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'desc_text_shadow',
                'selector' => '{{WRAPPER}} .dl-caption.desc',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'desc_box_shadow',
                'selector' => '{{WRAPPER}} .dl-caption.desc .dl-cap',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'desc_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-caption.desc .dl-cap',
            ]
        );

        $this->add_responsive_control(
            'desc_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.desc .dl-cap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'desc_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.desc .dl-cap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'desc_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-caption.desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Button Controls
     *
     * @return void
     */
    private function style_button() {

        $this->start_controls_section(
            'style_button',
            [
                'label' => esc_html__( 'Button', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'btn_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .slider-btn',
            ]
        );

        $this->add_responsive_control(
            'btn_icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 150,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .slider-btn i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_space_between',
            [
                'label'      => esc_html__( 'Space Between', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .slider-btn' => 'column-gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .slider-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'btn_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .slider-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs( 'style_btn_tabs' );

        $this->start_controls_tab(
            'style_btn_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'btn_normal_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .slider-btn',
            ]
        );

        $this->add_control(
            'btn_normal_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slider-btn' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'btn_normal_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .slider-btn',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'btn_normal_box_shadow',
                'selector' => '{{WRAPPER}} .slider-btn',
            ]
        );

        $this->add_responsive_control(
            'btn_normal_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .slider-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_btn_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'btn_hover_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .slider-btn:before'
            ]
        );

        $this->add_control(
            'btn_hover_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slider-btn:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'btn_hover_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .slider-btn:hover',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'btn_hover_box_shadow',
                'selector' => '{{WRAPPER}} .slider-btn:hover',
            ]
        );

        $this->add_responsive_control(
            'btn_hover_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .slider-btn:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

    }

    /**
     * Secondary Button Controls
     *
     * @return void
     */
    private function style_secondary_button() {

        $this->start_controls_section(
            'secondary_style_button',
            [
                'label' => esc_html__( 'Secondary Button', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'secondary_btn_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .slider-secondary-btn',
            ]
        );

        $this->add_responsive_control(
            'secondary_btn_icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 150,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .slider-secondary-btn i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'secondary_btn_space_between',
            [
                'label'      => esc_html__( 'Space Between', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .slider-secondary-btn' => 'column-gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'secondary_btn_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .slider-secondary-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'secondary_btn_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .slider-secondary-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs( 'style_secondary_btn_tabs' );

        $this->start_controls_tab(
            'style_btn_secondary_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'btn_secondary_normal_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .slider-secondary-btn',
            ]
        );

        $this->add_control(
            'secondary_btn_normal_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slider-secondary-btn' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'secondary_btn_normal_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .slider-secondary-btn',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'secondary_btn_normal_box_shadow',
                'selector' => '{{WRAPPER}} .slider-secondary-btn',
            ]
        );

        $this->add_responsive_control(
            'secondary_btn_normal_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .slider-secondary-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_secondary_btn_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'secondary_btn_hover_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .slider-secondary-btn:before',
            ]
        );

        $this->add_control(
            'secondary_btn_hover_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slider-secondary-btn:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'secondary_btn_hover_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .slider-secondary-btn:hover',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'secondary_btn_hover_box_shadow',
                'selector' => '{{WRAPPER}} .slider-secondary-btn:hover',
            ]
        );

        $this->add_responsive_control(
            'secondary_btn_hover_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .slider-secondary-btn:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

    }

    /**
     * Play Button Controls
     *
     * @return void
     */
    private function style_play_button() {

        $this->start_controls_section(
            'style_play_button',
            [
                'label' => esc_html__( 'Play Button', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'play_btn_size',
            [
                'label'      => esc_html__( 'Play Button Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 250,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-play-btn .play-icon' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'play_btn_icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 150,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-play-btn .play-icon svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'play_btn_space_between',
            [
                'label'      => esc_html__( 'Space Between', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 150,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-play-btn' => 'column-gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'play_btn_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-play-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs( 'style_play_btn_tabs' );

        $this->start_controls_tab(
            'style_play_btn_icon_tab',
            [
                'label' => esc_html__( 'Play Icon', 'redias-core' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'play_btn_icon_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-play-btn .play-icon',
            ]
        );

        $this->add_control(
            'play_btn_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-play-btn .play-icon' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'play_btn_icon_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-play-btn .play-icon',
            ]
        );

        $this->add_responsive_control(
            'play_btn_icon_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-play-btn .play-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'play_btn_hover_stuff',
            [
                'label'     => esc_html__( 'Hover', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'      => 'play_btn_icon_hover_background',
                'label'     => esc_html__( 'Background', 'redias-core' ),
                'types'     => ['classic', 'gradient'],
                'selector'  => '{{WRAPPER}} .dl-play-btn:hover .play-icon',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'play_btn_icon_hover_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-play-btn:hover .play-icon' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'play_btn_icon_hover_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-play-btn:hover .play-icon',
            ]
        );

        $this->add_responsive_control(
            'play_btn_icon_hover_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-play-btn:hover .play-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_play_btn_text_tab',
            [
                'label' => esc_html__( 'Text/Label', 'redias-core' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'play_btn_text_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-play-btn small',
            ]
        );

        $this->add_control(
            'play_btn_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-play-btn small' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'play_btn_text_hover_stuff',
            [
                'label'     => esc_html__( 'Hover', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'play_btn_text_hover_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-play-btn:hover small' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

    }

    /**
     * Style Carousel Navigation
     *
     * @return void
     */
    protected function style_navigation() {

        $this->start_controls_section(
            'section_carousel_navigation_style',
            [
                'label'     => esc_html__( 'Navigation', 'redias-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'nav_hide_mobile',
            [
                'label'        => esc_html__( 'Hide on Mobile', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
                'condition'    => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'nav_visibility',
            [
                'label'     => esc_html__( 'Visibility', 'redias-core' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'hover-on-visible',
                'options'   => [
                    'hover-on-visible' => esc_html__( 'Hover on Visible', 'redias-core' ),
                    'always-visible'   => esc_html__( 'Always Visible', 'redias-core' ),
                ],
                'condition' => [
                    'slider_nav' => 'yes',
                    'nav_layout' => '2',
                ],
            ]
        );

        $this->add_control(
            'nav_left_arrow',
            [
                'label' => esc_html__( 'Left Icon', 'textdomain' ),
                'type' => Controls_Manager::ICONS,
                'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-long-arrow-alt-left',
					'library' => 'elementor-icons-line-awesome-icons'
				],
                'condition'    => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'nav_right_arrow',
            [
                'label' => esc_html__( 'Right Icon', 'textdomain' ),
                'type' => Controls_Manager::ICONS,
                'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-long-arrow-alt-right',
					'library' => 'elementor-icons-line-awesome-icons'
				],
                'condition'    => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'nav_width',
            [
                'label'      => esc_html__( 'Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 300,
                        'step' => 1,
                    ],
                    'em' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-slider-button-prev, {{WRAPPER}} .dl-slider-button-next' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'nav_height',
            [
                'label'      => esc_html__( 'Height', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 300,
                        'step' => 1,
                    ],
                    'em' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-slider-button-prev, {{WRAPPER}} .dl-slider-button-next' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'nav_icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-slider-button-prev, {{WRAPPER}} .dl-slider-button-next' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'nav_top_bottom_pos',
            [
                'label'      => esc_html__( 'Top Bottom Position', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'range'      => [
                    'px' => [
                        'min'  => -1000,
                        'max'  => 1000,
                        'step' => 5,
                    ],
                    '%'  => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => '%',
                    'size' => -50,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .nav-2.dl-slider-button-prev, {{WRAPPER}} .nav-2.dl-slider-button-next' => 'transform: translateY({{SIZE}}{{UNIT}});',
                ],
                'condition'  => [
                    'slider_nav' => 'yes',
                    'nav_layout' => '2',
                ],
            ]
        );

        $this->add_responsive_control(
            'nav_left_right_pos',
            [
                'label'      => esc_html__( 'Left Right Position', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'range'      => [
                    'px' => [
                        'min'  => -1000,
                        'max'  => 1000,
                        'step' => 5,
                    ],
                    '%'  => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .nav-2.dl-slider-button-prev'                         => 'left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .nav-2.dl-slider-button-next'                         => 'left: auto; right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .hover-on-visible:hover .nav-2.dl-slider-button-prev' => 'left: calc({{SIZE}}{{UNIT}} + 5px);',
                    '{{WRAPPER}} .hover-on-visible:hover .nav-2.dl-slider-button-next' => 'left: auto; right: calc({{SIZE}}{{UNIT}} + 5px);',
                ],
                'condition'  => [
                    'slider_nav' => 'yes',
                    'nav_layout' => '2',
                ],
            ]
        );

        $this->start_controls_tabs( 'nav_style_tabs' );

        $this->start_controls_tab(
            'nav_style_normal_tab',
            [
                'label'     => esc_html__( 'Normal', 'redias-core' ),
                'condition' => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'      => 'nav_normal_bg',
                'label'     => esc_html__( 'Background', 'redias-core' ),
                'types'     => ['classic', 'gradient'],
                'selector'  => '{{WRAPPER}} .dl-slider-button-prev, {{WRAPPER}} .dl-slider-button-next',
                'condition' => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'nav_normal_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-slider-button-prev, {{WRAPPER}} .dl-slider-button-next' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'      => 'nav_normal_border',
                'label'     => esc_html__( 'Border', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-slider-button-prev, {{WRAPPER}} .dl-slider-button-next',
                'condition' => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'      => 'nav_normal_box_shadow',
                'selector'  => '{{WRAPPER}} .dl-slider-button-prev, {{WRAPPER}} .dl-slider-button-next',
                'condition' => [
                    'carouse_nav' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'nav_normal_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-slider-button-prev, {{WRAPPER}} .dl-slider-button-next' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'nav_style_hover_tab',
            [
                'label'     => esc_html__( 'Hover', 'redias-core' ),
                'condition' => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'      => 'nav_hover_bg',
                'label'     => esc_html__( 'Background', 'redias-core' ),
                'types'     => ['classic', 'gradient'],
                'selector'  => '{{WRAPPER}} .dl-slider-button-prev:hover, {{WRAPPER}} .dl-slider-button-next:hover',
                'condition' => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'nav_hover_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-slider-button-prev:hover, {{WRAPPER}} .dl-slider-button-next:hover' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'      => 'nav_hover_border',
                'label'     => esc_html__( 'Border', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-slider-button-prev:hover, {{WRAPPER}} .dl-slider-button-next:hover',
                'condition' => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'      => 'nav_hover_box_shadow',
                'selector'  => '{{WRAPPER}} .dl-slider-button-prev:hover, {{WRAPPER}} .dl-slider-button-next:hover',
                'condition' => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'nav_hover_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-slider-button-prev:hover, {{WRAPPER}} .dl-slider-button-next:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

    }

    /**
     * Style Carousel Pagination
     *
     * @return void
     */
    protected function style_pagination() {

        $this->start_controls_section(
            'section_carousel_pagination_style',
            [
                'label'     => esc_html__( 'Pagination ( Bullets )', 'redias-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'slider_pagination' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'pagi_style',
            [
                'label'     => esc_html__( 'Style', 'redias-core' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => '7',
                'options'   => [
                    '1' => esc_html__( 'Dots Circle', 'redias-core' ),
                    '2' => esc_html__( 'Dots', 'redias-core' ),
                    '3' => esc_html__( 'Dots Stroke', 'redias-core' ),
                    '7' => esc_html__( 'Dots Square', 'redias-core' ),
                    '4' => esc_html__( 'Numbers', 'redias-core' ),
                    '5' => esc_html__( 'Lines', 'redias-core' ),
                    '6' => esc_html__( 'Fraction', 'redias-core' ),
                    
                ],
                'condition' => [
                    'slider_pagination' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'bullet_space_between_item',
            [
                'label'      => esc_html__( 'Space Between Item', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-swiper-pagination'                                               => 'column-gap: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-4 .swiper-pagination-bullet-active' => 'column-gap: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'slider_pagination' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'dots_size',
            [
                'label'      => esc_html__( 'Dots Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 150,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-swiper-pagination .swiper-pagination-bullet'              => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-2 .swiper-pagination-bullet' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'slider_pagination' => 'yes',
                    'pagi_style!'       => ['4', '5', '6'],
                ],
            ]
        );

        $this->add_responsive_control(
            'number_line_width',
            [
                'label'      => esc_html__( 'Line Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 150,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-4 .swiper-pagination-bullet-active' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-5 .swiper-pagination-bullet'        => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'slider_pagination' => 'yes',
                    'pagi_style'        => ['4', '5'],
                ],
            ]
        );

        $this->add_responsive_control(
            'number_line_height',
            [
                'label'      => esc_html__( 'Line Height', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 150,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-4 .swiper-pagination-bullet-active .line' => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-5 .swiper-pagination-bullet'              => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'slider_pagination' => 'yes',
                    'pagi_style'        => ['4', '5'],
                ],
            ]
        );

        $this->add_responsive_control(
            'dots_active_size',
            [
                'label'      => esc_html__( 'Dot Active Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 150,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-2 .swiper-pagination-bullet-active' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'slider_pagination' => 'yes',
                    'pagi_style'        => '2',
                ],
            ]
        );

        $this->start_controls_tabs( 'bullet_style_tabs' );

        $this->start_controls_tab(
            'bullet_style_normal_tab',
            [
                'label'     => esc_html__( 'Normal', 'redias-core' ),
                'condition' => [
                    'slider_pagination' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'number_pagi_typography',
                'label'     => esc_html__( 'Typography', 'redias-core' ),
                'selector'  => '{{WRAPPER}} .dl-swiper-pagination.pagi-style-4 .swiper-pagination-bullet .number, {{WRAPPER}} .pagi-style-6.swiper-pagination-fraction',
                'condition' => [
                    'slider_pagination' => 'yes',
                    'pagi_style'        => ['4', '6'],
                ],
            ]
        );

        $this->add_control(
            'bullet_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-swiper-pagination .swiper-pagination-bullet .solid-fill'                                                                                        => 'fill: {{VALUE}}',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-2 .swiper-pagination-bullet, {{WRAPPER}} .dl-swiper-pagination.pagi-style-7 .swiper-pagination-bullet'                                                                                       => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-3 .swiper-pagination-bullet:before'                                                                                => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-4 .swiper-pagination-bullet .number'                                                                               => 'color: {{VALUE}}',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-5 .swiper-pagination-bullet:before'                                                                                => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .pagi-style-6.swiper-pagination-fraction .swiper-pagination-current, {{WRAPPER}} .pagi-style-6.swiper-pagination-fraction .swiper-pagination-total' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'slider_pagination' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'fraction_sep_color',
            [
                'label'     => esc_html__( 'Separator Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagi-style-6.swiper-pagination-fraction' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'slider_pagination' => 'yes',
                    'pagi_style'        => '6',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'bullet_style_active_tab',
            [
                'label'     => esc_html__( 'Active', 'redias-core' ),
                'condition' => [
                    'slider_pagination' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'bullet_circle_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-swiper-pagination .swiper-pagination-bullet-active .solid-fill'         => 'fill: {{VALUE}}',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-2 .swiper-pagination-bullet-active, {{WRAPPER}} .dl-swiper-pagination.pagi-style-7 .swiper-pagination-bullet-active'        => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-3 .swiper-pagination-bullet-active:before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-4 .swiper-pagination-bullet-active .line'  => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-5 .swiper-pagination-bullet-active:after'  => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .pagi-style-6.swiper-pagination-fraction .swiper-pagination-current'        => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'slider_pagination' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'dots_square_shadow_color',
            [
                'label' => esc_html__( 'Shadow Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-7 .swiper-pagination-bullet' => '--redias-shadow-color: {{VALUE}}',
                ],
                'condition' => [
                    'slider_pagination' => 'yes',
                    'pagi_style' => '7'
                ]
            ]
        );

        $this->add_control(
            'fraction_text_stroke',
            [
                'label'        => esc_html__( 'Text Stroke', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'condition' => [
                    'slider_pagination' => 'yes',
                    'pagi_style' => '6'
                ],
            ]
        );

        $this->add_control(
            'popover_fraction_text_stroke',
            [
                'label'        => esc_html__( 'Stroke Options', 'redias-core' ),
                'type'         => Controls_Manager::POPOVER_TOGGLE,
                'label_off'    => esc_html__( 'Default', 'redias-core' ),
                'label_on'     => esc_html__( 'Custom', 'redias-core' ),
                'return_value' => 'yes',
                'condition'    => [
                    'slider_pagination' => 'yes',
                    'pagi_style' => '6',
                    'fraction_text_stroke' => 'yes'
                ],
            ]
        );

        $this->start_popover();

        $this->add_responsive_control(
            'fraction_text_stroke_width',
            [
                'label'      => esc_html__( 'Stroke Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 50,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .pagi-style-6.swiper-pagination-fraction .swiper-pagination-current' => '-webkit-text-stroke-width: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'slider_pagination' => 'yes',
                    'pagi_style' => '6',
                    'fraction_text_stroke' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'fraction_text_stroke_color',
            [
                'label'     => esc_html__( 'Stroke Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagi-style-6.swiper-pagination-fraction .swiper-pagination-current' => '-webkit-text-stroke-color: {{VALUE}}',
                ],
                'condition' => [
                    'slider_pagination' => 'yes',
                    'pagi_style' => '6',
                    'fraction_text_stroke' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'fraction_text_fill_color',
            [
                'label'     => esc_html__( 'Fill Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pagi-style-6.swiper-pagination-fraction .swiper-pagination-current' => '-webkit-text-fill-color: {{VALUE}}',
                ],
                'condition' => [
                    'slider_pagination' => 'yes',
                    'pagi_style' => '6',
                    'fraction_text_stroke' => 'yes'
                ],
            ]
        );

        $this->end_popover();

        $this->add_control(
            'bullet_stroke_color',
            [
                'label'     => esc_html__( 'Stroke Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-swiper-pagination .swiper-pagination-bullet-active .path' => 'stroke: {{VALUE}}',
                ],
                'condition' => [
                    'slider_pagination' => 'yes',
                    'pagi_style'        => ['1', '3'],
                ],
            ]
        );

        $this->add_responsive_control(
            'bullet_stroke_width',
            [
                'label'      => esc_html__( 'Stroke Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'range'      => [
                    'px' => [
                        'min'  => 1,
                        'max'  => 10,
                        'step' => 1,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-swiper-pagination .swiper-pagination-bullet .path'               => 'stroke-width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-swiper-pagination.pagi-style-3 .swiper-pagination-bullet-active' => 'box-shadow: 0 0 0 {{SIZE}}{{UNIT}} {{bullet_stroke_color.VALUE}};',
                ],
                'condition'  => [
                    'slider_pagination' => 'yes',
                    'pagi_style'        => ['1', '3'],
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

    }

    protected function render() {
		$settings = $this->get_settings_for_display();
		$slider_items = $settings['slide_items'];
		$pagiStyle = $settings['pagi_style'];
		$data = [
			'autoplay' => 'yes' === $settings['autoplay'] ? true : false,
			'autoplaySpeed' => ! empty( $settings['autoplay_speed']['size'] ) ? $settings['autoplay_speed']['size'] : 5000,
			'speed' => ! empty( $settings['anim_speed'] ) ? $settings['anim_speed'] : 1000,
			'direction' => ! empty( $settings['slide_dir'] ) ? $settings['slide_dir'] : 'horizontal',
			'effect' => ! empty( $settings['slide_effect'] ) ? $settings['slide_effect'] : 'fade',
			'initialSlide' => ! empty( $settings['initial_slide'] ) ? ( $settings['initial_slide'] - 1 ) : 0,
			'grabCursor'=> 'yes' === $settings['grabcursor'] ? true : false,
			'loop'=> 'yes' === $settings['infinite_loop'] ? true : false,
			'pauseOnHover'=> 'yes' === $settings['pause_on_hover'] ? true : false,
			'parallax'=> 'yes' === $settings['parallax'] ? true : false,
			'mousewheel'=> 'yes' === $settings['mousewheel'] ? true : false,
			'navigation' => $settings['slider_nav'],
			'pagination' => $settings['slider_pagination'],
			'pagiStyle' => 'style-' . $pagiStyle
		];

		$nav_visibility = '';
		$nav_mobile_view = '';
		if( 'yes' === $settings['slider_nav'] && '2' === $settings['nav_layout'] ) {
			$nav_visibility = 'hover-on-visible' === $settings['nav_visibility'] ? $settings['nav_visibility'] : '';
		}
		if( 'yes' === $settings['slider_nav'] && 'yes' === $settings['nav_hide_mobile'] ) {
			$nav_mobile_view = 'mobile-none';
		}

		$this->add_render_attribute(
			'slider_wrapper',
			[
				'class' => [ 'dl-slider', 'swiper-container', $settings['fullscreen'], $nav_visibility, $nav_mobile_view ],
				'dir' => is_rtl() ? 'rtl' : $settings['text_direction'],
				'data-settings' => wp_json_encode( $data ),
			]
		);
		if( $slider_items ) {
		?>
		<div <?php echo $this->get_render_attribute_string( 'slider_wrapper' ); ?>>
			<div class="swiper-wrapper">
				<?php foreach( $slider_items as $slide ) : ?>
				<div class="swiper-slide elementor-repeater-item-<?php echo esc_attr( $slide['_id'] ) ; ?>">
					<?php 
					SliderHelper::get_slider_image( $settings, $slide );
					SliderHelper::get_slider_shapes( $settings );
					if( 'yes' === $slide['slide_overlay'] ) {
						echo '<div class="overlay"></div>';
					}
					?>
					<div class="slider-content-wrap text-<?php echo esc_attr($slide['content_align']); ?>">
						<div class="content-width">
							<div class="slider-content">
								<?php
								SliderHelper::get_sub_heading( $slide );
								SliderHelper::get_heading( $slide );
								SliderHelper::get_description( $slide );
								$text_masking = 'yes' === $slide['text_masking'] ? ' text-masking' : '';
								?>
								<div class="dl-btn-group<?php echo esc_attr( $text_masking ); ?>">
									<?php 
									SliderHelper::get_btn( $slide );
									SliderHelper::get_secondary_btn( $slide );
									SliderHelper::get_play_btn( $slide ); 
									?>
								</div>
							</div>
						</div>
					</div>
				</div>
				<?php endforeach; ?>
			</div>
			<?php
			SliderHelper::get_slider_controls( $settings );
			?>
			<div class="slider-preloader"><div class="dot-flashing"></div></div>
		</div>
		<?php
		}else{
			esc_html_e( 'No slides careated. Please create the slides from the Slides section.', 'redias-core' );
		}
	}

}