<?php
/**
 * Sponsor Grid
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\SponsorCarousel;

use RediasCore\Traits\CarouselControls;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Repeater;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Widget_Base;
use Elementor\Icons_Manager;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    use CarouselControls;

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-sponsor-carousel';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Sponsor Carousel', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-carousel';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'logo', 'sponsor', 'logo caroseul', 'sponsor carousel', 'redias' ];
    }

    public function get_style_depends() {
        return [ 'redias-sponsor-carousel', 'slick', 'elementor-icons-line-awesome-icons' ];
    }

    public function get_script_depends() {
        return [ 'slick', 'redias-el-script' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_general();
        $this->section_items();
        $this->section_controls();
        $this->style_pagination();

    }

    /**
	 * General Controls
	 *
	 * @return void
	 */
	protected function section_general() {
		$this->start_controls_section(
			'section_general',
			[
				'label' => esc_html__( 'General', 'redias-core' )
			]
		);

		$this->add_control(
            'sponsor_style',
            [
                'label'   => esc_html__( 'Style', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'style-1',
                'options' => [
                    'style-1' => esc_html__( 'Style 1', 'redias-core' ),
                    'style-2' => esc_html__( 'Style 2', 'redias-core' ),
                    'style-3' => esc_html__( 'Style 3', 'redias-core' ),
                    'style-4' => esc_html__( 'Style 4', 'redias-core' ),
                    'style-5' => esc_html__( 'Style 5', 'redias-core' ),
                ],
            ]
        );

        $this->add_control(
            'sponsor_bg',
            [
                'label' => esc_html__( 'Background Color', 'textdomain' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-sponsor-item' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sponsor_radius',
            [
                'label' => esc_html__( 'Border Radius', 'textdomain' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .dl-sponsor-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'spnsor_box_shadow',
                'selector' => '{{WRAPPER}} .dl-sponsor-item',
            ]
        );

        $this->add_responsive_control(
            'sponsor_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-sponsor-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .dl-sponsor-item .dl-sponsor-img-hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sponsor_carousel_width',
            [
                'label'                => esc_html__( 'Carousel View', 'redias-core' ),
                'type'                 => Controls_Manager::CHOOSE,
                'options'              => [
                    'full'  => [
                        'title' => esc_html__( 'Full', 'redias-core' ),
                        'icon'  => 'eicon-slider-full-screen',
                    ],
                    'boxed' => [
                        'title' => esc_html__( 'Boxed', 'redias-core' ),
                        'icon'  => 'eicon-slider-push',
                    ],
                ],
                'toggle'               => false,
                'selectors_dictionary' => [
                    'full'  => 'overflow: inherit',
                    'boxed' => 'overflow-x: hidden',
                ],
                'default'              => 'boxed',
                'selectors'            => [
                    '{{WRAPPER}} .dl-sponsor-carousel' => '{{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

	}

    /**
     * Sponsor Items
     *
     * @return void
     */
    protected function section_items() {

        $this->start_controls_section(
            'section_sponsor_items',
            [
                'label' => esc_html__( 'Sponsor Items', 'redias-core' ),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'image',
            [
                'label'   => esc_html__( 'Choose Image', 'redias-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'link',
            [
                'label'         => esc_html__( 'Link', 'redias-core' ),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '',
                    'is_external' => true,
                    'nofollow'    => true,
                ],
            ]
        );

        $this->add_control(
            'sponsor_items',
            [
                'label'   => esc_html__( 'Sponsor Items', 'redias-core' ),
                'type'    => Controls_Manager::REPEATER,
                'fields'  => $repeater->get_controls(),
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                ],
            ]
        );

		$this->end_controls_section();

    }

    /**
	 * Carousel Controls
	 *
	 * @return void
	 */
	protected function section_controls() {

		$this->start_controls_section(
			'section_carousel_settings',
			[
				'label' => esc_html__( 'Carousel Settings', 'redias-core' )
			]
		);

        $this->add_control(
			'carousel',
			[
				'label' => esc_html__( 'Carousel', 'redias-core' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'yes',
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$slides_per_show = range( 1, 10 );
		$slides_per_show = array_combine( $slides_per_show, $slides_per_show );

		$this->add_responsive_control(
			'slides_per_show',
			[
				'label' => esc_html__( 'Slides to Show', 'elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 6,
				'tablet_default' => 3,
				'mobile_default' => 2,
				'options' => $slides_per_show,
				'frontend_available' => true,
				'render_type' => 'ui',
			]
		);

		$this->add_responsive_control(
			'slides_per_scroll',
			[
				'label' => esc_html__( 'Slides to Scroll', 'elementor' ),
				'type' => Controls_Manager::SELECT,
				'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'elementor' ),
				'default' => 3,
				'tablet_default' => 2,
				'mobile_default' => 1,
				'options' => $slides_per_show,
				'condition' => [
					'slides_per_show!' => '1'
				],
				'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

        $this->add_responsive_control(
			'spaceBetween',
			[
				'label'      => esc_html__( 'Space Between', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px', 'em'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 150,
						'step' => 1
					],
					'em'  => [
						'min' => 0,
						'max' => 100
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .slick-list' => 'margin: 0 -{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .slick-slide' => 'margin: 0 {{SIZE}}{{UNIT}};'
				],
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'        => esc_html__( 'Autoplay', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'autoplay_speed',
			[
				'label'   => esc_html__( 'Autoplay Speed', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 500,
				'max'     => 20000,
				'step'    => 5,
				'default' => 5000,
				'condition' => [
					'autoplay' => 'yes'
                ],
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'pause_on_hover',
			[
				'label'        => esc_html__( 'Pause on Hover', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'condition' => [
					'autoplay' => 'yes'
				],
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'infinite_loop',
			[
				'label'        => esc_html__( 'Infinite Loop', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'anim_speed',
			[
				'label'   => esc_html__( 'Animation Speed', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 100,
				'max'     => 3000,
				'step'    => 5,
				'default' => 500,
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

        $this->add_control(
			'center_mode',
			[
				'label'        => esc_html__( 'Center Mode', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'no',
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

        $this->add_responsive_control(
			'center_padding',
			[
				'label'   => esc_html__( 'Center Padding', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 0,
				'max'     => 200,
				'step'    => 1,
				'default' => 50,
				'tablet_default' => 30,
				'mobile_default' => 10,
                'frontend_available' => true,
				'render_type' => 'ui',
                'condition' => [
					'center_mode' => 'yes'
				],
			]
		);

		$this->add_control(
			'navigation',
			[
				'label' => esc_html__( 'Navigation', 'redias-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'None', 'redias-core' ),
					'arrow' => esc_html__( 'Arrow', 'redias-core' ),
					'dots' => esc_html__( 'Dots', 'redias-core' ),
					'both' => esc_html__( 'Arrow & Dots', 'redias-core' ),
				],
				'default' => 'none',
				'frontend_available' => true,
				'style_transfer' => true
			]
		);

        $this->add_control(
			'arrow_prev_icon',
			[
				'label' => esc_html__( 'Previous Icon', 'redias-core' ),
				'label_block' => false,
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-long-arrow-alt-left',
					'library' => 'elementor-icons-line-awesome-icons',
				],
				'condition' => [
					'navigation' => ['arrow', 'both']
				],
			]
		);

		$this->add_control(
			'arrow_next_icon',
			[
				'label' => esc_html__( 'Next Icon', 'redias-core' ),
				'label_block' => false,
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-long-arrow-alt-right',
					'library' => 'elementor-icons-line-awesome-icons',
				],
				'condition' => [
					'navigation' => ['arrow', 'both']
				],
			]
		);

		$this->end_controls_section();

	}

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

		$settings = $this->get_settings_for_display();

        $sponsor_items = $settings['sponsor_items'];

        $nav_mobile = 'yes' === $settings['dots_hide_mobile'] ? ' dots-none' : '';

		$this->add_render_attribute(
			'carousel_wrapper',
			[ 
				'class' => [ 'dl-carousel', $settings['sponsor_style'] ],
			]
		);

        if ( ! empty( $sponsor_items ) ) : ?>
        <div <?php echo $this->get_render_attribute_string( 'carousel_wrapper' ); ?>>
                <?php foreach ( $sponsor_items as $sponsor_item ):
                    $target   = $sponsor_item['link']['is_external'] ? ' target="_blank"' : '';
                    $nofollow = $sponsor_item['link']['nofollow'] ? ' rel="nofollow"' : ''; 
                    if( ! empty( $sponsor_item['image']['url'] ) ) :
                    ?>
                    <div class="slick-slide">
                        <div class="dl-sponsor-item">
                            <?php if ( '' != $sponsor_item['link']['url'] ) {
                                echo '<a href="' . esc_url( $sponsor_item['link']['url'] ) . '" ' . $target . ' ' . $nofollow . '>';
                            } ?>
                        <?php if ( 'style-4' === $settings['sponsor_style'] ): ?>
                            <div class="dl-sponsor-img-hover">
                                <img src="<?php echo esc_url( $sponsor_item['image']['url'] ); ?>" alt="<?php echo esc_attr( get_the_title( $sponsor_item['image']['id'] ) ); ?>">
                            </div>
                            <div class="dl-sponsor-img">
                                <img src="<?php echo esc_url( $sponsor_item['image']['url'] ); ?>" alt="<?php echo esc_attr( get_the_title( $sponsor_item['image']['id'] ) ); ?>">
                            </div>
                        <?php else: ?>
                        <img src="<?php echo esc_url( $sponsor_item['image']['url'] ); ?>" alt="<?php echo esc_attr( get_the_title( $sponsor_item['image']['id'] ) ); ?>">
                    <?php endif;?>
                    <?php if ( '' != $sponsor_item['link']['url'] ) {
                        echo '</a>';
                    }?>
                        </div>
                    </div>
                <?php 
                endif;
                endforeach;?>
            <?php
				echo '<div class="carousel-preloader"><div class="dot-flashing"></div></div>';
            ?>
        </div>
        <?php if( 'dots' === $settings['navigation'] ) : ?>
        <div class="dl-carousel-dots<?php echo esc_attr( $nav_mobile ); ?>"></div>
        <?php endif; ?>
        <div class="dl-carousel-nav"></div>
        <?php if ( ! empty( $settings['arrow_prev_icon']['value'] ) ) : ?>
			<button type="button" class="slick-prev nav-hidden"><?php Icons_Manager::render_icon( $settings['arrow_prev_icon'], ['aria-hidden' => 'true'] ); ?></button>
		<?php endif; ?>

		<?php if ( ! empty( $settings['arrow_next_icon']['value'] ) ) : ?>
			<button type="button" class="slick-next nav-hidden"><?php Icons_Manager::render_icon( $settings['arrow_next_icon'], ['aria-hidden' => 'true'] ); ?></button>
		<?php endif; ?>
        <?php
        endif;

    }

}