<?php
/**
 * Team
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Team;

use RediasCore\Classes\Helper;
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Icons_Manager;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-team';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Team', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-person';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'team', 'member', 'person', 'redias' ];
    }

    public function get_style_depends() {
        return [ 'redias-team', 'elementor-icons-fa-brands' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->content_section();
        $this->content_box_style();
        $this->name_style();
        $this->position_style();
        $this->social_links_style();
        
    }

    /**
     * Content section
     *
     * @return void
     */
    protected function content_section() {

        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__( 'Team Content', 'redias-core' )
            ]
        );

        $this->add_control(
            'box_radius',
            [
                'label'      => esc_html__('Image Radius', 'text_domain'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .team-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'team_img',
            [
                'label'   => esc_html__( 'Team Image', 'redias-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'name',
            [
                'label'       => esc_html__( 'Name', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Félix Lengyel', 'redias-core' ),
                'placeholder' => esc_html__( 'Name...', 'redias-core' ),
                'label_block' => true
            ]
        );

        $this->add_control(
            'position',
            [
                'label'       => esc_html__( 'Position', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'CEO/Founder', 'redias-core' ),
                'placeholder' => esc_html__( 'Position...', 'redias-core' ),
                'label_block' => true
            ]
        );

        $repeater = new Repeater();
        
        $repeater->add_control(
            'icon',
            [
                'label'   => esc_html__( 'Icon', 'redias-core' ),
                'type'    => Controls_Manager::ICONS,
                'default' => [
                    'value'   => 'fas fa-star',
                    'library' => 'solid',
                ],
            ]
        );

        $repeater->add_control(
            'link',
            [
                'label'       => __( 'Link', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '',
                'placeholder' => esc_html__( 'Link goes here', 'redias-core' ),
                'label_block' => true
            ]
        );

        $repeater->add_control(
            'custom_social_color',
            [
                'label'        => esc_html__( 'Custom Colors', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'return_value' => 'yes',
                'default'      => 'no',
                'separator'    => 'before',
            ]
        );

        $repeater->add_control(
            'social_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-content .team-social {{CURRENT_ITEM}} a' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'custom_social_color' => 'yes',
                ],
                'separator' => 'before',
            ]
        );

        $repeater->add_control(
            'social_icon_hover_color',
            [
                'label'     => esc_html__( 'Hover Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-content .team-social {{CURRENT_ITEM}} a:hover' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'custom_social_color' => 'yes',
                ],
                'separator' => 'before',
            ]
        );
        
        $this->add_control(
            'social_links',
            [
                'label'       => esc_html__( 'Social Links', 'redias-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'icon'   => [
                            'value'   => 'fab fa-facebook',
                            'library' => 'brands',
                        ],
                        'link' => '#'
                    ],
                    [
                        'icon'   => [
                            'value'   => 'fab fa-twitter',
                            'library' => 'brands',
                        ],
                        'link' => '#'
                    ],
                    [
                        'icon'   => [
                            'value'   => 'fab fa-pinterest',
                            'library' => 'brands',
                        ],
                        'link' => '#'
                    ],
                    [
                        'icon'   => [
                            'value'   => 'fab fa-linkedin',
                            'library' => 'brands',
                        ],
                        'link' => '#'
                    ],
                ],
                'title_field' => '{{{ elementor.helpers.renderIcon( this, icon, {}, "i", "panel" ) }}}',
            ]
        );

        $this->add_control(
            'team_link',
            [
                'label'         => esc_html__( 'Link', 'redias-core' ),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '',
                    'is_external' => true,
                    'nofollow'    => true,
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Content Box Style
     *
     * @return void
     */
    protected function content_box_style() {

        $this->start_controls_section(
            'content_box_style',
            [
                'label' => esc_html__( 'Content Box', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'content_box_bg',
                'label'   => esc_html__('Background', 'Text-domain'),
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .team-wrap .team-content',
            ]
        );

        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'content_box_border',
				'label'    => esc_html__( 'Border', 'redias-core' ),
				'selector' => '{{WRAPPER}} .team-wrap .team-content',
			]
		);

        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'content_box_shadow',
				'selector' => '{{WRAPPER}} .team-wrap .team-content',
			]
		);

		$this->add_responsive_control(
			'box_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .team-wrap .team-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

        $this->add_responsive_control(
			'content_box_padding',
			[
				'label'      => esc_html__( 'Padding', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .team-wrap .team-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .team-wrap:hover .team-social' => 'bottom: {{BOTTOM}}{{UNIT}};',
				],
			]
		);

        $this->add_responsive_control(
			'content_box_margin',
			[
				'label'      => esc_html__( 'Margin', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .team-wrap .team-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
        
        $this->end_controls_section();

    }

    /**
     * Name Style
     *
     * @return void
     */
    protected function name_style() {

        $this->start_controls_section(
            'name_style',
            [
                'label' => esc_html__( 'Name', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'name_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .team-wrap .team-content h3',
            ]
        );

        $this->add_control(
            'name_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-wrap .team-content h3' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .team-wrap .team-content h3 a' => 'color: {{VALUE}}'
                ],
            ]
        );

        $this->add_control(
            'name_hover_color',
            [
                'label'     => esc_html__( 'Hover Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-wrap .team-content h3 a:hover' => 'color: {{VALUE}}'
                ],
                'condition' => [
                    'team_link[url]!' => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'name_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .team-wrap .team-content h3',
            ]
        );

        $this->add_responsive_control(
            'name_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .team-wrap .team-content h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Position Style
     *
     * @return void
     */
    protected function position_style() {

        $this->start_controls_section(
            'position_style',
            [
                'label' => esc_html__( 'Position', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'position_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .team-wrap .team-content h4',
            ]
        );

        $this->add_control(
            'position_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-wrap .team-content h4' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'position_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .team-wrap .team-content h4' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Social Links Style
     *
     * @return void
     */
    protected function social_links_style() {

        $this->start_controls_section(
            'social_links_style',
            [
                'label' => esc_html__( 'Social Links', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'social_wrap_bg',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-content .team-social' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'social_wrap_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .team-content .team-social' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'social_wrap_radius',
            [
                'label'      => esc_html__('Border Radius', 'text_domain'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .team-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs( 'social_icons_style_tabs' );
        
        $this->start_controls_tab(
            'social_style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
            ]
        );

        $this->add_control(
            'social_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-content .team-social li a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'social_icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 5,
                        'max'  => 50,
                        'step' => 1
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .team-content .team-social li' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'social_icons_space_between',
            [
                'label'      => esc_html__( 'Icon Space Between', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 100,
                        'step' => 1,
                    ]
                ],
                'selectors'  => [
                    '{{WRAPPER}} .team-content .team-social li' => 'margin: 0 {{SIZE}}{{UNIT}};',
                ]
            ]
        );

        $this->end_controls_tab();
        
        $this->start_controls_tab(
            'social_style_hover_tab',
            [
                'label' => __( 'Hover', 'redias-core' ),
            ]
        );

        $this->add_control(
            'social_icon_hover_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .team-content .team-social li a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        $social_links = $settings['social_links'];

        $this->add_render_attribute(
			'wrapper', [ 'class' => [ 'team-wrap' ] ]
		);

        $this->add_inline_editing_attributes( 'name', 'none' );
        $this->add_inline_editing_attributes( 'position', 'none' );
        ?>
        <div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
        <?php if( ! empty( $settings['team_img']['url'] ) ) : ?>
            <img src="<?php echo esc_url( $settings['team_img']['url'] ); ?>" alt="<?php echo esc_attr( $settings['name'] ); ?>">
            <div class="team-content">
                <?php
                    if( ! empty( $settings['name'] ) ) {
                        if ( ! empty( $settings['team_link']['url'] ) ) {
                            if( Helper::is_el_edit_mode() ) {
                                echo '<h3><a '. $this->get_render_attribute_string( 'team_link' ) .'><span '. $this->get_render_attribute_string( 'name' ) .'>'. Helper::kses_basic( $settings['name'] ) .'</span></a></h3>';
                            }else{
                                echo '<h3 '. $this->get_render_attribute_string( 'name' ) .'><a '. $this->get_render_attribute_string( 'team_link' ) .'>'. Helper::kses_basic( $settings['name'] ) .'</a></h3>';
                            }
                        }else{
                            echo '<h3 '. $this->get_render_attribute_string( 'name' ) .'>'. Helper::kses_basic( $settings['name'] ) .'</h3>';
                        }
                    }
                    if( ! empty( $settings['position'] ) ) {
                        echo '<h4 '. $this->get_render_attribute_string( 'position' ) .'>'. Helper::kses_basic( $settings['position'] ) .'</h4>';
                    }
                ?>
                <?php if( $social_links > 0 ) : ?>
                <ul class="team-social">
                    <?php 
                    foreach( $social_links as $index => $social_link ) : ?>
                    <?php if( ! empty( $social_link['link'] ) ) : ?>
                        <li class="elementor-repeater-item-<?php echo $social_link['_id']; ?>"><a href="<?php echo esc_url( $social_link['link'] ); ?>" target="_blank"><?php Icons_Manager::render_icon( $social_link['icon'], [ 'aria-hidden' => 'true' ] ); ?></a></li>
                    <?php endif; ?>
                    <?php endforeach; ?>
                </ul>
                <?php endif; ?>
            </div>
        <?php endif; ?>
        </div>
        <?php
    }

    protected function content_template(){}

}