<?php
/**
 * Carousel Controls
 *
 * @package RediasCore
 */
namespace RediasCore\Traits;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;

defined( 'ABSPATH' ) || die();

trait CarouselControls{

	/**
	 * Style Carousel Navigation
	 *
	 * @return void
	 */
	protected function style_navigation( $condition_key = 'carousel' ) {

		$this->start_controls_section(
			'section_carousel_navigation_style',
			[
				'label' => esc_html__( 'Navigation', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);

		$this->add_control(
			'nav_hide_mobile',
			[
				'label'        => esc_html__( 'Hide on Mobile/Tablet', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);

		$this->add_control(
			'nav_style',
			[
				'label'   => esc_html__( 'Style', 'textdomain' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'centered',
				'options' => [
					'centered'  => esc_html__( 'Centered', 'textdomain' ),
					'top-right' => esc_html__( 'Top Right', 'textdomain' ),
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);

		$this->add_responsive_control(
			'nav_spacebetween',
			[
				'label'      => esc_html__( 'Space Between', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px', 'em'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 50,
						'step' => 1,
					],
					'em'  => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .dl-carousel-nav.nav-top-right' => 'column-gap: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both'],
					'nav_style' => 'top-right'
				]
			]
		);

		$this->add_responsive_control(
			'nav_width',
			[
				'label'      => esc_html__( 'Width', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px', 'em'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 300,
						'step' => 1,
					],
					'em'  => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .dl-carousel-nav button' => 'width: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);

		$this->add_responsive_control(
			'nav_height',
			[
				'label'      => esc_html__( 'Height', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px', 'em'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 300,
						'step' => 1,
					],
					'em'  => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .dl-carousel-nav button' => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .navi-top-right .slick-slider' => 'padding-top: calc({{SIZE}}{{UNIT}} + 10px);'
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);

		$this->add_responsive_control(
			'nav_icon_size',
			[
				'label'      => esc_html__( 'Icon Size', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 200,
						'step' => 1,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .dl-carousel-nav button' => 'font-size: {{SIZE}}{{UNIT}};'
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);

		$this->add_responsive_control(
			'nav_x_position',
			[
				'label'      => esc_html__( 'X Position', 'textdomain' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px', '%'],
				'range'      => [
					'px' => [
						'min'  => -1000,
						'max'  => 1000,
						'step' => 1,
					],
					'%'  => [
						'min' => -100,
						'max' => 100,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .nav-centered.dl-carousel-nav button' => 'left: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .nav-centered.dl-carousel-nav button.slick-next' => 'left: auto; right: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .dl-carousel-nav.nav-top-right' => 'right: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);

		$this->add_responsive_control(
			'nav_y_position',
			[
				'label'      => esc_html__( 'Y Position', 'textdomain' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px', '%'],
				'range'      => [
					'px' => [
						'min'  => -100,
						'max'  => 1500,
						'step' => 1,
					],
					'%'  => [
						'min' => -100,
						'max' => 100,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .nav-centered.dl-carousel-nav button' => 'top: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .dl-carousel-nav.nav-top-right' => 'top: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);

		$this->start_controls_tabs( 'nav_style_tabs' );
		
		$this->start_controls_tab(
			'nav_style_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'redias-core' ),
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'nav_normal_bg',
				'label'    => esc_html__( 'Background', 'redias-core' ),
				'types'    => ['classic', 'gradient'],
				'selector' => '{{WRAPPER}} .dl-carousel-nav button',
				'exclude'  => ['image'],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);

		$this->add_control(
			'nav_icon_color',
			[
				'label'       => esc_html__( 'Icon Color', 'Text-domain' ),
				'type'     => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dl-carousel-nav button' => 'color: {{VALUE}}',
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);
				
		$this->end_controls_tab();
		
		$this->start_controls_tab(
			'nav_style_hover_tab',
			[
				'label' => esc_html__( 'Hover', 'redias-core' ),
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);
				
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'nav_hover_bg',
				'label'    => esc_html__( 'Background', 'redias-core' ),
				'types'    => ['classic', 'gradient'],
				'exclude'  => ['image'],
				'selector' => '{{WRAPPER}} .dl-carousel-nav button:hover',
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);

		$this->add_control(
			'nav_icon_hover_color',
			[
				'label'       => esc_html__( 'Icon Color', 'Text-domain' ),
				'type'     => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dl-carousel-nav button:hover' => 'color: {{VALUE}}',
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['arrow', 'both']
				]
			]
		);
		
		$this->end_controls_tab();
		
		$this->end_controls_tabs();

		$this->end_controls_section();

	}

	/**
	 * Style Carousel Pagination
	 *
	 * @return void
	 */
	protected function style_pagination( $condition_key = 'carousel' ) {

		$this->start_controls_section(
			'section_carousel_pagination_style',
			[
				'label' => esc_html__( 'Pagination ( Bullets )', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['dots', 'both']
				]
			]
		);

		$this->add_control(
			'dots_hide_mobile',
			[
				'label'        => esc_html__( 'Hide on Mobile/Tablet', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'no',
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['dots', 'both']
				]
			]
		);

		$this->add_responsive_control(
			'dots_top_spacing',
			[
				'label'      => esc_html__( 'Top Spacing', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 150,
						'step' => 1,
					]
				],
				'selectors'  => [
					'{{WRAPPER}} .dl-carousel-dots' => 'margin-top: {{SIZE}}{{UNIT}}; margin-bottom: 4px;',
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['dots', 'both']
				]
			]
		);

		$this->add_responsive_control(
            'dots_alignment',
            [
                'label' => esc_html__( 'Alignment', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon' => 'eicon-text-align-right',
                    ]
                ],
                'default' => 'center',
                'toggle' => false,
                'selectors_dictionary' => [
                    'left' => 'justify-content: flex-start',
                    'center' => 'justify-content: center',
                    'right' => 'justify-content: flex-end',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-carousel-dots .slick-dots' => '{{VALUE}}'
                ]
            ]
        );

		$this->add_responsive_control(
			'bullet_size',
			[
				'label'      => esc_html__( 'Size', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 150,
						'step' => 1,
					]
				],
				'selectors'  => [
					'{{WRAPPER}} .dl-carousel-dots .slick-dots li' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['dots', 'both']
				]
			]
		);

		$this->add_responsive_control(
			'dots_space_between_item',
			[
				'label'      => esc_html__( 'Space Between Item', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					]
				],
				'selectors'  => [
					'{{WRAPPER}} .dl-carousel-dots .slick-dots' => 'column-gap: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['dots', 'both']
				]
			]
		);

		$this->add_responsive_control(
            'dots_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-carousel-dots .slick-dots li span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    $condition_key => 'yes',
					'navigation' => ['dots', 'both']
                ],
            ]
        );

		$this->start_controls_tabs( 'bullet_style_tabs' );
		
		$this->start_controls_tab(
			'bullet_style_normal_tab',
			[
				'label' => __( 'Normal', 'redias-core' ),
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['dots', 'both']
				]
			]
		);
		
		$this->add_control(
			'bullet_color',
			[
				'label'     => esc_html__( 'Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dl-carousel-dots .slick-dots li span' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['dots', 'both']
				]
			]
		);
		
		$this->end_controls_tab();
		
		$this->start_controls_tab(
			'bullet_style_active_tab',
			[
				'label' => __( 'Active', 'redias-core' ),
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['dots', 'both']
				]
			]
		);
		
		$this->add_control(
			'bullet_hover_color',
			[
				'label'     => esc_html__( 'Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dl-carousel-dots .slick-dots li.slick-active span' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['dots', 'both']
				]
			]
		);

		$this->add_control(
			'bullet_border_color',
			[
				'label'     => esc_html__( 'Border Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dl-carousel-dots .slick-dots li.slick-active span' => 'box-shadow: 0px 0px 0px 3px {{VALUE}};',
				],
				'condition' => [
					$condition_key => 'yes',
					'navigation' => ['dots', 'both']
				]
			]
		);
		
		$this->end_controls_tab();
		
		$this->end_controls_tabs();

		$this->end_controls_section();

	}

}