<?php
/**
 * Lightbox
 *
 * @package RediasCore
 */
namespace RediasCore\Traits;

use Elementor\Controls_Manager;
use Elementor\Embed;

defined( 'ABSPATH' ) || die();

trait Lightbox {

    /**
     * Lightbox Options
     *
     * @return void
     */
    protected function section_lightbox() {

        $this->start_controls_section(
            'section_lightbox_settings',
            [
                'label' => esc_html__( 'Lightbox Settings', 'redias-core' ),
            ]
        );

        $this->add_control(
            'start',
            [
                'label'       => esc_html__( 'Start Time', 'redias-core' ),
                'type'        => Controls_Manager::NUMBER,
                'description' => esc_html__( 'Specify a start time (in seconds)', 'redias-core' ),
                'condition'   => [
                    'loop' => '',
                ],
            ]
        );

        $this->add_control(
            'end',
            [
                'label'       => esc_html__( 'End Time', 'redias-core' ),
                'type'        => Controls_Manager::NUMBER,
                'description' => esc_html__( 'Specify an end time (in seconds)', 'redias-core' ),
                'condition'   => [
                    'loop' => '',
                ],
            ]
        );

        $this->add_control(
            'video_options',
            [
                'label'     => esc_html__( 'Video Options', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label' => esc_html__( 'Autoplay', 'redias-core' ),
                'type'  => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'play_on_mobile',
            [
                'label'     => esc_html__( 'Play On Mobile', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'mute',
            [
                'label' => esc_html__( 'Mute', 'redias-core' ),
                'type'  => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'loop',
            [
                'label' => esc_html__( 'Loop', 'redias-core' ),
                'type'  => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'aspect_ratio',
            [
                'label'              => esc_html__( 'Aspect Ratio', 'redias-core' ),
                'type'               => Controls_Manager::SELECT,
                'options'            => [
                    '169' => '16:9',
                    '219' => '21:9',
                    '43'  => '4:3',
                    '32'  => '3:2',
                    '11'  => '1:1',
                    '916' => '9:16',
                ],
                'default'            => '169',
                'prefix_class'       => 'elementor-aspect-ratio-',
                'frontend_available' => true,
            ]
        );

        $this->add_control(
            'controls',
            [
                'label'     => esc_html__( 'Player Controls', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'label_on'  => esc_html__( 'Show', 'redias-core' ),
                'default'   => 'yes',
            ]
        );

        $this->add_control(
            'showinfo',
            [
                'label'     => esc_html__( 'Video Info', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'label_on'  => esc_html__( 'Show', 'redias-core' ),
                'default'   => 'yes',
            ]
        );

        $this->add_control(
            'modestbranding',
            [
                'label'     => esc_html__( 'Modest Branding', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'condition' => [
                    'controls' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'logo',
            [
                'label'     => esc_html__( 'Logo', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'label_on'  => esc_html__( 'Show', 'redias-core' ),
                'default'   => 'yes',
            ]
        );

        // YouTube.
        $this->add_control(
            'youtube_options',
            [
                'label'     => esc_html__( 'YouTube Options', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'yt_privacy',
            [
                'label'       => esc_html__( 'Privacy Mode', 'redias-core' ),
                'type'        => Controls_Manager::SWITCHER,
                'description' => esc_html__( 'When you turn on privacy mode, YouTube won\'t store information about visitors on your website unless they play the video.', 'redias-core' ),
            ]
        );

        $this->add_control(
            'rel',
            [
                'label'   => esc_html__( 'Suggested Videos', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    ''    => esc_html__( 'Current Video Channel', 'redias-core' ),
                    'yes' => esc_html__( 'Any Video', 'redias-core' ),
                ],
            ]
        );

        // Vimeo.
        $this->add_control(
            'vimeo_options',
            [
                'label'     => esc_html__( 'Vimeo Options', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'vimeo_title',
            [
                'label'     => esc_html__( 'Intro Title', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'label_on'  => esc_html__( 'Show', 'redias-core' ),
                'default'   => 'yes',
            ]
        );

        $this->add_control(
            'vimeo_portrait',
            [
                'label'     => esc_html__( 'Intro Portrait', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'label_on'  => esc_html__( 'Show', 'redias-core' ),
                'default'   => 'yes',
            ]
        );

        $this->add_control(
            'vimeo_byline',
            [
                'label'     => esc_html__( 'Intro Byline', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'label_on'  => esc_html__( 'Show', 'redias-core' ),
                'default'   => 'yes',
            ]
        );

        $this->add_control(
            'color',
            [
                'label'   => esc_html__( 'Controls Color', 'redias-core' ),
                'type'    => Controls_Manager::COLOR,
                'default' => '',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Lightbox Style
     *
     * @return void
     */
    protected function lightbox_style() {

        $this->start_controls_section(
            'section_lightbox_style',
            [
                'label'     => esc_html__( 'Lightbox', 'redias-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'lightbox_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '#elementor-lightbox-{{ID}}' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'lightbox_ui_color',
            [
                'label'     => esc_html__( 'UI Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '#elementor-lightbox-{{ID}} .dialog-lightbox-close-button' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'lightbox_ui_color_hover',
            [
                'label'     => esc_html__( 'UI Hover Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '#elementor-lightbox-{{ID}} .dialog-lightbox-close-button:hover' => 'color: {{VALUE}}',
                ],
                'separator' => 'after',
            ]
        );

        $this->add_control(
            'lightbox_video_width',
            [
                'label'     => esc_html__( 'Content Width', 'redias-core' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'unit' => '%',
                ],
                'range'     => [
                    '%' => [
                        'min' => 30,
                    ],
                ],
                'selectors' => [
                    '(desktop+)#elementor-lightbox-{{ID}} .elementor-video-container' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'lightbox_content_position',
            [
                'label'                => esc_html__( 'Content Position', 'redias-core' ),
                'type'                 => Controls_Manager::SELECT,
                'frontend_available'   => true,
                'options'              => [
                    ''    => esc_html__( 'Center', 'redias-core' ),
                    'top' => esc_html__( 'Top', 'redias-core' ),
                ],
                'selectors'            => [
                    '#elementor-lightbox-{{ID}} .elementor-video-container' => '{{VALUE}}; transform: translateX(-50%);',
                ],
                'selectors_dictionary' => [
                    'top' => 'top: 60px',
                ],
            ]
        );

        $this->add_responsive_control(
            'lightbox_content_animation',
            [
                'label'              => esc_html__( 'Entrance Animation', 'redias-core' ),
                'type'               => Controls_Manager::ANIMATION,
                'frontend_available' => true,
            ]
        );

        $this->end_controls_section();

    }

    /**
	 * Get embed params.
	 *
	 * Retrieve video widget embed parameters.
	 *
	 * @since 1.5.0
	 * @access public
	 *
	 * @return array Video embed parameters.
	 */
	public function get_embed_params( $video_type = 'youtube', $video_url = '' ) {
		$settings = $this->get_settings_for_display();

		$params = [];

		if ( $settings['autoplay'] ) {
			$params['autoplay'] = '1';

			if ( $settings['play_on_mobile'] ) {
				$params['playsinline'] = '1';
			}
		}

		$params_dictionary = [];

		if ( 'youtube' === $video_type ) {
			$params_dictionary = [
				'loop',
				'controls',
				'mute',
				'rel',
				'modestbranding',
			];

			if ( $settings['loop'] ) {
				$video_properties = Embed::get_video_properties( $video_url );

				$params['playlist'] = $video_properties['video_id'];
			}

			$params['start'] = $settings['start'];

			$params['end'] = $settings['end'];

			$params['wmode'] = 'opaque';
		} elseif ( 'vimeo' === $video_type ) {
			$params_dictionary = [
				'loop',
				'mute' => 'muted',
				'vimeo_title' => 'title',
				'vimeo_portrait' => 'portrait',
				'vimeo_byline' => 'byline',
			];

			$params['color'] = str_replace( '#', '', $settings['color'] );

			$params['autopause'] = '0';
		} elseif ( 'dailymotion' === $video_type ) {
			$params_dictionary = [
				'controls',
				'mute',
				'showinfo' => 'ui-start-screen-info',
				'logo' => 'ui-logo',
			];

			$params['ui-highlight'] = str_replace( '#', '', $settings['color'] );

			$params['start'] = $settings['start'];

			$params['endscreen-enable'] = '0';
		}

		foreach ( $params_dictionary as $key => $param_name ) {
			$setting_name = $param_name;

			if ( is_string( $key ) ) {
				$setting_name = $key;
			}

			$setting_value = $settings[ $setting_name ] ? '1' : '0';

			$params[ $param_name ] = $setting_value;
		}

		return $params;
	}

	/**
	 * @since 2.1.0
	 * @access private
	 */
	private function get_embed_options( $video_type = 'youtube' ) {
		$settings = $this->get_settings_for_display();

		$embed_options = [];

		if ( 'youtube' === $video_type ) {
			$embed_options['privacy'] = $settings['yt_privacy'];
		} elseif ( 'vimeo' === $video_type ) {
			$embed_options['start'] = $settings['start'];
		}

		$embed_options['lazy_load'] = ! empty( $settings['lazy_load'] );

		return $embed_options;
	}

}