<?php
/**
 * Slider Control Trait
 *
 * @package RediasCore
 */
namespace RediasCore\Traits;

use RediasCore\Classes\SliderHelper;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Elementor\Utils;

defined( 'ABSPATH' ) || die();

trait SliderControls {

    /**
     * Slider Settings
     *
     * @return void
     */
    private function section_slider_settings() {

        $this->start_controls_section(
            'section_slider_settings',
            [
                'label' => esc_html__( 'Slider Settings', 'redias-core' ),
            ]
        );

        $this->add_control(
            'fullscreen',
            [
                'label'   => esc_html__( 'Fullscreen', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'fullscreen' => esc_html__( 'Enable', 'redias-core' ),
                    'custom'     => esc_html__( 'Disable', 'redias-core' ),
                ],
                'default' => 'custom',
            ]
        );

        $this->add_responsive_control(
            'slider_height',
            [
                'label'           => esc_html__( 'Slider Height', 'redias-core' ),
                'type'            => Controls_Manager::SLIDER,
                'range'           => [
                    'px' => [
                        'min' => 0,
                        'max' => 2000,
                    ],
                ],
                'desktop_default' => [
                    'size' => 650,
                    'unit' => 'px',
                ],
                'tablet_default'  => [
                    'size' => 580,
                    'unit' => 'px',
                ],
                'mobile_default'  => [
                    'size' => 480,
                    'unit' => 'px',
                ],
                'selectors'       => [
                    '{{WRAPPER}} .dl-slider.custom .swiper-slide'        => 'min-height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-slider.custom .slider-content-wrap' => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-slider.custom.swiper-container'     => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition'       => [
                    'fullscreen' => 'custom',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_container_width',
            [
                'label'           => esc_html__( 'Content Container Width', 'redias-core' ),
                'type'            => Controls_Manager::SLIDER,
                'size_units'      => ['px', '%'],
                'range'           => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 3000,
                        'step' => 5,
                    ],
                    '%'  => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'desktop_default' => [
                    'size' => 1140,
                    'unit' => 'px',
                ],
                'tablet_default'  => [
                    'size' => 95,
                    'unit' => '%',
                ],
                'mobile_default'  => [
                    'size' => 95,
                    'unit' => '%',
                ],
                'selectors'       => [
                    '{{WRAPPER}} .content-width'      => 'max-width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-slider-controls' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'slider-content-bg',
            [
                'label' => esc_html__( 'Content Background Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#ff6a32',
                'selectors' => [
                    '{{WRAPPER}} .content-width .slider-content' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'slider-content-bg-dot',
            [
                'label' => esc_html__( 'Background Dot', 'redias-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'redias-core' ),
                'label_off' => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default' => 'yes'
            ]
        );

        $this->add_control(
            'slider-content-dot-bg',
            [
                'label' => esc_html__( 'Dot Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .content-width .slider-content:before' => 'background-color: {{VALUE}}; content: ""; width: 10px; height: 10px; position: absolute; right: 10px; bottom: 10px;',
                ],
                'condition' => [
                    'slider-content-bg-dot' => 'yes'
                ]
            ]
        );

        $this->add_responsive_control(
            'slider-text-align',
            [
                'label' => esc_html__( 'Content Alignment', 'redias-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'left',
                'prefix_class' => 'align-',
                'toggle' => false,
                'selectors' => [
                    '{{WRAPPER}} .content-width' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}}.align-right .content-width' => 'text-align: left;',
                    '.rtl {{WRAPPER}}.align-right .content-width' => 'text-align: right;',
                    '.rtl {{WRAPPER}}.align-left .content-width' => 'text-align: right;',
                    '{{WRAPPER}}.align-center .content-width .dl-btn-group' => 'justify-content: center;',
                ]
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label'              => esc_html__( 'Content Padding', 'redias-core' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => ['px', 'em'],
                'default'            => [
                    'left'  => [
                        'size' => 30,
                        'unit' => 'px',
                    ],
                    'right' => [
                        'size' => 30,
                        'unit' => 'px',
                    ],
                ],
                'selectors'          => [
                    '{{WRAPPER}} .content-width .slider-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}; display: inline-block;',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Slides Controls
     *
     * @return void
     */
    private function section_slides() {
        $this->start_controls_section(
            'section_slider_slides',
            [
                'label' => esc_html__( 'Slides', 'redias-core' ),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'text_masking',
            [
                'label'        => esc_html__( 'Text Masking', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $repeater->add_responsive_control(
            'content_align',
            [
                'label'   => esc_html__( 'Alignment', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'left',
                'toggle'  => false,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .content-width' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} {{CURRENT_ITEM}} .text-right .content-width' => 'text-align: left;',
                    '{{WRAPPER}} {{CURRENT_ITEM}} .text-center .content-width .dl-btn-group' => 'justify-content: center;'
                ]
            ]
        );

        $repeater->add_control(
            'bg_img_heading',
            [
                'label'     => esc_html__( 'Slider Background', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $repeater->add_control(
            'bg_type',
            [
                'label'   => esc_html__( 'Type', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'color'    => [
                        'title' => esc_html__( 'Color', 'redias-core' ),
                        'icon'  => 'eicon-global-colors',
                    ],
                    'image'    => [
                        'title' => esc_html__( 'Image', 'redias-core' ),
                        'icon'  => 'eicon-image',
                    ],
                    'gradient' => [
                        'title' => esc_html__( 'Gradient', 'redias-core' ),
                        'icon'  => 'eicon-barcode',
                    ],
                ],
                'default' => 'image',
                'toggle'  => false,
            ]
        );

        $repeater->add_control(
            'slide_color_bg',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .slide-img-wrap' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'bg_type' => 'color',
                ],
            ]
        );

        $repeater->add_control(
            'slide_image',
            [
                'label'     => esc_html__( 'Choose Slide Image', 'redias-core' ),
                'type'      => Controls_Manager::MEDIA,
                'default'   => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'bg_type' => 'image',
                ],
            ]
        );

        $repeater->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'        => 'slide_gradient_bg',
                'label'       => esc_html__( 'Gradient', 'redias-core' ),
                'description' => esc_html__( 'Create gradient background using this control.', 'redias-core' ),
                'types'       => ['gradient'],
                'selector'    => '{{WRAPPER}} {{CURRENT_ITEM}} .slide-img-wrap',
                'condition'   => [
                    'bg_type' => 'gradient',
                ],
            ]
        );

        $repeater->add_control(
            'kenburns_effect',
            [
                'label'     => esc_html__( 'Kenburns Effect', 'redias-core' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'none',
                'options'   => SliderHelper::get_kenburns_effects(),
                'separator' => 'before',
                'condition' => [
                    'bg_type' => 'image',
                ],
            ]
        );

        $repeater->add_control(
            'kenburns_duration',
            [
                'label'       => esc_html__( 'Kenburns Duration', 'redias-core' ),
                'description' => esc_html__( 'Duration calculate in milliseconds(ms).', 'redias-core' ),
                'type'        => Controls_Manager::NUMBER,
                'min'         => 100,
                'max'         => 30000,
                'step'        => 100,
                'default'     => 12000,
                'condition'   => [
                    'bg_type'          => 'image',
                    'kenburns_effect!' => 'none',
                ],
            ]
        );

        $repeater->add_control(
            'slide_overlay',
            [
                'label'     => esc_html__( 'Overlay', 'redias-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'separator' => 'before',
            ]
        );

        $repeater->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'      => 'slide_ov_background',
                'label'     => esc_html__( 'Background', 'redias-core' ),
                'types'     => ['classic', 'gradient'],
                'selector'  => '{{WRAPPER}} {{CURRENT_ITEM}} .overlay',
                'condition' => [
                    'slide_overlay' => 'yes',
                ],
            ]
        );

        $repeater->add_responsive_control(
            'slide_ov_opacity',
            [
                'label'      => esc_html__( 'Opacity', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 1,
                        'step' => 0.1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .overlay' => 'opacity: {{SIZE}};',
                ],
                'condition'  => [
                    'slide_overlay' => 'yes',
                ],
            ]
        );

        $repeater->add_control(
            'slider_bg_ov_blend_mode',
            [
                'label'     => esc_html__( 'Overlay Blend Mode', 'redias-core' ),
                'type'      => Controls_Manager::SELECT,
                'separator' => 'none',
                'options'   => [
                    'inherit'     => 'Normal',
                    'multiply'    => 'Multiply',
                    'screen'      => 'Screen',
                    'overlay'     => 'Overlay',
                    'darken'      => 'Darken',
                    'lighten'     => 'Lighten',
                    'color-dodge' => 'Color Dodge',
                    'saturation'  => 'Saturation',
                    'color'       => 'Color',
                    'difference'  => 'Difference',
                    'exclusion'   => 'Exclusion',
                    'hue'         => 'Hue',
                    'luminosity'  => 'Luminosity',
                ],
                'default'   => 'inherit',
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .overlay' => 'mix-blend-mode: {{VALUE}}',
                ],
                'condition' => [
                    'slide_overlay' => 'yes',
                ],
            ]
        );

        $repeater->add_control(
            'subheading_heading',
            [
                'label'     => esc_html__( 'Sub Heading', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $repeater->start_controls_tabs( 'subheading_tabs' );

        $repeater->start_controls_tab(
            'subheading_tab',
            [
                'label' => esc_html__( 'Text', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'sub_heading', [
                'label'       => '',
                'placeholder' => esc_html__( 'Sub heading goes here...', 'redias-core' ),
                'description' => esc_html__( 'Use {{Text}} format for highlighted/dual color text', 'redias-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'rows'        => 4
            ]
        );

        $repeater->end_controls_tab();

        $repeater->start_controls_tab(
            'subheading_tab_anim',
            [
                'label' => esc_html__( 'Animation', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'sh_animation',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'dlFadeIn',
                'options' => SliderHelper::get_effects(),
            ]
        );

        $repeater->add_control(
            'sh_anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'sh_animation',
                            'operator' => '!in',
                            'value'    => ['none', 'char-top', 'char-right', 'char-bottom', 'char-expand'],
                        ],
                    ],
                ],
            ]
        );

        $repeater->add_control(
            'sh_anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'sh_animation',
                            'operator' => '!in',
                            'value'    => ['none', 'char-top', 'char-right', 'char-bottom', 'char-expand'],
                        ],
                    ],
                ],
            ]
        );

        $repeater->end_controls_tab();

        $repeater->end_controls_tabs();

        $repeater->add_control(
            'heading_sec',
            [
                'label'     => esc_html__( 'Heading', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $repeater->start_controls_tabs( 'heading_tabs' );

        $repeater->start_controls_tab(
            'heading_tab',
            [
                'label' => esc_html__( 'Text', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'heading', [
                'label'       => '',
                'placeholder' => esc_html__( 'Heading goes here...', 'redias-core' ),
                'description' => esc_html__( 'Seperate the line using comma. Use {{Text}} format for highlighted/dual color text.', 'redias-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'rows'        => 4
            ]
        );

        $repeater->end_controls_tab();

        $repeater->start_controls_tab(
            'heading_tab_anim',
            [
                'label' => esc_html__( 'Animation', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'h_animation',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'dlFadeIn',
                'options' => SliderHelper::get_effects()
            ]
        );

        $repeater->add_control(
            'h_anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'h_animation',
                            'operator' => '!in',
                            'value'    => ['none', 'char-top', 'char-right', 'char-bottom', 'char-expand'],
                        ],
                    ],
                ],
            ]
        );

        $repeater->add_control(
            'h_anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'h_animation',
                            'operator' => '!in',
                            'value'    => ['none', 'char-top', 'char-right', 'char-bottom', 'char-expand'],
                        ],
                    ],
                ],
            ]
        );

        $repeater->end_controls_tab();

        $repeater->end_controls_tabs();

        $repeater->add_control(
            'desc_heading',
            [
                'label'     => esc_html__( 'Description', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $repeater->start_controls_tabs( 'desc_tabs' );

        $repeater->start_controls_tab(
            'desc_tab',
            [
                'label' => esc_html__( 'Text', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'desc', [
                'label'       => '',
                'placeholder' => esc_html__( 'Desctiption goes here...', 'redias-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'rows'        => 4,
            ]
        );

        $repeater->end_controls_tab();

        $repeater->start_controls_tab(
            'desc_tab_anim',
            [
                'label' => esc_html__( 'Animation', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'd_animation',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'dlFadeIn',
                'options' => SliderHelper::get_effects()
            ]
        );

        $repeater->add_control(
            'd_anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'd_animation',
                            'operator' => '!in',
                            'value'    => ['none', 'char-top', 'char-right', 'char-bottom', 'char-expand'],
                        ],
                    ],
                ],
            ]
        );

        $repeater->add_control(
            'd_anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'd_animation',
                            'operator' => '!in',
                            'value'    => ['none', 'char-top', 'char-right', 'char-bottom', 'char-expand'],
                        ],
                    ],
                ],
            ]
        );

        $repeater->end_controls_tab();

        $repeater->end_controls_tabs();

        $repeater->add_control(
            'btn_caption_heading',
            [
                'label'     => esc_html__( 'Button', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $repeater->start_controls_tabs( 'btn_caption_tabs' );

        $repeater->start_controls_tab(
            'btn_caption_tab',
            [
                'label' => esc_html__( 'Button', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'btn_label', [
                'label'       => esc_html__( 'Label', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Learn More', 'redias-core' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'btn_url',
            [
                'label'         => esc_html__( 'Link', 'redias-core' ),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
                'show_external' => false,
            ]
        );

        $repeater->add_control(
            'btn_icon',
            [
                'label'                  => esc_html__( 'Button Icon', 'redias-core' ),
                'description'            => esc_html__( 'Choose a icon using this icon control.', 'redias-core' ),
                'type'                   => Controls_Manager::ICONS,
                'skin'                   => 'inline',
                'exclude_inline_options' => 'svg',
                'default'                => [
                    'value'   => 'fas fa-chevron-right',
                    'library' => 'solid',
                ],
            ]
        );

        $repeater->add_control(
            'btn_icon_position',
            [
                'label'                => esc_html__( 'Icon Position', 'redias-core' ),
                'type'                 => Controls_Manager::CHOOSE,
                'options'              => [
                    'left'  => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default'              => 'right',
                'selectors_dictionary' => [
                    'left'  => 'flex-flow: row-reverse',
                    'right' => 'flex-flow: inherit',
                ],
                'toggle'               => false,
                'selectors'            => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .slider-btn' => '{{VALUE}}',
                ],
                'condition'            => [
                    'btn_icon!' => '',
                ],
            ]
        );

        $repeater->end_controls_tab();

        $repeater->start_controls_tab(
            'btn_caption_tab_anim',
            [
                'label' => esc_html__( 'Animation', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'btn_animation',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'dlFadeIn',
                'options' => SliderHelper::get_effects(SliderHelper::get_excluded_effects())
            ]
        );

        $repeater->add_control(
            'btn_anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'btn_animation',
                            'operator' => '!in',
                            'value'    => ['none', 'char-top', 'char-right', 'char-bottom', 'char-expand'],
                        ],
                    ],
                ],
            ]
        );

        $repeater->add_control(
            'btn_anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'btn_animation',
                            'operator' => '!in',
                            'value'    => ['none', 'char-top', 'char-right', 'char-bottom', 'char-expand'],
                        ],
                    ],
                ],
            ]
        );

        $repeater->end_controls_tab();

        $repeater->end_controls_tabs();

        // Secondary Button Controls
        $repeater->add_control(
            'secondary_btn_caption_heading',
            [
                'label'     => esc_html__( 'Secondary Button', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        
        $repeater->start_controls_tabs( 'secondary_btn_caption_tabs' );
        
        $repeater->start_controls_tab(
            'secondary_btn_caption_tab',
            [
                'label' => esc_html__( 'Button', 'redias-core' ),
            ]
        );
        
        $repeater->add_control(
            'secondary_btn_label', [
                'label'       => esc_html__( 'Label', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Get Started', 'redias-core' ),
                'label_block' => true,
            ]
        );
        
        $repeater->add_control(
            'secondary_btn_url',
            [
                'label'         => esc_html__( 'Link', 'redias-core' ),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
                'show_external' => false,
            ]
        );
        
        $repeater->add_control(
            'secondary_btn_icon',
            [
                'label'                  => esc_html__( 'Button Icon', 'redias-core' ),
                'description'            => esc_html__( 'Choose a icon using this icon control.', 'redias-core' ),
                'type'                   => Controls_Manager::ICONS,
                'skin'                   => 'inline',
                'exclude_inline_options' => 'svg',
                'default'                => [
                    'value'   => 'fas fa-chevron-right',
                    'library' => 'solid',
                ],
            ]
        );
        
        $repeater->add_control(
            'secondary_btn_icon_position',
            [
                'label'                => esc_html__( 'Icon Position', 'redias-core' ),
                'type'                 => Controls_Manager::CHOOSE,
                'options'              => [
                    'left'  => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default'              => 'right',
                'selectors_dictionary' => [
                    'left'  => 'flex-flow: row-reverse',
                    'right' => 'flex-flow: inherit',
                ],
                'toggle'               => false,
                'selectors'            => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .slider-secondary-btn' => '{{VALUE}}',
                ],
                'condition'            => [
                    'secondary_btn_icon!' => '',
                ],
            ]
        );
        
        $repeater->end_controls_tab();
        
        $repeater->start_controls_tab(
            'secondary_btn_caption_tab_anim',
            [
                'label' => esc_html__( 'Animation', 'redias-core' ),
            ]
        );
        
        $repeater->add_control(
            'secondary_btn_animation',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'dl-fadeIn',
                'options' => SliderHelper::get_effects(SliderHelper::get_excluded_effects()),
            ]
        );
        
        $repeater->add_control(
            'secondary_btn_anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'secondary_btn_animation',
                            'operator' => '!in',
                            'value'    => ['none', 'char-top', 'char-right', 'char-bottom', 'char-expand'],
                        ],
                    ],
                ],
            ]
        );
        
        $repeater->add_control(
            'secondary_btn_anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'secondary_btn_animation',
                            'operator' => '!in',
                            'value'    => ['none', 'char-top', 'char-right', 'char-bottom', 'char-expand'],
                        ],
                    ],
                ],
            ]
        );
        
        $repeater->end_controls_tab();
        
        $repeater->end_controls_tabs();

        // Play Button Controls
        $repeater->add_control(
            'play_btn_caption_heading',
            [
                'label'     => esc_html__( 'Play Button', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $repeater->start_controls_tabs( 'play_btn_caption_tabs' );

        $repeater->start_controls_tab(
            'play_btn_caption_tab',
            [
                'label' => esc_html__( 'Button', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'play_btn_label', [
                'label'       => esc_html__( 'Label', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Watch Video', 'redias-core' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'play_btn_url',
            [
                'label'         => esc_html__( 'Link', 'redias-core' ),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
                'show_external' => false,
            ]
        );

        $repeater->end_controls_tab();

        $repeater->start_controls_tab(
            'play_btn_caption_tab_anim',
            [
                'label' => esc_html__( 'Animation', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'play_btn_animation',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'dlFadeIn',
                'options' => SliderHelper::get_effects(SliderHelper::get_excluded_effects()),
            ]
        );

        $repeater->add_control(
            'play_btn_anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'play_btn_animation',
                            'operator' => '!in',
                            'value'    => ['none'],
                        ],
                    ],
                ],
            ]
        );

        $repeater->add_control(
            'play_btn_anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'play_btn_animation',
                            'operator' => '!in',
                            'value'    => ['none'],
                        ],
                    ],
                ],
            ]
        );

        $repeater->end_controls_tab();

        $repeater->end_controls_tabs();

        $this->add_control(
            'slide_items',
            [
                'label'   => esc_html__( 'Create Slides', 'redias-core' ),
                'type'    => Controls_Manager::REPEATER,
                'fields'  => $repeater->get_controls(),
                'default' => [
                    [
                        'bg_type'     => 'image',
                        'slide_image' => [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ],
                        'sub_heading' => esc_html__( 'Medium Caption', 'redias-core' ),
                        'heading'     => esc_html__( 'Big Caption #1', 'redias-core' ),
                        'desc'        => esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'redias-core' ),
                        'btn_label'   => esc_html__( 'Learn More', 'redias-core' ),
                        'btn_url'     => [
                            'url' => '#',
                        ],
                    ],
                    [
                        'bg_type'     => 'image',
                        'slide_image' => [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ],
                        'sub_heading' => esc_html__( 'Medium Caption', 'redias-core' ),
                        'heading'     => esc_html__( 'Big Caption #2', 'redias-core' ),
                        'desc'        => esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'redias-core' ),
                        'btn_label'   => esc_html__( 'Learn More', 'redias-core' ),
                        'btn_url'     => [
                            'url' => '#',
                        ],
                    ],
                    [
                        'bg_type'     => 'image',
                        'slide_image' => [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ],
                        'sub_heading' => esc_html__( 'Medium Caption', 'redias-core' ),
                        'heading'     => esc_html__( 'Big Caption #3', 'redias-core' ),
                        'desc'        => esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'redias-core' ),
                        'btn_label'   => esc_html__( 'Learn More', 'redias-core' ),
                        'btn_url'     => [
                            'url' => '#',
                        ],
                    ],
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Slider Controls
     *
     * @return void
     */
    private function section_slider_controls() {
        $this->start_controls_section(
            'section_slider_controls',
            [
                'label' => esc_html__( 'Slider Controls', 'redias-core' ),
            ]
        );

        $this->add_control(
            'parallax',
            [
                'label'        => esc_html__( 'Parallax', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'slide_dir',
            [
                'label'     => esc_html__( 'Slide Direction', 'redias-core' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'horizontal',
                'options'   => [
                    'horizontal' => esc_html__( 'Horizontal', 'redias-core' ),
                    'vertical'   => esc_html__( 'Vertical', 'redias-core' ),
                ],
                'condition' => [
                    'parallax!' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'slide_effect',
            [
                'label'     => esc_html__( 'Effect', 'redias-core' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'fade',
                'options'   => [
                    'fade'      => esc_html__( 'Fade', 'redias-core' ),
                    'slide'     => esc_html__( 'Slide', 'redias-core' )
                ],
                'condition' => [
                    'parallax!' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'initial_slide',
            [
                'label'   => esc_html__( 'Initial Slide', 'redias-core' ),
                'type'    => Controls_Manager::NUMBER,
                'min'     => 1,
                'max'     => 10,
                'step'    => 1,
                'default' => 1
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label'        => esc_html__( 'Autoplay', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
            ]
        );

        $this->add_control(
            'autoplay_speed',
            [
                'label'      => esc_html__( 'Autoplay Speed', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 500,
                        'max'  => 20000,
                        'step' => 5,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 5000,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .autoplay-active .dl-swiper-pagination.pagi-style-5 .swiper-pagination-bullet-active:after' => 'animation-duration: {{SIZE}}ms;',
                ],
                'condition'  => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'pause_on_hover',
            [
                'label'        => esc_html__( 'Pause on Hover', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
                'condition'    => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'infinite_loop',
            [
                'label'        => esc_html__( 'Infinite Loop', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'grabcursor',
            [
                'label'        => esc_html__( 'Grab Cursor', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
            ]
        );

        $this->add_control(
            'mousewheel',
            [
                'label'       => esc_html__( 'Mouse Wheel', 'redias-core' ),
                'type'        => Controls_Manager::SWITCHER,
                'description' => esc_html__( 'Enables navigation through slides using mouse wheel.', 'elementor' ),
                'label_on'    => esc_html__( 'Yes', 'redias-core' ),
                'label_off'   => esc_html__( 'No', 'redias-core' ),
            ]
        );

        $this->add_control(
            'anim_speed',
            [
                'label'   => esc_html__( 'Animation Speed', 'redias-core' ),
                'type'    => Controls_Manager::NUMBER,
                'min'     => 100,
                'max'     => 3000,
                'step'    => 5,
                'default' => 1000,
            ]
        );

        $this->add_control(
            'text_direction',
            [
                'label'   => esc_html__( 'Text Direction', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'ltr',
                'options' => [
                    'ltr' => esc_html__( 'Left - LTR', 'redias-core' ),
                    'rtl' => esc_html__( 'Right - RTL', 'redias-core' ),
                ],
            ]
        );

        $this->add_control(
            'slider_nav',
            [
                'label'        => esc_html__( 'Navigation', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'no'
            ]
        );

        $this->add_control(
            'slider_pagination',
            [
                'label'        => esc_html__( 'Pagination ( Bullets )', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'nav_controls_head',
            [
                'label'     => esc_html__( 'Navigation Controls', 'redias-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'nav_layout',
            [
                'label'     => esc_html__( 'Layout', 'redias-core' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    '1' => [
                        'title' => esc_html__( 'Bottom', 'redias-core' ),
                        'icon'  => 'eicon-v-align-bottom',
                    ],
                    '2' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon'  => 'eicon-v-align-middle',
                    ],
                ],
                'default'   => '1',
                'toggle'    => false,
                'condition' => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'nav_alignment',
            [
                'label'                => esc_html__( 'Alignment', 'redias-core' ),
                'type'                 => Controls_Manager::CHOOSE,
                'options'              => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'toggle'               => false,
                'selectors_dictionary' => [
                    'left'   => 'justify-content: flex-start',
                    'center' => 'justify-content: center',
                    'right'  => 'justify-content: flex-end',
                ],
                'default'              => 'right',
                'selectors'            => [
                    '{{WRAPPER}} .dl-slider-controls' => '{{VALUE}}',
                ],
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'slider_nav',
                            'operator' => '===',
                            'value' => 'yes',
                        ],
                        [
                            'name' => 'slider_pagination',
                            'operator' => '===',
                            'value' => 'yes'
                        ],
                    ],
                ],
            ]
        );

        $this->add_responsive_control(
            'nav_space_between_item',
            [
                'label'      => esc_html__( 'Space Between', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 500,
                        'step' => 1,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-slider-controls.style-1' => 'column-gap: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'slider_nav'    => 'yes',
                    'nav_layout'    => '1',
                    'nav_alignment' => 'center',
                ],
            ]
        );

        $this->add_responsive_control(
            'nav_bottom_spacing',
            [
                'label'              => esc_html__( 'Bottom Spacing', 'redias-core' ),
                'type'               => Controls_Manager::DIMENSIONS,
                'size_units'         => ['px', '%', 'em'],
                'allowed_dimensions' => ['bottom'],
                'selectors'          => [
                    '{{WRAPPER}} .dl-slider-controls' => 'bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition'          => [
                    'slider_nav' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Slider Shape
     *
     * @return void
     */
    private function section_slider_shape() {

        $this->start_controls_section(
            'section_slider_shape',
            [
                'label' => esc_html__( 'Slider Shape', 'redias-core' )
            ]
        );
        
        $this->add_control(
            'slider_shape',
            [
                'label' => esc_html__( 'Slider Shape', 'redias-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'redias-core' ),
                'label_off' => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
                'default' => 'no'
            ]
        );

        $this->add_responsive_control(
            'slider_shape_width',
            [
                'label' => esc_html__( 'Shape Width', 'redias-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 400
                ],
                'tablet_default' => [
                    'unit' => 'px',
                    'size' => 300
                ],
                'mobile_default' => [
                    'unit' => 'px',
                    'size' => 240
                ],
                'selectors' => [
                    '{{WRAPPER}} .slider-shape-wrap' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .slider-shape-wrap .slider-shape' => 'width: calc({{SIZE}}{{UNIT}} / 2);'
                ],
                'condition' => [
                    'slider_shape' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'shape1_color',
            [
                'label' => esc_html__( 'Shape 1 Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slider-shape-wrap .slider-shape:first-child' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'slider_shape' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'shape2_color',
            [
                'label' => esc_html__( 'Shape 2 Color', 'redias-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slider-shape-wrap .slider-shape:last-child' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'slider_shape' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'slider_shape_anim_heading',
            [
                'label' => esc_html__( 'Shape Animation', 'redias-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        // Tab Start
        $this->start_controls_tabs( 'slider_shape_tabs' );

        $this->start_controls_tab(
            'slider_shape1_tab',
            [
                'label' => esc_html__( 'Shape 1', 'redias-core' ),
                'condition' => [
                    'slider_shape' => 'yes'
                ]
            ]
        );
        
        $this->add_control(
            'shape1_animation',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'dlFadeInRight',
                'options' => SliderHelper::get_effects(SliderHelper::get_excluded_effects()),
                'condition' => [
                    'slider_shape' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'shape1_anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 500,
                ],
                'condition' => [
                    'slider_shape' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'shape1_anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'condition' => [
                    'slider_shape' => 'yes'
                ]
            ]
        );
        
        $this->end_controls_tab();
        
        $this->start_controls_tab(
            'slider_shape2_tab',
            [
                'label' => esc_html__( 'Shape 2', 'redias-core' ),
                'condition' => [
                    'slider_shape' => 'yes'
                ]
            ]
        );
        
        $this->add_control(
            'shape2_animation',
            [
                'label'   => esc_html__( 'Effect', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'dlFadeInRight',
                'options' => SliderHelper::get_effects(SliderHelper::get_excluded_effects()),
                'condition' => [
                    'slider_shape' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'shape2_anim_delay',
            [
                'label'      => esc_html__( 'Delay', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 800,
                ],
                'condition' => [
                    'slider_shape' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'shape2_anim_duration',
            [
                'label'      => esc_html__( 'Duration', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 5000,
                        'step' => 10,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 1000,
                ],
                'condition' => [
                    'slider_shape' => 'yes'
                ]
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        // Tab End
        
        $this->end_controls_section();

    }

    /**
     * Image Settings Controls
     *
     * @return void
     */
    private function section_image_settings() {
        $this->start_controls_section(
            'section_slider_image_settings',
            [
                'label' => esc_html__( 'Image Settings', 'redias-core' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'    => 'imagesize',
                'exclude' => ['custom'],
                'include' => [],
                'default' => 'full',
            ]
        );

        $this->add_responsive_control(
            'image_position',
            [
                'label'     => esc_html__( 'Image Position', 'redias-core' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'center',
                'options'   => [
                    'top'    => esc_html__( 'Top', 'redias-core' ),
                    'bottom' => esc_html__( 'Bottom', 'redias-core' ),
                    'left'   => esc_html__( 'Left', 'redias-core' ),
                    'Right'  => esc_html__( 'Right', 'redias-core' ),
                    'center' => esc_html__( 'Center', 'redias-core' ),
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-slider .slide-img' => 'object-position: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();
    }

}