<?php
/**
 * About Widget
 *
 * @package RediasCore
 */
namespace RediasCore\Widgets;

use RediasCore\Classes\Helper;

class AboutWidget extends \WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'redias_about_widget', // Base ID
			esc_html__( 'Redias - About', 'redias-core' ), // Name
			array( 'description' => esc_html__( 'This is custom about widget to show about info.', 'redias-core' ), ) // Args
		);
		add_action( 'admin_footer', array( $this, 'media_fields' ) );
        add_action( 'customize_controls_print_footer_scripts', array( $this, 'media_fields' ) );
	}

	private $widget_fields = array(
		array(
			'label' => 'Upload Logo',
			'id' => 'upload_logo',
			'type' => 'media',
			'desc' => 'Upload your logo using this image uploader.'
		),
		array(
			'label' => 'Logo URL',
			'id' => 'logo_link',
			'type' => 'url',
			'desc' => 'If url is empty then home url will set by default.',
			'placeholder' => 'URL goes here...'
		),
		array(
			'label' => 'Description',
			'id' => 'description',
			'type' => 'textarea',
			'placeholder' => 'Description goes here...',
			'default' => 'We provide outstanding business consulting services through teamwork.'
		),
		array(
			'label' => 'Facebook',
			'id' => 'facebook',
			'type' => 'text',
			'placeholder' => 'Facebook link...'
		),
		array(
			'label' => 'Twitter',
			'id' => 'twitter',
			'type' => 'text',
			'placeholder' => 'Twitter link...'
		),
		array(
			'label' => 'Instagram',
			'id' => 'instagram',
			'type' => 'text',
			'placeholder' => 'Instagram link...'
		),
		array(
			'label' => 'Pinterest',
			'id' => 'pinterest',
			'type' => 'text',
			'placeholder' => 'Pinterest link...'
		),
		array(
			'label' => 'Flickr',
			'id' => 'flickr',
			'type' => 'text',
			'placeholder' => 'Flickr link...'
		),
		array(
			'label' => 'Behance',
			'id' => 'behance',
			'type' => 'text',
			'placeholder' => 'Behance link...'
		),
		array(
			'label' => 'YouTube',
			'id' => 'youtube',
			'type' => 'text',
			'placeholder' => 'YouTube link...'
		),
		array(
			'label' => 'Dribbble',
			'id' => 'dribbble',
			'type' => 'text',
			'placeholder' => 'Dribbble link...'
		),
		array(
			'label' => 'Linkedin',
			'id' => 'linkedin',
			'type' => 'text',
			'placeholder' => 'Linkedin link...'
		),
	);

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
        echo $args['before_widget'];
        $logo_url = ! empty( $instance['upload_logo'] ) ? wp_get_attachment_url( $instance['upload_logo'] ) : '';
		$logo_alt = ! empty( $instance['upload_logo'] ) ? get_post_meta( $instance['upload_logo'], '_wp_attachment_image_alt', true ) : '';
		$logo_link = $instance['logo_link'] ? $instance['logo_link'] : home_url( '/' );
        $desc = $instance['description'];
		$social_items = [
			'facebook-f' => $instance['facebook'],
			'twitter' => $instance['twitter'],
			'instagram' => $instance['instagram'],
			'pinterest-2' => $instance['pinterest'],
			'linkedin-in' => $instance['linkedin'],
			'behance' => $instance['behance'],
			'youtube-2' => $instance['youtube'],
			'dribbble' => $instance['dribbble'],
			'flickr' => $instance['flickr']
		];

		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}
        ?>
        <div class="dl-widget-about">
            <?php
                if( ! empty( $logo_url ) ){
                    echo '<div class="widget-brand"><a href="'. esc_url( $logo_link ) .'"><img src="'. esc_url( $logo_url ) .'" alt="'. esc_attr( $logo_alt ) .'" /></a></div>';
                }
            ?>
            <?php if( ! empty( $desc ) ) : ?>
                <p><?php echo esc_html( $desc ); ?></p>
            <?php endif;
			
			if( $social_items ){
				echo '<ul class="wt-social-icons left">';
				foreach($social_items as $key => $social){
					if( ! empty( $social ) ) {
						echo '<li class="'. esc_attr( $key ) .'"><a href="'. esc_url( $social ) .'"><i class="dl dl-'. esc_attr( $key ) .'"></i></a></li>';
					}
				}
				echo '</ul>';
			}
            ?>
        </div>
        <?php
		echo $args['after_widget'];
	}

	public function media_fields() {
		?><script>
			jQuery(document).ready(function($){
				if ( typeof wp.media !== 'undefined' ) {
					var _custom_media = true,
					_orig_send_attachment = wp.media.editor.send.attachment;
					$(document).on('click','.custommedia',function(e) {
						var send_attachment_bkp = wp.media.editor.send.attachment;
						var button = $(this);
						var id = button.attr('id');
						_custom_media = true;
							wp.media.editor.send.attachment = function(props, attachment){
							if ( _custom_media ) {
								$('input#'+id).val(attachment.id);
								$('span#preview'+id).css('background-image', 'url('+attachment.url+')');
								$('input#'+id).trigger('change');
							} else {
								return _orig_send_attachment.apply( this, [props, attachment] );
							};
						}
						wp.media.editor.open(button);
						return false;
					});
					$('.add_media').on('click', function(){
						_custom_media = false;
					});
					$(document).on('click', '.remove-media', function() {
						var parent = $(this).parents('p');
						parent.find('input[type="media"]').val('').trigger('change');
						parent.find('span').css('background-image', 'url()');
					});
				}
			});
		</script><?php
	}

	public function field_generator( $instance ) {
		$output = '';
		foreach ( $this->widget_fields as $widget_field ) {
			$default = '';
			$desc = '';
			$placeholder = '';
			if ( isset($widget_field['default']) ) {
				$default = $widget_field['default'];
			}
			if( isset( $widget_field['desc'] ) ) {
				$desc = '<div style="display: block; margin: 0 0 10px; font-size: 13px; color: #777;">'. esc_html( $widget_field['desc'] ) .'</div>';
			}
			if( isset( $widget_field['placeholder'] ) ) {
				$placeholder = 'placeholder="'. esc_attr( $widget_field['placeholder'] ) .'"';
			}
			$widget_value = ! empty( $instance[$widget_field['id']] ) ? $instance[$widget_field['id']] : esc_html__( $default, 'redias-core' );
			switch ( $widget_field['type'] ) {
				case 'media':
					$media_url = '';
					if ($widget_value) {
						$media_url = wp_get_attachment_url($widget_value);
					}
					$output .= '<p>';
					$output .= '<label for="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'">'.esc_attr( $widget_field['label'], 'redias-core' ).':</label> ';
					$output .= $desc;
					$output .= '<input style="display:none;" class="widefat" id="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'" name="'.esc_attr( $this->get_field_name( $widget_field['id'] ) ).'" type="'.$widget_field['type'].'" value="'.$widget_value.'">';
					$output .= '<span id="preview'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'" style="margin-right:10px;border:2px solid #eee;display:block;width: 100px;height:100px;background-image:url('.$media_url.');background-size:contain;background-repeat:no-repeat;"></span>';
					$output .= '<button id="'.$this->get_field_id( $widget_field['id'] ).'" class="button select-media custommedia">Add Media</button>';
					$output .= '<input style="width: 19%;" class="button remove-media" id="buttonremove" name="buttonremove" type="button" value="Clear" />';
					$output .= '</p>';
					break;
				case 'textarea':
					$output .= '<p>';
					$output .= '<label for="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'">'.esc_attr( $widget_field['label'], 'redias-core' ).':</label> ';
					$output .= $desc;
					$output .= '<textarea class="widefat" id="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'" name="'.esc_attr( $this->get_field_name( $widget_field['id'] ) ).'" rows="4" cols="4" value="'.esc_attr( $widget_value ).'" '. $placeholder .'>'.$widget_value.'</textarea>';
					$output .= '</p>';
					break;
				default:
					$output .= '<p>';
					$output .= '<label for="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'">'.esc_attr( $widget_field['label'], 'redias-core' ).':</label> ';
					$output .= $desc;
					$output .= '<input class="widefat" id="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'" name="'.esc_attr( $this->get_field_name( $widget_field['id'] ) ).'" type="'.$widget_field['type'].'" value="'.esc_attr( $widget_value ).'" '. $placeholder .'>';
					$output .= '</p>';
			}
		}
		echo $output;
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'redias-core' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" placeholder="<?php esc_html_e( 'Title...', 'redias-core') ; ?>">
		</p>
		<?php
		$this->field_generator( $instance );
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		foreach ( $this->widget_fields as $widget_field ) {
			switch ( $widget_field['type'] ) {
				default:
					$instance[$widget_field['id']] = ( ! empty( $new_instance[$widget_field['id']] ) ) ? strip_tags( $new_instance[$widget_field['id']] ) : '';
			}
		}
		return $instance;
	}

}