<?php
/**
 * Contact Widget
 *
 * @package RediasCore
 */
namespace RediasCore\Widgets;

use RediasCore\Classes\Helper;

class ContactWidget extends \WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'redias_contact_widget', // Base ID
			esc_html__( 'Redias - Contact Info', 'redias-core' ), // Name
			array( 'description' => esc_html__( 'This is custom contact widget to show contact information.', 'redias-core' ), ) // Args
		);
	}

	private $widget_fields = array(
		array(
			'label' => 'Label (Address)',
			'placeholder' => 'Address label...',
			'id' => 'redias_address_label',
			'type' => 'text',
		),
		array(
			'label' => 'Address',
			'id' => 'redias_address',
			'type' => 'textarea',
		),
		array(
			'label' => 'Label (Phone)',
			'placeholder' => 'Phone label...',
			'id' => 'redias_phone_label',
			'type' => 'text',
		),
		array(
			'label' => 'Phone',
			'placeholder' => '123 456 7890',
			'id' => 'redias_phone',
			'type' => 'text',
		),
		array(
			'label' => 'Label (Email)',
			'placeholder' => 'Email label...',
			'id' => 'redias_email_label',
			'type' => 'text',
		),
		array(
			'label' => 'Email',
            'placeholder' => 'Email address goes here...',
			'id' => 'redias_email',
			'type' => 'email',
		)
	);

	static function contact_item( $label = '', $text = '', $link = '' ) {
		$output = '';
		if( ! empty( $text ) ) {
			$output .= '<li>';
			if( ! empty( $label ) ) {
				$output .= '<div class="label">'. esc_html( $label ) .':</div>';
			}
			if( ! empty( $link ) ) {
				$output .= '<a href="mailto:' . esc_url( $link ) . '" class="list-text">' . Helper::kses_basic( $text ) . '</a>';
			}else{
				$output .= '<div class="list-text">' . Helper::kses_basic( $text ) . '</div>';
			}
			$output .= '</li>';
		}
		return $output;
		
	}

	public function widget( $args, $instance ) {
		echo $args['before_widget'];

		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}
		$address_label = ! empty( $instance['redias_address_label'] ) ? $instance['redias_address_label'] : esc_html__('Location', 'redias-core');
		$phone_label = ! empty( $instance['redias_phone_label'] ) ? $instance['redias_phone_label'] : esc_html__('Phone', 'redias-core');
		$email_label = ! empty( $instance['redias_email_label'] ) ? $instance['redias_email_label'] : esc_html__('Join Us', 'redias-core');
		$address = ! empty( $instance['redias_address'] ) ? $instance['redias_address'] : '';
		$phone = ! empty( $instance['redias_phone'] ) ? $instance['redias_phone'] : '';
		$email = ! empty( $instance['redias_email'] ) ? $instance['redias_email'] : '';
		echo '<ul class="contact-info-list">';
		echo self::contact_item($address_label, $address);
		echo self::contact_item($phone_label, $phone);
		echo self::contact_item($email_label, $email, $email);
		echo '</ul>';
		
		echo $args['after_widget'];
	}

	public function field_generator( $instance ) {
		$output = '';
		foreach ( $this->widget_fields as $widget_field ) {
			$default = '';
			if ( isset($widget_field['default']) ) {
				$default = $widget_field['default'];
			}
			$widget_value = ! empty( $instance[$widget_field['id']] ) ? $instance[$widget_field['id']] : esc_html__( $default, 'redias-core' );
			switch ( $widget_field['type'] ) {
				case 'textarea':
					$output .= '<p>';
					$output .= '<label for="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'">'.esc_attr( $widget_field['label'], 'redias-core' ).':</label> ';
					$output .= '<textarea class="widefat" id="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'" name="'.esc_attr( $this->get_field_name( $widget_field['id'] ) ).'" rows="4" cols="4" value="'.esc_attr( $widget_value ).'">'.$widget_value.'</textarea>';
					$output .= '</p>';
					break;
				default:
                    $text_plceholder = ! empty( $widget_field['placeholder'] ) ? ' placeholder="'. esc_attr( $widget_field['placeholder'] ) .'"' : '';
					$output .= '<p>';
					$output .= '<label for="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'">'.esc_attr( $widget_field['label'], 'redias-core' ).':</label> ';
					$output .= '<input class="widefat" id="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'" name="'.esc_attr( $this->get_field_name( $widget_field['id'] ) ).'" type="'.$widget_field['type'].'" value="'.esc_attr( $widget_value ).'"'. $text_plceholder .'>';
					$output .= '</p>';
                    if( ! empty( $widget_field['desc'] ) ) {
                        $output .= '<p style="color: #888;">'. Helper::kses_basic( $widget_field['desc'] ) .'</p>';
                    }
			}
		}
		echo $output;
	}

	public function form( $instance ) {
		$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'redias-core' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<?php
		$this->field_generator( $instance );
	}

	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		
		foreach ( $this->widget_fields as $widget_field ) {
			switch ( $widget_field['type'] ) {
				default:
					$instance[$widget_field['id']] = ( ! empty( $new_instance[$widget_field['id']] ) ) ? strip_tags( $new_instance[$widget_field['id']] ) : '';
			}
		}

		return $instance;
	}

}