<?php
/**
 * MailChimp Widget
 *
 * @package RediasCore
 */
namespace RediasCore\Widgets;

class MailChimpWidget extends \WP_Widget {
	
	/**
	 * @var array
	 */
	private $default_instance_settings = array(
		'form_id' => ''
	);

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'redias_mc_widget', // Base ID
			esc_html__( 'Redias - MailChimp', 'redias-core' ), // Name
			array( 'description' => esc_html__( 'This is custom mailchimp widget to show mailchimp newsletter form.', 'redias-core' ), ) // Args
		);
	}

	private $widget_fields = array(
		array(
			'label' => 'Style',
			'id' => 'style',
			'type' => 'number',
			'min' => 1,
			'max' => 2,
			'default' => 1
		),
		array(
			'label' => 'Description',
			'id' => 'description',
			'type' => 'textarea',
			'placeholder' => 'Description goes here...',
			'default' => 'Get the latest updates and offers for business services yearly.'
		),
		array(
			'label' => 'Facebook',
			'id' => 'facebook',
			'type' => 'text',
			'placeholder' => 'Facebook link...'
		),
		array(
			'label' => 'Twitter',
			'id' => 'twitter',
			'type' => 'text',
			'placeholder' => 'Twitter link...'
		),
		array(
			'label' => 'Instagram',
			'id' => 'instagram',
			'type' => 'text',
			'placeholder' => 'Instagram link...'
		),
		array(
			'label' => 'Pinterest',
			'id' => 'pinterest',
			'type' => 'text',
			'placeholder' => 'Pinterest link...'
		),
		array(
			'label' => 'Flickr',
			'id' => 'flickr',
			'type' => 'text',
			'placeholder' => 'Flickr link...'
		),
		array(
			'label' => 'Behance',
			'id' => 'behance',
			'type' => 'text',
			'placeholder' => 'Behance link...'
		),
		array(
			'label' => 'YouTube',
			'id' => 'youtube',
			'type' => 'text',
			'placeholder' => 'YouTube link...'
		),
		array(
			'label' => 'Dribbble',
			'id' => 'dribbble',
			'type' => 'text',
			'placeholder' => 'Dribbble link...'
		),
		array(
			'label' => 'Linkedin',
			'id' => 'linkedin',
			'type' => 'text',
			'placeholder' => 'Linkedin link...'
		),
	);

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
        echo $args['before_widget'];
        $desc = $instance['description'];
        $style = $instance['style'];
		$instance_settings = array_merge( $this->default_instance_settings, $instance );

		$social_items = [];
		( '' != $instance['facebook'] ) ? $social_items['facebook-f'] = $instance['facebook'] : '';
		( '' != $instance['twitter'] ) ? $social_items['twitter'] = $instance['twitter'] : '';
		( '' != $instance['instagram'] ) ? $social_items['instagram'] = $instance['instagram'] : '';
		( '' != $instance['pinterest'] ) ? $social_items['pinterest-2'] = $instance['pinterest'] : '';
		( '' != $instance['linkedin'] ) ? $social_items['linkedin-in'] = $instance['linkedin'] : '';
		( '' != $instance['behance'] ) ? $social_items['behance'] = $instance['behance'] : '';
		( '' != $instance['youtube'] ) ? $social_items['youtube-2'] = $instance['youtube'] : '';
		( '' != $instance['dribbble'] ) ? $social_items['dribbble'] = $instance['dribbble'] : '';
		( '' != $instance['flickr'] ) ? $social_items['flickr'] = $instance['flickr'] : '';
		
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}

		echo '<div class="mc4wp-form-widget style-'. $style .'">';
		
		mc4wp_show_form( $instance_settings['form_id'] );
		
		if( ! empty( $desc ) ){
			echo '<p class="desc">'. esc_html( $desc ) .'</p>';
		}

		if( $social_items ){
			echo '<ul class="mc-social-icons">';
			foreach($social_items as $key => $social){
				if( ! empty( $social ) ) {
					echo '<li class="'. esc_attr( $key ) .'"><a href="'. esc_url( $social ) .'" target="_blank"><i class="dl dl-'. esc_attr( $key ) .'"></i></a></li>';
				}
			}
			echo '</ul>';
		}
		echo '</div>';
        
		echo $args['after_widget'];
	}

	public function field_generator( $instance ) {
		$output = '';
		foreach ( $this->widget_fields as $widget_field ) {
			$default = '';
			$desc = '';
			$placeholder = '';
			$min = '';
			$max = '';
			if ( isset($widget_field['default']) ) {
				$default = $widget_field['default'];
			}
			if( isset( $widget_field['desc'] ) ) {
				$desc = '<div style="display: block; margin: 0 0 10px; font-size: 13px; color: #777;">'. esc_html( $widget_field['desc'] ) .'</div>';
			}
			if( isset( $widget_field['placeholder'] ) ) {
				$placeholder = ' placeholder="'. esc_attr( $widget_field['placeholder'] ) .'"';
			}
			if( isset( $widget_field['min'] ) ) {
				$min = ' min="'. esc_attr( $widget_field['min'] ) .'"';
			}
			if( isset( $widget_field['max'] ) ) {
				$max = ' max="'. esc_attr( $widget_field['max'] ) .'"';
			}
			$widget_value = ! empty( $instance[$widget_field['id']] ) ? $instance[$widget_field['id']] : esc_html__( $default, 'redias-core' );
			switch ( $widget_field['type'] ) {
				case 'textarea':
					$output .= '<p>';
					$output .= '<label for="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'">'.esc_attr( $widget_field['label'], 'redias-core' ).':</label> ';
					$output .= $desc;
					$output .= '<textarea class="widefat" id="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'" name="'.esc_attr( $this->get_field_name( $widget_field['id'] ) ).'" rows="4" cols="4" value="'.esc_attr( $widget_value ).'"'. $placeholder .'>'.$widget_value.'</textarea>';
					$output .= '</p>';
					break;
				default:
					$output .= '<p>';
					$output .= '<label for="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'">'.esc_attr( $widget_field['label'], 'redias-core' ).':</label> ';
					$output .= $desc;
					$output .= '<input class="widefat" id="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'" name="'.esc_attr( $this->get_field_name( $widget_field['id'] ) ).'" type="'.$widget_field['type'].'" value="'.esc_attr( $widget_value ).'"'. $placeholder . $min . $max .'>';
					$output .= '</p>';
			}
		}
		echo $output;
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$settings = array_merge( $this->default_instance_settings, (array) $instance );
		$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'redias-core' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" placeholder="<?php esc_html_e( 'Title...', 'redias-core') ; ?>">
		</p>
		<p class="description">
			<?php printf( __( 'You can edit your sign-up form in the <a href="%s">Mailchimp for WordPress form settings</a>.', 'redias-core' ), admin_url( 'admin.php?page=mailchimp-for-wp-forms' ) ); ?>
		</p>
		<?php
		/**
		 * Runs right after the widget settings form is outputted
		 *
		 * @param array $settings
		 * @param mc4wp_form_widget $this
		 * @ignore
		 */
		do_action( 'mc4wp_form_widget_form', $settings, $this );
		
		$this->field_generator( $instance );
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		foreach ( $this->widget_fields as $widget_field ) {
			switch ( $widget_field['type'] ) {
				default:
					$instance[$widget_field['id']] = ( ! empty( $new_instance[$widget_field['id']] ) ) ? strip_tags( $new_instance[$widget_field['id']] ) : '';
			}
		}
		/**
		 * Filters the widget settings before they are saved.
		 *
		 * @param array $new_settings
		 * @param array $old_settings
		 * @param redias_mc4wp_form_widget $widget
		 * @ignore
		 */
		$instance = apply_filters( 'redias_mc4wp_form_widget_update_settings', $new_instance, $old_instance, $this );
		return $instance;
	}

}