<?php
/**
 * Plugin Name: Redias Core
 * Description: This is a core plugin of Redias WordPress theme.
 * Plugin URI: https://themes.dynamiclayers.net/redias
 * Author: DynamicLayers
 * Author URI: https://themeforest.net/user/dynamiclayers
 * Version: 1.0.0
 * Elementor tested up to: 3.13.3
 * License: GPL2 or later
 * Text Domain: redias-core
 * Domain Path: /languages
 * @package RediasCore
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

require_once __DIR__ . '/vendor/autoload.php';

/**
 * The main plugin class
 */
final class RediasCore {

    /**
     * Plugin version
     *
     * @var string
     */
    const version = '1.0.0';

    /**
     * Class construcotr
     */
    private function __construct() {
        $this->define_constants();

        register_activation_hook( __FILE__, [$this, 'activate'] );

        add_action( 'plugins_loaded', [$this, 'init_plugin'] );

        add_action( 'elementor/init', [$this, 'elementor_init'] );

        add_action( 'widgets_init', [$this, 'widgets_init'] );
    }

    /**
     * Initializes a singleton instance
     *
     * @return \RediasCore
     */
    static function init() {
        static $instance = false;

        if ( ! $instance ) {
            $instance = new self();
        }

        return $instance;
    }

    /**
     * Define the required plugin constants
     *
     * @return void
     */
    public function define_constants() {
        define( 'REDIASCORE_VERSION', self::version );
        define( 'REDIASCORE_FILE', __FILE__ );
        define( 'REDIASCORE_PATH', __DIR__ );
        define( 'REDIASCORE_URL', plugins_url( '', REDIASCORE_FILE ) );
        define( 'REDIASCORE_ASSETS', REDIASCORE_URL . '/assets' );
    }

    /**
     * Initialize the plugin
     *
     * @return void
     */
    public function init_plugin() {

        load_plugin_textdomain( 'redias-core', false, basename( dirname( __FILE__ ) ) . '/languages' );
        add_image_size( 'redias-h-720x360', 720, 360, true );
        add_image_size( 'redias-260x260', 260, 260, true );
        new \RediasCore\Classes\PostTypes();
        
        if ( ! class_exists( 'CSF' ) ) {
            require_once REDIASCORE_PATH . '/lib/csf/codestar-framework.php';
        }

        if ( class_exists( 'ACF' ) ) {
            new RediasCore\Classes\AcfExtend();
            require_once REDIASCORE_PATH . '/lib/acf/acf-data.php';
        }

        if ( is_admin() ) {
            new \RediasCore\Classes\Elementor();
            new \RediasCore\Classes\AdminAssets();
            if( 'enabled' == \RediasCore\Classes\Helper::get_csf_option('redias-cloner', 'disabled') ) {
                new \RediasCore\Classes\PostClonner();
            }
            if( class_exists('OCDI_Plugin') ) {
                new \RediasCore\Classes\DemoImporter();
            }
        } else {
            new \RediasCore\Classes\Assets();
        }

    }

    /**
     * Elementor Initialize
     *
     * @return void
     */
    public function elementor_init() {

        $assets      = new \RediasCore\Classes\Assets();
        $iconManager = new \RediasCore\Classes\IconManager();
        $assets->el_scripts();
        $iconManager->init();
        new \RediasCore\Classes\Widgets();
        new \RediasCore\Elementor\Module\AdvancedBackground();
        new \RediasCore\Classes\Controls();
        $wpml_manager = new \RediasCore\Classes\WpmlManager();
        $wpml_manager->init();

    }

    /**
     * Widgets Initialize
     *
     * @return void
     */
    public function widgets_init() {

        new \RediasCore\Classes\Widgets();
        register_widget( '\RediasCore\Widgets\PostWidget' );
        register_widget( '\RediasCore\Widgets\AboutWidget' );
        register_widget( '\RediasCore\Widgets\ContactWidget' );
        if( function_exists('_mc4wp_load_plugin') ) {
            register_widget( '\RediasCore\Widgets\MailChimpWidget' );
        }
        if ( class_exists( 'WooCommerce' ) ) {
            register_widget( '\RediasCore\Widgets\MiniCart' );
        }
    }

    /**
     * Do stuff upon plugin activation
     *
     * @return void
     */
    public function activate() {
        $installer = new \RediasCore\Classes\Installer();
        $installer->run();
    }
}

/**
 * Initializes the main plugin
 *
 * @return \RediasCore
 */
function redias_core_init() {
    return RediasCore::init();
}

// kick-off the plugin
redias_core_init();
