<?php
/**
 * The template for displaying comments.
 *
 * The area of the page that contains both current comments
 * and the comment form.
 *
 * @package redias
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<div id="comments" class="comments-area">

	<?php
	// You can start editing here -- including this comment!
	if ( have_comments() ) : ?>
		<h2 class="post-footer-title">
			<?php
			$comments_number = get_comments_number();
			printf( _x( 'Comments (%s)', 'comments title', 'redias' ),$comments_number );
			?>
		</h2>

		<ol class="comment-list">
			<?php
				wp_list_comments( array(
					'avatar_size' => 100,
					'style'       => 'ol',
					'short_ping'  => true,
					'reply_text'  => esc_html__( 'Reply', 'redias' ),
				) );
			?>
		</ol>

		<?php the_comments_pagination( array(
			'prev_text' => '<span class="screen-reader-text"><i class="dl dl-long-arrow-alt-left"></i>' . esc_html__( 'Previous', 'redias' ) . '</span>',
			'next_text' => '<span class="screen-reader-text">' . esc_html__( 'Next', 'redias' ). '<i class="dl dl-long-arrow-alt-right"></i>',
		) );

	endif; // Check for have_comments().

	// If comments are closed and there are comments, let's leave a little note, shall we?
	if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) : ?>

		<p class="no-comments"><?php echo esc_html__( 'Comments are closed.', 'redias' ); ?></p>
	<?php
	endif;
	if( is_singular('matches') ) {
		$redias_comment_label = esc_html__( 'Match Comment', 'redias' );
	}else{
		$redias_comment_label = esc_html__( 'Post Comment', 'redias' );
	}
	$redias_commenter     = wp_get_current_commenter();
	$redias_form_style = 'default';
	$redias_comment_args = array(
		'class_form' => 'dl-comment-form',
		'label_submit' => $redias_comment_label,
		'title_reply'  => $redias_comment_label,
		// remove "Logged in as"
		'logged_in_as'         => '',
		// remove text before textarea
		'comment_notes_before' => '',
		// remove text after textarea
		'comment_notes_after'  => '',
		'fields' => array(
			//Author field
			'author' => '<div class="dl-comment-row"><div class="dl-comment-col"><input id="author" name="author" type="text" aria-required="true" placeholder="' . esc_attr__( 'Your name', 'redias' ) .'"/></div>',
			//Email Field
			'email' => '<div class="dl-comment-col"><input id="email" name="email" type="email" placeholder="' . esc_attr__( 'Your email', 'redias' ) .'" /></div></div>',
		),
		'comment_field' => '<div class="dl-comment-body"><textarea id="comment" name="comment" rows="4" aria-required="true" placeholder="'. esc_attr__( 'Your comment', 'redias' ) .'"></textarea></div>',
	);
	comment_form( $redias_comment_args );

	// Comment Field Order
	function redias_comment_fields_custom_order( $fields ) {
		$comment_field = $fields['comment'];
		$author_field = $fields['author'];
		$email_field = $fields['email'];
		$cookies_field = $fields['cookies'];

		unset( $fields['comment'] );
		unset( $fields['author'] );
		unset( $fields['email'] );
		unset( $fields['url'] );
		unset( $fields['cookies'] );

		$fields['author'] = $author_field;
		$fields['email'] = $email_field;
		$fields['comment'] = $comment_field;
		$fields['cookies'] = $cookies_field;
		
		return $fields;
	}
	add_filter( 'comment_form_fields', 'redias_comment_fields_custom_order' );
	?>

</div><!-- #comments -->
