<?php
/**
 * CSF Helper Class
 *
 * @package Redias
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class RediasCsfHelper{

    /**
     * CSF CSS Background
     *
     * @param string $selector
     * @param string $value
     * @return void
     */
    static function background( $selector = '', $value = '', $extra_poperty = [] ) {
        $output = '';
        if( ! empty( $selector || $value ) ) {
            if( null != $value ) {
                $from_color = $value['background-color'];
                $bg_color_only = ! empty( $from_color ) ? 'background-color: ' . $from_color .';' : '';
                $to_color = isset( $value['background-gradient-color'] ) ? $value['background-gradient-color'] : '';
                $gradient_dir = isset( $value['background-gradient-direction'] ) ? $value['background-gradient-direction'] : '';
                $gradient_direction = '' != $gradient_dir ? $gradient_dir : 'to bottom';
                $bg_color = ! empty( $from_color && $to_color ) ? 'background: linear-gradient('. $gradient_direction .', '. $from_color .', '. $to_color .');' : $bg_color_only;
                $bg_img = ! empty( $value['background-image']['url'] ) ? 'background-image: url('. $value['background-image']['url'] .');' : '';
                $bg_position = ! empty( $value['background-position'] ) ? 'background-position: ' . $value['background-position'] . ';' : '';
                $bg_repeat = ! empty( $value['background-repeat'] ) ? 'background-repeat: ' . $value['background-repeat'] . ';' : '';
                $bg_atts = ! empty( $value['background-attachment'] ) ? 'background-attachment: ' . $value['background-attachment'] . ';' : '';
                $bg_size = ! empty( $value['background-size'] ) ? 'background-size: ' . $value['background-size'] . ';' : '';
                $bg_origin = ! empty( $value['background-origin'] ) ? 'background-origin: ' . $value['background-origin'] . ';' : '';
                $bg_clip = ! empty( $value['background-clip'] ) ? 'background-clip: ' . $value['background-clip'] . ';' : '';
                $bg_b_mode = ! empty( $value['background-blend-mode'] ) ? 'background-blend-mode: ' . $value['background-blend-mode'] . ';' : '';
                $items = [];
                if( ! empty( $value['background-image']['url'] ) ) {
                    $items[] = ! empty( $bg_color_only ) ? $bg_color_only : '';
                    $items[] = $bg_img;
                    $items[] = $bg_position;
                    $items[] = $bg_repeat;
                    $items[] = $bg_atts;
                    $items[] = $bg_size;
                    $items[] = $bg_origin;
                    $items[] = $bg_clip;
                    $items[] = $bg_b_mode;
                }else{
                    $items[] = ! empty( $from_color && $to_color ) ? $bg_color : $bg_color_only;
                }
                if( ! empty( $bg_color || $bg_img ) ) {
                    if( $items ) {
                        $output .= $selector . '{';
                            foreach( $items as $item ) {
                                if( ! empty( $item ) ) {
                                    $output .= $item;
                                }
                            }
                            if( ! empty( $extra_poperty ) && is_array( $extra_poperty ) ) {
                                foreach ( $extra_poperty as $poperty ) {
                                    $output .= $poperty;
                                }
                            }
                        $output .= '}';
                    }
                }
            }
        }
        return $output;
    }

    /**
     * CSF CSS Text Gradient
     *
     * @param string $value
     * @return void
     */
    static function getGradient( $value = '' ) {
        if( ! empty( $value ) ) {
            if( null != $value ) {
                $from_color = $value['background-color'];
                $color_only = ! empty( $from_color ) ? $from_color .';' : '';
                $to_color = isset( $value['background-gradient-color'] ) ? $value['background-gradient-color'] : '';
                $gradient_dir = isset( $value['background-gradient-direction'] ) ? $value['background-gradient-direction'] : '';
                $gradient_direction = '' != $gradient_dir ? $gradient_dir : 'to bottom';
                $gradient_color = ! empty( $from_color && $to_color ) ? 'linear-gradient('. $gradient_direction .', '. $from_color .', '. $to_color .');' : $color_only . ';';
                return $gradient_color;
            }
        }else{
            return '';
        }
        
    }

    /**
     * CSF CSS Slider
     *
     * @param string $poperty
     * @param string $value
     * @param string $unit
     * @return void
     */
    static function slider( $poperty = 'width', $value = '', $unit = 'px' ) {
        if( ! empty( $value ) && null != $value ) {
            return $poperty . ': ' . $value . $unit . ';';
        }else{
            return '';
        }
    }

    /**
     * CSF CSS Dimensions
     *
     * @param string $value
     * @return void
     */
    static function dimensions( $value = '', $prefix = '' ) {
        $output = '';
        if( ! empty( $value ) && null != $value ) {
            $poperty_prefix = '' != $prefix ? $prefix . '-' : '';
            $unit = ! empty( $value['unit'] ) ? $value['unit'] : '';
            $output .= ! empty( $value['width'] ) ? $poperty_prefix . 'width: ' . $value['width'] . $unit . ';' : '';
            $output .= ! empty( $value['height'] ) ? $poperty_prefix . 'height: ' . $value['height'] . $unit . ';' : '';
        }
        return $output;
    }

    /**
     * CSF CSS Color
     *
     * @param string $poperty
     * @param string $value
     * @return void
     */
    static function color( $poperty = 'color', $value = '' ) {
        if( ! empty( $poperty && $value ) && null != $value ) {
            return $poperty . ': ' . $value . ';';
        }else{
            return '';
        }
    }

    /**
     * CSF Border Helper
     *
     * @param array $value
     * @return void
     */
    static function get_borders( $value = [] ) {
        $bd_items = [];
        $style = '' != $value['style'] ? $value['style'] : 'solid';
        $color = '' != $value['color'] ? $value['color'] : 'transparent';
        $output = '';
        if( array_key_exists( 'top', $value ) && '' != $value['top'] ) {
            $bd_items[] = 'border-top: ' . $value['top'] . 'px ' . $style . ' ' . $color . ';';
        }
        if( array_key_exists( 'right', $value ) && '' != $value['right'] ) {
            $bd_items[] = 'border-right: ' . $value['right'] . 'px ' . $style . ' ' . $color . ';';
        }
        if( array_key_exists( 'bottom', $value ) && '' != $value['bottom'] ) {
            $bd_items[] = 'border-bottom: ' . $value['bottom'] . 'px ' . $style . ' ' . $color . ';';
        }
        if( array_key_exists( 'left', $value ) && '' != $value['left'] ) {
            $bd_items[] = 'border-left: ' . $value['left'] . 'px ' . $style . ' ' . $color . ';';
        }
        if( '' != $bd_items ) {
            foreach( $bd_items as $bd_item ) {
                if( '' != $bd_item ) {
                    $output .= $bd_item;
                }
            }
        }
        return $output;
    }

    /**
     * CSF CSS Border
     *
     * @param array $value
     * @return void
     */
    static function border( $value = [] ) {
        $output = '';
        if( ! empty( $value ) && null != $value ) {
            if ( array_key_exists('all', $value ) ) {
                if( ! empty( $value['style'] && $value['color'] ) && '' != $value['all']  ) {
                    $output .= $value['all'] . 'px ' . $value['style'] . ' ' . $value['color'] . ';';
                }
            }else{
                $output .= self::get_borders ($value );
            }
        }
        return $output;
    }

    /**
     * CSF CSS Spacing
     *
     * @param string $poperty
     * @param array $value
     * @return void
     */
    static function spacing( $poperty = 'margin', $value = [] ) {
        $output = '';
        if( ! empty( $value && $poperty ) && null != $value ) {
            if( array_key_exists( 'all', $value ) ) {
                $output .= '' != $value['all'] ? $poperty . ': ' . $value['all'] . $value['unit'] . ';' : '';
            }else{
                if( array_key_exists( 'top', $value ) ) {
                    $output .= '' != $value['top'] ? $poperty . '-top: ' . $value['top'] . $value['unit'] . ';' : '';
                }
                if( array_key_exists( 'right', $value ) ) {
                    $output .= '' != $value['right'] ? $poperty . '-right: ' . $value['right'] . $value['unit'] . ';' : '';
                }
                if( array_key_exists( 'bottom', $value ) ) {
                    $output .= '' != $value['bottom'] ? $poperty . '-bottom: ' . $value['bottom'] . $value['unit'] . ';' : '';
                }
                if( array_key_exists( 'left', $value ) ) {
                    $output .= '' != $value['left'] ? $poperty . '-left: ' . $value['left'] . $value['unit'] . ';' : '';
                }
            }
        }
        return $output;
    }

    /**
     * CSF CSS Typography
     *
     * @param string $selector
     * @param array $values
     * @return void
     */
    static function typography( $selector = '', $values = [], $poperty = '', $extra_poperty = '' ) {
        $output = '';
        if( ! empty( $selector && $values ) ) {
            if( null != $values ) {
                $items = self::get_typo_items( $values );
                if( $items ) {
                    $output .= $selector . '{';
                        if( ! empty( $poperty ) ) {
                            if( array_key_exists( $poperty, $items ) ) {
                                $output .= $items[$poperty];
                            }
                        }else{
                            foreach( $items as $item ) {
                                $output .= $item;
                            }
                        }
                        if( ! empty( $extra_poperty ) ) {
                            $output .= $extra_poperty;
                        }
                    $output .= '}';
                }
            }
        }
        return $output;
    }

    /**
     * Get Typography Item
     *
     * @param string $poperty
     * @param array $value
     * @return void
     */
    static function get_typo_item( $poperty = '', $value = [] ) {
        if( array_key_exists( $poperty, $value ) ) {
            if( '' != $poperty && '' != $value[$poperty] ) {
                if( 'font-family' === $poperty ) {
                    return $poperty . ': "' . $value[$poperty] . '", sans-serif;';
                }elseif( 'font-size' === $poperty ) {
                    return $poperty . ': ' . $value[$poperty] . $value['unit'] . ';';
                }elseif( 'line-height' === $poperty ) {
                    return $poperty . ': ' . $value[$poperty] . $value['unit'] . ';';
                }elseif( 'letter-spacing' === $poperty ) {
                    return $poperty . ': ' . $value[$poperty] . $value['unit'] . ';';
                }else{
                    return $poperty . ': ' . $value[$poperty] . ';';
                }
            }else{
                return '';
            }
        }else{
            return '';
        }
    }

    /**
     * Get Typography Items as an Array
     *
     * @param array $values
     * @return array
     */
    static function get_typo_items( $values = [] ) {
        $array = [];
        if( $values ) {
            foreach( $values as $key => $value ) {
                if( '' != $value && 'subset' != $key && 'type' != $key && 'unit' != $key ) {
                    $array[$key] = self::get_typo_item( $key, $values );
                }
            }
        }
        return $array;
    }

}