<?php
defined( 'ABSPATH' ) || exit;

// Services
CSF::createSection( 'redias_opt', array(
    'id'    => 'service_sec',
    'title' => esc_html__( 'Service', 'redias' ),
    'icon'  => 'dashicons-before dashicons-buddicons-topics',
) );

// Page Banner
CSF::createSection( 'redias_opt', array(
    'parent' => 'service_sec',
    'title'  => esc_html__( 'Page Banner', 'redias' ),
    'icon'   => 'fa fa-angle-double-right',
    'fields' => array(

        array(
            'type'    => 'subheading',
            'content' => esc_html__( 'Page Banner', 'redias' ),
        ),

        array(
            'id'                       => 'service_page_banner_bg',
            'type'                     => 'background',
            'title'                    => esc_html__( 'Background Image', 'redias' ),
            'subtitle'                 => esc_html__( 'You can change the service page banner background image using this option.', 'redias' ),
            'background_blend_mode'    => false,
            'background_image_preview' => true,
        ),

        array(
            'id'                    => 'service_single_overlay_color',
            'type'                  => 'background',
            'title'                 => esc_html__( 'Overlay Color', 'redias' ),
            'background_gradient'   => true,
            'background_image'   => false,
            'background_position'   => false,
            'background_repeat'   => false,
            'background_attachment'   => false,
            'background_size'   => false,
            'background_image_preview'   => false,
        ),

        array(
            'id'          => 'service_pb_subtitle',
            'type'        => 'text',
            'title'       => esc_html__( 'Subtitle', 'redias' ),
            'subtitle'    => esc_html__( 'You can enter the service page banner subtitle text using this field.', 'redias' ),
            'placeholder' => esc_html__( 'Subtitle goes here..', 'redias' ),
            'default'     => esc_html__( 'Our Services!', 'redias' ),
        ),

        array(
            'id'          => 'service_pb_title',
            'type'        => 'text',
            'title'       => esc_html__( 'Title', 'redias' ),
            'subtitle'    => esc_html__( 'You can enter the service page banner title text using this field.', 'redias' ),
            'placeholder' => esc_html__( 'Title goes here..', 'redias' ),
            'default'     => esc_html__( 'Market-Leading Digital Agency {{Expertise!}}', 'redias' ),
        ),

        array(
            'id'         => 'service_pb_desc',
            'type'       => 'textarea',
            'title'      => esc_html__( 'Description', 'redias' ),
            'subtitle'   => esc_html__( 'You can enter the service page banner description text using this field.', 'redias' ),
            'default'    => esc_html__( 'Everything your digital consulting business needs is already here!', 'redias' ),
            'attributes' => array(
                'rows'        => 4,
                'placeholder' => esc_html__( 'Description...', 'redias' ),
            ),
        ),

    ),
) );

// Service Details
CSF::createSection( 'redias_opt', array(
    'parent' => 'service_sec',
    'title'  => esc_html__( 'Service Details', 'redias' ),
    'icon'   => 'fa fa-angle-double-right',
    'fields' => array(

        array(
            'type'    => 'subheading',
            'content' => esc_html__( 'Service Details', 'redias' ),
        ),

        array(
            'id'         => 'service_bg_img',
            'type'       => 'button_set',
            'title'      => esc_html__('Header Image Source', 'redias'),
            'options'    => array(
                'featured_img'  => esc_html__('Featured Image', 'redias'),
                'custom' => esc_html__('Custom', 'redias')
            ),
            'default'    => 'featured_img'
        ),

        array(
            'id'                       => 'service_page_banner_bg',
            'type'                     => 'background',
            'title'                    => esc_html__('Background Image', 'redias'),
            'subtitle'                 => esc_html__('You can change the service page banner background image using this option.', 'redias'),
            'background_blend_mode'    => false,
            'background_image_preview' => true,
            'dependency' => array('service_bg_img', '!=', 'featured_img')
        ),

        array(
            'id'                    => 'service_overlay_color',
            'type'                  => 'background',
            'title'                 => esc_html__('Header Overlay Color', 'redias'),
            'background_gradient'   => true,
            'background_image'   => false,
            'background_position'   => false,
            'background_repeat'   => false,
            'background_attachment'   => false,
            'background_size'   => false,
            'background_image_preview'   => false
        ),

        array(
            'id'       => 'service_sidebar_layout',
            'type'     => 'select',
            'title'    => esc_html__( 'Sidebar Layout', 'redias' ),
            'subtitle' => esc_html__( 'Choose sidebar layout from this select box.', 'redias' ),
            'options'  => array(
                'default'       => esc_html__( 'Default', 'redias' ),
                'no-sidebar'    => esc_html__( 'No Sidebar', 'redias' ),
                'left-sidebar'  => esc_html__( 'Left Sidebar', 'redias' ),
                'right-sidebar' => esc_html__( 'Right Sidebar', 'redias' ),
            ),
            'default'  => 'right-sidebar'
        ),

        array(
            'id'         => 'service_sidebar_widget',
            'type'       => 'select',
            'title'      => esc_html__( 'Select Sidebar', 'redias' ),
            'subtitle'   => esc_html__( 'Select Sidebar area from this select box.', 'redias' ),
            'options'    => array(
                'default'       => esc_html__( 'Default', 'redias' ),
                'left-sidebar'  => esc_html__( 'Left Sidebar', 'redias' ),
                'right-sidebar' => esc_html__( 'Right Sidebar', 'redias' ),
                'service-sidebar' => esc_html__( 'Service Sidebar', 'redias' ),
                'footer-1'      => esc_html__( 'Footer 1', 'redias' ),
                'footer-2'      => esc_html__( 'Footer 2', 'redias' ),
                'footer-3'      => esc_html__( 'Footer 3', 'redias' ),
                'footer-4'      => esc_html__( 'Footer 4', 'redias' )
            ),
            'default'    => 'service-sidebar',
            'dependency' => array( 'service_sidebar_layout|service_sidebar_layout', '!=|!=', 'default|no-sidebar' ),
        ),

        array(
            'id'       => 'service_navigation',
            'type'     => 'button_set',
            'title'    => esc_html__( 'Navigation', 'redias' ),
            'subtitle' => esc_html__( 'You can show or hide service navigation from the blog details page.', 'redias' ),
            'options'  => array(
                'show' => esc_html__( 'Show', 'redias' ),
                'hide' => esc_html__( 'Hide', 'redias' ),
            ),
            'default'  => 'show',
        ),

        array(
            'id'       => 'service_comments',
            'type'     => 'button_set',
            'title'    => esc_html__( 'Comments', 'redias' ),
            'subtitle' => esc_html__( 'You can show or hide service comments using this option.', 'redias' ),
            'options'  => array(
                'show' => esc_html__( 'Show', 'redias' ),
                'hide' => esc_html__( 'Hide', 'redias' ),
            ),
            'default'  => 'hide'
        ),

        array(
            'id'       => 'service_post_share',
            'type'     => 'button_set',
            'title'    => esc_html__( 'Social Share Buttons', 'redias' ),
            'subtitle' => esc_html__( 'You can show or hide service social share buttons using this option.', 'redias' ),
            'options'  => array(
                'show' => esc_html__( 'Show', 'redias' ),
                'hide' => esc_html__( 'Hide', 'redias' ),
            ),
            'default'  => 'show',
        ),

    ),
) );