<?php
/**
 * Sidebar Check Class
 *
 * @package Redias
 */

class RediasSidebar {

    /**
     * Sidebar Activation
     *
     * @param string $sidebar_id
     * @param string $cls_name
     * @return void
     */
    static function get_sidebar_active( $sidebar_id = 'right-sidebar', $cls_name = 'right-sidebar' ) {
        if ( is_active_sidebar( $sidebar_id ) ) {
            return $cls_name;
        } else {
            return 'full-width';
        }
    }

    /**
     * Single sidebar status check
     *
     * @param array $args
     * @param array keys [ 'meta_layout', 'meta_widget', 'global_layout', 'global_widget', 'blog_layout', 'blog_widget' ]
     * @return string
     */
    static function single_sidebar_status( $args = [] ) {
        $output = '';
        if ( 'default' != $args['meta_layout'] ) {
            if ( 'no-sidebar' === $args['meta_layout'] ) {
                $output = 'full-width test';
            } else {
                $msb_right = 'default' === $args['meta_widget'] ? self::get_sidebar_active( $args['global_widget'], 'right-sidebar' ) : self::get_sidebar_active( $args['meta_widget'], 'right-sidebar' );
                $msb_left  = 'default' === $args['meta_widget'] ? self::get_sidebar_active( $args['global_widget'], 'left-sidebar' ) : self::get_sidebar_active( $args['meta_widget'], 'left-sidebar' );
                $output = 'right-sidebar' === $args['meta_layout'] ? $msb_right : $msb_left;
            }
        } else {
            if ( 'default' != $args['blog_layout'] ) {
                if ( 'no-sidebar' === $args['blog_layout'] ) {
                    $output = 'full-width';
                } else {
                    $sb_right = 'default' === $args['blog_widget'] ? self::get_sidebar_active( $args['global_widget'], 'right-sidebar' ) : self::get_sidebar_active( $args['blog_widget'], 'right-sidebar' );
                    $sb_left  = 'default' === $args['blog_widget'] ? self::get_sidebar_active( $args['global_widget'], 'left-sidebar' ) : self::get_sidebar_active( $args['blog_widget'], 'left-sidebar' );
                    $output   = 'right-sidebar' === $args['blog_layout'] ? $sb_right : $sb_left;
                }
            } else {
                if ( 'no-sidebar' === $args['global_layout'] ) {
                    $output = 'full-width';
                } else {
                    $output = 'right-sidebar' === $args['global_layout'] ? self::get_sidebar_active( $args['global_widget'], 'right-sidebar' ) : self::get_sidebar_active( $args['global_widget'], 'left-sidebar' );
                }
            }
        }
        return $output;
    }

    /**
     * Page sidebar status check
     *
     * @param array $args
     * @param array keys ['meta_layout', 'meta_widget', 'global_layout', 'global_widget']
     * @return void
     */
    static function page_sidebar_status( $args = [] ) {
        $output = 'full-width';
        if ( 'default' != $args['meta_layout'] ) {
            if ( 'no-sidebar' === $args['meta_layout'] ) {
                $output = 'full-width';
            } else {
                $msb_right = 'default' === $args['meta_widget'] ? self::get_sidebar_active( $args['global_widget'], 'right-sidebar' ) : self::get_sidebar_active( $args['meta_widget'], 'right-sidebar' );
                $msb_left  = 'default' === $args['meta_widget'] ? self::get_sidebar_active( $args['global_widget'], 'left-sidebar' ) : self::get_sidebar_active( $args['meta_widget'], 'left-sidebar' );
                $output = 'right-sidebar' === $args['meta_layout'] ? $msb_right : $msb_left;
            }
        } else {
            if ( 'no-sidebar' === $args['global_layout'] ) {
                $output = 'full-width';
            } else {
                $output = 'right-sidebar' === $args['global_layout'] ? self::get_sidebar_active( $args['global_widget'], 'right-sidebar' ) : self::get_sidebar_active( $args['global_widget'], 'left-sidebar' );
            }
        }
        return $output;
    }

    /**
     * Sidebar status check
     *
     * @param array $args
     * @param array keys ['global_layout', 'global_widget']
     * @return void
     */
    static function sidebar_status( $args = [] ) {
        $output = 'full-width';
        if ( 'no-sidebar' === $args['global_layout'] ) {
            $output = 'full-width';
        } else {
            $output = 'right-sidebar' === $args['global_layout'] ? self::get_sidebar_active( $args['global_widget'], 'right-sidebar' ) : self::get_sidebar_active( $args['global_widget'], 'left-sidebar' );
        }
        return $output;
    }

    /**
     * Get sidebar widget ID
     *
     * @param string $meta_widget
     * @param string $global_widget
     * @param string $blog_widget
     * @return void
     */
    static function sidebar_widget_id( $meta_widget = 'default', $global_widget = 'right-sidebar', $blog_widget = 'right-sidebar', $service_widget = 'service-sidebar' ) {
        $sidebar_id = '';
        if ( 'default' != $meta_widget ) {
            $sidebar_id = $meta_widget;
        } else {
            if ( is_page() ) {
                $sidebar_id = $global_widget;
            } elseif ( is_single() ) {
                $sidebar_id = 'default' != $blog_widget ? $blog_widget : $global_widget;
            }elseif ( is_singular('dl-service') ) {
                $sidebar_id = 'default' != $service_widget ? $service_widget : $global_widget;
            }
        }
        return $sidebar_id;
    }
    
}