<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Redias
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function redias_body_classes( $classes ) {
    // Adds a class of hfeed to non-singular pages.
    if ( ! is_singular() ) {
        $classes[] = 'hfeed';
    }

    $header_type = redias_get_option( 'header_type', '1' );
    $custom_page_header = RediasHelper::get_meta_field( 'redias_header_style', 'default' );

    if( 'default' != $custom_page_header ) {
        if( '1' === $custom_page_header ) {
            $classes[] = 'header-default';
        }else{
            $classes[] = 'header-2';
        }
    }else{
        if( '1' === $header_type ) {
            $classes[] = 'header-default';
        }else{
            $classes[] = 'header-2';
        }
    }
    

    if( has_nav_menu( 'primary' ) ) {
        $classes[] = 'is-primary-menu';
    }
    // Page Banner
    $global_banner = redias_get_option( 'ph_visibility', 'show' );
    if ( is_page() ) {
        $banner_meta = RediasHelper::get_meta_field( 'redias_page_header', 'default' );
        if ( 'default' != $banner_meta && 'hide' === $banner_meta ) {
            $classes[] = 'no-page-banner';
        } else {
            if ( 'hide' === $global_banner ) {
                $classes[] = 'no-page-banner';
            }
        }
    } else {
        if ( 'hide' === $global_banner ) {
            $classes[] = 'no-page-banner';
        }
    }

    if( 'show_all' === redias_get_option('preloader_control', 'show_all') ) {
        $classes[] = 'is-preloader';
    } elseif( 'only_home' === redias_get_option('preloader_control', 'show_all') ) {
        if( is_home() ) {
            $classes[] = 'is-preloader';
        }
    }

    if( 'enable' === redias_get_option('header_sticky', 'enable') ) {
        $classes[] = 'sticky-enable';
    }

    return $classes;
}
add_filter( 'body_class', 'redias_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function redias_pingback_header() {
    if ( is_singular() && pings_open() ) {
        printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
    }
}
add_action( 'wp_head', 'redias_pingback_header' );

/**
 * Add Logo Uploader in the Customizer
 *
 * @param [type] $wp_customize
 * @return void
 */
function redias_custom_logo_uploader( $wp_customize ) {

    $wp_customize->add_setting( 'redias_retina_logo', array(
        'sanitize_callback' => 'esc_attr',
    ) );

    $wp_customize->add_setting( 'redias_sticky_logo', array(
        'sanitize_callback' => 'esc_attr',
    ) );

    $wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'redias_retina_logo', array(
        'label'         => esc_html__( 'Retina Logo', 'redias' ),
        'section'       => 'title_tagline',
        'settings'      => 'redias_retina_logo',
        'mime_type'     => 'image',
        'priority'      => 9,
        'width'         => 360,
        'height'        => 80,
        'flex_width'    => true,
        'flex_height'   => true,
        'button_labels' => array(
            'select'       => esc_html__( 'Select Retina Logo', 'redias' ),
            'change'       => esc_html__( 'Change Logo', 'redias' ),
            'remove'       => esc_html__( 'Remove', 'redias' ),
            'default'      => esc_html__( 'Default', 'redias' ),
            'placeholder'  => esc_html__( 'No logo selected', 'redias' ),
            'frame_title'  => esc_html__( 'Select Retina Logo', 'redias' ),
            'frame_button' => esc_html__( 'Choose Logo', 'redias' ),
        ),
    ) ) );

    $wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'redias_sticky_logo', array(
        'label'         => esc_html__( 'Sticky Logo', 'redias' ),
        'section'       => 'title_tagline',
        'settings'      => 'redias_sticky_logo',
        'mime_type'     => 'image',
        'priority'      => 9,
        'width'         => 360,
        'height'        => 80,
        'flex_width'    => true,
        'flex_height'   => true,
        'button_labels' => array(
            'select'       => esc_html__( 'Select Sticky Logo', 'redias' ),
            'change'       => esc_html__( 'Change Logo', 'redias' ),
            'remove'       => esc_html__( 'Remove', 'redias' ),
            'default'      => esc_html__( 'Default', 'redias' ),
            'placeholder'  => esc_html__( 'No logo selected', 'redias' ),
            'frame_title'  => esc_html__( 'Select Sticky Logo', 'redias' ),
            'frame_button' => esc_html__( 'Choose Logo', 'redias' ),
        ),
    ) ) );

}
add_action( 'customize_register', 'redias_custom_logo_uploader' );

/**
 * Modify Comment Date
 */
if ( ! function_exists( 'redias_comment_date' ) ) {
    function redias_comment_date( $date ) {
        $date = date( "F j, Y" );
        return $date;
    }
}
add_filter( 'get_comment_date', 'redias_comment_date' );