<?php
/**
 * Template hooks for this theme
 *
 * @package Redias
 */

// Header
function redias_header_hook() {
    $header_type = redias_get_option( 'header_type', '1' );
    $custom_page_header = RediasHelper::get_meta_field( 'redias_header_style', 'default' );
    if( 'default' != $custom_page_header ) {
        get_template_part( 'global-templates/header/header', $custom_page_header );
    }else{
        get_template_part( 'global-templates/header/header', $header_type );
    }
}
add_action( 'redias_header', 'redias_header_hook' );

// Header Site Branding
function redias_header_site_branding() {
    $custom_logo     = RediasHelper::get_meta_field( 'redias_custom_logo' );
    $custom_logo_src = wp_get_attachment_image_src( $custom_logo, 'full' );
    $custom_logo_url = ! empty( $custom_logo_src ) ? $custom_logo_src[0] : '';
    $site_logo       = get_theme_mod( 'custom_logo' );
    $site_logo_url   = ! empty( $site_logo ) ? wp_get_attachment_url( $site_logo ) : '';
    $retina_logo     = RediasHelper::get_retina_logo( 'redias_retina_logo' );
    $fallback_logo   = get_template_directory_uri() . '/assets/img/logo.png';
    if ( ! empty( $custom_logo_url ) ) {
        $logo_url = $custom_logo_url;
    } else {
        if ( ! has_custom_logo() ) {
            $logo_url = $fallback_logo;
        } else {
            $logo_url = $site_logo_url;
        }
    }
    echo '<img src="' . esc_url( $logo_url ) . '" ' . wp_kses( $retina_logo, RediasHelper::get_allowed_html_tags( 'intermediate' ) ) . ' alt="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '"/>';
}
add_action( 'redias_site_branding', 'redias_header_site_branding' );

// Single Post Banner
function redias_single_post_banner() {
    get_template_part( 'global-templates/post', 'banner' );
}
add_action( 'redias_single_post_banner', 'redias_single_post_banner' );

// Page Banner
function redias_page_banner() {
    if ( ! is_single() && ! is_404() ) {
        $global_visibility = redias_get_option( 'ph_visibility', 'show' );
        if ( is_page() ) {
            $ph_visibility = RediasHelper::get_meta_field( 'redias_page_header', 'default' );
            if ( 'default' != $ph_visibility ) {
                if ( 'show' === $ph_visibility ) {
                    get_template_part( 'global-templates/page', 'banner' );
                }
            } else {
                if ( 'show' === $global_visibility ) {
                    get_template_part( 'global-templates/page', 'banner' );
                }
            }
        } else {
            if ( 'show' === $global_visibility ) {
                get_template_part( 'global-templates/page', 'banner' );
            }
        }
    }
}
add_action( 'redias_page_banner', 'redias_page_banner' );

// Single Post Banner
function redias_single_project_banner() {
    get_template_part( 'global-templates/project', 'banner' );
}
add_action( 'redias_single_project_banner', 'redias_single_project_banner' );

// Social Share
function redias_social_share() {
    $redias_pin_img = ! empty( RediasHelper::get_featured_image_url() ) ? 'data-image="'. esc_url( RediasHelper::get_featured_image_url() ) .'"' : '';
    $title = get_the_title();
    $tw_hastag = '';
    $fb_hastag = '';
    $pin_img = $redias_pin_img;
    if( is_single() ) {
        $title = ! empty( RediasHelper::get_field('dl_description') ) ? RediasHelper::get_field('dl_description') : get_the_title();
        $hastags = RediasHelper::get_field('dl_hashtags');
        $tw_hastag = ! empty( $hastags ) ? ' data-hashtags="'. $hastags .'"' : '';
        if( ! empty( $hastags ) ) {
            $hastags_arr = preg_split ("/\,/", $hastags);
            $fb_hastag = ' data-hashtag="'. $hastags_arr[0] .'"';
        }
        $pin_img = RediasHelper::get_field('dl_pinterest_image');
        if( ! empty( $pin_img ) ) {
            $redias_pin_img = 'data-image="'. $pin_img .'"';
        }
    }
    ?>
    <div class="post-social-share brand-color">
        <div class="facebook cursor-effect sound-effect" data-sharer="facebook"<?php echo RediasHelper::kses_advance( $fb_hastag ); ?> data-url="<?php the_permalink(); ?>" data-title="<?php echo esc_attr( $title ); ?>"><i class="la la-facebook"></i></div>
        <div class="twitter cursor-effect sound-effect" data-sharer="twitter"<?php echo RediasHelper::kses_advance( $tw_hastag ); ?>  data-title="<?php echo esc_attr( $title ); ?>" data-url="<?php the_permalink(); ?>"><i class="la la-twitter"></i></div>
        <div class="pinterest cursor-effect sound-effect" data-sharer="pinterest" data-description="<?php echo esc_attr( $title ); ?>" data-url="<?php the_permalink(); ?>" <?php echo RediasHelper::kses_advance( $redias_pin_img ); ?>><i class="la la-pinterest-p"></i></div>
        <div class="linkedin cursor-effect sound-effect" data-sharer="linkedin" data-url="<?php the_permalink(); ?>" data-title="<?php echo esc_attr( $title ); ?>"><i class="la la-linkedin"></i></div>
    </div>
    <?php
}
add_action( 'redias_social_share', 'redias_social_share' );

/**
 * 404 Page Template Action
 *
 * @return void
 */
function redias_404_page_template() {
    $template = redias_get_option( 'redias_404_template', 'default' );
    if ( 'default' === $template ) {
        get_template_part( 'global-templates/404', 'template' );
    } else {
        $el_block = redias_get_option( 'redias_404_el' );
        if ( ! empty( $el_block ) ) {
            RediasHelper::loop_by_id( $el_block, 'elementor_library' );
        } else {
            get_template_part( 'global-templates/404', 'template' );
        }
    }
}
add_action( 'redias_404_page_template', 'redias_404_page_template' );

/**
 * Redias Footer Hook
 *
 * @return void
 */
function redias_footer() {
    $page_footer = RediasHelper::get_field( 'redias_template_style' );
    $el_template = RediasHelper::get_field( 'redias_el_template' );
    if ( 'default' != $page_footer ) {
        if ( ! empty( $el_template ) ) {
            RediasHelper::loop_by_id( $el_template, 'elementor_library' );
        } else {
            do_action( 'redias_footer_template' );
        }
    } else {
        do_action( 'redias_footer_template' );
    }
}
add_action( 'redias_footer', 'redias_footer' );

/**
 * Footer template
 *
 * @return void
 */
function redias_footer_template() {
    $footer_template = redias_get_option( 'redias_footer_template', 'default' );
    $el_template     = redias_get_option( 'redias_el_template' );
    if ( 'default' === $footer_template ) {
        get_template_part( 'global-templates/footer-widget', 'template' );
    } else {
        if ( ! empty( $el_template ) ) {
            RediasHelper::loop_by_id( $el_template, 'elementor_library' );
        } else {
            get_template_part( 'global-templates/footer-widget', 'template' );
        }
    }

}
add_action( 'redias_footer_template', 'redias_footer_template' );

/**
 * Preloader
 *
 * @return void
 */
function redias_preloader() {
    if( 'show_all' === redias_get_option('preloader_control', 'show_all') ) {
        echo '<div id="preloader-wrap"><div class="spinner"></div></div>';
    } elseif( 'only_home' === redias_get_option('preloader_control', 'show_all') ) {
        if( is_home() ) {
            echo '<div id="preloader-wrap"><div class="spinner"></div></div>';
        }
    }
}
add_action( 'redias_preloader', 'redias_preloader' );

/**
 * Header Cart Button
 *
 * @return void
 */
function redias_header_cart_btn() {
    ?>
    <div class="dl-shopping-cart-btn cursor-effect">
        <span class="shopping-cart-inner">
            <span class="count redias-cart-count">0</span>
            <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 32"><path d="M 16 3 C 13.253906 3 11 5.253906 11 8 L 11 9 L 6.0625 9 L 6 9.9375 L 5 27.9375 L 4.9375 29 L 27.0625 29 L 27 27.9375 L 26 9.9375 L 25.9375 9 L 21 9 L 21 8 C 21 5.253906 18.746094 3 16 3 Z M 16 5 C 17.65625 5 19 6.34375 19 8 L 19 9 L 13 9 L 13 8 C 13 6.34375 14.34375 5 16 5 Z M 7.9375 11 L 11 11 L 11 14 L 13 14 L 13 11 L 19 11 L 19 14 L 21 14 L 21 11 L 24.0625 11 L 24.9375 27 L 7.0625 27 Z"></path></svg>
        </span>
    </div>
    <?php
}

/**
 * Header cart button action
 *
 * @return void
 */
function redias_header_cart_btn_action() {
    if( class_exists('WooCommerce') ) {
        if ( apply_filters( 'woocommerce_widget_cart_is_hidden', is_cart() || is_checkout() ) ) {
            return;
        }
        $woo_cart = redias_get_option( 'woo_cart', 'all' );
        if( 'all' === $woo_cart ) {
            redias_header_cart_btn();
        }elseif( 'woo' === $woo_cart && ( is_woocommerce() || is_cart() || is_checkout() || is_account_page() ) ) {
            redias_header_cart_btn();
        }
    }
}
add_action( 'redias_header_cart', 'redias_header_cart_btn_action' );

/**
 * Header cart view
 *
 * @return void
 */
function redias_header_cart_view() {
    $woo_cart = redias_get_option( 'woo_cart','all' );
    if( class_exists('WooCommerce') ) {
        if ( apply_filters( 'woocommerce_widget_cart_is_hidden', is_cart() || is_checkout() ) ) {
            return;
        }
        if( 'all' === $woo_cart ) {
            get_template_part('global-templates/cart', 'overlay');
        }elseif( 'woo' === $woo_cart  && ( is_woocommerce() || is_cart() || is_checkout() || is_account_page() ) ) {
            get_template_part('global-templates/cart', 'overlay');
        }
    }
}
add_action( 'redias_header_cart_view', 'redias_header_cart_view' );