<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Redias
 */

if ( ! function_exists( 'redias_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function redias_posted_on() {
		$archive_year  = get_the_time( 'Y' );
		$archive_month = get_the_time( 'm' );
		$archive_day   = get_the_time( 'd' );
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}
		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date('M j, Y') ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date( 'M j, Y' ) )
		);
		echo '<a href="' . esc_url( get_day_link( $archive_year, $archive_month, $archive_day ) ) . '" rel="bookmark"><i class="la la-calendar"></i>' . $time_string . '</a>';
	}
endif;

if ( ! function_exists( 'redias_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function redias_posted_by( $avatar = false ) {
		$author_id = get_the_author_meta( 'ID' );
		if ( empty( $author_id ) && ! empty( $GLOBALS['post']->post_author ) ) {
			$author_id = $GLOBALS['post']->post_author;
		}
		if ( $author_id > 0 ) {
			$author_link   = get_author_posts_url( $author_id );
			$author_name   = get_the_author_meta( 'display_name', $author_id );
			
			if( $avatar === true ) {
				$author_avatar = get_avatar( get_the_author_meta( 'user_email', $author_id ), 80 );
				echo '<a href="'. esc_url( $author_link ) .'" class="author">'. RediasHelper::kses_advance( $author_avatar ) . esc_html( $author_name ) .'</a>';
			}else{
				echo '<a href="'. esc_url( $author_link ) .'"><i class="la la-user"></i>'. esc_html( $author_name ) .'</a>';
			}
		}
	}
endif;

if ( ! function_exists( 'redias_comments_link' ) ) :

	function redias_comments_link() {
		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			?>
			<a class="post-comments" href="<?php comments_link(); ?>">
				<i class="la la-comments"></i>
				<?php 
				comments_number( 
					esc_html__( 'No Comments', 'redias' ), 
					esc_html__( '1 Comment', 'redias' ), 
					esc_html__( '% Comments', 'redias' ) 
				); 
				?>
			</a>
			<?php
		}
	}

endif;

if ( ! function_exists( 'redias_entry_header' ) ) :
	/**
	 * Prints HTML with meta information for the author, date and comments.
	 */
	function redias_entry_header($avatar = false) {
		$post_author = redias_get_option( 'blog_post_author', 'show' );
		$post_date = redias_get_option( 'blog_post_date', 'show' );
		$post_comments = redias_get_option( 'blog_post_comments', 'show' );
		$post_edit = redias_get_option( 'blog_post_edit', 'show' );
		if( 'show' === $post_author || 'show' === $post_date || 'show' === $post_comments || 'show' === $post_edit ) :
		?>
		<div class="post-meta"> <?php
			if( 'show' === $post_author ) {
				redias_posted_by( $avatar );
			}
			if( 'show' === $post_date ) {
				redias_posted_on();
			}
			if( is_single() ) {
				if( 'show' === $post_comments ) {
					redias_comments_link();
				}
			}
			if( 'show' === $post_edit ) {
				$post_edit_link = get_edit_post_link();
				if( ! empty( $post_edit_link ) ) {
					echo '<a href="'. esc_url( $post_edit_link ) .'" title="'. esc_html__( 'Edit Post', 'redias' ) .'"><i class="la la-edit"></i></a>';
				}
			}
		?>
		</div>
		<?php
		endif;
	}
endif;

if ( ! function_exists( 'redias_excerpt' ) ) {
	/**
	 * Excerpt Lenth
	 */
	function redias_excerpt( $limit = 20, $suffix = '...' ) {
		$excerpt = explode( ' ', get_the_excerpt(), $limit );
		if ( count( $excerpt ) >= $limit ) {
			array_pop( $excerpt) ;
			$excerpt = implode( " ",$excerpt ) . $suffix;
		} else {
			$excerpt = implode( " ",$excerpt );
		}
		$excerpt = preg_replace( '`[[^]]*]`','', $excerpt );
		return $excerpt;
	}
}

if ( ! function_exists( 'redias_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function redias_post_thumbnail( $size = 'post-thumbnail' ) {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		} 
		$cat_pos = redias_get_option( 'blog_post_cat_pos', 'bottom-left' );
		?>
		<div class="post-thumbnail <?php echo esc_attr( $cat_pos ); ?>">
			<a href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
				<?php
					the_post_thumbnail(
						$size,
						array(
							'alt' => the_title_attribute(
								array(
									'echo' => false,
								)
							),
						)
					);
				?>
			</a>
			<?php 
			if( 'show' === redias_get_option( 'blog_post_cat', 'show' ) ) {
				RediasHelper::get_terms('category');
			}
			?>
		</div>
		<?php
	}
endif;

if ( ! function_exists( 'redias_post_nav' ) ):
	/**
	 * Display navigation to next/previous post when applicable.
	 *
	 * @return void
	 */
    function redias_post_nav() {
        // Don't print empty markup if there's nowhere to navigate.
        $previous        = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
        $next            = get_adjacent_post( false, '', false );
        $prev_thumb_url  = get_the_post_thumbnail_url( get_previous_post(), 'medium' );
        $next_thumb_url  = get_the_post_thumbnail_url( get_next_post(), 'medium' );
        $prev_thumb      = ! empty( $prev_thumb_url ) ? 'background-image: url('. esc_url( $prev_thumb_url ) .');' : '';
        $next_thumb      = ! empty( $next_thumb_url ) ? 'background-image: url('. esc_url( $next_thumb_url ) .');' : '';

        if ( ! $next && ! $previous ) {
            return;
        }
		$cls = '';
		if( is_singular( 'redias-projects' ) && 'show' == redias_get_option( 'project_nav_btn', 'show' ) ) {
			$cls = ' all-projects';
		}
		?>
		<div class="nav-links-single<?php echo esc_attr( $cls ); ?>">
			<nav class="navigation post-navigation" role="navigation" aria-label="Posts">
				<div class="nav-links">
				<?php
					$prev_post = get_previous_post();
					if ( $prev_post ): ?>
					<div class="nav-previous<?php echo ! empty( $prev_thumb ) ? ' has-image' : ' no-image'; ?>" style="<?php echo esc_attr( $prev_thumb ); ?>">
						<a href="<?php echo get_the_permalink( $prev_post ); ?>" rel="prev">
							<div class="nav-text">
								<span class="post-text"><i class="la la-long-arrow-alt-left"></i><?php esc_html_e( 'Previous', 'redias' );?></span>
								<h6 class="post-title"><?php echo esc_html( get_the_title( $prev_post->ID ) ); ?></h6>
							</div>
						</a>
					</div>
					<?php else: ?>
						<div class="nav-previous"></div>
					<?php endif;
					
					if( is_singular( 'dl-project' ) && 'show' == redias_get_option( 'project_navigation', 'show' ) ) :
						$nav_title = redias_get_option( 'project_nav_btn_title', esc_html__( 'View All Projects', 'redias' ) );
						$nav_btn_url = ! empty( redias_get_option('project_nav_btn_link') ) ? redias_get_option('project_nav_btn_link') : get_post_type_archive_link( 'dl-project');
					?>
					<div class="all-projects">
						<a href="<?php echo esc_url( $nav_btn_url ); ?>" title="<?php echo esc_attr( $nav_title ); ?>"><svg xmlns="http://www.w3.org/2000/svg" height="30" viewBox="0 0 444 444" width="30"><path d="M7 0h181a7 7 0 0 1 7 7v181a7 7 0 0 1-7 7H7a7 7 0 0 1-7-7V7a7 7 0 0 1 7-7zm249 0h181a7 7 0 0 1 7 7v181a7 7 0 0 1-7 7H256a7 7 0 0 1-7-7V7a7 7 0 0 1 7-7zM7 249h181a7 7 0 0 1 7 7v181a7 7 0 0 1-7 7H7a7 7 0 0 1-7-7V256a7 7 0 0 1 7-7zm249 0h181a7 7 0 0 1 7 7v181a7 7 0 0 1-7 7H256a7 7 0 0 1-7-7V256a7 7 0 0 1 7-7zm0 0"/></svg></a>
					</div>
					<?php
					endif;

					$next_post = get_next_post();
					if ( $next_post ): ?>
					<div class="nav-next<?php echo ! empty( $next_thumb ) ? ' has-image' : ' no-image'; ?>" style="<?php echo esc_attr( $next_thumb ); ?>">
						<a href="<?php echo get_the_permalink( $next_post ); ?>" rel="next">
							<div class="nav-text">
								<span class="post-text"><?php esc_html_e( 'Next', 'redias' );?><i class="la la-long-arrow-alt-right"></i></span>
								<h6 class="post-title"><?php echo esc_html( get_the_title( $next_post->ID ) ); ?></h6>
							</div>
						</a>
					</div>
					<?php else : ?>
						<div class="nav-next"></div>
					<?php endif;?>
				</div>
			</nav>
		</div>
		<?php
    }
endif;

if ( ! function_exists( 'redias_author_box' ) ) :
	/**
	 * Author Box
	 *
	 */
	function redias_author_box() {
		global $post;
		if ( is_single() && isset( $post->post_author ) ) {

			// Get author's display name
            $display_name = get_the_author_meta( 'display_name', $post->post_author );

            // If display name is not available then use nickname as display name
            if ( empty( $display_name ) ) {
                $display_name = get_the_author_meta( 'nickname', $post->post_author );
            }
			
			// Author posts link
            $posts_link = get_author_posts_url( get_the_author_meta( 'ID', $post->post_author ), get_the_author_meta( 'nickname', $post->post_author ) );

            // Get author's biographical information or description
            $user_description = get_the_author_meta( 'user_description', $post->post_author );
			if( empty( $user_description ) ) {
				$desc_cls = ' no-desc';
			}else{
				$desc_cls = '';
			}
			?>
			<div class="post-author-box<?php echo esc_attr( $desc_cls ); ?>">
				<a href="<?php echo esc_url( $posts_link ); ?>" class="author-avatar">
					<?php echo get_avatar( get_the_author_meta( 'user_email', $post->post_author ), 150 ); ?>
				</a>
				<div class="author-info">
					<h3><a href="<?php echo esc_url( $posts_link ); ?>"><?php echo esc_html( $display_name ); ?></a></h3>
					<?php if( ! empty( $user_description ) ) : ?>
						<p><?php echo RediasHelper::kses_basic( $user_description ); ?></p>
					<?php endif; 
					if( function_exists('get_field') ) : 
					$social_profiles = get_field('redias_social_links', 'user_' . get_the_author_meta( 'ID', $post->post_author ) );
					if( $social_profiles ) :
					?>
					<ul>
						<?php 
						foreach ($social_profiles as $social_profile ) {
							if( ! empty( $social_profile['type'] && $social_profile['link'] ) ) {
								echo '<li><a href="'. esc_url( $social_profile['link'] ) .'" target="_blank"><i class="la la-'. esc_attr( $social_profile['type'] ) .'"></i></a></li>';
							}
						}
						?>
					</ul>
					<?php 
					endif;
					endif; ?>
				</div>
			</div>
			<?php
		}
	}
endif;

if ( ! function_exists( 'redias_the_posts_navigation' ) ) :
	/**
	 * Post Navigation
	 *
	 * @return void
	 */
	function redias_the_posts_navigation() {
		the_posts_pagination(
			array(
				'mid_size'  => 2,
				'prev_text' => sprintf(
					'%s',
					'<i class="dl dl-long-arrow-alt-left"></i>'
				),
				'next_text' => sprintf(
					'%s',
					'<i class="dl dl-long-arrow-alt-right"></i>'
				),
			)
		);
	}
	
endif;

if ( ! function_exists( 'wp_body_open' ) ) :
	/**
	 * Shim for sites older than 5.2.
	 *
	 * @link https://core.trac.wordpress.org/ticket/12563
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
endif;

/**
 * Sidebar Activation
 */
if( ! function_exists('redias_sidebar_activation') ) {
	function redias_sidebar_activation( $options = [] ) {
		if( empty( $options ) ) {
			return '';
		}
		$args = [
			'meta' => [
				'layout' => isset( $options['meta_layout'] ) ? $options['meta_layout'] : 'default',
				'area' => isset( $options['meta_area'] ) ? $options['meta_area'] : 'default'
			],
			'opt' => [
				'layout' => isset( $options['opt_layout'] ) ? $options['opt_layout'] : 'right-sidebar',
				'area' => isset( $options['opt_area'] ) ? $options['opt_area'] : 'right-sidebar'
			]
		];
		$meta = $args['meta'];
		$opt = $args['opt'];
		$output = '';
		if( 'default' != $meta['layout'] ) {
			$sidebar_id = 'default' != $meta['area'] ? $meta['area'] : $opt['area'];
			if( 'right-sidebar' === $meta['layout'] ) {
				$output = RediasSidebar::get_sidebar_active( $sidebar_id, 'right-sidebar');
			}elseif( 'left-sidebar' === $meta['layout'] ) {
				$output = RediasSidebar::get_sidebar_active( $sidebar_id, 'left-sidebar');
			}else{
				$output = 'full-width';
			}
		}else{
			if( 'right-sidebar' === $opt['layout'] ) {
				$output = RediasSidebar::get_sidebar_active( $opt['area'], 'right-sidebar');
			}elseif( 'left-sidebar' === $opt['layout'] ) {
				$output = RediasSidebar::get_sidebar_active( $opt['area'], 'left-sidebar');
			}else{
				$output = 'full-width';
			}
		}
		return $output;
	}
}