<?php
/**
 * The template for displaying single project
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#single-post
 *
 * @package Redias
 */

get_header();
$redias_sub_heading = RediasHelper::get_meta_field( 'sub_heading' );
$redias_heading = RediasHelper::get_meta_field( 'big_heading' );
$redias_desc = RediasHelper::get_meta_field( 'short_description' );
$redias_project_heading = RediasHelper::get_meta_field( 'project_info_heading' );
$redias_project_desc = RediasHelper::get_meta_field( 'project_info_desc' );
$redias_project_info = ! empty( RediasHelper::get_meta_field( 'project_info' ) ) ? RediasHelper::get_meta_field( 'project_info' ) : [];
$redias_bg_img = '';
if( 'featured_img' === redias_get_option('project_bg_img', 'featured_img') ) {
	$redias_bg_img_src = wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'full' );
	$redias_bg_img_url = isset($redias_bg_img_src[0]) ? $redias_bg_img_src[0] : '';
	$redias_bg_img = ! empty( $redias_bg_img_url ) ? 'style="background-image: url('. $redias_bg_img_url .')"' : '';
}
?>

<section class="service-header-area" <?php echo RediasHelper::kses_basic( $redias_bg_img ); ?>>
	<div class="<?php RediasHelper::theme_layout(); ?>">
		<div class="service-header-content">
			<?php
				if( ! empty( $redias_sub_heading ) ) {
					echo '<h4>'. esc_html( $redias_sub_heading ) .'</h4>';
				}
				if( ! empty( $redias_heading ) ){
					echo '<h2>'. RediasHelper::kses_advance( RediasHelper::get_highlighted_text( $redias_heading ) ) .'</h2>';
				}else{
					echo '<h2>'. RediasHelper::kses_advance( get_the_title() ) .'</h2>';
				}
				if( ! empty( $redias_desc ) ) {
					echo '<p>'. RediasHelper::kses_basic( $redias_desc ) .'</p>';
				}else{
					echo '<p>'. RediasHelper::kses_basic( RediasHelper::get_the_excerpt() ) .'</p>';
				}
			?>
		</div>
	</div>
</section><!-- ./service-header-area -->

<section class="wrapper">
	<div class="<?php RediasHelper::theme_layout(); ?>">
		<main id="primary" class="site-main">
			<div id="post-<?php the_ID(); ?>" <?php post_class( array( 'project-content' ) ); ?>>
			<?php
			while ( have_posts() ) : ?>
				<div class="project-head">
					<?php
					if( has_post_thumbnail() ) {
						echo '<div class="project-thumb">';
							the_post_thumbnail('full', ['class' => 'project-single-img'] );
						echo '</div>';
					} 
					if( ! empty( $redias_project_info ) ) : ?>
					<div class="project-details">
						<?php
						if( ! empty( $redias_project_heading ) ) {
							echo '<h2 class="project-title">'. RediasHelper::kses_basic( $redias_project_heading ) .'</h2>';
						}
						if( ! empty( $redias_project_desc ) ) {
							echo '<p>'. RediasHelper::kses_basic( $redias_project_desc ) .'</p>';
						}
						?>
						<ul class="info-list">
						<?php 
						if( RediasHelper::has_terms('project-category') ) {
							?>
							<li><label><?php esc_html_e( 'Category', 'redias' ); ?></label><span><?php RediasHelper::get_terms( 'project-category', 1, true, '', false, get_the_ID() ); ?></span></li>
							<?php
						}
						foreach( $redias_project_info as $redias_info ) {
							if( 'text' === $redias_info['type'] ) {
								if( ! empty( $redias_info['label'] && $redias_info['value'] ) ) {
									echo '<li><label>'. esc_html( $redias_info['label'] ) .'</label><span>'. esc_html( $redias_info['value'] ) .'</span></li>';
								}
							}elseif( 'date' === $redias_info['type'] ) {
								if( ! empty( $redias_info['label'] && $redias_info['pick_date'] ) ) {
									echo '<li><label>'. esc_html( $redias_info['label'] ) .'</label><span>'. esc_html( $redias_info['pick_date'] ) .'</span></li>';
								}
							}else{
								if( ! empty( $redias_info['label'] && $redias_info['rating'] ) ) {
									echo '
									<li>
										<label>'. esc_html( $redias_info['label'] ) .'</label>
										<ul class="ratings rating-'. esc_attr( $redias_info['rating'] ) .'">
											<li><i class="las la-star"></i></li>
											<li><i class="las la-star"></i></li>
											<li><i class="las la-star"></i></li>
											<li><i class="las la-star"></i></li>
											<li><i class="las la-star"></i></li>
										</ul>
									</li>';
								}
							}
						} ?>
						</ul>
						<?php 
						if( 'show' === redias_get_option( 'project_social_share', 'show' ) ) {
							do_action('redias_social_share');
						} ?>
					</div>
					<?php endif; ?>
				</div>
				<div class="content-area">
					<h2 class="project-heading"><?php the_title(); ?></h2>
					<?php 
						the_post();
						the_content();
					?>
				</div>
				<?php if( 'show' === redias_get_option('project_navigation', 'show') ) : ?>
				<div class="project-footer">
					<?php redias_post_nav(); ?>
				</div>
				<?php 
				endif;
				endwhile; ?>
			</div>
		</main><!-- #main -->
	</div><!-- .container -->
</section>
<?php 
if( 'show' === redias_get_option( 'related_project', 'hide' ) ) {
	RediasRelatedItems::project();
}
if( 'show' === redias_get_option( 'project_comments', 'hide' ) ) : ?>
<section class="project-comments">
	<div class="container">
		<?php
		if ( comments_open() || get_comments_number() ) {
			comments_template();
		}
		?>
	</div>
</section>
<?php endif; ?>
<?php
get_footer();
