<?php
/**
 * The template for displaying all single services
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#single-post
 *
 * @package Redias
 */

get_header();
$redias_sidebar_args = [
	'meta_layout' => RediasHelper::get_meta_field( 'redias_layout', 'default' ),
	'meta_widget' => RediasHelper::get_meta_field( 'redias_sidebar_widgets', 'default' ),
	'global_layout' => redias_get_option( 'theme_sidebar_layout', 'right-sidebar' ),
	'global_widget' => redias_get_option( 'theme_sidebar_widget', 'right-sidebar' ),
	'blog_layout' => redias_get_option( 'service_sidebar_layout', 'default' ),
	'blog_widget' => redias_get_option( 'service_sidebar_widget', 'default' )
];
$redias_sub_heading = RediasHelper::get_meta_field( 'sub_heading' );
$redias_heading = RediasHelper::get_meta_field( 'big_heading' );
$redias_desc = RediasHelper::get_meta_field( 'short_description' );
$redias_bg_img = '';
if( 'featured_img' === redias_get_option('service_bg_img', 'featured_img') ) {
	$redias_bg_img_src = wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'full' );
	$redias_bg_img_url = isset($redias_bg_img_src[0]) ? $redias_bg_img_src[0] : '';
	$redias_bg_img = ! empty( $redias_bg_img_url ) ? 'style="background-image: url('. $redias_bg_img_url .')"' : '';
}
?>
<section class="service-header-area" <?php echo RediasHelper::kses_basic( $redias_bg_img ); ?>>
	<div class="<?php RediasHelper::theme_layout(); ?>">
		<div class="service-header-content">
			<?php
				if( ! empty( $redias_sub_heading ) ) {
					echo '<h4>'. esc_html( $redias_sub_heading ) .'</h4>';
				}
				if( ! empty( $redias_heading ) ){
					echo '<h2>'. RediasHelper::kses_advance( RediasHelper::get_highlighted_text( $redias_heading ) ) .'</h2>';
				}else{
					echo '<h2>'. RediasHelper::kses_advance( get_the_title() ) .'</h2>';
				}
				if( ! empty( $redias_desc ) ) {
					echo '<p>'. RediasHelper::kses_basic( $redias_desc ) .'</p>';
				}else{
					echo '<p>'. RediasHelper::kses_basic( RediasHelper::get_the_excerpt() ) .'</p>';
				}
			?>
		</div>
	</div>
</section><!-- ./service-header-area -->

<section class="wrapper">
	<div class="<?php RediasHelper::theme_layout(); ?>">
		<div class="dl-row <?php echo esc_attr( RediasSidebar::single_sidebar_status( $redias_sidebar_args ) ); ?>">
			<main id="primary" class="site-main">
				<div id="post-<?php the_ID(); ?>" <?php post_class( array( 'content' ) ); ?>>
				<?php
				while ( have_posts() ) :
					if( has_post_thumbnail() ) {
						echo '<div class="post-thumb">';
							the_post_thumbnail('full', ['class' => 'post-single-img'] );
						echo '</div>';
					} ?>
					<h2 class="service-title"><?php the_title(); ?></h2>
					<div class="content-area">
					<?php 
						the_post();

						the_content();

						wp_link_pages( array(
							'before' => '<div class="page-links">',
							'after'  => '</div>',
							'link_before' => '<span>',
							'link_after'  => '</span>',
						) ); 
					?>
					</div>
					<?php if( 'show' === redias_get_option( 'service_post_share', 'show' ) ) : ?>
					<div class="single-post-footer">
						<?php
							if( 'show' === redias_get_option( 'service_post_share', 'show' ) ) {
								do_action('redias_social_share');
							}
						?>
					</div>
					<?php 
					endif;
					$redias_service_nav = redias_get_option( 'service_navigation', 'show' );
					$redias_service_comment = redias_get_option( 'service_comments', 'hide' );
					if( 'show' === $redias_service_nav || 'show' === $redias_service_comment ) : ?>
					<div class="post-footer-area">
						<?php
						if( 'show' === $redias_service_nav ) {
							redias_post_nav();
						}

						if( 'show' === $redias_service_comment ) {
							if ( comments_open() || get_comments_number() ) {
								comments_template();
							}
						}
						?>
					</div>
					<?php endif; ?>
					<?php endwhile; ?>
				</div>
			</main><!-- #main -->
			<?php get_sidebar(); ?>
		</div><!-- .dl-row -->
	</div><!-- .container -->
</section>
<?php
get_footer();
